-- MariaDB dump 10.19  Distrib 10.5.22-MariaDB, for Linux (x86_64)
--
-- Host: localhost    Database: heat
-- ------------------------------------------------------
-- Server version	10.5.22-MariaDB

/*!40101 SET @OLD_CHARACTER_SET_CLIENT=@@CHARACTER_SET_CLIENT */;
/*!40101 SET @OLD_CHARACTER_SET_RESULTS=@@CHARACTER_SET_RESULTS */;
/*!40101 SET @OLD_COLLATION_CONNECTION=@@COLLATION_CONNECTION */;
/*!40101 SET NAMES utf8mb4 */;
/*!40103 SET @OLD_TIME_ZONE=@@TIME_ZONE */;
/*!40103 SET TIME_ZONE='+00:00' */;
/*!40014 SET @OLD_UNIQUE_CHECKS=@@UNIQUE_CHECKS, UNIQUE_CHECKS=0 */;
/*!40014 SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0 */;
/*!40101 SET @OLD_SQL_MODE=@@SQL_MODE, SQL_MODE='NO_AUTO_VALUE_ON_ZERO' */;
/*!40111 SET @OLD_SQL_NOTES=@@SQL_NOTES, SQL_NOTES=0 */;

--
-- Table structure for table `event`
--

DROP TABLE IF EXISTS `event`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `event` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `uuid` varchar(36) DEFAULT NULL,
  `stack_id` varchar(36) NOT NULL,
  `created_at` datetime DEFAULT NULL,
  `updated_at` datetime DEFAULT NULL,
  `resource_action` varchar(255) DEFAULT NULL,
  `resource_status` varchar(255) DEFAULT NULL,
  `resource_name` varchar(255) DEFAULT NULL,
  `physical_resource_id` varchar(255) DEFAULT NULL,
  `resource_status_reason` varchar(255) DEFAULT NULL,
  `resource_type` varchar(255) DEFAULT NULL,
  `resource_properties` blob DEFAULT NULL,
  `rsrc_prop_data_id` int(11) DEFAULT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `uuid` (`uuid`),
  KEY `stack_id` (`stack_id`),
  KEY `ev_rsrc_prop_data_ref` (`rsrc_prop_data_id`),
  CONSTRAINT `ev_rsrc_prop_data_ref` FOREIGN KEY (`rsrc_prop_data_id`) REFERENCES `resource_properties_data` (`id`),
  CONSTRAINT `event_ibfk_1` FOREIGN KEY (`stack_id`) REFERENCES `stack` (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=2129 DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `event`
--

LOCK TABLES `event` WRITE;
/*!40000 ALTER TABLE `event` DISABLE KEYS */;
INSERT INTO `event` VALUES (1,'46e1d241-cecd-4ad8-8d05-a3c35ff00c2b','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:21',NULL,'CREATE','IN_PROGRESS','overcloud','e859a2ee-38d3-411a-99f8-e1215b7d5532','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2,'38cce62a-8e4a-4f6a-8a62-aae5167706f1','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:23',NULL,'CREATE','IN_PROGRESS','DeploymentServerBlacklistDict','overcloud-DeploymentServerBlacklistDict-tikmizxtzzrb','state changed','OS::Heat::Value',NULL,1),(3,'86388fb9-950d-4a0a-b044-0492d2ee5d87','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:23',NULL,'CREATE','COMPLETE','DeploymentServerBlacklistDict','overcloud-DeploymentServerBlacklistDict-tikmizxtzzrb','state changed','OS::Heat::Value',NULL,1),(4,'b1ca673b-c8cf-488f-8c7f-6307932a6a68','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:24',NULL,'CREATE','IN_PROGRESS','ComputeRoleUserData','overcloud-ComputeRoleUserData-tfc5nw4fswaz','state changed','OS::TripleO::Compute::NodeUserData',NULL,NULL),(5,'1ce7e556-9dc5-4d21-8199-03a182f23d8e','400db758-ed36-4ac1-9d8d-3e199660ba13','2026-06-10 07:46:24',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeRoleUserData-tfc5nw4fswaz','400db758-ed36-4ac1-9d8d-3e199660ba13','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(6,'a2367558-08ba-4760-8d01-511cdfab4126','400db758-ed36-4ac1-9d8d-3e199660ba13','2026-06-10 07:46:24',NULL,'CREATE','IN_PROGRESS','userdata','overcloud-ComputeRoleUserData-tfc5nw4fswaz-userdata-lyjcdmlifloo','state changed','OS::Heat::MultipartMime',NULL,NULL),(7,'b063f2b3-c0d2-4a6f-9a8f-41001c2d86b8','400db758-ed36-4ac1-9d8d-3e199660ba13','2026-06-10 07:46:24',NULL,'CREATE','COMPLETE','userdata','ac8801d5-5147-4b3d-9237-66ebb2006ebe','state changed','OS::Heat::MultipartMime',NULL,NULL),(8,'5af878cc-d5fc-4f7b-8d64-98a83068f917','400db758-ed36-4ac1-9d8d-3e199660ba13','2026-06-10 07:46:24',NULL,'CREATE','COMPLETE','overcloud-ComputeRoleUserData-tfc5nw4fswaz','400db758-ed36-4ac1-9d8d-3e199660ba13','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(9,'9f061659-0654-4d86-a4a0-c80ad482b379','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:25',NULL,'CREATE','IN_PROGRESS','ServiceNetMap','overcloud-ServiceNetMap-75lehehdthri','state changed','OS::TripleO::ServiceNetMap',NULL,NULL),(10,'f7ddd423-cd9a-47a0-a393-1d0e321f7974','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:25',NULL,'CREATE','COMPLETE','ComputeRoleUserData','400db758-ed36-4ac1-9d8d-3e199660ba13','state changed','OS::TripleO::Compute::NodeUserData',NULL,NULL),(11,'c8528fce-3eab-4741-9e48-fa09268b7362','edec1557-21b9-4b51-9d3a-de484f74af2a','2026-06-10 07:46:25',NULL,'CREATE','IN_PROGRESS','overcloud-ServiceNetMap-75lehehdthri','edec1557-21b9-4b51-9d3a-de484f74af2a','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(12,'2d88a128-c840-466e-8e7d-c2e1beab120d','edec1557-21b9-4b51-9d3a-de484f74af2a','2026-06-10 07:46:25',NULL,'CREATE','IN_PROGRESS','ServiceNetMapValue','overcloud-ServiceNetMap-75lehehdthri-ServiceNetMapValue-wpw2rgwemk72','state changed','OS::Heat::Value',NULL,4),(13,'22a7c986-7903-4274-b1de-e63eba2609d3','edec1557-21b9-4b51-9d3a-de484f74af2a','2026-06-10 07:46:25',NULL,'CREATE','COMPLETE','ServiceNetMapValue','overcloud-ServiceNetMap-75lehehdthri-ServiceNetMapValue-wpw2rgwemk72','state changed','OS::Heat::Value',NULL,4),(14,'080096ba-4be2-40fd-bd08-2a05aa368e20','edec1557-21b9-4b51-9d3a-de484f74af2a','2026-06-10 07:46:25',NULL,'CREATE','COMPLETE','overcloud-ServiceNetMap-75lehehdthri','edec1557-21b9-4b51-9d3a-de484f74af2a','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(15,'932e0adb-1b49-4fb4-8b4e-85f328ca3b19','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:26',NULL,'CREATE','IN_PROGRESS','ControllerRoleUserData','overcloud-ControllerRoleUserData-r2osvcgw7d3z','state changed','OS::TripleO::Controller::NodeUserData',NULL,NULL),(16,'4f00a934-a71a-474f-af21-e00ef323ae13','75f92b43-6653-410a-a8a6-838499d78f5d','2026-06-10 07:46:26',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerRoleUserData-r2osvcgw7d3z','75f92b43-6653-410a-a8a6-838499d78f5d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(17,'873580d6-85e2-4d55-8b5a-668d2913b664','75f92b43-6653-410a-a8a6-838499d78f5d','2026-06-10 07:46:26',NULL,'CREATE','IN_PROGRESS','userdata','overcloud-ControllerRoleUserData-r2osvcgw7d3z-userdata-rj6s6sszv2lv','state changed','OS::Heat::MultipartMime',NULL,NULL),(18,'0ac372da-d739-4bd9-a1a8-d465bd4bbc82','75f92b43-6653-410a-a8a6-838499d78f5d','2026-06-10 07:46:26',NULL,'CREATE','COMPLETE','userdata','9459fd40-ca91-4a8a-9a84-a7f88889faf4','state changed','OS::Heat::MultipartMime',NULL,NULL),(19,'40af9cb4-488f-43fe-b0a1-8159677a4112','75f92b43-6653-410a-a8a6-838499d78f5d','2026-06-10 07:46:26',NULL,'CREATE','COMPLETE','overcloud-ControllerRoleUserData-r2osvcgw7d3z','75f92b43-6653-410a-a8a6-838499d78f5d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(20,'f6fe3ca2-af90-4d6b-819e-925e35da08e7','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:26',NULL,'CREATE','COMPLETE','ServiceNetMap','edec1557-21b9-4b51-9d3a-de484f74af2a','state changed','OS::TripleO::ServiceNetMap',NULL,NULL),(21,'e18e827a-d4c9-4b8b-95fb-2181b66418a9','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:26',NULL,'CREATE','IN_PROGRESS','CephStorageServiceNetMapLower','overcloud-CephStorageServiceNetMapLower-i7b4icu2uwt7','state changed','OS::Heat::Value',NULL,6),(22,'4ba21cce-c14c-410b-bb91-f4918f6d8b4e','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:26',NULL,'CREATE','COMPLETE','CephStorageServiceNetMapLower','overcloud-CephStorageServiceNetMapLower-i7b4icu2uwt7','state changed','OS::Heat::Value',NULL,6),(23,'f2a6bcac-e00e-472b-b352-023b268147df','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:26',NULL,'CREATE','IN_PROGRESS','NetworkerServiceNetMapLower','overcloud-NetworkerServiceNetMapLower-g4aogwb7s65r','state changed','OS::Heat::Value',NULL,8),(24,'e28ee846-a7ec-4c49-96e2-8c19d6bde3e8','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:26',NULL,'CREATE','IN_PROGRESS','CellControllerComputeServiceNetMapLower','overcloud-CellControllerComputeServiceNetMapLower-3gf6p36go4et','state changed','OS::Heat::Value',NULL,9),(25,'3fb8f854-9b6a-46ae-abf6-3ef30a29c162','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:26',NULL,'CREATE','IN_PROGRESS','ComputeServiceNetMapLower','overcloud-ComputeServiceNetMapLower-blt62wvjvjcg','state changed','OS::Heat::Value',NULL,10),(26,'19d7c02d-0fde-490b-a2df-13a12f57dc22','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:26',NULL,'CREATE','COMPLETE','NetworkerServiceNetMapLower','overcloud-NetworkerServiceNetMapLower-g4aogwb7s65r','state changed','OS::Heat::Value',NULL,8),(27,'4cecb324-fc80-4012-a03b-c764048339a6','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:26',NULL,'CREATE','COMPLETE','CellControllerComputeServiceNetMapLower','overcloud-CellControllerComputeServiceNetMapLower-3gf6p36go4et','state changed','OS::Heat::Value',NULL,9),(28,'70b1c315-1a5f-4a23-8aef-7bc142fc5e6f','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:26',NULL,'CREATE','COMPLETE','ComputeServiceNetMapLower','overcloud-ComputeServiceNetMapLower-blt62wvjvjcg','state changed','OS::Heat::Value',NULL,10),(29,'12880f71-23d4-4c9d-88e3-edac11b04596','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:27',NULL,'CREATE','IN_PROGRESS','BlockStorageServiceNetMapLower','overcloud-BlockStorageServiceNetMapLower-r4kwykm7xbnk','state changed','OS::Heat::Value',NULL,13),(30,'0d50c775-fd50-4035-b779-b7aac9b7ab4e','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:27',NULL,'CREATE','IN_PROGRESS','CellControllerServiceNetMapLower','overcloud-CellControllerServiceNetMapLower-xznp7q4gwedi','state changed','OS::Heat::Value',NULL,15),(31,'eaec0953-a1c2-4e09-bf97-5863928b28ba','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:27',NULL,'CREATE','IN_PROGRESS','ObjectStorageServiceNetMapLower','overcloud-ObjectStorageServiceNetMapLower-ydihgtpizrss','state changed','OS::Heat::Value',NULL,16),(32,'4d1382e5-5089-421e-bef0-10e713543104','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:27',NULL,'CREATE','COMPLETE','ObjectStorageServiceNetMapLower','overcloud-ObjectStorageServiceNetMapLower-ydihgtpizrss','state changed','OS::Heat::Value',NULL,16),(33,'49fafaa4-c8db-4473-b057-342b1f44b2d6','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:27',NULL,'CREATE','IN_PROGRESS','ControllerServiceNetMapLower','overcloud-ControllerServiceNetMapLower-cmesnylrmtr3','state changed','OS::Heat::Value',NULL,17),(34,'e8de2e2b-bc2f-4918-8fb0-33ae61340864','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:27',NULL,'CREATE','COMPLETE','ControllerServiceNetMapLower','overcloud-ControllerServiceNetMapLower-cmesnylrmtr3','state changed','OS::Heat::Value',NULL,17),(35,'e9c5b53d-83ed-4cfc-9bfc-de80b162ec80','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:27',NULL,'CREATE','IN_PROGRESS','ControlVirtualIP','overcloud-ControlVirtualIP-rep7x5z5oubt','state changed','OS::TripleO::Network::Ports::ControlPlaneVipPort',NULL,19),(36,'a9a038e5-0620-495c-8c05-2c3eeba02caf','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:27',NULL,'CREATE','COMPLETE','BlockStorageServiceNetMapLower','overcloud-BlockStorageServiceNetMapLower-r4kwykm7xbnk','state changed','OS::Heat::Value',NULL,13),(37,'372441b2-ff51-45a0-966b-b54861ae6fbf','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:27',NULL,'CREATE','COMPLETE','CellControllerServiceNetMapLower','overcloud-CellControllerServiceNetMapLower-xznp7q4gwedi','state changed','OS::Heat::Value',NULL,15),(38,'d572138a-84e7-426c-be47-d3a8c47877d8','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:27',NULL,'CREATE','IN_PROGRESS','NetworkerRoleUserData','overcloud-NetworkerRoleUserData-n6zgkknj64l4','state changed','OS::TripleO::Networker::NodeUserData',NULL,NULL),(39,'0157af9f-54ba-4857-b6f0-7e0fa1159d80','a6e7db7f-8229-42b8-a051-76876a6f52ea','2026-06-10 07:46:27',NULL,'CREATE','IN_PROGRESS','overcloud-ControlVirtualIP-rep7x5z5oubt','a6e7db7f-8229-42b8-a051-76876a6f52ea','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(40,'50f530ab-85a7-49fa-a5c3-4d69fb817d41','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:27',NULL,'CREATE','COMPLETE','ControllerRoleUserData','75f92b43-6653-410a-a8a6-838499d78f5d','state changed','OS::TripleO::Controller::NodeUserData',NULL,NULL),(41,'bb5078f2-3747-404e-9d69-31dd2acbca2f','a6e7db7f-8229-42b8-a051-76876a6f52ea','2026-06-10 07:46:27',NULL,'CREATE','COMPLETE','overcloud-ControlVirtualIP-rep7x5z5oubt','a6e7db7f-8229-42b8-a051-76876a6f52ea','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(42,'baada61d-d09e-434a-8168-5170cfe6207f','c9c37e18-60ff-43cf-ac4e-9b8b3164d8d4','2026-06-10 07:46:27',NULL,'CREATE','IN_PROGRESS','overcloud-NetworkerRoleUserData-n6zgkknj64l4','c9c37e18-60ff-43cf-ac4e-9b8b3164d8d4','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(43,'7d538b59-f346-4c88-864d-c73a8165a019','c9c37e18-60ff-43cf-ac4e-9b8b3164d8d4','2026-06-10 07:46:27',NULL,'CREATE','IN_PROGRESS','userdata','overcloud-NetworkerRoleUserData-n6zgkknj64l4-userdata-4o5em4idvba2','state changed','OS::Heat::MultipartMime',NULL,NULL),(44,'c168f9ed-3c18-4afd-8561-4b224111cd4e','c9c37e18-60ff-43cf-ac4e-9b8b3164d8d4','2026-06-10 07:46:27',NULL,'CREATE','COMPLETE','userdata','8445f0dd-cc42-4699-ac2a-81602e76b802','state changed','OS::Heat::MultipartMime',NULL,NULL),(45,'c1aa9d90-ce9b-4623-a463-3c4cfb27db2d','c9c37e18-60ff-43cf-ac4e-9b8b3164d8d4','2026-06-10 07:46:27',NULL,'CREATE','COMPLETE','overcloud-NetworkerRoleUserData-n6zgkknj64l4','c9c37e18-60ff-43cf-ac4e-9b8b3164d8d4','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(46,'da7abb1b-d742-431e-ab3d-fc26833022cd','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:28',NULL,'CREATE','IN_PROGRESS','NodeAdminUserData','overcloud-NodeAdminUserData-tqmbqve4vl3x','state changed','OS::TripleO::NodeAdminUserData',NULL,NULL),(47,'dbf3ddb3-091b-4af6-8def-5bf88a1fbd69','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:28',NULL,'CREATE','COMPLETE','ControlVirtualIP','a6e7db7f-8229-42b8-a051-76876a6f52ea','state changed','OS::TripleO::Network::Ports::ControlPlaneVipPort',NULL,19),(48,'8c443fbb-15ad-4a4d-a221-950dd0309f63','de547041-49e8-4e9e-9af8-cd2f2c76a9a1','2026-06-10 07:46:28',NULL,'CREATE','IN_PROGRESS','overcloud-NodeAdminUserData-tqmbqve4vl3x','de547041-49e8-4e9e-9af8-cd2f2c76a9a1','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(49,'7c9c8b27-7d8e-4a49-b89f-63811469680c','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:28',NULL,'CREATE','COMPLETE','NetworkerRoleUserData','c9c37e18-60ff-43cf-ac4e-9b8b3164d8d4','state changed','OS::TripleO::Networker::NodeUserData',NULL,NULL),(50,'e83b5145-c1e8-4350-81e6-0ed79d40b1a2','de547041-49e8-4e9e-9af8-cd2f2c76a9a1','2026-06-10 07:46:28',NULL,'CREATE','IN_PROGRESS','user_config','overcloud-NodeAdminUserData-tqmbqve4vl3x-user_config-ed5q6gjxx3mj','state changed','OS::Heat::CloudConfig',NULL,25),(51,'cdf8cfae-1e65-461a-a03d-7d423f1ed3d0','de547041-49e8-4e9e-9af8-cd2f2c76a9a1','2026-06-10 07:46:28',NULL,'CREATE','COMPLETE','user_config','69bde4a0-243b-4815-bdeb-f1181438e124','state changed','OS::Heat::CloudConfig',NULL,25),(52,'5b483d94-2550-467c-a8ce-2ecc10e5820d','de547041-49e8-4e9e-9af8-cd2f2c76a9a1','2026-06-10 07:46:28',NULL,'CREATE','IN_PROGRESS','userdata','overcloud-NodeAdminUserData-tqmbqve4vl3x-userdata-vobn6slosoac','state changed','OS::Heat::MultipartMime',NULL,28),(53,'ee298dda-49ea-4b76-ae0d-1a1613150b12','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:28',NULL,'CREATE','IN_PROGRESS','Networks','overcloud-Networks-uzvljlktbqix','state changed','OS::TripleO::Network',NULL,29),(54,'2d788613-53f5-4bd2-9d24-00f2cc9f29a8','de547041-49e8-4e9e-9af8-cd2f2c76a9a1','2026-06-10 07:46:28',NULL,'CREATE','COMPLETE','userdata','2716fe79-f303-4979-9e37-3fdfb2dabdc5','state changed','OS::Heat::MultipartMime',NULL,28),(55,'f5039b2f-bd88-4b4d-ac77-3097cfb23f72','e1e9aed4-2054-49cb-bb5d-3720a675f4f9','2026-06-10 07:46:28',NULL,'CREATE','IN_PROGRESS','overcloud-Networks-uzvljlktbqix','e1e9aed4-2054-49cb-bb5d-3720a675f4f9','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(56,'1fda1af6-59c7-4626-9d89-ab24144151fb','de547041-49e8-4e9e-9af8-cd2f2c76a9a1','2026-06-10 07:46:28',NULL,'CREATE','COMPLETE','overcloud-NodeAdminUserData-tqmbqve4vl3x','de547041-49e8-4e9e-9af8-cd2f2c76a9a1','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(57,'49de596e-c61c-42fa-8025-057106fb9c9e','e1e9aed4-2054-49cb-bb5d-3720a675f4f9','2026-06-10 07:46:28',NULL,'CREATE','IN_PROGRESS','NetworkCidrMap','overcloud-Networks-uzvljlktbqix-NetworkCidrMap-4lyq2ossmmwv','state changed','OS::Heat::Value',NULL,30),(58,'73081336-9803-449f-b1e8-7a156acf6691','e1e9aed4-2054-49cb-bb5d-3720a675f4f9','2026-06-10 07:46:28',NULL,'CREATE','COMPLETE','NetworkCidrMap','overcloud-Networks-uzvljlktbqix-NetworkCidrMap-4lyq2ossmmwv','state changed','OS::Heat::Value',NULL,30),(59,'de86bf92-8c37-4678-949b-f8641a68c024','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:29',NULL,'CREATE','IN_PROGRESS','CephStorageRoleUserData','overcloud-CephStorageRoleUserData-dvqxmvvcls6p','state changed','OS::TripleO::CephStorage::NodeUserData',NULL,NULL),(60,'1a73731e-dead-47d1-9972-d3280be52133','40db82f0-2402-43dc-8ba8-e648298a5b9e','2026-06-10 07:46:29',NULL,'CREATE','IN_PROGRESS','overcloud-CephStorageRoleUserData-dvqxmvvcls6p','40db82f0-2402-43dc-8ba8-e648298a5b9e','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(61,'bf76a606-3bd3-4846-b61f-3854badf6cba','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:29',NULL,'CREATE','COMPLETE','NodeAdminUserData','de547041-49e8-4e9e-9af8-cd2f2c76a9a1','state changed','OS::TripleO::NodeAdminUserData',NULL,NULL),(62,'c4b8f6c3-fe9f-454e-bd66-f1663433a74b','40db82f0-2402-43dc-8ba8-e648298a5b9e','2026-06-10 07:46:29',NULL,'CREATE','IN_PROGRESS','userdata','overcloud-CephStorageRoleUserData-dvqxmvvcls6p-userdata-3iicgwlbkw5s','state changed','OS::Heat::MultipartMime',NULL,NULL),(63,'ead95bb4-407f-4d58-a3fa-472c3bfb459a','40db82f0-2402-43dc-8ba8-e648298a5b9e','2026-06-10 07:46:29',NULL,'CREATE','COMPLETE','userdata','ff9e6e88-d31f-4995-bed6-d18ce8c7b31b','state changed','OS::Heat::MultipartMime',NULL,NULL),(64,'081f86c5-a498-449d-8028-e0a50cccb573','40db82f0-2402-43dc-8ba8-e648298a5b9e','2026-06-10 07:46:29',NULL,'CREATE','COMPLETE','overcloud-CephStorageRoleUserData-dvqxmvvcls6p','40db82f0-2402-43dc-8ba8-e648298a5b9e','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(65,'866cd575-70d4-4350-8d84-95951e563dff','e1e9aed4-2054-49cb-bb5d-3720a675f4f9','2026-06-10 07:46:29',NULL,'CREATE','IN_PROGRESS','NetworkExtraConfig','overcloud-Networks-uzvljlktbqix-NetworkExtraConfig-cvptfh2izooq','state changed','OS::TripleO::Network::ExtraConfig',NULL,NULL),(66,'d793a9e0-ad4c-4cc1-9586-daf14f24658a','e1e9aed4-2054-49cb-bb5d-3720a675f4f9','2026-06-10 07:46:29',NULL,'CREATE','COMPLETE','NetworkExtraConfig','4755c946-da05-40ad-9833-3b206fbfbb5c','state changed','OS::TripleO::Network::ExtraConfig',NULL,NULL),(67,'de91b71c-489c-4abc-bed5-b362d747f518','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:30',NULL,'CREATE','IN_PROGRESS','CloudNames','overcloud-CloudNames-kepihhv3lvzi','state changed','OS::Heat::Value',NULL,32),(68,'255b27fc-b8bb-4b3c-a1c0-9c717f693165','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:30',NULL,'CREATE','COMPLETE','CloudNames','overcloud-CloudNames-kepihhv3lvzi','state changed','OS::Heat::Value',NULL,32),(69,'083bb70b-bedd-4b5c-835e-975e6d878856','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:30',NULL,'CREATE','COMPLETE','CephStorageRoleUserData','40db82f0-2402-43dc-8ba8-e648298a5b9e','state changed','OS::TripleO::CephStorage::NodeUserData',NULL,NULL),(70,'c68f26b3-1316-4632-91e7-96f394ea7745','e1e9aed4-2054-49cb-bb5d-3720a675f4f9','2026-06-10 07:46:30',NULL,'CREATE','IN_PROGRESS','NetworkAttributesMap','overcloud-Networks-uzvljlktbqix-NetworkAttributesMap-p6k4tlhpgisb','state changed','OS::Heat::Value',NULL,35),(71,'b2bf7024-c0e8-49c8-9022-1cf273019c9a','e1e9aed4-2054-49cb-bb5d-3720a675f4f9','2026-06-10 07:46:30',NULL,'CREATE','COMPLETE','NetworkAttributesMap','overcloud-Networks-uzvljlktbqix-NetworkAttributesMap-p6k4tlhpgisb','state changed','OS::Heat::Value',NULL,35),(72,'05f843a6-12f6-497a-ad43-b4fb1068a193','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:31',NULL,'CREATE','IN_PROGRESS','NodeTimesyncUserData','overcloud-NodeTimesyncUserData-phxrlnwi3er6','state changed','OS::TripleO::NodeTimesyncUserData',NULL,NULL),(73,'5e73d891-f9cf-47aa-8ed7-69adf5fcc50a','a950a665-c904-4c02-ae58-2fa1d97ff323','2026-06-10 07:46:31',NULL,'CREATE','IN_PROGRESS','overcloud-NodeTimesyncUserData-phxrlnwi3er6','a950a665-c904-4c02-ae58-2fa1d97ff323','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(74,'ed9dfa66-f02d-4205-8466-2eb349045fcd','a950a665-c904-4c02-ae58-2fa1d97ff323','2026-06-10 07:46:31',NULL,'CREATE','IN_PROGRESS','timesync_chrony','overcloud-NodeTimesyncUserData-phxrlnwi3er6-timesync_chrony-sjrou3hrwjgz','state changed','OS::Heat::SoftwareConfig',NULL,36),(75,'4cb0e3fd-54fb-445d-86e6-d68eacd7b959','a950a665-c904-4c02-ae58-2fa1d97ff323','2026-06-10 07:46:31',NULL,'CREATE','COMPLETE','timesync_chrony','bafb0590-adb1-493b-a609-00875cc96eba','state changed','OS::Heat::SoftwareConfig',NULL,36),(76,'c5037ebf-361d-43c0-97c9-3fe82cfbeef8','e1e9aed4-2054-49cb-bb5d-3720a675f4f9','2026-06-10 07:46:31',NULL,'CREATE','IN_PROGRESS','NetworkIpVersionMap','overcloud-Networks-uzvljlktbqix-NetworkIpVersionMap-zhceuuecnxg5','state changed','OS::Heat::Value',NULL,37),(77,'d2cf7ffa-8b46-4833-9ed1-d6a298b19a74','e1e9aed4-2054-49cb-bb5d-3720a675f4f9','2026-06-10 07:46:31',NULL,'CREATE','COMPLETE','NetworkIpVersionMap','overcloud-Networks-uzvljlktbqix-NetworkIpVersionMap-zhceuuecnxg5','state changed','OS::Heat::Value',NULL,37),(78,'61e1b575-1361-4bb8-bd70-fa841270084c','e1e9aed4-2054-49cb-bb5d-3720a675f4f9','2026-06-10 07:46:31',NULL,'CREATE','COMPLETE','overcloud-Networks-uzvljlktbqix','e1e9aed4-2054-49cb-bb5d-3720a675f4f9','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(79,'72eb1a8e-9e4f-4f84-ac72-a62c572fe245','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:32',NULL,'CREATE','IN_PROGRESS','CellControllerComputeRoleUserData','overcloud-CellControllerComputeRoleUserData-k3wjjg5gqrwt','state changed','OS::TripleO::CellControllerCompute::NodeUserData',NULL,NULL),(80,'21c0527f-c413-4e91-bec4-625a5a1a15d6','3b3f1d9c-48a6-4179-9ac7-127a34ed6e59','2026-06-10 07:46:32',NULL,'CREATE','IN_PROGRESS','overcloud-CellControllerComputeRoleUserData-k3wjjg5gqrwt','3b3f1d9c-48a6-4179-9ac7-127a34ed6e59','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(81,'28efb884-3eec-4389-9232-68a046210c25','3b3f1d9c-48a6-4179-9ac7-127a34ed6e59','2026-06-10 07:46:32',NULL,'CREATE','IN_PROGRESS','userdata','overcloud-CellControllerComputeRoleUserData-k3wjjg5gqrwt-userdata-yldimxxnl52b','state changed','OS::Heat::MultipartMime',NULL,NULL),(82,'852d6c5e-311a-4e43-87eb-549d009977af','3b3f1d9c-48a6-4179-9ac7-127a34ed6e59','2026-06-10 07:46:32',NULL,'CREATE','COMPLETE','userdata','3ae14333-65d8-4480-b95a-0c63ed905daa','state changed','OS::Heat::MultipartMime',NULL,NULL),(83,'c662fc1a-7cb8-45f9-ad6b-b7fe2b4128ed','3b3f1d9c-48a6-4179-9ac7-127a34ed6e59','2026-06-10 07:46:32',NULL,'CREATE','COMPLETE','overcloud-CellControllerComputeRoleUserData-k3wjjg5gqrwt','3b3f1d9c-48a6-4179-9ac7-127a34ed6e59','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(84,'0cdddf03-abfd-4f5b-9aa0-642fff668ac4','a950a665-c904-4c02-ae58-2fa1d97ff323','2026-06-10 07:46:32',NULL,'CREATE','IN_PROGRESS','timesync_sync','overcloud-NodeTimesyncUserData-phxrlnwi3er6-timesync_sync-k4izcgwpztmy','state changed','OS::Heat::SoftwareConfig',NULL,38),(85,'0289768e-02ff-4842-b566-de9b47a0e5bc','a950a665-c904-4c02-ae58-2fa1d97ff323','2026-06-10 07:46:32',NULL,'CREATE','COMPLETE','timesync_sync','a7c70ed4-c65b-4916-8205-db7d87649e99','state changed','OS::Heat::SoftwareConfig',NULL,38),(86,'3ff0941a-dfc6-4ef9-b60e-bbe877dfa3d2','a950a665-c904-4c02-ae58-2fa1d97ff323','2026-06-10 07:46:32',NULL,'CREATE','IN_PROGRESS','userdata','overcloud-NodeTimesyncUserData-phxrlnwi3er6-userdata-i7xwccrlufbh','state changed','OS::Heat::MultipartMime',NULL,39),(87,'f2e43568-9847-47aa-af3f-c4c629c4017d','a950a665-c904-4c02-ae58-2fa1d97ff323','2026-06-10 07:46:32',NULL,'CREATE','COMPLETE','userdata','cca21eb8-17fa-41fa-8504-80d103e0a3e0','state changed','OS::Heat::MultipartMime',NULL,39),(88,'7e608336-9aad-4030-9bae-f79060e5874b','a950a665-c904-4c02-ae58-2fa1d97ff323','2026-06-10 07:46:32',NULL,'CREATE','COMPLETE','overcloud-NodeTimesyncUserData-phxrlnwi3er6','a950a665-c904-4c02-ae58-2fa1d97ff323','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(89,'70cb50e1-23ac-49b9-bbd4-407517e669c2','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:32',NULL,'CREATE','COMPLETE','Networks','e1e9aed4-2054-49cb-bb5d-3720a675f4f9','state changed','OS::TripleO::Network',NULL,29),(90,'6ca8a3a1-7b7d-4907-86ef-bb6a011377dd','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:33',NULL,'CREATE','IN_PROGRESS','StorageMgmtVirtualIP','overcloud-StorageMgmtVirtualIP-v2qs3sxnfqlj','state changed','OS::TripleO::Network::Ports::StorageMgmtVipPort',NULL,43),(91,'2775ec8c-d06e-4786-b18a-95a6559902da','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:33',NULL,'CREATE','IN_PROGRESS','NetworkerNetworkConfig','overcloud-NetworkerNetworkConfig-qcuzghczab76','state changed','OS::TripleO::Networker::Net::SoftwareConfig',NULL,NULL),(92,'79758682-430e-4848-8023-7eebb4c45068','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:33',NULL,'CREATE','COMPLETE','NetworkerNetworkConfig','b436f6e1-22b2-4283-a54b-8ed080649c0e','state changed','OS::TripleO::Networker::Net::SoftwareConfig',NULL,NULL),(93,'a6498eaa-7926-48fa-ac26-a767b35539ec','94363fdb-9eb3-4461-b02c-24be1620302e','2026-06-10 07:46:33',NULL,'CREATE','IN_PROGRESS','overcloud-StorageMgmtVirtualIP-v2qs3sxnfqlj','94363fdb-9eb3-4461-b02c-24be1620302e','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(94,'648f37fd-e5de-4982-b2c6-8d3eee0ceca8','94363fdb-9eb3-4461-b02c-24be1620302e','2026-06-10 07:46:33',NULL,'CREATE','COMPLETE','overcloud-StorageMgmtVirtualIP-v2qs3sxnfqlj','94363fdb-9eb3-4461-b02c-24be1620302e','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(95,'52115804-a1bd-4831-a18a-0ac34107da1e','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:33',NULL,'CREATE','IN_PROGRESS','CephStorageNetworkConfig','overcloud-CephStorageNetworkConfig-7uz5zsbleeux','state changed','OS::TripleO::CephStorage::Net::SoftwareConfig',NULL,NULL),(96,'cf211784-8b0a-4e70-961b-945d429f23a4','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:33',NULL,'CREATE','IN_PROGRESS','NetCidrMapValue','overcloud-NetCidrMapValue-7qxdka6cmasf','state changed','OS::Heat::Value',NULL,44),(97,'6f2c0e98-ab9e-4aea-ba53-6b3080f31f6d','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:33',NULL,'CREATE','COMPLETE','NetCidrMapValue','overcloud-NetCidrMapValue-7qxdka6cmasf','state changed','OS::Heat::Value',NULL,44),(98,'2be62358-27ec-4d84-9c30-30678d772e20','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:33',NULL,'CREATE','IN_PROGRESS','InternalApiVirtualIP','overcloud-InternalApiVirtualIP-ys55it6o3w7k','state changed','OS::TripleO::Network::Ports::InternalApiVipPort',NULL,45),(99,'33c44bbd-b137-48c7-8a2a-8edb9d740f7f','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:33',NULL,'CREATE','IN_PROGRESS','CellControllerRoleUserData','overcloud-CellControllerRoleUserData-udiuomedlk4u','state changed','OS::TripleO::CellController::NodeUserData',NULL,NULL),(100,'885d5b2e-5e8f-4d2d-b51a-ada42ee1293b','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:33',NULL,'CREATE','IN_PROGRESS','ControllerNetworkConfig','overcloud-ControllerNetworkConfig-mdmhihr5m4ia','state changed','OS::TripleO::Controller::Net::SoftwareConfig',NULL,NULL),(101,'ef6979aa-b8f3-4f24-8530-3c20e30261db','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:33',NULL,'CREATE','COMPLETE','CephStorageNetworkConfig','f8f1ad19-719d-4564-9991-f8bd1a6e7e76','state changed','OS::TripleO::CephStorage::Net::SoftwareConfig',NULL,NULL),(102,'52fdf4e1-1760-4117-a86a-3e9a12e99361','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:33',NULL,'CREATE','COMPLETE','ControllerNetworkConfig','ead220d7-6ac3-4760-8435-84aba53e339a','state changed','OS::TripleO::Controller::Net::SoftwareConfig',NULL,NULL),(103,'ccd4eb07-0c23-4e76-a458-659e6190adaa','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:33',NULL,'CREATE','COMPLETE','NodeTimesyncUserData','a950a665-c904-4c02-ae58-2fa1d97ff323','state changed','OS::TripleO::NodeTimesyncUserData',NULL,NULL),(104,'118a1426-2a84-4be0-81d4-97677495d7a2','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:33',NULL,'CREATE','IN_PROGRESS','CellControllerNetworkConfig','overcloud-CellControllerNetworkConfig-l7atopn2czqb','state changed','OS::TripleO::CellController::Net::SoftwareConfig',NULL,NULL),(105,'3fe62f5e-af49-404b-a7ee-e0215098727b','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:33',NULL,'CREATE','COMPLETE','CellControllerComputeRoleUserData','3b3f1d9c-48a6-4179-9ac7-127a34ed6e59','state changed','OS::TripleO::CellControllerCompute::NodeUserData',NULL,NULL),(106,'bd1dbde4-9eb3-451d-83b0-2f392e64ae7e','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:33',NULL,'CREATE','IN_PROGRESS','BlockStorageNetworkConfig','overcloud-BlockStorageNetworkConfig-cqe6wnmngeot','state changed','OS::TripleO::BlockStorage::Net::SoftwareConfig',NULL,NULL),(107,'71fb105e-f3eb-4b7f-92c5-b5078f5d8d1b','afafbe59-c2a8-4b9a-9716-1975778a59df','2026-06-10 07:46:33',NULL,'CREATE','IN_PROGRESS','overcloud-InternalApiVirtualIP-ys55it6o3w7k','afafbe59-c2a8-4b9a-9716-1975778a59df','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(108,'acf747c6-d48f-49f6-9583-da03a6f0ff92','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:33',NULL,'CREATE','COMPLETE','CellControllerNetworkConfig','622b64f2-26bb-436e-a8fc-4051b8022ebb','state changed','OS::TripleO::CellController::Net::SoftwareConfig',NULL,NULL),(109,'04e0fa8b-7edc-4989-95db-340a7076751d','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:33',NULL,'CREATE','IN_PROGRESS','StorageVirtualIP','overcloud-StorageVirtualIP-m5vokadapngx','state changed','OS::TripleO::Network::Ports::StorageVipPort',NULL,46),(110,'0704ec34-38d0-4036-9dd5-7d7eb4f2c844','afafbe59-c2a8-4b9a-9716-1975778a59df','2026-06-10 07:46:33',NULL,'CREATE','COMPLETE','overcloud-InternalApiVirtualIP-ys55it6o3w7k','afafbe59-c2a8-4b9a-9716-1975778a59df','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(111,'c00ffc35-0d75-4473-9616-2226d47bb2cd','b2a63afb-2e63-4a26-9472-34a274a169cd','2026-06-10 07:46:33',NULL,'CREATE','IN_PROGRESS','overcloud-CellControllerRoleUserData-udiuomedlk4u','b2a63afb-2e63-4a26-9472-34a274a169cd','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(112,'e8de50c0-4576-4cf2-a684-72c246ea5560','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:33',NULL,'CREATE','COMPLETE','InternalApiVirtualIP','afafbe59-c2a8-4b9a-9716-1975778a59df','state changed','OS::TripleO::Network::Ports::InternalApiVipPort',NULL,45),(113,'da64a89a-d40d-423a-90c0-136b8167872f','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:33',NULL,'CREATE','COMPLETE','BlockStorageNetworkConfig','7584f332-6cbc-45f6-b600-70762e0ccaef','state changed','OS::TripleO::BlockStorage::Net::SoftwareConfig',NULL,NULL),(114,'29f27f5d-a07e-4d80-a54e-69de9a4eea14','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:33',NULL,'CREATE','IN_PROGRESS','CellControllerComputeNetworkConfig','overcloud-CellControllerComputeNetworkConfig-hegzgw5bgrk3','state changed','OS::TripleO::CellControllerCompute::Net::SoftwareConfig',NULL,NULL),(115,'40bddd48-2ccd-4e4f-ba57-75d7c9a66eda','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:33',NULL,'CREATE','COMPLETE','CellControllerComputeNetworkConfig','a16f8227-4a8b-4522-965a-12f82ee36fd1','state changed','OS::TripleO::CellControllerCompute::Net::SoftwareConfig',NULL,NULL),(116,'0e1f6585-228c-414d-a023-3be7a60cee0c','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:33',NULL,'CREATE','IN_PROGRESS','NetIpVersionMapValue','overcloud-NetIpVersionMapValue-ebtouwd7xc6p','state changed','OS::Heat::Value',NULL,49),(117,'1b1f424c-9bca-4cc3-80a2-5f3bfb4cc5fa','842e653e-735b-47be-a6e2-d2a1c3087f98','2026-06-10 07:46:33',NULL,'CREATE','IN_PROGRESS','overcloud-StorageVirtualIP-m5vokadapngx','842e653e-735b-47be-a6e2-d2a1c3087f98','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(118,'f8309c6c-4b32-4979-9f17-0878bdb514dc','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:33',NULL,'CREATE','COMPLETE','NetIpVersionMapValue','overcloud-NetIpVersionMapValue-ebtouwd7xc6p','state changed','OS::Heat::Value',NULL,49),(119,'7dfca07c-3fd0-4c45-a565-0547397dd5d9','842e653e-735b-47be-a6e2-d2a1c3087f98','2026-06-10 07:46:33',NULL,'CREATE','COMPLETE','overcloud-StorageVirtualIP-m5vokadapngx','842e653e-735b-47be-a6e2-d2a1c3087f98','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(120,'16d8ec90-015f-4965-85fe-0e4b41f9a1fc','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:33',NULL,'CREATE','IN_PROGRESS','ComputeNetworkConfig','overcloud-ComputeNetworkConfig-mpff4lcc3uuh','state changed','OS::TripleO::Compute::Net::SoftwareConfig',NULL,NULL),(121,'0ec992ba-c3ef-47b8-9062-d464e57e5dbf','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:33',NULL,'CREATE','COMPLETE','StorageVirtualIP','842e653e-735b-47be-a6e2-d2a1c3087f98','state changed','OS::TripleO::Network::Ports::StorageVipPort',NULL,46),(122,'931ec356-e3bd-4f7d-b6ec-b780d28868fe','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:33',NULL,'CREATE','IN_PROGRESS','ObjectStorageNetworkConfig','overcloud-ObjectStorageNetworkConfig-zwmem22geiyx','state changed','OS::TripleO::ObjectStorage::Net::SoftwareConfig',NULL,NULL),(123,'fb86d69a-9032-4e33-b361-b03fce506662','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:33',NULL,'CREATE','COMPLETE','ComputeNetworkConfig','2b12322f-9784-44b9-bc61-a1c405964937','state changed','OS::TripleO::Compute::Net::SoftwareConfig',NULL,NULL),(124,'0fc5eeda-2349-4822-8602-588695e705a6','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:33',NULL,'CREATE','COMPLETE','ObjectStorageNetworkConfig','2c02ff2b-f640-4fd9-978f-7c9fcfad2724','state changed','OS::TripleO::ObjectStorage::Net::SoftwareConfig',NULL,NULL),(125,'55de28a9-e286-4084-8f63-18feef0764b1','b2a63afb-2e63-4a26-9472-34a274a169cd','2026-06-10 07:46:33',NULL,'CREATE','IN_PROGRESS','userdata','overcloud-CellControllerRoleUserData-udiuomedlk4u-userdata-qygirdxs6i67','state changed','OS::Heat::MultipartMime',NULL,NULL),(126,'7d2d37af-6ad9-40c2-b2c0-cf78f1fd6c61','b2a63afb-2e63-4a26-9472-34a274a169cd','2026-06-10 07:46:33',NULL,'CREATE','COMPLETE','userdata','4a6b414b-79ca-4d69-8d67-43770103ca89','state changed','OS::Heat::MultipartMime',NULL,NULL),(127,'77870bf5-bae9-46b3-8f80-d34c18670036','b2a63afb-2e63-4a26-9472-34a274a169cd','2026-06-10 07:46:33',NULL,'CREATE','COMPLETE','overcloud-CellControllerRoleUserData-udiuomedlk4u','b2a63afb-2e63-4a26-9472-34a274a169cd','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(128,'9eac1a4e-545d-4f58-896f-190e9a01f363','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:33',NULL,'CREATE','IN_PROGRESS','PublicVirtualIP','overcloud-PublicVirtualIP-akti7kbi3lsj','state changed','OS::TripleO::Network::Ports::ExternalVipPort',NULL,54),(129,'8bd9f022-8f16-4557-b45c-2c480ebcc9f3','2fd975f7-81e1-4d87-b719-56dbe7363961','2026-06-10 07:46:33',NULL,'CREATE','IN_PROGRESS','overcloud-PublicVirtualIP-akti7kbi3lsj','2fd975f7-81e1-4d87-b719-56dbe7363961','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(130,'7860bdae-eec0-40ff-b9a1-80d7b7d45ec9','2fd975f7-81e1-4d87-b719-56dbe7363961','2026-06-10 07:46:33',NULL,'CREATE','COMPLETE','overcloud-PublicVirtualIP-akti7kbi3lsj','2fd975f7-81e1-4d87-b719-56dbe7363961','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(131,'6e81d6b1-2d80-4907-a393-a754cb0275ca','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:34',NULL,'CREATE','COMPLETE','StorageMgmtVirtualIP','94363fdb-9eb3-4461-b02c-24be1620302e','state changed','OS::TripleO::Network::Ports::StorageMgmtVipPort',NULL,43),(132,'6de1c981-c032-437c-b368-9884bec9cabc','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:34',NULL,'CREATE','IN_PROGRESS','NodeUserData','overcloud-NodeUserData-eij56vq4tbnm','state changed','OS::TripleO::NodeUserData',NULL,NULL),(133,'117777cc-0bbf-41f3-bf07-089103b5ace1','648a3890-056d-4a7b-bcbe-4a5fee4be05a','2026-06-10 07:46:34',NULL,'CREATE','IN_PROGRESS','overcloud-NodeUserData-eij56vq4tbnm','648a3890-056d-4a7b-bcbe-4a5fee4be05a','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(134,'82f1c720-0bdc-4a1f-a375-86e10e153c53','648a3890-056d-4a7b-bcbe-4a5fee4be05a','2026-06-10 07:46:34',NULL,'CREATE','IN_PROGRESS','userdata','overcloud-NodeUserData-eij56vq4tbnm-userdata-xtfqbozvqsun','state changed','OS::Heat::MultipartMime',NULL,NULL),(135,'02374eeb-a8af-4b4b-a307-47b75cfbda25','648a3890-056d-4a7b-bcbe-4a5fee4be05a','2026-06-10 07:46:34',NULL,'CREATE','COMPLETE','userdata','60b262b7-66f6-4f8f-864d-a9f41013ea3e','state changed','OS::Heat::MultipartMime',NULL,NULL),(136,'e76357eb-a656-4951-a5ce-7838b6313385','648a3890-056d-4a7b-bcbe-4a5fee4be05a','2026-06-10 07:46:34',NULL,'CREATE','COMPLETE','overcloud-NodeUserData-eij56vq4tbnm','648a3890-056d-4a7b-bcbe-4a5fee4be05a','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(137,'19de59eb-84f4-4f54-bc45-e1008b523b40','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:34',NULL,'CREATE','COMPLETE','CellControllerRoleUserData','b2a63afb-2e63-4a26-9472-34a274a169cd','state changed','OS::TripleO::CellController::NodeUserData',NULL,NULL),(138,'fd75607a-aa18-42dd-9bea-d975f90014d2','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:34',NULL,'CREATE','COMPLETE','PublicVirtualIP','2fd975f7-81e1-4d87-b719-56dbe7363961','state changed','OS::TripleO::Network::Ports::ExternalVipPort',NULL,54),(139,'5ef55f66-dcb5-4953-ac6b-0164c74b6268','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:35',NULL,'CREATE','IN_PROGRESS','VipMap','overcloud-VipMap-aphdildlbd2l','state changed','OS::TripleO::Network::Ports::NetVipMap',NULL,59),(140,'9e711fc0-d044-4f94-9cd7-4fc17b2b64c3','66e5fa8e-5dd9-4d10-965f-dd4c061d4d5d','2026-06-10 07:46:35',NULL,'CREATE','IN_PROGRESS','overcloud-VipMap-aphdildlbd2l','66e5fa8e-5dd9-4d10-965f-dd4c061d4d5d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(141,'8933b4cf-1a0a-447d-99c7-5df1d24813e2','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:35',NULL,'CREATE','IN_PROGRESS','ObjectStorageRoleUserData','overcloud-ObjectStorageRoleUserData-hpjhrdg243bc','state changed','OS::TripleO::ObjectStorage::NodeUserData',NULL,NULL),(142,'0f96287f-20e7-448d-9689-db7d3b3037de','66e5fa8e-5dd9-4d10-965f-dd4c061d4d5d','2026-06-10 07:46:35',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','overcloud-VipMap-aphdildlbd2l-NetIpMapValue-x4b3kon6fkw2','state changed','OS::Heat::Value',NULL,60),(143,'18b8dab7-de04-4c86-a089-9cb9b1a91e12','66e5fa8e-5dd9-4d10-965f-dd4c061d4d5d','2026-06-10 07:46:35',NULL,'CREATE','COMPLETE','NetIpMapValue','overcloud-VipMap-aphdildlbd2l-NetIpMapValue-x4b3kon6fkw2','state changed','OS::Heat::Value',NULL,60),(144,'14953623-30a4-46f3-9b43-bbdc1695ee02','66e5fa8e-5dd9-4d10-965f-dd4c061d4d5d','2026-06-10 07:46:35',NULL,'CREATE','COMPLETE','overcloud-VipMap-aphdildlbd2l','66e5fa8e-5dd9-4d10-965f-dd4c061d4d5d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(145,'1f4ae6ee-2f8d-4904-8b4d-78bfc475336f','cd856e73-1c60-497d-a432-fcb28fc468e8','2026-06-10 07:46:35',NULL,'CREATE','IN_PROGRESS','overcloud-ObjectStorageRoleUserData-hpjhrdg243bc','cd856e73-1c60-497d-a432-fcb28fc468e8','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(146,'9c29d09a-42e9-4074-9761-2ace8f43d194','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:35',NULL,'CREATE','COMPLETE','NodeUserData','648a3890-056d-4a7b-bcbe-4a5fee4be05a','state changed','OS::TripleO::NodeUserData',NULL,NULL),(147,'ab2fee2a-c225-46f3-bb60-ad2b242a3dc5','cd856e73-1c60-497d-a432-fcb28fc468e8','2026-06-10 07:46:35',NULL,'CREATE','IN_PROGRESS','userdata','overcloud-ObjectStorageRoleUserData-hpjhrdg243bc-userdata-jciwpawlljic','state changed','OS::Heat::MultipartMime',NULL,NULL),(148,'78cf5203-b112-4268-b7f2-74ec4eb4233c','cd856e73-1c60-497d-a432-fcb28fc468e8','2026-06-10 07:46:35',NULL,'CREATE','COMPLETE','userdata','b2bcedc9-9a61-4082-b4bc-f44ab7f3000c','state changed','OS::Heat::MultipartMime',NULL,NULL),(149,'352ed43e-c1ca-4d9b-a51c-014bd2688e44','cd856e73-1c60-497d-a432-fcb28fc468e8','2026-06-10 07:46:35',NULL,'CREATE','COMPLETE','overcloud-ObjectStorageRoleUserData-hpjhrdg243bc','cd856e73-1c60-497d-a432-fcb28fc468e8','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(150,'312bb990-6378-402a-b8e9-fa4ef4200e82','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:35',NULL,'CREATE','IN_PROGRESS','CephStorageUserData','overcloud-CephStorageUserData-p7ngu5t3rnxm','state changed','OS::Heat::MultipartMime',NULL,61),(151,'be822caa-f4bb-4fd2-a1ac-1c2db338bb3b','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:35',NULL,'CREATE','IN_PROGRESS','ComputeUserData','overcloud-ComputeUserData-kry24n3a3qsx','state changed','OS::Heat::MultipartMime',NULL,62),(152,'0df9886d-4559-4123-91cc-17f787c40f50','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:35',NULL,'CREATE','IN_PROGRESS','CellControllerUserData','overcloud-CellControllerUserData-en76qgldskdq','state changed','OS::Heat::MultipartMime',NULL,63),(153,'bd735143-1bed-4706-bf50-167cde510dc0','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:35',NULL,'CREATE','IN_PROGRESS','NetworkerUserData','overcloud-NetworkerUserData-gs3fbwf4phfm','state changed','OS::Heat::MultipartMime',NULL,65),(154,'4d4a0ef6-1516-46a0-8cc9-d3a113ca24e9','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:35',NULL,'CREATE','IN_PROGRESS','ControllerUserData','overcloud-ControllerUserData-bj53ytfrb772','state changed','OS::Heat::MultipartMime',NULL,66),(155,'0d76e16e-4c6c-49e0-8279-f00e57e8090e','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:35',NULL,'CREATE','IN_PROGRESS','CellControllerComputeUserData','overcloud-CellControllerComputeUserData-djsq5fezw65j','state changed','OS::Heat::MultipartMime',NULL,67),(156,'c0438d44-b961-4e6f-b2d7-7210f082fab3','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:35',NULL,'CREATE','COMPLETE','CellControllerUserData','a59c12b0-4d86-42fe-a843-8f5cf4333d1b','state changed','OS::Heat::MultipartMime',NULL,63),(157,'f60c1235-81f5-4d2e-a028-0e82fcf73fd4','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:35',NULL,'CREATE','COMPLETE','NetworkerUserData','e1ce676c-2018-4f2d-97b9-0a153249a489','state changed','OS::Heat::MultipartMime',NULL,65),(158,'bc393422-752e-402f-a544-00b01b6ee5de','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:35',NULL,'CREATE','COMPLETE','ComputeUserData','3e113588-c0e4-4997-8859-71cfae275548','state changed','OS::Heat::MultipartMime',NULL,62),(159,'9e02d069-a249-40aa-a5de-81349b57e754','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:35',NULL,'CREATE','COMPLETE','CephStorageUserData','175f22c7-fa6b-4744-a0b6-c7a62b2292b5','state changed','OS::Heat::MultipartMime',NULL,61),(160,'5a459632-783b-43cc-a926-bfb7635d2533','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:35',NULL,'CREATE','COMPLETE','ControllerUserData','cecc8089-a249-459b-97e9-0c0c4a245f42','state changed','OS::Heat::MultipartMime',NULL,66),(161,'4c62024f-298c-441a-a722-333b8b9f94e7','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:35',NULL,'CREATE','COMPLETE','CellControllerComputeUserData','d8f716ab-f314-40ed-b011-a7b361faa1d9','state changed','OS::Heat::MultipartMime',NULL,67),(162,'41cd1f66-eb19-43ac-8fde-3be350db0d0e','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:36',NULL,'CREATE','COMPLETE','VipMap','66e5fa8e-5dd9-4d10-965f-dd4c061d4d5d','state changed','OS::TripleO::Network::Ports::NetVipMap',NULL,59),(163,'d4f47d90-4d5b-44d9-8cd8-38ad77b00f31','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:36',NULL,'CREATE','IN_PROGRESS','BlockStorageRoleUserData','overcloud-BlockStorageRoleUserData-e33lnojhkhta','state changed','OS::TripleO::BlockStorage::NodeUserData',NULL,NULL),(164,'9933490a-9398-4cbe-8cb3-f653883b34c2','abb22af1-95e7-42d3-8775-d27f6389268b','2026-06-10 07:46:36',NULL,'CREATE','IN_PROGRESS','overcloud-BlockStorageRoleUserData-e33lnojhkhta','abb22af1-95e7-42d3-8775-d27f6389268b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(165,'426120fb-0342-497c-8d8e-95c8402a5baf','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:36',NULL,'CREATE','COMPLETE','ObjectStorageRoleUserData','cd856e73-1c60-497d-a432-fcb28fc468e8','state changed','OS::TripleO::ObjectStorage::NodeUserData',NULL,NULL),(166,'3f64fd8c-a5db-4f36-a43a-ad9519991515','abb22af1-95e7-42d3-8775-d27f6389268b','2026-06-10 07:46:36',NULL,'CREATE','IN_PROGRESS','userdata','overcloud-BlockStorageRoleUserData-e33lnojhkhta-userdata-2jpyucwqctnw','state changed','OS::Heat::MultipartMime',NULL,NULL),(167,'52e9fd4d-ee4a-47bd-bf46-757fb2cdff91','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:36',NULL,'CREATE','IN_PROGRESS','VipHosts','overcloud-VipHosts-o2mkritlwgvj','state changed','OS::Heat::Value',NULL,70),(168,'becb52e6-80e0-4a48-ba4d-e62fe70f8e12','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:36',NULL,'CREATE','COMPLETE','VipHosts','overcloud-VipHosts-o2mkritlwgvj','state changed','OS::Heat::Value',NULL,70),(169,'30eb9389-ddce-492c-b5a2-9b6c2ac23288','abb22af1-95e7-42d3-8775-d27f6389268b','2026-06-10 07:46:36',NULL,'CREATE','COMPLETE','userdata','99d03c1d-82ef-4900-b10b-5001a8c74c1d','state changed','OS::Heat::MultipartMime',NULL,NULL),(170,'0d099f84-9777-4c31-bad0-d48c5fc24079','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:36',NULL,'CREATE','IN_PROGRESS','ObjectStorageUserData','overcloud-ObjectStorageUserData-hu2ciccnxywa','state changed','OS::Heat::MultipartMime',NULL,72),(171,'bc16b4ea-92d5-4fa3-b0a7-7cf722ce329d','abb22af1-95e7-42d3-8775-d27f6389268b','2026-06-10 07:46:36',NULL,'CREATE','COMPLETE','overcloud-BlockStorageRoleUserData-e33lnojhkhta','abb22af1-95e7-42d3-8775-d27f6389268b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(172,'ded4fbfb-9a20-4ce9-b61c-167788e1d33d','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:36',NULL,'CREATE','IN_PROGRESS','EndpointMap','overcloud-EndpointMap-wwtl32ssp5my','state changed','OS::TripleO::EndpointMap',NULL,74),(173,'f410ac09-8e6c-407b-bf6c-c519b2549d73','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:36',NULL,'CREATE','COMPLETE','ObjectStorageUserData','3bbbb0e8-60b5-4238-8903-a6776ab0b947','state changed','OS::Heat::MultipartMime',NULL,72),(174,'42d78751-1c39-4683-b876-b5b5667c3ef7','603f48a2-61d9-4004-8609-a835a315672b','2026-06-10 07:46:36',NULL,'CREATE','IN_PROGRESS','overcloud-EndpointMap-wwtl32ssp5my','603f48a2-61d9-4004-8609-a835a315672b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(175,'e0f516ab-093b-4bf4-9c09-5d24f2fdd35d','603f48a2-61d9-4004-8609-a835a315672b','2026-06-10 07:46:36',NULL,'CREATE','COMPLETE','overcloud-EndpointMap-wwtl32ssp5my','603f48a2-61d9-4004-8609-a835a315672b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(176,'f087371a-de21-456e-9b90-83549ba1e28d','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:37',NULL,'CREATE','COMPLETE','BlockStorageRoleUserData','abb22af1-95e7-42d3-8775-d27f6389268b','state changed','OS::TripleO::BlockStorage::NodeUserData',NULL,NULL),(177,'e323dd30-64df-4266-9af5-963cdfe284ff','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:37',NULL,'CREATE','IN_PROGRESS','BlockStorageUserData','overcloud-BlockStorageUserData-l3wbrpxrbyd6','state changed','OS::Heat::MultipartMime',NULL,76),(178,'f1dd7678-892f-496f-b10f-b30d32deceec','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:37',NULL,'CREATE','COMPLETE','BlockStorageUserData','206cff4a-6df6-4d95-86cf-59b6f7e6346f','state changed','OS::Heat::MultipartMime',NULL,76),(179,'0610b655-1448-4ed3-b1b8-105a2f45bd45','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:37',NULL,'CREATE','COMPLETE','EndpointMap','603f48a2-61d9-4004-8609-a835a315672b','state changed','OS::TripleO::EndpointMap',NULL,74),(180,'7d549e6c-4167-456f-aba8-76656531b9e8','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:38',NULL,'CREATE','IN_PROGRESS','EndpointMapData','overcloud-EndpointMapData-6uzowelha7vf','state changed','OS::Heat::Value',NULL,78),(181,'2e776cb5-415c-4182-b8a4-7cd786f2425b','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:38',NULL,'CREATE','COMPLETE','EndpointMapData','overcloud-EndpointMapData-6uzowelha7vf','state changed','OS::Heat::Value',NULL,78),(182,'296818b7-753b-4d0c-bd52-8df880f0e120','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:38',NULL,'CREATE','IN_PROGRESS','ObjectStorageServiceChain','overcloud-ObjectStorageServiceChain-dequd3rmhxkf','state changed','OS::TripleO::ObjectStorageServices',NULL,79),(183,'4560376f-85c4-4501-a661-f5d3117493ec','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:38',NULL,'CREATE','IN_PROGRESS','ControllerServiceChain','overcloud-ControllerServiceChain-ym5qnskzqqum','state changed','OS::TripleO::ControllerServices',NULL,80),(184,'e852f656-960d-403b-bcdc-3905057121b1','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:38',NULL,'CREATE','IN_PROGRESS','ComputeServiceChain','overcloud-ComputeServiceChain-xhvnas4abrxo','state changed','OS::TripleO::ComputeServices',NULL,81),(185,'24f5d6c1-3a4f-44e2-a976-3a8a58f12bb8','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:38',NULL,'CREATE','IN_PROGRESS','CellControllerServiceChain','overcloud-CellControllerServiceChain-2rvojby7tcbp','state changed','OS::TripleO::CellControllerServices',NULL,82),(186,'498e932e-9a42-44d2-ab53-792a2e3d6a6b','67454241-df97-4bc4-ba26-4f82633996c2','2026-06-10 07:46:38',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum','67454241-df97-4bc4-ba26-4f82633996c2','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(187,'e068b1ab-0abd-48c0-a8ff-7125065cd63f','8f6c9167-89dc-41b2-9c9e-3779bc4a7cea','2026-06-10 07:46:38',NULL,'CREATE','IN_PROGRESS','overcloud-ObjectStorageServiceChain-dequd3rmhxkf','8f6c9167-89dc-41b2-9c9e-3779bc4a7cea','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(188,'6ab29e2f-e91f-4101-9c07-07be213ff047','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:38',NULL,'CREATE','IN_PROGRESS','CellControllerComputeServiceChain','overcloud-CellControllerComputeServiceChain-5oe2tf36z5cg','state changed','OS::TripleO::CellControllerComputeServices',NULL,83),(189,'55aa6dcd-d007-488b-8f73-f287193cb3f2','91b09edf-7f19-488f-896a-b6248296e4e5','2026-06-10 07:46:38',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-xhvnas4abrxo','91b09edf-7f19-488f-896a-b6248296e4e5','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(190,'510be981-5c24-4969-a785-149d2ca2ba38','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:38',NULL,'CREATE','IN_PROGRESS','NetworkerServiceChain','overcloud-NetworkerServiceChain-ak2dppqa6der','state changed','OS::TripleO::NetworkerServices',NULL,85),(191,'bd655ecc-0aab-40ad-bc9a-b6ee5997c5bd','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:38',NULL,'CREATE','IN_PROGRESS','BlockStorageServiceChain','overcloud-BlockStorageServiceChain-m3ph455dvrx7','state changed','OS::TripleO::BlockStorageServices',NULL,86),(192,'3f30ed27-788c-4bb8-83a6-89d59a17dc38','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:38',NULL,'CREATE','IN_PROGRESS','CephStorageServiceChain','overcloud-CephStorageServiceChain-zf4ksr3szeyt','state changed','OS::TripleO::CephStorageServices',NULL,87),(193,'fa2d7f10-af92-4ad5-9274-2d21d382b007','3798ef7d-11ff-4293-878c-a0429431ac48','2026-06-10 07:46:38',NULL,'CREATE','IN_PROGRESS','overcloud-CellControllerServiceChain-2rvojby7tcbp','3798ef7d-11ff-4293-878c-a0429431ac48','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(194,'c0c843a9-7380-41bd-ab89-eaa5595ae960','67c8c988-b2f5-467c-a3c6-b667d3637fef','2026-06-10 07:46:38',NULL,'CREATE','IN_PROGRESS','overcloud-NetworkerServiceChain-ak2dppqa6der','67c8c988-b2f5-467c-a3c6-b667d3637fef','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(195,'0b1fce05-a00c-4b67-9d21-7aa28434c584','63c9cc63-2dcd-4378-8459-4b9e0f6f08b8','2026-06-10 07:46:38',NULL,'CREATE','IN_PROGRESS','overcloud-BlockStorageServiceChain-m3ph455dvrx7','63c9cc63-2dcd-4378-8459-4b9e0f6f08b8','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(196,'c34f8142-d9cb-47fe-aa70-dbe87da8a27e','6c6b9a1e-bed0-472c-af16-d27293da060e','2026-06-10 07:46:39',NULL,'CREATE','IN_PROGRESS','overcloud-CellControllerComputeServiceChain-5oe2tf36z5cg','6c6b9a1e-bed0-472c-af16-d27293da060e','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(197,'c4d0a1c6-5240-46c7-acc5-42877abdad18','2ee7a31b-abeb-4c25-930b-397eab924de7','2026-06-10 07:46:39',NULL,'CREATE','IN_PROGRESS','overcloud-CephStorageServiceChain-zf4ksr3szeyt','2ee7a31b-abeb-4c25-930b-397eab924de7','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(198,'23d5ce1f-2079-49f1-abc7-9f3c8c749523','67454241-df97-4bc4-ba26-4f82633996c2','2026-06-10 07:46:39',NULL,'CREATE','IN_PROGRESS','ServiceChain','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4','state changed','OS::Heat::ResourceChain',NULL,88),(199,'794affde-ff95-4908-aa51-c371630425c8','67c8c988-b2f5-467c-a3c6-b667d3637fef','2026-06-10 07:46:39',NULL,'CREATE','IN_PROGRESS','ServiceChain','overcloud-NetworkerServiceChain-ak2dppqa6der-ServiceChain-puosngaentlz','state changed','OS::Heat::ResourceChain',NULL,89),(200,'1e60991d-3678-40bc-a142-0f4e7a38423a','bc34bbb6-3f9b-44b5-a5bc-7ed22f41fc1f','2026-06-10 07:46:39',NULL,'CREATE','IN_PROGRESS','overcloud-NetworkerServiceChain-ak2dppqa6der-ServiceChain-puosngaentlz','bc34bbb6-3f9b-44b5-a5bc-7ed22f41fc1f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(201,'d0e91d1c-348f-4494-9c41-292e5c422ccb','bc34bbb6-3f9b-44b5-a5bc-7ed22f41fc1f','2026-06-10 07:46:39',NULL,'CREATE','COMPLETE','overcloud-NetworkerServiceChain-ak2dppqa6der-ServiceChain-puosngaentlz','bc34bbb6-3f9b-44b5-a5bc-7ed22f41fc1f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(202,'c79bc586-a50c-4032-9c3e-6f8eab3a99c6','3798ef7d-11ff-4293-878c-a0429431ac48','2026-06-10 07:46:39',NULL,'CREATE','IN_PROGRESS','ServiceChain','overcloud-CellControllerServiceChain-2rvojby7tcbp-ServiceChain-mlgfx7bhxvn7','state changed','OS::Heat::ResourceChain',NULL,90),(203,'ce57239b-6c16-4925-aab2-ecc02d54792b','2ee7a31b-abeb-4c25-930b-397eab924de7','2026-06-10 07:46:39',NULL,'CREATE','IN_PROGRESS','ServiceChain','overcloud-CephStorageServiceChain-zf4ksr3szeyt-ServiceChain-ri3qiy6qgche','state changed','OS::Heat::ResourceChain',NULL,91),(204,'3d3528a7-be92-4a19-b68f-a7460c233552','ea88e0ef-1d48-44f9-993d-42f9056350c4','2026-06-10 07:46:39',NULL,'CREATE','IN_PROGRESS','overcloud-CellControllerServiceChain-2rvojby7tcbp-ServiceChain-mlgfx7bhxvn7','ea88e0ef-1d48-44f9-993d-42f9056350c4','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(205,'c6bf71a3-e8b4-4fd6-8309-26e87675b939','f4fe80db-20d2-42cc-8f54-cf643cd6cdeb','2026-06-10 07:46:39',NULL,'CREATE','IN_PROGRESS','overcloud-CephStorageServiceChain-zf4ksr3szeyt-ServiceChain-ri3qiy6qgche','f4fe80db-20d2-42cc-8f54-cf643cd6cdeb','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(206,'82a37419-a08f-4aaa-affc-7f0f3693f1ec','f4fe80db-20d2-42cc-8f54-cf643cd6cdeb','2026-06-10 07:46:39',NULL,'CREATE','COMPLETE','overcloud-CephStorageServiceChain-zf4ksr3szeyt-ServiceChain-ri3qiy6qgche','f4fe80db-20d2-42cc-8f54-cf643cd6cdeb','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(207,'34208baf-c604-4755-a1f1-f32b8f3c6a58','ea88e0ef-1d48-44f9-993d-42f9056350c4','2026-06-10 07:46:39',NULL,'CREATE','COMPLETE','overcloud-CellControllerServiceChain-2rvojby7tcbp-ServiceChain-mlgfx7bhxvn7','ea88e0ef-1d48-44f9-993d-42f9056350c4','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(208,'108231a8-525b-4d3d-8b76-1ba5e063b75a','8f6c9167-89dc-41b2-9c9e-3779bc4a7cea','2026-06-10 07:46:39',NULL,'CREATE','IN_PROGRESS','ServiceChain','overcloud-ObjectStorageServiceChain-dequd3rmhxkf-ServiceChain-zfz5dorojm2o','state changed','OS::Heat::ResourceChain',NULL,93),(209,'743a106c-75d7-490f-9674-beb8de30f07c','698b3791-f424-476d-ad04-b524118b0f55','2026-06-10 07:46:39',NULL,'CREATE','IN_PROGRESS','overcloud-ObjectStorageServiceChain-dequd3rmhxkf-ServiceChain-zfz5dorojm2o','698b3791-f424-476d-ad04-b524118b0f55','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(210,'a35915e5-15d9-4cb1-bd16-a0e7502d256a','6c6b9a1e-bed0-472c-af16-d27293da060e','2026-06-10 07:46:39',NULL,'CREATE','IN_PROGRESS','ServiceChain','overcloud-CellControllerComputeServiceChain-5oe2tf36z5cg-ServiceChain-6uciyspqyvtd','state changed','OS::Heat::ResourceChain',NULL,94),(211,'2a2bec3e-8b1c-4a40-bc62-b55368fbdcc0','698b3791-f424-476d-ad04-b524118b0f55','2026-06-10 07:46:39',NULL,'CREATE','COMPLETE','overcloud-ObjectStorageServiceChain-dequd3rmhxkf-ServiceChain-zfz5dorojm2o','698b3791-f424-476d-ad04-b524118b0f55','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(212,'1cb81833-d4ca-469d-b48e-2f03e890131e','4660c1ff-ee4f-4b87-9420-b1079d552738','2026-06-10 07:46:40',NULL,'CREATE','IN_PROGRESS','overcloud-CellControllerComputeServiceChain-5oe2tf36z5cg-ServiceChain-6uciyspqyvtd','4660c1ff-ee4f-4b87-9420-b1079d552738','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(213,'c7681943-ef52-4cf3-8715-3080f8419549','4660c1ff-ee4f-4b87-9420-b1079d552738','2026-06-10 07:46:40',NULL,'CREATE','COMPLETE','overcloud-CellControllerComputeServiceChain-5oe2tf36z5cg-ServiceChain-6uciyspqyvtd','4660c1ff-ee4f-4b87-9420-b1079d552738','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(214,'aacf71e4-5ddd-493a-b503-dcc4e32ce82b','91b09edf-7f19-488f-896a-b6248296e4e5','2026-06-10 07:46:40',NULL,'CREATE','IN_PROGRESS','ServiceChain','overcloud-ComputeServiceChain-xhvnas4abrxo-ServiceChain-vox3qre3vi3y','state changed','OS::Heat::ResourceChain',NULL,92),(215,'871cc201-e8c5-4d13-9a15-0abda384d741','e6287ac3-40be-4a55-b065-d74cf60a14e3','2026-06-10 07:46:40',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-xhvnas4abrxo-ServiceChain-vox3qre3vi3y','e6287ac3-40be-4a55-b065-d74cf60a14e3','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(216,'757953e8-55bc-4d1d-a4f9-dfaa00516dd7','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:46:40',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4','418cb07f-f8ef-4b77-a27d-29311653bd9d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(217,'01125959-5de2-4269-9da9-a1b0a37e8560','e6287ac3-40be-4a55-b065-d74cf60a14e3','2026-06-10 07:46:40',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-xhvnas4abrxo-ServiceChain-vox3qre3vi3y','e6287ac3-40be-4a55-b065-d74cf60a14e3','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(218,'d087fb05-e254-493c-9a96-c73f1cff8ae2','63c9cc63-2dcd-4378-8459-4b9e0f6f08b8','2026-06-10 07:46:40',NULL,'CREATE','IN_PROGRESS','ServiceChain','overcloud-BlockStorageServiceChain-m3ph455dvrx7-ServiceChain-r2i3p2pfnqoe','state changed','OS::Heat::ResourceChain',NULL,95),(219,'82354443-e5cf-4795-b095-27e3cc37738c','67c8c988-b2f5-467c-a3c6-b667d3637fef','2026-06-10 07:46:40',NULL,'CREATE','COMPLETE','ServiceChain','bc34bbb6-3f9b-44b5-a5bc-7ed22f41fc1f','state changed','OS::Heat::ResourceChain',NULL,89),(220,'7c5f17d3-a601-4c8f-8b32-c7ff252eadb0','729ad72b-a7c7-4679-815c-2e4955f85c53','2026-06-10 07:46:40',NULL,'CREATE','IN_PROGRESS','overcloud-BlockStorageServiceChain-m3ph455dvrx7-ServiceChain-r2i3p2pfnqoe','729ad72b-a7c7-4679-815c-2e4955f85c53','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(221,'00fce763-a3a7-46d0-8b09-d91e71d65d48','67c8c988-b2f5-467c-a3c6-b667d3637fef','2026-06-10 07:46:40',NULL,'CREATE','IN_PROGRESS','ScaleTasks','overcloud-NetworkerServiceChain-ak2dppqa6der-ScaleTasks-v7cbxpl3fm2f','state changed','OS::Heat::Value',NULL,96),(222,'8e1563a3-943a-477e-8cca-e3e6c75ce8e6','729ad72b-a7c7-4679-815c-2e4955f85c53','2026-06-10 07:46:40',NULL,'CREATE','COMPLETE','overcloud-BlockStorageServiceChain-m3ph455dvrx7-ServiceChain-r2i3p2pfnqoe','729ad72b-a7c7-4679-815c-2e4955f85c53','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(223,'7a9fdb24-1b19-49e7-a347-4574b77cbf38','67c8c988-b2f5-467c-a3c6-b667d3637fef','2026-06-10 07:46:40',NULL,'CREATE','IN_PROGRESS','HostPrepTasks','overcloud-NetworkerServiceChain-ak2dppqa6der-HostPrepTasks-lgr46lubp667','state changed','OS::Heat::Value',NULL,97),(224,'0fec5853-15f2-4322-a172-7b23eb8994f9','67c8c988-b2f5-467c-a3c6-b667d3637fef','2026-06-10 07:46:40',NULL,'CREATE','COMPLETE','HostPrepTasks','overcloud-NetworkerServiceChain-ak2dppqa6der-HostPrepTasks-lgr46lubp667','state changed','OS::Heat::Value',NULL,97),(225,'ff2aa30a-16e7-4730-8418-41dd8187215e','67c8c988-b2f5-467c-a3c6-b667d3637fef','2026-06-10 07:46:40',NULL,'CREATE','COMPLETE','ScaleTasks','overcloud-NetworkerServiceChain-ak2dppqa6der-ScaleTasks-v7cbxpl3fm2f','state changed','OS::Heat::Value',NULL,96),(226,'d2bf8150-9dff-484a-a8b5-d73734b6970c','3798ef7d-11ff-4293-878c-a0429431ac48','2026-06-10 07:46:40',NULL,'CREATE','COMPLETE','ServiceChain','ea88e0ef-1d48-44f9-993d-42f9056350c4','state changed','OS::Heat::ResourceChain',NULL,90),(227,'660c1496-816d-4eab-b5d1-f7cd0eddf00a','67c8c988-b2f5-467c-a3c6-b667d3637fef','2026-06-10 07:46:40',NULL,'CREATE','IN_PROGRESS','ExternalDeployTasks','overcloud-NetworkerServiceChain-ak2dppqa6der-ExternalDeployTasks-kzxosmp2opn5','state changed','OS::Heat::Value',NULL,98),(228,'66d2315d-32e9-4ae1-aa72-5e855585e7c0','2ee7a31b-abeb-4c25-930b-397eab924de7','2026-06-10 07:46:40',NULL,'CREATE','COMPLETE','ServiceChain','f4fe80db-20d2-42cc-8f54-cf643cd6cdeb','state changed','OS::Heat::ResourceChain',NULL,91),(229,'61a6e229-b044-4b1c-b9a6-b0d7d4bab804','67c8c988-b2f5-467c-a3c6-b667d3637fef','2026-06-10 07:46:40',NULL,'CREATE','IN_PROGRESS','AnsibleGroupVars','overcloud-NetworkerServiceChain-ak2dppqa6der-AnsibleGroupVars-4pnryrzdydq7','state changed','OS::Heat::Value',NULL,99),(230,'6801e466-6e02-4b68-a296-874c70384a09','67c8c988-b2f5-467c-a3c6-b667d3637fef','2026-06-10 07:46:40',NULL,'CREATE','IN_PROGRESS','HostFirewallTasks','overcloud-NetworkerServiceChain-ak2dppqa6der-HostFirewallTasks-xv5ayiukqttz','state changed','OS::Heat::Value',NULL,100),(231,'946be05c-c615-4eab-9a43-0efffb955c78','67c8c988-b2f5-467c-a3c6-b667d3637fef','2026-06-10 07:46:40',NULL,'CREATE','COMPLETE','HostFirewallTasks','overcloud-NetworkerServiceChain-ak2dppqa6der-HostFirewallTasks-xv5ayiukqttz','state changed','OS::Heat::Value',NULL,100),(232,'1347879b-b4eb-430c-96e7-6bd57599e02b','67c8c988-b2f5-467c-a3c6-b667d3637fef','2026-06-10 07:46:40',NULL,'CREATE','IN_PROGRESS','UpdateTasks','overcloud-NetworkerServiceChain-ak2dppqa6der-UpdateTasks-figkqx4igoyp','state changed','OS::Heat::Value',NULL,101),(233,'428101a0-fb63-4146-ad25-b87930490edc','67c8c988-b2f5-467c-a3c6-b667d3637fef','2026-06-10 07:46:40',NULL,'CREATE','COMPLETE','AnsibleGroupVars','overcloud-NetworkerServiceChain-ak2dppqa6der-AnsibleGroupVars-4pnryrzdydq7','state changed','OS::Heat::Value',NULL,99),(234,'62675819-5077-48dc-875b-b59c6abf042a','67c8c988-b2f5-467c-a3c6-b667d3637fef','2026-06-10 07:46:40',NULL,'CREATE','IN_PROGRESS','DockerPuppetTasks','overcloud-NetworkerServiceChain-ak2dppqa6der-DockerPuppetTasks-ea6wml5uqqga','state changed','OS::Heat::Value',NULL,102),(235,'0cf3cdd7-80e5-47ee-97da-c646e74eb94d','8f6c9167-89dc-41b2-9c9e-3779bc4a7cea','2026-06-10 07:46:40',NULL,'CREATE','COMPLETE','ServiceChain','698b3791-f424-476d-ad04-b524118b0f55','state changed','OS::Heat::ResourceChain',NULL,93),(236,'ce893262-9c4e-41fa-8e80-f9faa7ace04a','67c8c988-b2f5-467c-a3c6-b667d3637fef','2026-06-10 07:46:40',NULL,'CREATE','COMPLETE','ExternalDeployTasks','overcloud-NetworkerServiceChain-ak2dppqa6der-ExternalDeployTasks-kzxosmp2opn5','state changed','OS::Heat::Value',NULL,98),(237,'ce448767-48ac-4fee-8f4d-3c0783a61cc0','67c8c988-b2f5-467c-a3c6-b667d3637fef','2026-06-10 07:46:40',NULL,'CREATE','IN_PROGRESS','ExternalUpdateTasks','overcloud-NetworkerServiceChain-ak2dppqa6der-ExternalUpdateTasks-fo74ridjzs7y','state changed','OS::Heat::Value',NULL,104),(238,'db32724d-c39f-45eb-8a7b-138dbd8388f8','67c8c988-b2f5-467c-a3c6-b667d3637fef','2026-06-10 07:46:41',NULL,'CREATE','IN_PROGRESS','UpgradeBatchTasks','overcloud-NetworkerServiceChain-ak2dppqa6der-UpgradeBatchTasks-u2eu6kw6cqid','state changed','OS::Heat::Value',NULL,103),(239,'48b7dc60-d054-4b1f-8308-7e70dc2b0c88','67c8c988-b2f5-467c-a3c6-b667d3637fef','2026-06-10 07:46:41',NULL,'CREATE','COMPLETE','DockerPuppetTasks','overcloud-NetworkerServiceChain-ak2dppqa6der-DockerPuppetTasks-ea6wml5uqqga','state changed','OS::Heat::Value',NULL,102),(240,'f2dffa88-9173-4550-bfd0-b6e2a3f23cf9','67c8c988-b2f5-467c-a3c6-b667d3637fef','2026-06-10 07:46:41',NULL,'CREATE','IN_PROGRESS','KollaConfig','overcloud-NetworkerServiceChain-ak2dppqa6der-KollaConfig-banqlsdb6wjp','state changed','OS::Heat::Value',NULL,106),(241,'7507290b-044f-45f0-9df4-1ce4ba967d87','67c8c988-b2f5-467c-a3c6-b667d3637fef','2026-06-10 07:46:41',NULL,'CREATE','IN_PROGRESS','DockerConfigScripts','overcloud-NetworkerServiceChain-ak2dppqa6der-DockerConfigScripts-j67puwufzmem','state changed','OS::Heat::Value',NULL,105),(242,'78e9ccfe-8afd-4c25-aea6-a96d593168ce','67c8c988-b2f5-467c-a3c6-b667d3637fef','2026-06-10 07:46:41',NULL,'CREATE','COMPLETE','UpdateTasks','overcloud-NetworkerServiceChain-ak2dppqa6der-UpdateTasks-figkqx4igoyp','state changed','OS::Heat::Value',NULL,101),(243,'8f4ed14b-d149-4ae0-ac9c-3ebecde60be2','67c8c988-b2f5-467c-a3c6-b667d3637fef','2026-06-10 07:46:41',NULL,'CREATE','COMPLETE','KollaConfig','overcloud-NetworkerServiceChain-ak2dppqa6der-KollaConfig-banqlsdb6wjp','state changed','OS::Heat::Value',NULL,106),(244,'3b74278e-6267-42ad-a64a-703d0fc72d23','2ee7a31b-abeb-4c25-930b-397eab924de7','2026-06-10 07:46:41',NULL,'CREATE','IN_PROGRESS','PostUpdateTasks','overcloud-CephStorageServiceChain-zf4ksr3szeyt-PostUpdateTasks-7by6ishkzw4w','state changed','OS::Heat::Value',NULL,109),(245,'535a8404-14a0-43fa-ab60-5eace8daf3a2','2ee7a31b-abeb-4c25-930b-397eab924de7','2026-06-10 07:46:41',NULL,'CREATE','IN_PROGRESS','HostFirewallTasks','overcloud-CephStorageServiceChain-zf4ksr3szeyt-HostFirewallTasks-le7krf2picto','state changed','OS::Heat::Value',NULL,107),(246,'9b3a0f3b-52b8-4285-bc8a-e81e0dc3066d','67c8c988-b2f5-467c-a3c6-b667d3637fef','2026-06-10 07:46:41',NULL,'CREATE','IN_PROGRESS','FirewallRules','overcloud-NetworkerServiceChain-ak2dppqa6der-FirewallRules-zkd2notx3wji','state changed','OS::Heat::Value',NULL,108),(247,'2dde1722-6fd5-42d7-ad9a-60fca910a45e','67c8c988-b2f5-467c-a3c6-b667d3637fef','2026-06-10 07:46:41',NULL,'CREATE','COMPLETE','UpgradeBatchTasks','overcloud-NetworkerServiceChain-ak2dppqa6der-UpgradeBatchTasks-u2eu6kw6cqid','state changed','OS::Heat::Value',NULL,103),(248,'9896272c-a19e-4ebc-b89e-db7c4d5fe168','6c6b9a1e-bed0-472c-af16-d27293da060e','2026-06-10 07:46:41',NULL,'CREATE','COMPLETE','ServiceChain','4660c1ff-ee4f-4b87-9420-b1079d552738','state changed','OS::Heat::ResourceChain',NULL,94),(249,'94e4bcc7-152e-4f41-9598-c6759e4894a4','67c8c988-b2f5-467c-a3c6-b667d3637fef','2026-06-10 07:46:41',NULL,'CREATE','COMPLETE','ExternalUpdateTasks','overcloud-NetworkerServiceChain-ak2dppqa6der-ExternalUpdateTasks-fo74ridjzs7y','state changed','OS::Heat::Value',NULL,104),(250,'377c336e-ab85-4719-96f7-61cc5cbd126f','3798ef7d-11ff-4293-878c-a0429431ac48','2026-06-10 07:46:41',NULL,'CREATE','IN_PROGRESS','IpaRegistrationTasks','overcloud-CellControllerServiceChain-2rvojby7tcbp-IpaRegistrationTasks-gwrehnnfzvnl','state changed','OS::Heat::Value',NULL,110),(251,'c4c07b2e-8dfc-4d03-b4ac-a1960b03606e','67c8c988-b2f5-467c-a3c6-b667d3637fef','2026-06-10 07:46:41',NULL,'CREATE','IN_PROGRESS','ContainerPuppetTasks','overcloud-NetworkerServiceChain-ak2dppqa6der-ContainerPuppetTasks-4vansy3pbtje','state changed','OS::Heat::Value',NULL,112),(252,'cac899c6-d7a3-4953-b1fd-716cb8bcd6d7','67c8c988-b2f5-467c-a3c6-b667d3637fef','2026-06-10 07:46:41',NULL,'CREATE','COMPLETE','DockerConfigScripts','overcloud-NetworkerServiceChain-ak2dppqa6der-DockerConfigScripts-j67puwufzmem','state changed','OS::Heat::Value',NULL,105),(253,'241855be-b679-4721-a3d2-9db7141795d7','2ee7a31b-abeb-4c25-930b-397eab924de7','2026-06-10 07:46:41',NULL,'CREATE','IN_PROGRESS','KeystoneResourcesConfigs','overcloud-CephStorageServiceChain-zf4ksr3szeyt-KeystoneResourcesConfigs-qttbrhjuvuo3','state changed','OS::Heat::Value',NULL,114),(254,'e468f34b-fdb6-479e-963d-928ceccc54d9','3798ef7d-11ff-4293-878c-a0429431ac48','2026-06-10 07:46:41',NULL,'CREATE','IN_PROGRESS','PostUpdateTasks','overcloud-CellControllerServiceChain-2rvojby7tcbp-PostUpdateTasks-kupbpy5ojg5n','state changed','OS::Heat::Value',NULL,113),(255,'12775902-38a1-454c-a65f-1d63c034767a','2ee7a31b-abeb-4c25-930b-397eab924de7','2026-06-10 07:46:41',NULL,'CREATE','IN_PROGRESS','GlobalConfigSettings','overcloud-CephStorageServiceChain-zf4ksr3szeyt-GlobalConfigSettings-gwe3xnwwfceq','state changed','OS::Heat::Value',NULL,111),(256,'27322f00-b432-465f-b83f-8caa14368fff','2ee7a31b-abeb-4c25-930b-397eab924de7','2026-06-10 07:46:41',NULL,'CREATE','COMPLETE','PostUpdateTasks','overcloud-CephStorageServiceChain-zf4ksr3szeyt-PostUpdateTasks-7by6ishkzw4w','state changed','OS::Heat::Value',NULL,109),(257,'a2e61c8c-5eea-4f38-8be6-c0d84f48c30b','3798ef7d-11ff-4293-878c-a0429431ac48','2026-06-10 07:46:41',NULL,'CREATE','IN_PROGRESS','GlobalConfigSettings','overcloud-CellControllerServiceChain-2rvojby7tcbp-GlobalConfigSettings-q7octoqakwuj','state changed','OS::Heat::Value',NULL,115),(258,'e699351b-1eb3-4e9c-8033-959a892db5c5','8f6c9167-89dc-41b2-9c9e-3779bc4a7cea','2026-06-10 07:46:41',NULL,'CREATE','IN_PROGRESS','PuppetStepConfig','overcloud-ObjectStorageServiceChain-dequd3rmhxkf-PuppetStepConfig-ckwstx4yas7p','state changed','OS::Heat::Value',NULL,117),(259,'58b2bc71-b1f1-4449-92a6-893c439780b4','3798ef7d-11ff-4293-878c-a0429431ac48','2026-06-10 07:46:41',NULL,'CREATE','COMPLETE','IpaRegistrationTasks','overcloud-CellControllerServiceChain-2rvojby7tcbp-IpaRegistrationTasks-gwrehnnfzvnl','state changed','OS::Heat::Value',NULL,110),(260,'c78cb2e5-022a-4098-899e-88a4b2e32ab7','2ee7a31b-abeb-4c25-930b-397eab924de7','2026-06-10 07:46:41',NULL,'CREATE','COMPLETE','KeystoneResourcesConfigs','overcloud-CephStorageServiceChain-zf4ksr3szeyt-KeystoneResourcesConfigs-qttbrhjuvuo3','state changed','OS::Heat::Value',NULL,114),(261,'9be53ad8-b164-421e-a1b7-b87ded43b7da','3798ef7d-11ff-4293-878c-a0429431ac48','2026-06-10 07:46:41',NULL,'CREATE','IN_PROGRESS','DockerPuppetTasks','overcloud-CellControllerServiceChain-2rvojby7tcbp-DockerPuppetTasks-zctrhlxmzfk6','state changed','OS::Heat::Value',NULL,120),(262,'f7594000-1d50-4105-909a-cc826f6b9636','2ee7a31b-abeb-4c25-930b-397eab924de7','2026-06-10 07:46:41',NULL,'CREATE','IN_PROGRESS','IpaRegistrationTasks','overcloud-CephStorageServiceChain-zf4ksr3szeyt-IpaRegistrationTasks-5qfeg3nn7nrk','state changed','OS::Heat::Value',NULL,118),(263,'a38eddb6-3c2a-47f5-8613-41db148f00b6','3798ef7d-11ff-4293-878c-a0429431ac48','2026-06-10 07:46:41',NULL,'CREATE','COMPLETE','PostUpdateTasks','overcloud-CellControllerServiceChain-2rvojby7tcbp-PostUpdateTasks-kupbpy5ojg5n','state changed','OS::Heat::Value',NULL,113),(264,'5da74009-129d-43bb-9a1f-a141fd042901','2ee7a31b-abeb-4c25-930b-397eab924de7','2026-06-10 07:46:41',NULL,'CREATE','IN_PROGRESS','ContainerPuppetTasks','overcloud-CephStorageServiceChain-zf4ksr3szeyt-ContainerPuppetTasks-y42pgyntnb3g','state changed','OS::Heat::Value',NULL,119),(265,'d94356af-1f1f-4c29-81b4-2a39d459369e','67c8c988-b2f5-467c-a3c6-b667d3637fef','2026-06-10 07:46:41',NULL,'CREATE','COMPLETE','FirewallRules','overcloud-NetworkerServiceChain-ak2dppqa6der-FirewallRules-zkd2notx3wji','state changed','OS::Heat::Value',NULL,108),(266,'b79bd2dc-061f-42f4-b800-1fbd947db3b3','67c8c988-b2f5-467c-a3c6-b667d3637fef','2026-06-10 07:46:41',NULL,'CREATE','IN_PROGRESS','KeystoneResourcesConfigs','overcloud-NetworkerServiceChain-ak2dppqa6der-KeystoneResourcesConfigs-bd6et6hsa6p5','state changed','OS::Heat::Value',NULL,116),(267,'a8fa997b-d59c-4e89-acb3-489b1d03f882','8f6c9167-89dc-41b2-9c9e-3779bc4a7cea','2026-06-10 07:46:41',NULL,'CREATE','COMPLETE','PuppetStepConfig','overcloud-ObjectStorageServiceChain-dequd3rmhxkf-PuppetStepConfig-ckwstx4yas7p','state changed','OS::Heat::Value',NULL,117),(268,'73109383-7782-4d46-8fba-1156b3ab049f','2ee7a31b-abeb-4c25-930b-397eab924de7','2026-06-10 07:46:41',NULL,'CREATE','IN_PROGRESS','ScaleTasks','overcloud-CephStorageServiceChain-zf4ksr3szeyt-ScaleTasks-f4myesxkaxoo','state changed','OS::Heat::Value',NULL,123),(269,'bb69074e-dfba-40ff-b62b-8b91c5ffa1b0','2ee7a31b-abeb-4c25-930b-397eab924de7','2026-06-10 07:46:41',NULL,'CREATE','COMPLETE','HostFirewallTasks','overcloud-CephStorageServiceChain-zf4ksr3szeyt-HostFirewallTasks-le7krf2picto','state changed','OS::Heat::Value',NULL,107),(270,'813eb238-4c27-4e3a-9cac-3d336e81bf2c','67c8c988-b2f5-467c-a3c6-b667d3637fef','2026-06-10 07:46:41',NULL,'CREATE','IN_PROGRESS','UpgradeTasks','overcloud-NetworkerServiceChain-ak2dppqa6der-UpgradeTasks-4nzlbvv2h3ub','state changed','OS::Heat::Value',NULL,122),(271,'556d78cd-32d7-4b7b-8f3c-d7a6d6b0ee81','2ee7a31b-abeb-4c25-930b-397eab924de7','2026-06-10 07:46:41',NULL,'CREATE','IN_PROGRESS','MonitoringSubscriptionsConfig','overcloud-CephStorageServiceChain-zf4ksr3szeyt-MonitoringSubscriptionsConfig-idztii2elzbx','state changed','OS::Heat::Value',NULL,121),(272,'478f4ea1-f396-41ea-8dd9-d648f5bc7fad','3798ef7d-11ff-4293-878c-a0429431ac48','2026-06-10 07:46:41',NULL,'CREATE','COMPLETE','GlobalConfigSettings','overcloud-CellControllerServiceChain-2rvojby7tcbp-GlobalConfigSettings-q7octoqakwuj','state changed','OS::Heat::Value',NULL,115),(273,'3282c603-c7b0-41d8-93cf-c10d805f2c60','8f6c9167-89dc-41b2-9c9e-3779bc4a7cea','2026-06-10 07:46:41',NULL,'CREATE','IN_PROGRESS','PostUpgradeTasks','overcloud-ObjectStorageServiceChain-dequd3rmhxkf-PostUpgradeTasks-mhcxgkxldy7g','state changed','OS::Heat::Value',NULL,124),(274,'c62d16a5-6bf7-4758-a5ea-bb0df86316d8','3798ef7d-11ff-4293-878c-a0429431ac48','2026-06-10 07:46:41',NULL,'CREATE','COMPLETE','DockerPuppetTasks','overcloud-CellControllerServiceChain-2rvojby7tcbp-DockerPuppetTasks-zctrhlxmzfk6','state changed','OS::Heat::Value',NULL,120),(275,'1c4cc1d0-4d34-4fca-a400-ae0b1fa9592b','67c8c988-b2f5-467c-a3c6-b667d3637fef','2026-06-10 07:46:41',NULL,'CREATE','IN_PROGRESS','DockerConfig','overcloud-NetworkerServiceChain-ak2dppqa6der-DockerConfig-4qm6nmabgwbo','state changed','OS::Heat::Value',NULL,125),(276,'c5d182a3-db9b-4648-a4d7-c56d8e66d50e','3798ef7d-11ff-4293-878c-a0429431ac48','2026-06-10 07:46:41',NULL,'CREATE','IN_PROGRESS','FirewallFrontendRules','overcloud-CellControllerServiceChain-2rvojby7tcbp-FirewallFrontendRules-sqdtx44q3tkd','state changed','OS::Heat::Value',NULL,126),(277,'854e473e-58c3-44c9-b160-619593144466','67c8c988-b2f5-467c-a3c6-b667d3637fef','2026-06-10 07:46:41',NULL,'CREATE','COMPLETE','ContainerPuppetTasks','overcloud-NetworkerServiceChain-ak2dppqa6der-ContainerPuppetTasks-4vansy3pbtje','state changed','OS::Heat::Value',NULL,112),(278,'bf06e015-a664-40c3-a840-5b896d3b6a13','2ee7a31b-abeb-4c25-930b-397eab924de7','2026-06-10 07:46:41',NULL,'CREATE','COMPLETE','GlobalConfigSettings','overcloud-CephStorageServiceChain-zf4ksr3szeyt-GlobalConfigSettings-gwe3xnwwfceq','state changed','OS::Heat::Value',NULL,111),(279,'5478155d-834b-4a28-85fa-20e12c06c877','2ee7a31b-abeb-4c25-930b-397eab924de7','2026-06-10 07:46:41',NULL,'CREATE','COMPLETE','ScaleTasks','overcloud-CephStorageServiceChain-zf4ksr3szeyt-ScaleTasks-f4myesxkaxoo','state changed','OS::Heat::Value',NULL,123),(280,'a9affca3-14be-4cdb-a981-f5816052060c','6c6b9a1e-bed0-472c-af16-d27293da060e','2026-06-10 07:46:41',NULL,'CREATE','IN_PROGRESS','ExternalUpgradeTasks','overcloud-CellControllerComputeServiceChain-5oe2tf36z5cg-ExternalUpgradeTasks-qkhmuc3nhvrv','state changed','OS::Heat::Value',NULL,128),(281,'ade07370-580c-4eca-818d-89ac13419691','2ee7a31b-abeb-4c25-930b-397eab924de7','2026-06-10 07:46:41',NULL,'CREATE','IN_PROGRESS','FirewallRules','overcloud-CephStorageServiceChain-zf4ksr3szeyt-FirewallRules-nxr5gnbv3cat','state changed','OS::Heat::Value',NULL,127),(282,'6d57249d-8b2b-4a7a-a2f2-2ab4f31aadd5','2ee7a31b-abeb-4c25-930b-397eab924de7','2026-06-10 07:46:41',NULL,'CREATE','COMPLETE','IpaRegistrationTasks','overcloud-CephStorageServiceChain-zf4ksr3szeyt-IpaRegistrationTasks-5qfeg3nn7nrk','state changed','OS::Heat::Value',NULL,118),(283,'041fc63a-d638-4314-9868-d3e25b283c00','3798ef7d-11ff-4293-878c-a0429431ac48','2026-06-10 07:46:41',NULL,'CREATE','COMPLETE','FirewallFrontendRules','overcloud-CellControllerServiceChain-2rvojby7tcbp-FirewallFrontendRules-sqdtx44q3tkd','state changed','OS::Heat::Value',NULL,126),(284,'1f2201a6-319b-48b6-a754-c7ca12cc03e5','2ee7a31b-abeb-4c25-930b-397eab924de7','2026-06-10 07:46:41',NULL,'CREATE','COMPLETE','ContainerPuppetTasks','overcloud-CephStorageServiceChain-zf4ksr3szeyt-ContainerPuppetTasks-y42pgyntnb3g','state changed','OS::Heat::Value',NULL,119),(285,'f54ecff6-4f75-4cb3-a5a2-4fad946269e3','67c8c988-b2f5-467c-a3c6-b667d3637fef','2026-06-10 07:46:41',NULL,'CREATE','COMPLETE','KeystoneResourcesConfigs','overcloud-NetworkerServiceChain-ak2dppqa6der-KeystoneResourcesConfigs-bd6et6hsa6p5','state changed','OS::Heat::Value',NULL,116),(286,'3beef48a-e390-41d3-bf07-640b71269f8c','8f6c9167-89dc-41b2-9c9e-3779bc4a7cea','2026-06-10 07:46:41',NULL,'CREATE','IN_PROGRESS','PuppetConfig','overcloud-ObjectStorageServiceChain-dequd3rmhxkf-PuppetConfig-jgselmv4d235','state changed','OS::Heat::Value',NULL,131),(287,'c852b5f4-eb61-400e-8267-6363bb15e31e','2ee7a31b-abeb-4c25-930b-397eab924de7','2026-06-10 07:46:41',NULL,'CREATE','IN_PROGRESS','ExternalPostDeployTasks','overcloud-CephStorageServiceChain-zf4ksr3szeyt-ExternalPostDeployTasks-7oktczanqqko','state changed','OS::Heat::Value',NULL,130),(288,'c19a4982-1b46-4710-b3c8-81d82ba74d76','6c6b9a1e-bed0-472c-af16-d27293da060e','2026-06-10 07:46:41',NULL,'CREATE','COMPLETE','ExternalUpgradeTasks','overcloud-CellControllerComputeServiceChain-5oe2tf36z5cg-ExternalUpgradeTasks-qkhmuc3nhvrv','state changed','OS::Heat::Value',NULL,128),(289,'170f91c9-ce50-465e-a929-017e3df2f4e8','2ee7a31b-abeb-4c25-930b-397eab924de7','2026-06-10 07:46:41',NULL,'CREATE','IN_PROGRESS','ExternalUpgradeTasks','overcloud-CephStorageServiceChain-zf4ksr3szeyt-ExternalUpgradeTasks-twywzxezpdtr','state changed','OS::Heat::Value',NULL,136),(290,'e59e6269-6fb0-4388-92ce-07e19a62ac53','67c8c988-b2f5-467c-a3c6-b667d3637fef','2026-06-10 07:46:41',NULL,'CREATE','IN_PROGRESS','PostUpgradeTasks','overcloud-NetworkerServiceChain-ak2dppqa6der-PostUpgradeTasks-yn52stiu7qhi','state changed','OS::Heat::Value',NULL,129),(291,'676cf265-0340-4a66-8fd5-887e6def9195','8f6c9167-89dc-41b2-9c9e-3779bc4a7cea','2026-06-10 07:46:41',NULL,'CREATE','IN_PROGRESS','MonitoringSubscriptionsConfig','overcloud-ObjectStorageServiceChain-dequd3rmhxkf-MonitoringSubscriptionsConfig-qvwwqgtotsob','state changed','OS::Heat::Value',NULL,133),(292,'81790f2c-605b-4d8f-b842-299213a5e740','8f6c9167-89dc-41b2-9c9e-3779bc4a7cea','2026-06-10 07:46:41',NULL,'CREATE','IN_PROGRESS','ExternalPostDeployTasks','overcloud-ObjectStorageServiceChain-dequd3rmhxkf-ExternalPostDeployTasks-vbaahynh2ssp','state changed','OS::Heat::Value',NULL,132),(293,'42bb7dea-5659-4a6d-a3e1-dcefca0ea73d','2ee7a31b-abeb-4c25-930b-397eab924de7','2026-06-10 07:46:41',NULL,'CREATE','COMPLETE','MonitoringSubscriptionsConfig','overcloud-CephStorageServiceChain-zf4ksr3szeyt-MonitoringSubscriptionsConfig-idztii2elzbx','state changed','OS::Heat::Value',NULL,121),(294,'39c837aa-2fb9-4087-b6df-3d4737a0e15d','67c8c988-b2f5-467c-a3c6-b667d3637fef','2026-06-10 07:46:41',NULL,'CREATE','COMPLETE','UpgradeTasks','overcloud-NetworkerServiceChain-ak2dppqa6der-UpgradeTasks-4nzlbvv2h3ub','state changed','OS::Heat::Value',NULL,122),(295,'c5a1b5d0-97e1-4126-b8dc-e413df14dfa3','67c8c988-b2f5-467c-a3c6-b667d3637fef','2026-06-10 07:46:41',NULL,'CREATE','IN_PROGRESS','DeployStepsTasks','overcloud-NetworkerServiceChain-ak2dppqa6der-DeployStepsTasks-luezdseiovrb','state changed','OS::Heat::Value',NULL,134),(296,'ab90a9be-e8da-4c81-b112-5a480c2b4c86','2ee7a31b-abeb-4c25-930b-397eab924de7','2026-06-10 07:46:41',NULL,'CREATE','IN_PROGRESS','HostPrepTasks','overcloud-CephStorageServiceChain-zf4ksr3szeyt-HostPrepTasks-b4qz2cufbrfj','state changed','OS::Heat::Value',NULL,135),(297,'62c76a1d-66f3-4cbb-be73-dafd29ab5a48','2ee7a31b-abeb-4c25-930b-397eab924de7','2026-06-10 07:46:41',NULL,'CREATE','COMPLETE','ExternalUpgradeTasks','overcloud-CephStorageServiceChain-zf4ksr3szeyt-ExternalUpgradeTasks-twywzxezpdtr','state changed','OS::Heat::Value',NULL,136),(298,'5c3fb8ce-1032-4a56-aa0c-abd854853bde','8f6c9167-89dc-41b2-9c9e-3779bc4a7cea','2026-06-10 07:46:41',NULL,'CREATE','COMPLETE','PostUpgradeTasks','overcloud-ObjectStorageServiceChain-dequd3rmhxkf-PostUpgradeTasks-mhcxgkxldy7g','state changed','OS::Heat::Value',NULL,124),(299,'e5e372ce-5c4f-4432-b40c-3915c4964cca','2ee7a31b-abeb-4c25-930b-397eab924de7','2026-06-10 07:46:41',NULL,'CREATE','IN_PROGRESS','DeployStepsTasks','overcloud-CephStorageServiceChain-zf4ksr3szeyt-DeployStepsTasks-vzlja2bmsqme','state changed','OS::Heat::Value',NULL,140),(300,'f873a077-e41a-4ee8-b10b-1d4a41c3cf82','2ee7a31b-abeb-4c25-930b-397eab924de7','2026-06-10 07:46:41',NULL,'CREATE','IN_PROGRESS','PostUpgradeTasks','overcloud-CephStorageServiceChain-zf4ksr3szeyt-PostUpgradeTasks-zxb3axq5rw2m','state changed','OS::Heat::Value',NULL,137),(301,'a40c313a-efd2-4943-b665-981f08837410','67c8c988-b2f5-467c-a3c6-b667d3637fef','2026-06-10 07:46:41',NULL,'CREATE','COMPLETE','DockerConfig','overcloud-NetworkerServiceChain-ak2dppqa6der-DockerConfig-4qm6nmabgwbo','state changed','OS::Heat::Value',NULL,125),(302,'746a0317-693d-4dd6-bd4d-9f76d086d2d1','8f6c9167-89dc-41b2-9c9e-3779bc4a7cea','2026-06-10 07:46:41',NULL,'CREATE','IN_PROGRESS','DockerConfig','overcloud-ObjectStorageServiceChain-dequd3rmhxkf-DockerConfig-2kvfms2f2ped','state changed','OS::Heat::Value',NULL,142),(303,'efbe8151-7a84-476f-85bc-50eb2bedc0c6','2ee7a31b-abeb-4c25-930b-397eab924de7','2026-06-10 07:46:41',NULL,'CREATE','IN_PROGRESS','PuppetConfig','overcloud-CephStorageServiceChain-zf4ksr3szeyt-PuppetConfig-ehfezukeehsd','state changed','OS::Heat::Value',NULL,141),(304,'5a5d3fea-a46e-4d43-92c1-f507e27877c9','3798ef7d-11ff-4293-878c-a0429431ac48','2026-06-10 07:46:41',NULL,'CREATE','IN_PROGRESS','ServiceNames','overcloud-CellControllerServiceChain-2rvojby7tcbp-ServiceNames-dypmdm3mhbwq','state changed','OS::Heat::Value',NULL,139),(305,'a55a3039-00db-4c8e-85ba-e25486966acb','67c8c988-b2f5-467c-a3c6-b667d3637fef','2026-06-10 07:46:41',NULL,'CREATE','IN_PROGRESS','ExternalUpgradeTasks','overcloud-NetworkerServiceChain-ak2dppqa6der-ExternalUpgradeTasks-7ivma6e5zxxo','state changed','OS::Heat::Value',NULL,138),(306,'b2b9013d-223f-4a25-9359-1c9d32bc2ee7','2ee7a31b-abeb-4c25-930b-397eab924de7','2026-06-10 07:46:41',NULL,'CREATE','COMPLETE','DeployStepsTasks','overcloud-CephStorageServiceChain-zf4ksr3szeyt-DeployStepsTasks-vzlja2bmsqme','state changed','OS::Heat::Value',NULL,140),(307,'6809f4be-5e5f-46b6-84bc-0bdae2ff88fc','8f6c9167-89dc-41b2-9c9e-3779bc4a7cea','2026-06-10 07:46:41',NULL,'CREATE','COMPLETE','PuppetConfig','overcloud-ObjectStorageServiceChain-dequd3rmhxkf-PuppetConfig-jgselmv4d235','state changed','OS::Heat::Value',NULL,131),(308,'ac604321-8e64-4281-bcd2-37ed928010aa','2ee7a31b-abeb-4c25-930b-397eab924de7','2026-06-10 07:46:41',NULL,'CREATE','COMPLETE','FirewallRules','overcloud-CephStorageServiceChain-zf4ksr3szeyt-FirewallRules-nxr5gnbv3cat','state changed','OS::Heat::Value',NULL,127),(309,'93d38bea-8e63-4d5d-a4df-ba37e0d32607','8f6c9167-89dc-41b2-9c9e-3779bc4a7cea','2026-06-10 07:46:41',NULL,'CREATE','COMPLETE','DockerConfig','overcloud-ObjectStorageServiceChain-dequd3rmhxkf-DockerConfig-2kvfms2f2ped','state changed','OS::Heat::Value',NULL,142),(310,'a47e2d86-f0ea-4a19-a075-254b3edcc473','67c8c988-b2f5-467c-a3c6-b667d3637fef','2026-06-10 07:46:41',NULL,'CREATE','IN_PROGRESS','ExternalPostDeployTasks','overcloud-NetworkerServiceChain-ak2dppqa6der-ExternalPostDeployTasks-5e5flfqr5d2x','state changed','OS::Heat::Value',NULL,148),(311,'d2045ff4-25cc-43d5-914d-37cbb79b4b8b','2ee7a31b-abeb-4c25-930b-397eab924de7','2026-06-10 07:46:41',NULL,'CREATE','IN_PROGRESS','PreUpgradeRollingTasks','overcloud-CephStorageServiceChain-zf4ksr3szeyt-PreUpgradeRollingTasks-le43qizzz47t','state changed','OS::Heat::Value',NULL,144),(312,'d835e638-f03e-4cff-8601-95489cad41bf','8f6c9167-89dc-41b2-9c9e-3779bc4a7cea','2026-06-10 07:46:41',NULL,'CREATE','IN_PROGRESS','PostUpdateTasks','overcloud-ObjectStorageServiceChain-dequd3rmhxkf-PostUpdateTasks-ib5sxxzlh5af','state changed','OS::Heat::Value',NULL,143),(313,'fa4fd983-52bf-4b8d-995b-125d31ce45e6','8f6c9167-89dc-41b2-9c9e-3779bc4a7cea','2026-06-10 07:46:41',NULL,'CREATE','COMPLETE','ExternalPostDeployTasks','overcloud-ObjectStorageServiceChain-dequd3rmhxkf-ExternalPostDeployTasks-vbaahynh2ssp','state changed','OS::Heat::Value',NULL,132),(314,'5a7362b0-0d88-47cb-8aff-5e962e91e1ea','6c6b9a1e-bed0-472c-af16-d27293da060e','2026-06-10 07:46:41',NULL,'CREATE','IN_PROGRESS','PostUpdateTasks','overcloud-CellControllerComputeServiceChain-5oe2tf36z5cg-PostUpdateTasks-b5hgtitcwjsg','state changed','OS::Heat::Value',NULL,145),(315,'1b89cac8-8a1f-45da-bb4b-7812b604aeb1','8f6c9167-89dc-41b2-9c9e-3779bc4a7cea','2026-06-10 07:46:41',NULL,'CREATE','COMPLETE','MonitoringSubscriptionsConfig','overcloud-ObjectStorageServiceChain-dequd3rmhxkf-MonitoringSubscriptionsConfig-qvwwqgtotsob','state changed','OS::Heat::Value',NULL,133),(316,'f37cf0e9-1669-4bca-92dd-84c398aa4767','67c8c988-b2f5-467c-a3c6-b667d3637fef','2026-06-10 07:46:41',NULL,'CREATE','IN_PROGRESS','PuppetConfig','overcloud-NetworkerServiceChain-ak2dppqa6der-PuppetConfig-iilstbkc7xm3','state changed','OS::Heat::Value',NULL,146),(317,'b1c66769-02a3-416e-957b-2fb096beddbd','2ee7a31b-abeb-4c25-930b-397eab924de7','2026-06-10 07:46:41',NULL,'CREATE','COMPLETE','ExternalPostDeployTasks','overcloud-CephStorageServiceChain-zf4ksr3szeyt-ExternalPostDeployTasks-7oktczanqqko','state changed','OS::Heat::Value',NULL,130),(318,'e3885c3f-a617-4ddc-9fd0-788f9c0249d3','2ee7a31b-abeb-4c25-930b-397eab924de7','2026-06-10 07:46:41',NULL,'CREATE','COMPLETE','PostUpgradeTasks','overcloud-CephStorageServiceChain-zf4ksr3szeyt-PostUpgradeTasks-zxb3axq5rw2m','state changed','OS::Heat::Value',NULL,137),(319,'41d85d4e-8858-4ab2-ab7c-fadb273de966','2ee7a31b-abeb-4c25-930b-397eab924de7','2026-06-10 07:46:41',NULL,'CREATE','IN_PROGRESS','DockerPuppetTasks','overcloud-CephStorageServiceChain-zf4ksr3szeyt-DockerPuppetTasks-drxhmklxzp6k','state changed','OS::Heat::Value',NULL,151),(320,'ef1ed52d-8be4-4587-999f-a34a02088116','67c8c988-b2f5-467c-a3c6-b667d3637fef','2026-06-10 07:46:41',NULL,'CREATE','COMPLETE','PostUpgradeTasks','overcloud-NetworkerServiceChain-ak2dppqa6der-PostUpgradeTasks-yn52stiu7qhi','state changed','OS::Heat::Value',NULL,129),(321,'1516f56d-d5f5-4e2e-8a3f-7cc521b79781','67c8c988-b2f5-467c-a3c6-b667d3637fef','2026-06-10 07:46:41',NULL,'CREATE','COMPLETE','ExternalPostDeployTasks','overcloud-NetworkerServiceChain-ak2dppqa6der-ExternalPostDeployTasks-5e5flfqr5d2x','state changed','OS::Heat::Value',NULL,148),(322,'de88dc44-eaaf-408d-8a14-1fbe9d24eab2','3798ef7d-11ff-4293-878c-a0429431ac48','2026-06-10 07:46:41',NULL,'CREATE','IN_PROGRESS','FirewallRules','overcloud-CellControllerServiceChain-2rvojby7tcbp-FirewallRules-prtipphwisyw','state changed','OS::Heat::Value',NULL,147),(323,'22c1f65a-6e40-41be-b24b-ade3bf001238','67c8c988-b2f5-467c-a3c6-b667d3637fef','2026-06-10 07:46:41',NULL,'CREATE','COMPLETE','DeployStepsTasks','overcloud-NetworkerServiceChain-ak2dppqa6der-DeployStepsTasks-luezdseiovrb','state changed','OS::Heat::Value',NULL,134),(324,'20cccf26-ff8e-45db-b272-e133682e6131','2ee7a31b-abeb-4c25-930b-397eab924de7','2026-06-10 07:46:41',NULL,'CREATE','COMPLETE','HostPrepTasks','overcloud-CephStorageServiceChain-zf4ksr3szeyt-HostPrepTasks-b4qz2cufbrfj','state changed','OS::Heat::Value',NULL,135),(325,'f20dc426-dd81-484a-9829-695da9b8fdbf','2ee7a31b-abeb-4c25-930b-397eab924de7','2026-06-10 07:46:41',NULL,'CREATE','COMPLETE','PuppetConfig','overcloud-CephStorageServiceChain-zf4ksr3szeyt-PuppetConfig-ehfezukeehsd','state changed','OS::Heat::Value',NULL,141),(326,'805d8970-c1d0-4cb6-9f54-a54168ebb17f','3798ef7d-11ff-4293-878c-a0429431ac48','2026-06-10 07:46:41',NULL,'CREATE','IN_PROGRESS','ServiceServerMetadataHook','overcloud-CellControllerServiceChain-2rvojby7tcbp-ServiceServerMetadataHook-z5lr3n5d5rho','state changed','OS::TripleO::CellControllerServiceServerMetadataHook',NULL,NULL),(327,'f348fba7-d56c-4f3d-beda-edfa79961a2d','3798ef7d-11ff-4293-878c-a0429431ac48','2026-06-10 07:46:41',NULL,'CREATE','IN_PROGRESS','UpgradeBatchTasks','overcloud-CellControllerServiceChain-2rvojby7tcbp-UpgradeBatchTasks-a6bpgekdy72m','state changed','OS::Heat::Value',NULL,154),(328,'6bf51fd8-8e97-4474-98b6-14f06e20ac29','6c6b9a1e-bed0-472c-af16-d27293da060e','2026-06-10 07:46:41',NULL,'CREATE','IN_PROGRESS','UpgradeBatchTasks','overcloud-CellControllerComputeServiceChain-5oe2tf36z5cg-UpgradeBatchTasks-kcyk3i5fxgwt','state changed','OS::Heat::Value',NULL,150),(329,'5d2e5eda-af99-45ea-9f37-fc3e69c519b3','2ee7a31b-abeb-4c25-930b-397eab924de7','2026-06-10 07:46:41',NULL,'CREATE','COMPLETE','DockerPuppetTasks','overcloud-CephStorageServiceChain-zf4ksr3szeyt-DockerPuppetTasks-drxhmklxzp6k','state changed','OS::Heat::Value',NULL,151),(330,'67d8aea8-ee63-4855-965b-2e224a6ec5d0','2ee7a31b-abeb-4c25-930b-397eab924de7','2026-06-10 07:46:41',NULL,'CREATE','IN_PROGRESS','PreDeployStepTasks','overcloud-CephStorageServiceChain-zf4ksr3szeyt-PreDeployStepTasks-vzgzvlzn2qju','state changed','OS::Heat::Value',NULL,149),(331,'b23a3d81-7521-486e-a7fe-82f6e67403fe','3798ef7d-11ff-4293-878c-a0429431ac48','2026-06-10 07:46:41',NULL,'CREATE','COMPLETE','ServiceNames','overcloud-CellControllerServiceChain-2rvojby7tcbp-ServiceNames-dypmdm3mhbwq','state changed','OS::Heat::Value',NULL,139),(332,'af860bcf-6959-4620-94df-8105f76637c7','8f6c9167-89dc-41b2-9c9e-3779bc4a7cea','2026-06-10 07:46:41',NULL,'CREATE','IN_PROGRESS','ExternalUpdateTasks','overcloud-ObjectStorageServiceChain-dequd3rmhxkf-ExternalUpdateTasks-unw6emgjn7bk','state changed','OS::Heat::Value',NULL,152),(333,'b0cb11b2-72fd-46b8-8c9a-6fe311754344','2ee7a31b-abeb-4c25-930b-397eab924de7','2026-06-10 07:46:41',NULL,'CREATE','IN_PROGRESS','PuppetStepConfig','overcloud-CephStorageServiceChain-zf4ksr3szeyt-PuppetStepConfig-yfcfktkziff3','state changed','OS::Heat::Value',NULL,153),(334,'e7b53cb1-ebf1-4bef-ae0f-15b820c5307e','3798ef7d-11ff-4293-878c-a0429431ac48','2026-06-10 07:46:41',NULL,'CREATE','COMPLETE','UpgradeBatchTasks','overcloud-CellControllerServiceChain-2rvojby7tcbp-UpgradeBatchTasks-a6bpgekdy72m','state changed','OS::Heat::Value',NULL,154),(335,'aa4cbd9b-8973-4985-9336-4205d3983835','2ee7a31b-abeb-4c25-930b-397eab924de7','2026-06-10 07:46:41',NULL,'CREATE','IN_PROGRESS','DockerConfigScripts','overcloud-CephStorageServiceChain-zf4ksr3szeyt-DockerConfigScripts-ipz55rq6ygvn','state changed','OS::Heat::Value',NULL,155),(336,'77552270-248f-4975-880b-4817681b2671','6c6b9a1e-bed0-472c-af16-d27293da060e','2026-06-10 07:46:41',NULL,'CREATE','COMPLETE','PostUpdateTasks','overcloud-CellControllerComputeServiceChain-5oe2tf36z5cg-PostUpdateTasks-b5hgtitcwjsg','state changed','OS::Heat::Value',NULL,145),(337,'cd7ccc61-e277-40c2-a057-a16cd6f4363e','6c6b9a1e-bed0-472c-af16-d27293da060e','2026-06-10 07:46:41',NULL,'CREATE','IN_PROGRESS','PreDeployStepTasks','overcloud-CellControllerComputeServiceChain-5oe2tf36z5cg-PreDeployStepTasks-xnuls2tdht3m','state changed','OS::Heat::Value',NULL,157),(338,'7713a86b-4afe-44f1-8444-7f6e3a0555c8','2ee7a31b-abeb-4c25-930b-397eab924de7','2026-06-10 07:46:41',NULL,'CREATE','IN_PROGRESS','FirewallFrontendRules','overcloud-CephStorageServiceChain-zf4ksr3szeyt-FirewallFrontendRules-knujsc2npvpy','state changed','OS::Heat::Value',NULL,158),(339,'920ef2d9-bb83-433f-8a32-c42b3729c5b0','2ee7a31b-abeb-4c25-930b-397eab924de7','2026-06-10 07:46:41',NULL,'CREATE','COMPLETE','PreUpgradeRollingTasks','overcloud-CephStorageServiceChain-zf4ksr3szeyt-PreUpgradeRollingTasks-le43qizzz47t','state changed','OS::Heat::Value',NULL,144),(340,'56e36523-7b01-4271-8f5d-e0af94742139','67c8c988-b2f5-467c-a3c6-b667d3637fef','2026-06-10 07:46:41',NULL,'CREATE','COMPLETE','ExternalUpgradeTasks','overcloud-NetworkerServiceChain-ak2dppqa6der-ExternalUpgradeTasks-7ivma6e5zxxo','state changed','OS::Heat::Value',NULL,138),(341,'bc729545-e585-4d94-bc2e-db4252227d33','2ee7a31b-abeb-4c25-930b-397eab924de7','2026-06-10 07:46:41',NULL,'CREATE','IN_PROGRESS','AnsibleGroupVars','overcloud-CephStorageServiceChain-zf4ksr3szeyt-AnsibleGroupVars-fm3r45zv5x32','state changed','OS::Heat::Value',NULL,156),(342,'e57ec797-5d75-4485-8440-c5cd8c5a7515','67c8c988-b2f5-467c-a3c6-b667d3637fef','2026-06-10 07:46:41',NULL,'CREATE','IN_PROGRESS','FirewallFrontendRules','overcloud-NetworkerServiceChain-ak2dppqa6der-FirewallFrontendRules-ieiqlrdvy5si','state changed','OS::Heat::Value',NULL,161),(343,'b261573b-7d07-406b-ac71-8dcaf077f9da','8f6c9167-89dc-41b2-9c9e-3779bc4a7cea','2026-06-10 07:46:41',NULL,'CREATE','COMPLETE','PostUpdateTasks','overcloud-ObjectStorageServiceChain-dequd3rmhxkf-PostUpdateTasks-ib5sxxzlh5af','state changed','OS::Heat::Value',NULL,143),(344,'069b14e7-c468-4b16-92a4-bc8f5b84ac52','8f6c9167-89dc-41b2-9c9e-3779bc4a7cea','2026-06-10 07:46:41',NULL,'CREATE','IN_PROGRESS','UpdateTasks','overcloud-ObjectStorageServiceChain-dequd3rmhxkf-UpdateTasks-s3rph35sznb6','state changed','OS::Heat::Value',NULL,159),(345,'fab10dec-457a-458e-8603-353e4d7a272e','67c8c988-b2f5-467c-a3c6-b667d3637fef','2026-06-10 07:46:41',NULL,'CREATE','IN_PROGRESS','ServiceServerMetadataHook','overcloud-NetworkerServiceChain-ak2dppqa6der-ServiceServerMetadataHook-zj2red6biuqz','state changed','OS::TripleO::NetworkerServiceServerMetadataHook',NULL,NULL),(346,'155a51d7-d670-4466-bc5e-9056d1f8e029','3798ef7d-11ff-4293-878c-a0429431ac48','2026-06-10 07:46:41',NULL,'CREATE','COMPLETE','FirewallRules','overcloud-CellControllerServiceChain-2rvojby7tcbp-FirewallRules-prtipphwisyw','state changed','OS::Heat::Value',NULL,147),(347,'b3c9937f-6442-487e-850d-dd9ed96f74ac','2ee7a31b-abeb-4c25-930b-397eab924de7','2026-06-10 07:46:41',NULL,'CREATE','IN_PROGRESS','UpdateTasks','overcloud-CephStorageServiceChain-zf4ksr3szeyt-UpdateTasks-flkdgp2kav26','state changed','OS::Heat::Value',NULL,160),(348,'0d85646f-ab30-4aac-a34d-e0675f81ea3e','2ee7a31b-abeb-4c25-930b-397eab924de7','2026-06-10 07:46:41',NULL,'CREATE','COMPLETE','FirewallFrontendRules','overcloud-CephStorageServiceChain-zf4ksr3szeyt-FirewallFrontendRules-knujsc2npvpy','state changed','OS::Heat::Value',NULL,158),(349,'88f781d4-92fd-47dc-99aa-49b3cd8d1d23','2ee7a31b-abeb-4c25-930b-397eab924de7','2026-06-10 07:46:41',NULL,'CREATE','COMPLETE','PreDeployStepTasks','overcloud-CephStorageServiceChain-zf4ksr3szeyt-PreDeployStepTasks-vzgzvlzn2qju','state changed','OS::Heat::Value',NULL,149),(350,'3cb083a1-04eb-41a2-86d9-c7b01209369b','91b09edf-7f19-488f-896a-b6248296e4e5','2026-06-10 07:46:41',NULL,'CREATE','COMPLETE','ServiceChain','e6287ac3-40be-4a55-b065-d74cf60a14e3','state changed','OS::Heat::ResourceChain',NULL,92),(351,'cf52ade3-8d75-4704-b703-f8f5c5c7b1fd','3798ef7d-11ff-4293-878c-a0429431ac48','2026-06-10 07:46:41',NULL,'CREATE','IN_PROGRESS','PreUpgradeRollingTasks','overcloud-CellControllerServiceChain-2rvojby7tcbp-PreUpgradeRollingTasks-iaq34whbtlbt','state changed','OS::Heat::Value',NULL,163),(352,'da6743da-75ce-40e0-ab2e-064c95aa2dd4','67c8c988-b2f5-467c-a3c6-b667d3637fef','2026-06-10 07:46:41',NULL,'CREATE','COMPLETE','PuppetConfig','overcloud-NetworkerServiceChain-ak2dppqa6der-PuppetConfig-iilstbkc7xm3','state changed','OS::Heat::Value',NULL,146),(353,'2de8033e-5d8c-4513-97f6-b6105ef17a62','8f6c9167-89dc-41b2-9c9e-3779bc4a7cea','2026-06-10 07:46:41',NULL,'CREATE','IN_PROGRESS','DeployStepsTasks','overcloud-ObjectStorageServiceChain-dequd3rmhxkf-DeployStepsTasks-h2ag3paaka6z','state changed','OS::Heat::Value',NULL,162),(354,'bde7ac11-bba4-472b-b908-aa54abc5dae6','2ee7a31b-abeb-4c25-930b-397eab924de7','2026-06-10 07:46:41',NULL,'CREATE','COMPLETE','DockerConfigScripts','overcloud-CephStorageServiceChain-zf4ksr3szeyt-DockerConfigScripts-ipz55rq6ygvn','state changed','OS::Heat::Value',NULL,155),(355,'81814dec-1245-4823-8a02-da2341d05b16','6c6b9a1e-bed0-472c-af16-d27293da060e','2026-06-10 07:46:41',NULL,'CREATE','COMPLETE','UpgradeBatchTasks','overcloud-CellControllerComputeServiceChain-5oe2tf36z5cg-UpgradeBatchTasks-kcyk3i5fxgwt','state changed','OS::Heat::Value',NULL,150),(356,'6d1b8179-dcef-4ee2-be69-82dddd481e22','8f6c9167-89dc-41b2-9c9e-3779bc4a7cea','2026-06-10 07:46:41',NULL,'CREATE','IN_PROGRESS','ServiceConfigSettings','overcloud-ObjectStorageServiceChain-dequd3rmhxkf-ServiceConfigSettings-kypm5svbr3vq','state changed','OS::Heat::Value',NULL,165),(357,'ffbcd91e-f19d-4327-913a-34e1ef2f7358','6c6b9a1e-bed0-472c-af16-d27293da060e','2026-06-10 07:46:41',NULL,'CREATE','IN_PROGRESS','PuppetConfig','overcloud-CellControllerComputeServiceChain-5oe2tf36z5cg-PuppetConfig-t2pt36mooqr2','state changed','OS::Heat::Value',NULL,164),(358,'726fdeb4-d3a4-4527-889d-7de9290107a5','3798ef7d-11ff-4293-878c-a0429431ac48','2026-06-10 07:46:41',NULL,'CREATE','IN_PROGRESS','ContainerPuppetTasks','overcloud-CellControllerServiceChain-2rvojby7tcbp-ContainerPuppetTasks-gz3s54wkt5qn','state changed','OS::Heat::Value',NULL,166),(359,'923671fb-6b86-4226-ba41-233984e5fe52','67c8c988-b2f5-467c-a3c6-b667d3637fef','2026-06-10 07:46:41',NULL,'CREATE','COMPLETE','FirewallFrontendRules','overcloud-NetworkerServiceChain-ak2dppqa6der-FirewallFrontendRules-ieiqlrdvy5si','state changed','OS::Heat::Value',NULL,161),(360,'4e256eac-cce7-4890-807e-3e317fc3e2f4','2ee7a31b-abeb-4c25-930b-397eab924de7','2026-06-10 07:46:41',NULL,'CREATE','COMPLETE','PuppetStepConfig','overcloud-CephStorageServiceChain-zf4ksr3szeyt-PuppetStepConfig-yfcfktkziff3','state changed','OS::Heat::Value',NULL,153),(361,'9d00f0e6-bd90-475b-8236-01d58cf1363c','6c6b9a1e-bed0-472c-af16-d27293da060e','2026-06-10 07:46:41',NULL,'CREATE','COMPLETE','PreDeployStepTasks','overcloud-CellControllerComputeServiceChain-5oe2tf36z5cg-PreDeployStepTasks-xnuls2tdht3m','state changed','OS::Heat::Value',NULL,157),(362,'7df08161-7f64-4159-b2e0-d458471441dc','8f6c9167-89dc-41b2-9c9e-3779bc4a7cea','2026-06-10 07:46:41',NULL,'CREATE','COMPLETE','ExternalUpdateTasks','overcloud-ObjectStorageServiceChain-dequd3rmhxkf-ExternalUpdateTasks-unw6emgjn7bk','state changed','OS::Heat::Value',NULL,152),(363,'7d54b31d-8295-4cb3-a7ec-1cefc90f36a2','2ee7a31b-abeb-4c25-930b-397eab924de7','2026-06-10 07:46:41',NULL,'CREATE','IN_PROGRESS','UpgradeBatchTasks','overcloud-CephStorageServiceChain-zf4ksr3szeyt-UpgradeBatchTasks-n2e7hvyunvj6','state changed','OS::Heat::Value',NULL,168),(364,'d3abfa4f-ca91-455a-8837-dae13df93c8d','2ee7a31b-abeb-4c25-930b-397eab924de7','2026-06-10 07:46:41',NULL,'CREATE','IN_PROGRESS','ExternalDeployTasks','overcloud-CephStorageServiceChain-zf4ksr3szeyt-ExternalDeployTasks-e5ti4gkxuy2y','state changed','OS::Heat::Value',NULL,167),(365,'a02ab624-eeec-44b4-ab94-680e177d553a','67c8c988-b2f5-467c-a3c6-b667d3637fef','2026-06-10 07:46:41',NULL,'CREATE','IN_PROGRESS','PostUpdateTasks','overcloud-NetworkerServiceChain-ak2dppqa6der-PostUpdateTasks-axkfof53rg2x','state changed','OS::Heat::Value',NULL,169),(366,'a091f4df-c574-4745-b27b-1c6b78fe15c4','3798ef7d-11ff-4293-878c-a0429431ac48','2026-06-10 07:46:41',NULL,'CREATE','COMPLETE','ServiceServerMetadataHook','c258d9c9-1649-4913-90f1-d4b25e5b917a','state changed','OS::TripleO::CellControllerServiceServerMetadataHook',NULL,NULL),(367,'4a7f8ef5-1464-4eda-996a-e97a33cb77b4','2ee7a31b-abeb-4c25-930b-397eab924de7','2026-06-10 07:46:41',NULL,'CREATE','COMPLETE','AnsibleGroupVars','overcloud-CephStorageServiceChain-zf4ksr3szeyt-AnsibleGroupVars-fm3r45zv5x32','state changed','OS::Heat::Value',NULL,156),(368,'24a371bc-8f20-4b60-97f9-b75ee2ddf46f','2ee7a31b-abeb-4c25-930b-397eab924de7','2026-06-10 07:46:41',NULL,'CREATE','COMPLETE','UpdateTasks','overcloud-CephStorageServiceChain-zf4ksr3szeyt-UpdateTasks-flkdgp2kav26','state changed','OS::Heat::Value',NULL,160),(369,'9dea1ead-c149-4260-baee-76d9050c7f05','2ee7a31b-abeb-4c25-930b-397eab924de7','2026-06-10 07:46:41',NULL,'CREATE','IN_PROGRESS','DockerConfig','overcloud-CephStorageServiceChain-zf4ksr3szeyt-DockerConfig-5xam4plzrxyl','state changed','OS::Heat::Value',NULL,172),(370,'cccf713d-7e0d-4f97-9412-1065c775df48','63c9cc63-2dcd-4378-8459-4b9e0f6f08b8','2026-06-10 07:46:41',NULL,'CREATE','COMPLETE','ServiceChain','729ad72b-a7c7-4679-815c-2e4955f85c53','state changed','OS::Heat::ResourceChain',NULL,95),(371,'46d8b816-e767-42d6-ab0f-b2dcc69abc06','2ee7a31b-abeb-4c25-930b-397eab924de7','2026-06-10 07:46:41',NULL,'CREATE','IN_PROGRESS','UpgradeTasks','overcloud-CephStorageServiceChain-zf4ksr3szeyt-UpgradeTasks-vqp6o66updjg','state changed','OS::Heat::Value',NULL,170),(372,'5fee038c-909a-42f8-837b-9ded31b5b197','2ee7a31b-abeb-4c25-930b-397eab924de7','2026-06-10 07:46:41',NULL,'CREATE','IN_PROGRESS','ServiceConfigSettings','overcloud-CephStorageServiceChain-zf4ksr3szeyt-ServiceConfigSettings-pibepixasgzb','state changed','OS::Heat::Value',NULL,171),(373,'06fe73ca-54c5-4c71-be75-083dcfba9930','8f6c9167-89dc-41b2-9c9e-3779bc4a7cea','2026-06-10 07:46:41',NULL,'CREATE','COMPLETE','UpdateTasks','overcloud-ObjectStorageServiceChain-dequd3rmhxkf-UpdateTasks-s3rph35sznb6','state changed','OS::Heat::Value',NULL,159),(374,'79caff94-623a-45b4-80f2-2275f4a0c0f9','3798ef7d-11ff-4293-878c-a0429431ac48','2026-06-10 07:46:41',NULL,'CREATE','COMPLETE','PreUpgradeRollingTasks','overcloud-CellControllerServiceChain-2rvojby7tcbp-PreUpgradeRollingTasks-iaq34whbtlbt','state changed','OS::Heat::Value',NULL,163),(375,'14314d59-3e74-475a-aad7-0b0da49582c7','3798ef7d-11ff-4293-878c-a0429431ac48','2026-06-10 07:46:41',NULL,'CREATE','COMPLETE','ContainerPuppetTasks','overcloud-CellControllerServiceChain-2rvojby7tcbp-ContainerPuppetTasks-gz3s54wkt5qn','state changed','OS::Heat::Value',NULL,166),(376,'7850db57-82b9-4714-9f82-9fc1ca343217','3798ef7d-11ff-4293-878c-a0429431ac48','2026-06-10 07:46:41',NULL,'CREATE','IN_PROGRESS','PuppetConfig','overcloud-CellControllerServiceChain-2rvojby7tcbp-PuppetConfig-kihrnelh2bdx','state changed','OS::Heat::Value',NULL,175),(377,'eff59fca-0b69-4000-a227-85d7602fd45c','67c8c988-b2f5-467c-a3c6-b667d3637fef','2026-06-10 07:46:41',NULL,'CREATE','IN_PROGRESS','PuppetStepConfig','overcloud-NetworkerServiceChain-ak2dppqa6der-PuppetStepConfig-fb73jcmqi74d','state changed','OS::Heat::Value',NULL,174),(378,'9077c210-d146-463a-84eb-b773aa7e20a4','8f6c9167-89dc-41b2-9c9e-3779bc4a7cea','2026-06-10 07:46:41',NULL,'CREATE','IN_PROGRESS','UpgradeBatchTasks','overcloud-ObjectStorageServiceChain-dequd3rmhxkf-UpgradeBatchTasks-wvetp7xdv3oo','state changed','OS::Heat::Value',NULL,173),(379,'18949293-9cc1-4104-b696-fe670f7b92f9','8f6c9167-89dc-41b2-9c9e-3779bc4a7cea','2026-06-10 07:46:41',NULL,'CREATE','COMPLETE','ServiceConfigSettings','overcloud-ObjectStorageServiceChain-dequd3rmhxkf-ServiceConfigSettings-kypm5svbr3vq','state changed','OS::Heat::Value',NULL,165),(380,'53c33cf1-504d-4cb9-ad3f-1f8c69859d91','6c6b9a1e-bed0-472c-af16-d27293da060e','2026-06-10 07:46:41',NULL,'CREATE','IN_PROGRESS','ScaleTasks','overcloud-CellControllerComputeServiceChain-5oe2tf36z5cg-ScaleTasks-z6osjwoiuu7l','state changed','OS::Heat::Value',NULL,177),(381,'32d296d8-486c-42b4-a4e4-2fecb855bd2e','2ee7a31b-abeb-4c25-930b-397eab924de7','2026-06-10 07:46:41',NULL,'CREATE','COMPLETE','DockerConfig','overcloud-CephStorageServiceChain-zf4ksr3szeyt-DockerConfig-5xam4plzrxyl','state changed','OS::Heat::Value',NULL,172),(382,'77da0621-8773-4c29-b2de-84919914ef11','8f6c9167-89dc-41b2-9c9e-3779bc4a7cea','2026-06-10 07:46:41',NULL,'CREATE','COMPLETE','DeployStepsTasks','overcloud-ObjectStorageServiceChain-dequd3rmhxkf-DeployStepsTasks-h2ag3paaka6z','state changed','OS::Heat::Value',NULL,162),(383,'164032ba-1e2b-4f2a-8499-0ceab6ddef93','6c6b9a1e-bed0-472c-af16-d27293da060e','2026-06-10 07:46:41',NULL,'CREATE','IN_PROGRESS','ServiceConfigSettings','overcloud-CellControllerComputeServiceChain-5oe2tf36z5cg-ServiceConfigSettings-4yf53zllcug2','state changed','OS::Heat::Value',NULL,176),(384,'a050ada3-74b1-4d4a-a60c-1c12ab05d0be','3798ef7d-11ff-4293-878c-a0429431ac48','2026-06-10 07:46:41',NULL,'CREATE','COMPLETE','PuppetConfig','overcloud-CellControllerServiceChain-2rvojby7tcbp-PuppetConfig-kihrnelh2bdx','state changed','OS::Heat::Value',NULL,175),(385,'3d1baafe-3a0a-4c15-91ac-df4de6be073f','67c8c988-b2f5-467c-a3c6-b667d3637fef','2026-06-10 07:46:41',NULL,'CREATE','IN_PROGRESS','MonitoringSubscriptionsConfig','overcloud-NetworkerServiceChain-ak2dppqa6der-MonitoringSubscriptionsConfig-mqksrebulflq','state changed','OS::Heat::Value',NULL,179),(386,'ad3ef228-838e-4973-92dc-0e225b4323c1','6c6b9a1e-bed0-472c-af16-d27293da060e','2026-06-10 07:46:41',NULL,'CREATE','COMPLETE','PuppetConfig','overcloud-CellControllerComputeServiceChain-5oe2tf36z5cg-PuppetConfig-t2pt36mooqr2','state changed','OS::Heat::Value',NULL,164),(387,'2337eb19-2b1b-4865-ac26-feef7d36260d','67c8c988-b2f5-467c-a3c6-b667d3637fef','2026-06-10 07:46:41',NULL,'CREATE','COMPLETE','PostUpdateTasks','overcloud-NetworkerServiceChain-ak2dppqa6der-PostUpdateTasks-axkfof53rg2x','state changed','OS::Heat::Value',NULL,169),(388,'358e78de-92e3-4608-8313-8a35afffc03d','67c8c988-b2f5-467c-a3c6-b667d3637fef','2026-06-10 07:46:41',NULL,'CREATE','COMPLETE','ServiceServerMetadataHook','5a4e462d-181f-4f98-835d-5bca62dc6e53','state changed','OS::TripleO::NetworkerServiceServerMetadataHook',NULL,NULL),(389,'d8d674a0-e609-4cca-9e1b-303bbf05169a','67c8c988-b2f5-467c-a3c6-b667d3637fef','2026-06-10 07:46:41',NULL,'CREATE','IN_PROGRESS','GlobalConfigSettings','overcloud-NetworkerServiceChain-ak2dppqa6der-GlobalConfigSettings-7wpjnd3vjuff','state changed','OS::Heat::Value',NULL,185),(390,'f9245b5c-9235-4b08-a1d7-032a317d2eb0','8f6c9167-89dc-41b2-9c9e-3779bc4a7cea','2026-06-10 07:46:41',NULL,'CREATE','IN_PROGRESS','IpaRegistrationTasks','overcloud-ObjectStorageServiceChain-dequd3rmhxkf-IpaRegistrationTasks-g3f377v5xuxj','state changed','OS::Heat::Value',NULL,178),(391,'48cc0c23-b81d-4d2a-8429-a934ac8abaef','3798ef7d-11ff-4293-878c-a0429431ac48','2026-06-10 07:46:41',NULL,'CREATE','IN_PROGRESS','ServiceConfigSettings','overcloud-CellControllerServiceChain-2rvojby7tcbp-ServiceConfigSettings-zainqzzcbhv7','state changed','OS::Heat::Value',NULL,182),(392,'72754207-4ba9-4ea6-9061-781e939f6405','2ee7a31b-abeb-4c25-930b-397eab924de7','2026-06-10 07:46:41',NULL,'CREATE','IN_PROGRESS','ServiceNames','overcloud-CephStorageServiceChain-zf4ksr3szeyt-ServiceNames-5m3ymhr3byo4','state changed','OS::Heat::Value',NULL,180),(393,'0cf422c6-dfa8-4ace-976d-2a8b9295ad15','2ee7a31b-abeb-4c25-930b-397eab924de7','2026-06-10 07:46:42',NULL,'CREATE','COMPLETE','UpgradeBatchTasks','overcloud-CephStorageServiceChain-zf4ksr3szeyt-UpgradeBatchTasks-n2e7hvyunvj6','state changed','OS::Heat::Value',NULL,168),(394,'4b36deea-2be4-4713-8fc2-21f55ec15f68','6c6b9a1e-bed0-472c-af16-d27293da060e','2026-06-10 07:46:42',NULL,'CREATE','COMPLETE','ScaleTasks','overcloud-CellControllerComputeServiceChain-5oe2tf36z5cg-ScaleTasks-z6osjwoiuu7l','state changed','OS::Heat::Value',NULL,177),(395,'e5362db3-a202-4b7a-82de-02ddeadcdf2e','3798ef7d-11ff-4293-878c-a0429431ac48','2026-06-10 07:46:42',NULL,'CREATE','IN_PROGRESS','UpdateTasks','overcloud-CellControllerServiceChain-2rvojby7tcbp-UpdateTasks-qp44u3a4noul','state changed','OS::Heat::Value',NULL,187),(396,'febc0630-a106-4055-87a6-c0a128330052','2ee7a31b-abeb-4c25-930b-397eab924de7','2026-06-10 07:46:42',NULL,'CREATE','COMPLETE','ExternalDeployTasks','overcloud-CephStorageServiceChain-zf4ksr3szeyt-ExternalDeployTasks-e5ti4gkxuy2y','state changed','OS::Heat::Value',NULL,167),(397,'95b9d6ee-8777-47c3-8334-e235e1b4c525','2ee7a31b-abeb-4c25-930b-397eab924de7','2026-06-10 07:46:42',NULL,'CREATE','IN_PROGRESS','KollaConfig','overcloud-CephStorageServiceChain-zf4ksr3szeyt-KollaConfig-ckwsg5xabmyu','state changed','OS::Heat::Value',NULL,184),(398,'a6d95be8-e22c-40cf-aea1-87fb06747b0c','67c8c988-b2f5-467c-a3c6-b667d3637fef','2026-06-10 07:46:42',NULL,'CREATE','COMPLETE','PuppetStepConfig','overcloud-NetworkerServiceChain-ak2dppqa6der-PuppetStepConfig-fb73jcmqi74d','state changed','OS::Heat::Value',NULL,174),(399,'af53fca4-79a8-4dc1-a515-948713c6fc09','8f6c9167-89dc-41b2-9c9e-3779bc4a7cea','2026-06-10 07:46:42',NULL,'CREATE','IN_PROGRESS','ExternalDeployTasks','overcloud-ObjectStorageServiceChain-dequd3rmhxkf-ExternalDeployTasks-2uvrii4ug5wq','state changed','OS::Heat::Value',NULL,183),(400,'8fb710c5-369f-4d25-906d-90607dc96c4e','2ee7a31b-abeb-4c25-930b-397eab924de7','2026-06-10 07:46:42',NULL,'CREATE','IN_PROGRESS','ServiceServerMetadataHook','overcloud-CephStorageServiceChain-zf4ksr3szeyt-ServiceServerMetadataHook-kktd6z7mvc56','state changed','OS::TripleO::CephStorageServiceServerMetadataHook',NULL,NULL),(401,'88d03a37-c34c-4783-bd7d-635190711c54','2ee7a31b-abeb-4c25-930b-397eab924de7','2026-06-10 07:46:42',NULL,'CREATE','COMPLETE','UpgradeTasks','overcloud-CephStorageServiceChain-zf4ksr3szeyt-UpgradeTasks-vqp6o66updjg','state changed','OS::Heat::Value',NULL,170),(402,'0c399487-a726-484f-b6fe-9912162669e5','67c8c988-b2f5-467c-a3c6-b667d3637fef','2026-06-10 07:46:42',NULL,'CREATE','COMPLETE','GlobalConfigSettings','overcloud-NetworkerServiceChain-ak2dppqa6der-GlobalConfigSettings-7wpjnd3vjuff','state changed','OS::Heat::Value',NULL,185),(403,'54c873e2-522b-4234-bbf6-a5b8ad7b4eb7','2ee7a31b-abeb-4c25-930b-397eab924de7','2026-06-10 07:46:42',NULL,'CREATE','COMPLETE','ServiceConfigSettings','overcloud-CephStorageServiceChain-zf4ksr3szeyt-ServiceConfigSettings-pibepixasgzb','state changed','OS::Heat::Value',NULL,171),(404,'9f8f6096-9597-4c5e-a9af-a57cf7e8c893','2ee7a31b-abeb-4c25-930b-397eab924de7','2026-06-10 07:46:42',NULL,'CREATE','IN_PROGRESS','ExternalUpdateTasks','overcloud-CephStorageServiceChain-zf4ksr3szeyt-ExternalUpdateTasks-262rx5pe6jd4','state changed','OS::Heat::Value',NULL,186),(405,'02d53f01-8c4d-4d4f-9e29-7d9ea6fefe09','8f6c9167-89dc-41b2-9c9e-3779bc4a7cea','2026-06-10 07:46:42',NULL,'CREATE','COMPLETE','UpgradeBatchTasks','overcloud-ObjectStorageServiceChain-dequd3rmhxkf-UpgradeBatchTasks-wvetp7xdv3oo','state changed','OS::Heat::Value',NULL,173),(406,'5d7b2405-be63-4974-b350-4e22e80b8d2f','6c6b9a1e-bed0-472c-af16-d27293da060e','2026-06-10 07:46:42',NULL,'CREATE','IN_PROGRESS','UpgradeTasks','overcloud-CellControllerComputeServiceChain-5oe2tf36z5cg-UpgradeTasks-wkxbrx3iljj7','state changed','OS::Heat::Value',NULL,188),(407,'1ea9b42a-ce40-4cc2-9253-09bd8180ac9f','3798ef7d-11ff-4293-878c-a0429431ac48','2026-06-10 07:46:42',NULL,'CREATE','COMPLETE','UpdateTasks','overcloud-CellControllerServiceChain-2rvojby7tcbp-UpdateTasks-qp44u3a4noul','state changed','OS::Heat::Value',NULL,187),(408,'c377e0ea-5567-4c13-b580-483a830ceaea','67c8c988-b2f5-467c-a3c6-b667d3637fef','2026-06-10 07:46:42',NULL,'CREATE','COMPLETE','MonitoringSubscriptionsConfig','overcloud-NetworkerServiceChain-ak2dppqa6der-MonitoringSubscriptionsConfig-mqksrebulflq','state changed','OS::Heat::Value',NULL,179),(409,'d8b77a4a-6abd-456d-9e6f-a6b43cf89b04','63c9cc63-2dcd-4378-8459-4b9e0f6f08b8','2026-06-10 07:46:42',NULL,'CREATE','IN_PROGRESS','ScaleTasks','overcloud-BlockStorageServiceChain-m3ph455dvrx7-ScaleTasks-gxnnfzebk722','state changed','OS::Heat::Value',NULL,190),(410,'cf0d46e9-8c36-499e-bec0-4b95b3a92641','67c8c988-b2f5-467c-a3c6-b667d3637fef','2026-06-10 07:46:42',NULL,'CREATE','IN_PROGRESS','PreDeployStepTasks','overcloud-NetworkerServiceChain-ak2dppqa6der-PreDeployStepTasks-db436ocee4re','state changed','OS::Heat::Value',NULL,189),(411,'74a33e0c-ce2a-4b7d-9be8-20dcc80d45a4','3798ef7d-11ff-4293-878c-a0429431ac48','2026-06-10 07:46:42',NULL,'CREATE','COMPLETE','ServiceConfigSettings','overcloud-CellControllerServiceChain-2rvojby7tcbp-ServiceConfigSettings-zainqzzcbhv7','state changed','OS::Heat::Value',NULL,182),(412,'6cc4ddb9-3d79-4d09-9b5f-5e4f2f905cdd','67c8c988-b2f5-467c-a3c6-b667d3637fef','2026-06-10 07:46:42',NULL,'CREATE','IN_PROGRESS','ServiceConfigSettings','overcloud-NetworkerServiceChain-ak2dppqa6der-ServiceConfigSettings-rdjipfgkjyaw','state changed','OS::Heat::Value',NULL,193),(413,'4ef1a5c8-b5ce-4579-9189-44ae20d92c1b','6c6b9a1e-bed0-472c-af16-d27293da060e','2026-06-10 07:46:42',NULL,'CREATE','COMPLETE','ServiceConfigSettings','overcloud-CellControllerComputeServiceChain-5oe2tf36z5cg-ServiceConfigSettings-4yf53zllcug2','state changed','OS::Heat::Value',NULL,176),(414,'39e1fdf8-6db0-4fec-ae6d-386ea37b2214','2ee7a31b-abeb-4c25-930b-397eab924de7','2026-06-10 07:46:42',NULL,'CREATE','COMPLETE','ServiceNames','overcloud-CephStorageServiceChain-zf4ksr3szeyt-ServiceNames-5m3ymhr3byo4','state changed','OS::Heat::Value',NULL,180),(415,'9b7fed14-5de6-4497-871d-7925844ee9e8','91b09edf-7f19-488f-896a-b6248296e4e5','2026-06-10 07:46:42',NULL,'CREATE','IN_PROGRESS','FirewallFrontendRules','overcloud-ComputeServiceChain-xhvnas4abrxo-FirewallFrontendRules-vk6sqc4bhr3n','state changed','OS::Heat::Value',NULL,191),(416,'515fcd10-9ad7-4275-b857-805ae83b07fb','8f6c9167-89dc-41b2-9c9e-3779bc4a7cea','2026-06-10 07:46:42',NULL,'CREATE','COMPLETE','IpaRegistrationTasks','overcloud-ObjectStorageServiceChain-dequd3rmhxkf-IpaRegistrationTasks-g3f377v5xuxj','state changed','OS::Heat::Value',NULL,178),(417,'d3bac6c6-7bba-40f4-8006-8c16bee6b415','8f6c9167-89dc-41b2-9c9e-3779bc4a7cea','2026-06-10 07:46:42',NULL,'CREATE','IN_PROGRESS','ServiceServerMetadataHook','overcloud-ObjectStorageServiceChain-dequd3rmhxkf-ServiceServerMetadataHook-werynuoqhshs','state changed','OS::TripleO::ObjectStorageServiceServerMetadataHook',NULL,NULL),(418,'df643a6b-1a1e-47fb-85c3-7e1c1bf9750c','63c9cc63-2dcd-4378-8459-4b9e0f6f08b8','2026-06-10 07:46:42',NULL,'CREATE','COMPLETE','ScaleTasks','overcloud-BlockStorageServiceChain-m3ph455dvrx7-ScaleTasks-gxnnfzebk722','state changed','OS::Heat::Value',NULL,190),(419,'4015f7a9-a866-4624-9920-3eb0049610b8','91b09edf-7f19-488f-896a-b6248296e4e5','2026-06-10 07:46:42',NULL,'CREATE','IN_PROGRESS','ExternalUpdateTasks','overcloud-ComputeServiceChain-xhvnas4abrxo-ExternalUpdateTasks-dtuvu4onirom','state changed','OS::Heat::Value',NULL,194),(420,'e40eeda7-d00c-412d-8049-7d3d7dd4a21e','2ee7a31b-abeb-4c25-930b-397eab924de7','2026-06-10 07:46:42',NULL,'CREATE','COMPLETE','ExternalUpdateTasks','overcloud-CephStorageServiceChain-zf4ksr3szeyt-ExternalUpdateTasks-262rx5pe6jd4','state changed','OS::Heat::Value',NULL,186),(421,'5b32ddce-ab1d-4206-ae0c-2e49f6ba5adb','67c8c988-b2f5-467c-a3c6-b667d3637fef','2026-06-10 07:46:42',NULL,'CREATE','COMPLETE','ServiceConfigSettings','overcloud-NetworkerServiceChain-ak2dppqa6der-ServiceConfigSettings-rdjipfgkjyaw','state changed','OS::Heat::Value',NULL,193),(422,'7d6a94f2-fc21-4e81-b900-4561d72681a1','8f6c9167-89dc-41b2-9c9e-3779bc4a7cea','2026-06-10 07:46:42',NULL,'CREATE','IN_PROGRESS','DockerPuppetTasks','overcloud-ObjectStorageServiceChain-dequd3rmhxkf-DockerPuppetTasks-7xixori3xgbg','state changed','OS::Heat::Value',NULL,192),(423,'62a7e4b5-8ff3-4687-b511-688c550fd645','67c8c988-b2f5-467c-a3c6-b667d3637fef','2026-06-10 07:46:42',NULL,'CREATE','IN_PROGRESS','PreUpgradeRollingTasks','overcloud-NetworkerServiceChain-ak2dppqa6der-PreUpgradeRollingTasks-jrbrdhvpbalt','state changed','OS::Heat::Value',NULL,198),(424,'f8a6dfd1-a713-4b61-b312-3797e59956a5','8f6c9167-89dc-41b2-9c9e-3779bc4a7cea','2026-06-10 07:46:42',NULL,'CREATE','IN_PROGRESS','FirewallFrontendRules','overcloud-ObjectStorageServiceChain-dequd3rmhxkf-FirewallFrontendRules-jttn3yy5heja','state changed','OS::Heat::Value',NULL,196),(425,'e6623456-29e9-4ad5-9a1c-6073dcbbab4a','91b09edf-7f19-488f-896a-b6248296e4e5','2026-06-10 07:46:42',NULL,'CREATE','IN_PROGRESS','GlobalConfigSettings','overcloud-ComputeServiceChain-xhvnas4abrxo-GlobalConfigSettings-2xgubs5mctsc','state changed','OS::Heat::Value',NULL,200),(426,'48ef2a54-7ee2-4da9-bf19-746eb7db60b0','6c6b9a1e-bed0-472c-af16-d27293da060e','2026-06-10 07:46:42',NULL,'CREATE','IN_PROGRESS','PreUpgradeRollingTasks','overcloud-CellControllerComputeServiceChain-5oe2tf36z5cg-PreUpgradeRollingTasks-ovvzbzp6lhwl','state changed','OS::Heat::Value',NULL,195),(427,'624edee9-9e50-44a8-be65-4c6f8e5c4024','2ee7a31b-abeb-4c25-930b-397eab924de7','2026-06-10 07:46:42',NULL,'CREATE','COMPLETE','KollaConfig','overcloud-CephStorageServiceChain-zf4ksr3szeyt-KollaConfig-ckwsg5xabmyu','state changed','OS::Heat::Value',NULL,184),(428,'65e39085-9a0a-4d91-8600-1d1a573f7943','3798ef7d-11ff-4293-878c-a0429431ac48','2026-06-10 07:46:42',NULL,'CREATE','IN_PROGRESS','PostUpgradeTasks','overcloud-CellControllerServiceChain-2rvojby7tcbp-PostUpgradeTasks-qemv7fwmavp7','state changed','OS::Heat::Value',NULL,199),(429,'bf7f96c0-4898-4ac4-827d-fd5909b3fe24','63c9cc63-2dcd-4378-8459-4b9e0f6f08b8','2026-06-10 07:46:42',NULL,'CREATE','IN_PROGRESS','PreDeployStepTasks','overcloud-BlockStorageServiceChain-m3ph455dvrx7-PreDeployStepTasks-coz7zmu4wwn6','state changed','OS::Heat::Value',NULL,204),(430,'8dffefa6-306c-498f-9a34-f8a1429a5e5a','67c8c988-b2f5-467c-a3c6-b667d3637fef','2026-06-10 07:46:42',NULL,'CREATE','COMPLETE','PreDeployStepTasks','overcloud-NetworkerServiceChain-ak2dppqa6der-PreDeployStepTasks-db436ocee4re','state changed','OS::Heat::Value',NULL,189),(431,'7881b752-2342-4586-a3ec-48c3b2015fee','63c9cc63-2dcd-4378-8459-4b9e0f6f08b8','2026-06-10 07:46:42',NULL,'CREATE','IN_PROGRESS','GlobalConfigSettings','overcloud-BlockStorageServiceChain-m3ph455dvrx7-GlobalConfigSettings-d75orlbrig7i','state changed','OS::Heat::Value',NULL,197),(432,'bd0493c5-7e62-4d79-a1bd-2f8126fb22c4','67c8c988-b2f5-467c-a3c6-b667d3637fef','2026-06-10 07:46:42',NULL,'CREATE','COMPLETE','PreUpgradeRollingTasks','overcloud-NetworkerServiceChain-ak2dppqa6der-PreUpgradeRollingTasks-jrbrdhvpbalt','state changed','OS::Heat::Value',NULL,198),(433,'eabbe404-391e-4b56-a821-f66c0b128f75','91b09edf-7f19-488f-896a-b6248296e4e5','2026-06-10 07:46:42',NULL,'CREATE','COMPLETE','GlobalConfigSettings','overcloud-ComputeServiceChain-xhvnas4abrxo-GlobalConfigSettings-2xgubs5mctsc','state changed','OS::Heat::Value',NULL,200),(434,'b43d48e4-3242-4b33-857b-90554276e5d9','8f6c9167-89dc-41b2-9c9e-3779bc4a7cea','2026-06-10 07:46:42',NULL,'CREATE','IN_PROGRESS','AnsibleGroupVars','overcloud-ObjectStorageServiceChain-dequd3rmhxkf-AnsibleGroupVars-jgchbjypx54p','state changed','OS::Heat::Value',NULL,201),(435,'23d95e15-4c48-40ca-bd1d-47db60bf3749','6c6b9a1e-bed0-472c-af16-d27293da060e','2026-06-10 07:46:42',NULL,'CREATE','COMPLETE','UpgradeTasks','overcloud-CellControllerComputeServiceChain-5oe2tf36z5cg-UpgradeTasks-wkxbrx3iljj7','state changed','OS::Heat::Value',NULL,188),(436,'611d9cee-99a3-47e4-9b3c-dcbb82a622a0','63c9cc63-2dcd-4378-8459-4b9e0f6f08b8','2026-06-10 07:46:42',NULL,'CREATE','IN_PROGRESS','PuppetStepConfig','overcloud-BlockStorageServiceChain-m3ph455dvrx7-PuppetStepConfig-xj3y5urebpjc','state changed','OS::Heat::Value',NULL,208),(437,'723881ae-2b79-4b20-b00c-1a95795f0ac0','63c9cc63-2dcd-4378-8459-4b9e0f6f08b8','2026-06-10 07:46:42',NULL,'CREATE','COMPLETE','PreDeployStepTasks','overcloud-BlockStorageServiceChain-m3ph455dvrx7-PreDeployStepTasks-coz7zmu4wwn6','state changed','OS::Heat::Value',NULL,204),(438,'b6c9883f-5e41-4dbc-84d3-8c86902c09ee','91b09edf-7f19-488f-896a-b6248296e4e5','2026-06-10 07:46:42',NULL,'CREATE','COMPLETE','ExternalUpdateTasks','overcloud-ComputeServiceChain-xhvnas4abrxo-ExternalUpdateTasks-dtuvu4onirom','state changed','OS::Heat::Value',NULL,194),(439,'3eafb8e6-ad11-4543-a7ca-c4093444856f','8f6c9167-89dc-41b2-9c9e-3779bc4a7cea','2026-06-10 07:46:42',NULL,'CREATE','COMPLETE','ExternalDeployTasks','overcloud-ObjectStorageServiceChain-dequd3rmhxkf-ExternalDeployTasks-2uvrii4ug5wq','state changed','OS::Heat::Value',NULL,183),(440,'561af2e4-ae27-4435-96c8-990e0f681213','63c9cc63-2dcd-4378-8459-4b9e0f6f08b8','2026-06-10 07:46:42',NULL,'CREATE','IN_PROGRESS','IpaRegistrationTasks','overcloud-BlockStorageServiceChain-m3ph455dvrx7-IpaRegistrationTasks-tu3q32tvt3hb','state changed','OS::Heat::Value',NULL,212),(441,'1ba4c456-ca05-4cd4-a049-6a2afd1eacce','63c9cc63-2dcd-4378-8459-4b9e0f6f08b8','2026-06-10 07:46:42',NULL,'CREATE','COMPLETE','PuppetStepConfig','overcloud-BlockStorageServiceChain-m3ph455dvrx7-PuppetStepConfig-xj3y5urebpjc','state changed','OS::Heat::Value',NULL,208),(442,'ba483500-966a-41c4-8f28-348ef91456b5','3798ef7d-11ff-4293-878c-a0429431ac48','2026-06-10 07:46:42',NULL,'CREATE','IN_PROGRESS','DockerConfig','overcloud-CellControllerServiceChain-2rvojby7tcbp-DockerConfig-s3cfaqhu4fyb','state changed','OS::Heat::Value',NULL,206),(443,'c2dc6faf-a53b-453c-8685-38948e5e97d6','63c9cc63-2dcd-4378-8459-4b9e0f6f08b8','2026-06-10 07:46:42',NULL,'CREATE','IN_PROGRESS','KollaConfig','overcloud-BlockStorageServiceChain-m3ph455dvrx7-KollaConfig-pk7ajjez2m6c','state changed','OS::Heat::Value',NULL,202),(444,'0f911d7d-1e27-4cd2-8bc3-409cf825cd9e','6c6b9a1e-bed0-472c-af16-d27293da060e','2026-06-10 07:46:42',NULL,'CREATE','IN_PROGRESS','DockerConfig','overcloud-CellControllerComputeServiceChain-5oe2tf36z5cg-DockerConfig-e4y4znbrckhv','state changed','OS::Heat::Value',NULL,203),(445,'83e74262-783a-4fe0-9ba2-730910afd3ba','63c9cc63-2dcd-4378-8459-4b9e0f6f08b8','2026-06-10 07:46:42',NULL,'CREATE','COMPLETE','IpaRegistrationTasks','overcloud-BlockStorageServiceChain-m3ph455dvrx7-IpaRegistrationTasks-tu3q32tvt3hb','state changed','OS::Heat::Value',NULL,212),(446,'20cf3fa4-c314-44eb-9249-4ae71c7d16f6','63c9cc63-2dcd-4378-8459-4b9e0f6f08b8','2026-06-10 07:46:42',NULL,'CREATE','IN_PROGRESS','FirewallRules','overcloud-BlockStorageServiceChain-m3ph455dvrx7-FirewallRules-rxtdmfo366ds','state changed','OS::Heat::Value',NULL,205),(447,'9c6d386f-24d0-4167-a5b3-80d5714c55b3','63c9cc63-2dcd-4378-8459-4b9e0f6f08b8','2026-06-10 07:46:42',NULL,'CREATE','IN_PROGRESS','AnsibleGroupVars','overcloud-BlockStorageServiceChain-m3ph455dvrx7-AnsibleGroupVars-jbhbjltrv3mp','state changed','OS::Heat::Value',NULL,215),(448,'40662697-4edc-4a8d-9c37-c2459d663045','2ee7a31b-abeb-4c25-930b-397eab924de7','2026-06-10 07:46:42',NULL,'CREATE','COMPLETE','ServiceServerMetadataHook','6df0d614-be9f-4996-a87c-7f85cbfbe3fc','state changed','OS::TripleO::CephStorageServiceServerMetadataHook',NULL,NULL),(449,'18303615-9807-4af4-b2f2-bf8b9eb92bf0','8f6c9167-89dc-41b2-9c9e-3779bc4a7cea','2026-06-10 07:46:42',NULL,'CREATE','COMPLETE','FirewallFrontendRules','overcloud-ObjectStorageServiceChain-dequd3rmhxkf-FirewallFrontendRules-jttn3yy5heja','state changed','OS::Heat::Value',NULL,196),(450,'2984ce14-2031-4d29-9786-a1a41ab248b6','91b09edf-7f19-488f-896a-b6248296e4e5','2026-06-10 07:46:42',NULL,'CREATE','COMPLETE','FirewallFrontendRules','overcloud-ComputeServiceChain-xhvnas4abrxo-FirewallFrontendRules-vk6sqc4bhr3n','state changed','OS::Heat::Value',NULL,191),(451,'2c2b26ff-258d-4cec-bf81-8ae1926b840a','8f6c9167-89dc-41b2-9c9e-3779bc4a7cea','2026-06-10 07:46:42',NULL,'CREATE','IN_PROGRESS','HostFirewallTasks','overcloud-ObjectStorageServiceChain-dequd3rmhxkf-HostFirewallTasks-bketzlzwqyu3','state changed','OS::Heat::Value',NULL,210),(452,'461abd98-94b5-4c39-a70a-247f2731757c','63c9cc63-2dcd-4378-8459-4b9e0f6f08b8','2026-06-10 07:46:42',NULL,'CREATE','IN_PROGRESS','DockerConfig','overcloud-BlockStorageServiceChain-m3ph455dvrx7-DockerConfig-imgtjsirppyj','state changed','OS::Heat::Value',NULL,209),(453,'f2dc2879-6157-42d9-8086-33e0ede55036','6c6b9a1e-bed0-472c-af16-d27293da060e','2026-06-10 07:46:42',NULL,'CREATE','IN_PROGRESS','ExternalDeployTasks','overcloud-CellControllerComputeServiceChain-5oe2tf36z5cg-ExternalDeployTasks-gptlfu36oryl','state changed','OS::Heat::Value',NULL,211),(454,'9407ba2e-08ed-4e0a-98aa-8dfcec497a63','63c9cc63-2dcd-4378-8459-4b9e0f6f08b8','2026-06-10 07:46:42',NULL,'CREATE','COMPLETE','AnsibleGroupVars','overcloud-BlockStorageServiceChain-m3ph455dvrx7-AnsibleGroupVars-jbhbjltrv3mp','state changed','OS::Heat::Value',NULL,215),(455,'9eff23a5-f41c-4156-845b-5f0e192b0150','63c9cc63-2dcd-4378-8459-4b9e0f6f08b8','2026-06-10 07:46:42',NULL,'CREATE','IN_PROGRESS','UpgradeTasks','overcloud-BlockStorageServiceChain-m3ph455dvrx7-UpgradeTasks-jw3qiizgxxtk','state changed','OS::Heat::Value',NULL,218),(456,'ae345074-3976-42df-a360-3d66fd54838d','6c6b9a1e-bed0-472c-af16-d27293da060e','2026-06-10 07:46:42',NULL,'CREATE','COMPLETE','PreUpgradeRollingTasks','overcloud-CellControllerComputeServiceChain-5oe2tf36z5cg-PreUpgradeRollingTasks-ovvzbzp6lhwl','state changed','OS::Heat::Value',NULL,195),(457,'7bb77e5f-75f1-47be-944c-6f44e1f6f33c','8f6c9167-89dc-41b2-9c9e-3779bc4a7cea','2026-06-10 07:46:42',NULL,'CREATE','COMPLETE','DockerPuppetTasks','overcloud-ObjectStorageServiceChain-dequd3rmhxkf-DockerPuppetTasks-7xixori3xgbg','state changed','OS::Heat::Value',NULL,192),(458,'e5bc3643-a27b-4c90-819b-e0d861837f5b','67c8c988-b2f5-467c-a3c6-b667d3637fef','2026-06-10 07:46:42',NULL,'CREATE','IN_PROGRESS','IpaRegistrationTasks','overcloud-NetworkerServiceChain-ak2dppqa6der-IpaRegistrationTasks-yvkdqohphdlr','state changed','OS::Heat::Value',NULL,213),(459,'b335fa25-bcfa-4cee-9482-2929e54f4d15','63c9cc63-2dcd-4378-8459-4b9e0f6f08b8','2026-06-10 07:46:42',NULL,'CREATE','COMPLETE','UpgradeTasks','overcloud-BlockStorageServiceChain-m3ph455dvrx7-UpgradeTasks-jw3qiizgxxtk','state changed','OS::Heat::Value',NULL,218),(460,'6e6d3c61-a212-408d-998c-65bebecc2bed','63c9cc63-2dcd-4378-8459-4b9e0f6f08b8','2026-06-10 07:46:42',NULL,'CREATE','IN_PROGRESS','MonitoringSubscriptionsConfig','overcloud-BlockStorageServiceChain-m3ph455dvrx7-MonitoringSubscriptionsConfig-ykofydwc4jlt','state changed','OS::Heat::Value',NULL,220),(461,'6a92c1af-1600-4dfa-bf7e-1edb2f0f4a5d','67c8c988-b2f5-467c-a3c6-b667d3637fef','2026-06-10 07:46:42',NULL,'CREATE','IN_PROGRESS','ServiceNames','overcloud-NetworkerServiceChain-ak2dppqa6der-ServiceNames-iu2o3gyqcn55','state changed','OS::Heat::Value',NULL,214),(462,'d53fc5ec-8475-459c-aac3-05c7381edb99','3798ef7d-11ff-4293-878c-a0429431ac48','2026-06-10 07:46:42',NULL,'CREATE','IN_PROGRESS','ExternalUpdateTasks','overcloud-CellControllerServiceChain-2rvojby7tcbp-ExternalUpdateTasks-hnnzl5u6b6zl','state changed','OS::Heat::Value',NULL,217),(463,'d0dc6a07-f48f-4b61-b7b0-9db6790af2ca','63c9cc63-2dcd-4378-8459-4b9e0f6f08b8','2026-06-10 07:46:42',NULL,'CREATE','COMPLETE','GlobalConfigSettings','overcloud-BlockStorageServiceChain-m3ph455dvrx7-GlobalConfigSettings-d75orlbrig7i','state changed','OS::Heat::Value',NULL,197),(464,'28c58446-ca0d-43bf-a203-b2e52bf7c64e','63c9cc63-2dcd-4378-8459-4b9e0f6f08b8','2026-06-10 07:46:42',NULL,'CREATE','COMPLETE','MonitoringSubscriptionsConfig','overcloud-BlockStorageServiceChain-m3ph455dvrx7-MonitoringSubscriptionsConfig-ykofydwc4jlt','state changed','OS::Heat::Value',NULL,220),(465,'fe4e3d6b-f43a-4319-81ab-216025105664','63c9cc63-2dcd-4378-8459-4b9e0f6f08b8','2026-06-10 07:46:42',NULL,'CREATE','IN_PROGRESS','ContainerPuppetTasks','overcloud-BlockStorageServiceChain-m3ph455dvrx7-ContainerPuppetTasks-militxdl2hbo','state changed','OS::Heat::Value',NULL,226),(466,'326f50fa-1074-4f8a-94f5-95d54ed00547','63c9cc63-2dcd-4378-8459-4b9e0f6f08b8','2026-06-10 07:46:42',NULL,'CREATE','IN_PROGRESS','DeployStepsTasks','overcloud-BlockStorageServiceChain-m3ph455dvrx7-DeployStepsTasks-zeds4cmicnhs','state changed','OS::Heat::Value',NULL,216),(467,'81ac2ede-5ea7-45fb-9b56-ad029c99c2df','8f6c9167-89dc-41b2-9c9e-3779bc4a7cea','2026-06-10 07:46:42',NULL,'CREATE','COMPLETE','ServiceServerMetadataHook','1a46204b-5d12-499d-a3c0-b3d04e00ba9f','state changed','OS::TripleO::ObjectStorageServiceServerMetadataHook',NULL,NULL),(468,'82fab7fb-7a3a-487b-b432-7daf126733e3','8f6c9167-89dc-41b2-9c9e-3779bc4a7cea','2026-06-10 07:46:42',NULL,'CREATE','IN_PROGRESS','ExternalUpgradeTasks','overcloud-ObjectStorageServiceChain-dequd3rmhxkf-ExternalUpgradeTasks-f64sgepynv3x','state changed','OS::Heat::Value',NULL,219),(469,'a5698c49-c762-40b7-a60c-2ce8ac25cbb9','3798ef7d-11ff-4293-878c-a0429431ac48','2026-06-10 07:46:42',NULL,'CREATE','COMPLETE','PostUpgradeTasks','overcloud-CellControllerServiceChain-2rvojby7tcbp-PostUpgradeTasks-qemv7fwmavp7','state changed','OS::Heat::Value',NULL,199),(470,'0a2812f3-9d58-4ddb-b4dc-4a9f8691adda','63c9cc63-2dcd-4378-8459-4b9e0f6f08b8','2026-06-10 07:46:42',NULL,'CREATE','COMPLETE','ContainerPuppetTasks','overcloud-BlockStorageServiceChain-m3ph455dvrx7-ContainerPuppetTasks-militxdl2hbo','state changed','OS::Heat::Value',NULL,226),(471,'ad66bb92-34d1-44a0-ae73-33b213d0456b','63c9cc63-2dcd-4378-8459-4b9e0f6f08b8','2026-06-10 07:46:42',NULL,'CREATE','IN_PROGRESS','ExternalUpgradeTasks','overcloud-BlockStorageServiceChain-m3ph455dvrx7-ExternalUpgradeTasks-f6sda2jan7eh','state changed','OS::Heat::Value',NULL,231),(472,'a9261eba-6f42-4382-bd31-b6436ca36091','63c9cc63-2dcd-4378-8459-4b9e0f6f08b8','2026-06-10 07:46:42',NULL,'CREATE','IN_PROGRESS','ExternalDeployTasks','overcloud-BlockStorageServiceChain-m3ph455dvrx7-ExternalDeployTasks-egqcqyn6eo23','state changed','OS::Heat::Value',NULL,221),(473,'4af53d42-f657-4024-8722-80ecb770d767','63c9cc63-2dcd-4378-8459-4b9e0f6f08b8','2026-06-10 07:46:42',NULL,'CREATE','COMPLETE','FirewallRules','overcloud-BlockStorageServiceChain-m3ph455dvrx7-FirewallRules-rxtdmfo366ds','state changed','OS::Heat::Value',NULL,205),(474,'01615d67-54e7-45a8-aff3-015a8cd3a21b','8f6c9167-89dc-41b2-9c9e-3779bc4a7cea','2026-06-10 07:46:42',NULL,'CREATE','COMPLETE','AnsibleGroupVars','overcloud-ObjectStorageServiceChain-dequd3rmhxkf-AnsibleGroupVars-jgchbjypx54p','state changed','OS::Heat::Value',NULL,201),(475,'3f17bb40-a51a-42de-8dd4-064edbe67337','63c9cc63-2dcd-4378-8459-4b9e0f6f08b8','2026-06-10 07:46:42',NULL,'CREATE','IN_PROGRESS','FirewallFrontendRules','overcloud-BlockStorageServiceChain-m3ph455dvrx7-FirewallFrontendRules-vvhxwp67rqsq','state changed','OS::Heat::Value',NULL,222),(476,'46018e98-a990-447f-a46e-ea1da7934aa3','63c9cc63-2dcd-4378-8459-4b9e0f6f08b8','2026-06-10 07:46:42',NULL,'CREATE','COMPLETE','KollaConfig','overcloud-BlockStorageServiceChain-m3ph455dvrx7-KollaConfig-pk7ajjez2m6c','state changed','OS::Heat::Value',NULL,202),(477,'3cd85f67-4f5f-4a63-838f-a939705098a5','91b09edf-7f19-488f-896a-b6248296e4e5','2026-06-10 07:46:42',NULL,'CREATE','IN_PROGRESS','PuppetStepConfig','overcloud-ComputeServiceChain-xhvnas4abrxo-PuppetStepConfig-tpf56csg7emj','state changed','OS::Heat::Value',NULL,224),(478,'7fa25bf1-1582-4ca6-ab5d-d525dbc0be2e','3798ef7d-11ff-4293-878c-a0429431ac48','2026-06-10 07:46:42',NULL,'CREATE','IN_PROGRESS','PuppetStepConfig','overcloud-CellControllerServiceChain-2rvojby7tcbp-PuppetStepConfig-ivgy6krgj2uv','state changed','OS::Heat::Value',NULL,223),(479,'a2686db5-245d-43e6-a0f2-d08b6a8a73b1','63c9cc63-2dcd-4378-8459-4b9e0f6f08b8','2026-06-10 07:46:42',NULL,'CREATE','COMPLETE','ExternalUpgradeTasks','overcloud-BlockStorageServiceChain-m3ph455dvrx7-ExternalUpgradeTasks-f6sda2jan7eh','state changed','OS::Heat::Value',NULL,231),(480,'598fdb53-fbe0-4a56-bdb0-2941b34511e8','63c9cc63-2dcd-4378-8459-4b9e0f6f08b8','2026-06-10 07:46:42',NULL,'CREATE','IN_PROGRESS','PostUpgradeTasks','overcloud-BlockStorageServiceChain-m3ph455dvrx7-PostUpgradeTasks-fxk3kqo2dbdn','state changed','OS::Heat::Value',NULL,235),(481,'29a64d61-19a3-479e-954a-bb231454ccda','6c6b9a1e-bed0-472c-af16-d27293da060e','2026-06-10 07:46:42',NULL,'CREATE','COMPLETE','DockerConfig','overcloud-CellControllerComputeServiceChain-5oe2tf36z5cg-DockerConfig-e4y4znbrckhv','state changed','OS::Heat::Value',NULL,203),(482,'ae85bc90-6ece-4576-8934-d46a3d284d54','8f6c9167-89dc-41b2-9c9e-3779bc4a7cea','2026-06-10 07:46:42',NULL,'CREATE','IN_PROGRESS','PreUpgradeRollingTasks','overcloud-ObjectStorageServiceChain-dequd3rmhxkf-PreUpgradeRollingTasks-e5ns2cpeb3xl','state changed','OS::Heat::Value',NULL,227),(483,'ebefde76-e77a-420a-bd02-97ebc0940212','8f6c9167-89dc-41b2-9c9e-3779bc4a7cea','2026-06-10 07:46:42',NULL,'CREATE','COMPLETE','HostFirewallTasks','overcloud-ObjectStorageServiceChain-dequd3rmhxkf-HostFirewallTasks-bketzlzwqyu3','state changed','OS::Heat::Value',NULL,210),(484,'a8be9273-2902-4e41-9cdb-3d0c5f5cc485','63c9cc63-2dcd-4378-8459-4b9e0f6f08b8','2026-06-10 07:46:42',NULL,'CREATE','COMPLETE','DockerConfig','overcloud-BlockStorageServiceChain-m3ph455dvrx7-DockerConfig-imgtjsirppyj','state changed','OS::Heat::Value',NULL,209),(485,'b8524def-f54d-4ec1-8111-67ae89dea668','3798ef7d-11ff-4293-878c-a0429431ac48','2026-06-10 07:46:42',NULL,'CREATE','COMPLETE','DockerConfig','overcloud-CellControllerServiceChain-2rvojby7tcbp-DockerConfig-s3cfaqhu4fyb','state changed','OS::Heat::Value',NULL,206),(486,'bf9724a3-5d91-4c94-9126-a5280e66d045','63c9cc63-2dcd-4378-8459-4b9e0f6f08b8','2026-06-10 07:46:42',NULL,'CREATE','IN_PROGRESS','HostFirewallTasks','overcloud-BlockStorageServiceChain-m3ph455dvrx7-HostFirewallTasks-qfnfp6mk667x','state changed','OS::Heat::Value',NULL,225),(487,'8c568d15-c50b-41a0-9440-210ccee0e0b7','91b09edf-7f19-488f-896a-b6248296e4e5','2026-06-10 07:46:42',NULL,'CREATE','IN_PROGRESS','ServiceConfigSettings','overcloud-ComputeServiceChain-xhvnas4abrxo-ServiceConfigSettings-hidiusvvpwwd','state changed','OS::Heat::Value',NULL,228),(488,'b0427814-dd29-41bc-995a-536c63ed18c8','63c9cc63-2dcd-4378-8459-4b9e0f6f08b8','2026-06-10 07:46:42',NULL,'CREATE','IN_PROGRESS','PuppetConfig','overcloud-BlockStorageServiceChain-m3ph455dvrx7-PuppetConfig-6yminuishsar','state changed','OS::Heat::Value',NULL,238),(489,'dfcd97d0-c2d1-46d5-bab8-b324fe871cc7','63c9cc63-2dcd-4378-8459-4b9e0f6f08b8','2026-06-10 07:46:42',NULL,'CREATE','COMPLETE','PostUpgradeTasks','overcloud-BlockStorageServiceChain-m3ph455dvrx7-PostUpgradeTasks-fxk3kqo2dbdn','state changed','OS::Heat::Value',NULL,235),(490,'a5cba377-25a5-4ed9-8bc2-65b2247bccd2','63c9cc63-2dcd-4378-8459-4b9e0f6f08b8','2026-06-10 07:46:42',NULL,'CREATE','IN_PROGRESS','KeystoneResourcesConfigs','overcloud-BlockStorageServiceChain-m3ph455dvrx7-KeystoneResourcesConfigs-lajge6ajcmee','state changed','OS::Heat::Value',NULL,232),(491,'1f2ffd7f-8b4a-4562-9ae4-bd664b0cc711','3798ef7d-11ff-4293-878c-a0429431ac48','2026-06-10 07:46:42',NULL,'CREATE','COMPLETE','ExternalUpdateTasks','overcloud-CellControllerServiceChain-2rvojby7tcbp-ExternalUpdateTasks-hnnzl5u6b6zl','state changed','OS::Heat::Value',NULL,217),(492,'23e08217-085b-4f22-b19e-2eb3e11bc2d0','6c6b9a1e-bed0-472c-af16-d27293da060e','2026-06-10 07:46:42',NULL,'CREATE','COMPLETE','ExternalDeployTasks','overcloud-CellControllerComputeServiceChain-5oe2tf36z5cg-ExternalDeployTasks-gptlfu36oryl','state changed','OS::Heat::Value',NULL,211),(493,'a72756bf-9ad0-4132-bc87-e66aaf9dded7','63c9cc63-2dcd-4378-8459-4b9e0f6f08b8','2026-06-10 07:46:42',NULL,'CREATE','IN_PROGRESS','ExternalUpdateTasks','overcloud-BlockStorageServiceChain-m3ph455dvrx7-ExternalUpdateTasks-2h44xpq5xgaw','state changed','OS::Heat::Value',NULL,230),(494,'48e76622-2fdd-46ff-8441-a72d70ce3e54','6c6b9a1e-bed0-472c-af16-d27293da060e','2026-06-10 07:46:42',NULL,'CREATE','IN_PROGRESS','GlobalConfigSettings','overcloud-CellControllerComputeServiceChain-5oe2tf36z5cg-GlobalConfigSettings-y25j52xg3taw','state changed','OS::Heat::Value',NULL,229),(495,'dad13ad6-4630-4d62-870a-811dee7975b8','63c9cc63-2dcd-4378-8459-4b9e0f6f08b8','2026-06-10 07:46:42',NULL,'CREATE','COMPLETE','PuppetConfig','overcloud-BlockStorageServiceChain-m3ph455dvrx7-PuppetConfig-6yminuishsar','state changed','OS::Heat::Value',NULL,238),(496,'906ffa6b-f7c2-412e-8f9d-040c184d9503','3798ef7d-11ff-4293-878c-a0429431ac48','2026-06-10 07:46:42',NULL,'CREATE','IN_PROGRESS','ExternalUpgradeTasks','overcloud-CellControllerServiceChain-2rvojby7tcbp-ExternalUpgradeTasks-ocytu27fsfo2','state changed','OS::Heat::Value',NULL,242),(497,'8c7dfa82-15d7-486c-9947-9de88f615bde','6c6b9a1e-bed0-472c-af16-d27293da060e','2026-06-10 07:46:42',NULL,'CREATE','IN_PROGRESS','DockerPuppetTasks','overcloud-CellControllerComputeServiceChain-5oe2tf36z5cg-DockerPuppetTasks-inbyaw7bnser','state changed','OS::Heat::Value',NULL,233),(498,'c45d8aa2-c303-4c4f-a5e7-10a0d9f6977c','8f6c9167-89dc-41b2-9c9e-3779bc4a7cea','2026-06-10 07:46:42',NULL,'CREATE','IN_PROGRESS','ContainerPuppetTasks','overcloud-ObjectStorageServiceChain-dequd3rmhxkf-ContainerPuppetTasks-tz2plyf3guz2','state changed','OS::Heat::Value',NULL,234),(499,'65d4347c-37a4-49c8-911d-2a7db159dec8','67c8c988-b2f5-467c-a3c6-b667d3637fef','2026-06-10 07:46:42',NULL,'CREATE','COMPLETE','IpaRegistrationTasks','overcloud-NetworkerServiceChain-ak2dppqa6der-IpaRegistrationTasks-yvkdqohphdlr','state changed','OS::Heat::Value',NULL,213),(500,'49d71a96-3c28-4621-89f4-619e38b6b6be','63c9cc63-2dcd-4378-8459-4b9e0f6f08b8','2026-06-10 07:46:42',NULL,'CREATE','IN_PROGRESS','ServiceNames','overcloud-BlockStorageServiceChain-m3ph455dvrx7-ServiceNames-y653fe4guwkx','state changed','OS::Heat::Value',NULL,245),(501,'7ee36d4e-1921-4211-9fba-58c9e69c96ee','67c8c988-b2f5-467c-a3c6-b667d3637fef','2026-06-10 07:46:42',NULL,'CREATE','COMPLETE','ServiceNames','overcloud-NetworkerServiceChain-ak2dppqa6der-ServiceNames-iu2o3gyqcn55','state changed','OS::Heat::Value',NULL,214),(502,'079e3b5c-e3f5-4069-95fe-b30b5e2ad189','91b09edf-7f19-488f-896a-b6248296e4e5','2026-06-10 07:46:42',NULL,'CREATE','IN_PROGRESS','IpaRegistrationTasks','overcloud-ComputeServiceChain-xhvnas4abrxo-IpaRegistrationTasks-bnzpmnvgmzlg','state changed','OS::Heat::Value',NULL,237),(503,'a5d7469b-f9e5-4a8f-a4da-987e61571575','3798ef7d-11ff-4293-878c-a0429431ac48','2026-06-10 07:46:42',NULL,'CREATE','COMPLETE','ExternalUpgradeTasks','overcloud-CellControllerServiceChain-2rvojby7tcbp-ExternalUpgradeTasks-ocytu27fsfo2','state changed','OS::Heat::Value',NULL,242),(504,'876b3d60-c485-4227-952c-21f9f653fc1e','63c9cc63-2dcd-4378-8459-4b9e0f6f08b8','2026-06-10 07:46:42',NULL,'CREATE','IN_PROGRESS','HostPrepTasks','overcloud-BlockStorageServiceChain-m3ph455dvrx7-HostPrepTasks-q2txyq3y3rib','state changed','OS::Heat::Value',NULL,239),(505,'f95698bc-af17-434b-acc1-6ea1798e0d3b','63c9cc63-2dcd-4378-8459-4b9e0f6f08b8','2026-06-10 07:46:42',NULL,'CREATE','COMPLETE','ServiceNames','overcloud-BlockStorageServiceChain-m3ph455dvrx7-ServiceNames-y653fe4guwkx','state changed','OS::Heat::Value',NULL,245),(506,'00d3885a-9758-4eac-8991-3e71c25ef657','63c9cc63-2dcd-4378-8459-4b9e0f6f08b8','2026-06-10 07:46:42',NULL,'CREATE','COMPLETE','DeployStepsTasks','overcloud-BlockStorageServiceChain-m3ph455dvrx7-DeployStepsTasks-zeds4cmicnhs','state changed','OS::Heat::Value',NULL,216),(507,'ca21acb3-c030-430c-ac9d-01da8063ae0a','8f6c9167-89dc-41b2-9c9e-3779bc4a7cea','2026-06-10 07:46:42',NULL,'CREATE','COMPLETE','ExternalUpgradeTasks','overcloud-ObjectStorageServiceChain-dequd3rmhxkf-ExternalUpgradeTasks-f64sgepynv3x','state changed','OS::Heat::Value',NULL,219),(508,'034c5532-806c-4903-9305-3fe332327544','63c9cc63-2dcd-4378-8459-4b9e0f6f08b8','2026-06-10 07:46:42',NULL,'CREATE','IN_PROGRESS','UpgradeBatchTasks','overcloud-BlockStorageServiceChain-m3ph455dvrx7-UpgradeBatchTasks-nhh46ionp7jy','state changed','OS::Heat::Value',NULL,236),(509,'b7cc5a92-7fdd-45a3-87d7-bdb820a375cc','3798ef7d-11ff-4293-878c-a0429431ac48','2026-06-10 07:46:42',NULL,'CREATE','IN_PROGRESS','HostPrepTasks','overcloud-CellControllerServiceChain-2rvojby7tcbp-HostPrepTasks-ixr2rzyxt4up','state changed','OS::Heat::Value',NULL,243),(510,'b1a87590-fe32-4c96-92fb-2256c03a99f4','3798ef7d-11ff-4293-878c-a0429431ac48','2026-06-10 07:46:42',NULL,'CREATE','COMPLETE','PuppetStepConfig','overcloud-CellControllerServiceChain-2rvojby7tcbp-PuppetStepConfig-ivgy6krgj2uv','state changed','OS::Heat::Value',NULL,223),(511,'a62d7350-04a8-4717-80e0-101b14ac6a03','63c9cc63-2dcd-4378-8459-4b9e0f6f08b8','2026-06-10 07:46:42',NULL,'CREATE','IN_PROGRESS','PreUpgradeRollingTasks','overcloud-BlockStorageServiceChain-m3ph455dvrx7-PreUpgradeRollingTasks-5jhvptfikxrn','state changed','OS::Heat::Value',NULL,240),(512,'22b17b09-4df1-44ee-b05d-03d52cb611ff','63c9cc63-2dcd-4378-8459-4b9e0f6f08b8','2026-06-10 07:46:42',NULL,'CREATE','IN_PROGRESS','PostUpdateTasks','overcloud-BlockStorageServiceChain-m3ph455dvrx7-PostUpdateTasks-nh4fodk3kkpk','state changed','OS::Heat::Value',NULL,241),(513,'d808b52e-2389-42e9-a6f4-eb5f09d53ab9','63c9cc63-2dcd-4378-8459-4b9e0f6f08b8','2026-06-10 07:46:42',NULL,'CREATE','IN_PROGRESS','ServiceConfigSettings','overcloud-BlockStorageServiceChain-m3ph455dvrx7-ServiceConfigSettings-6hpdhdcdseeu','state changed','OS::Heat::Value',NULL,248),(514,'db7ac144-bc11-4a33-9882-0b6b07e5c7c1','63c9cc63-2dcd-4378-8459-4b9e0f6f08b8','2026-06-10 07:46:42',NULL,'CREATE','COMPLETE','FirewallFrontendRules','overcloud-BlockStorageServiceChain-m3ph455dvrx7-FirewallFrontendRules-vvhxwp67rqsq','state changed','OS::Heat::Value',NULL,222),(515,'97dfdd11-4206-4ce7-86c7-eae1a8391ca5','3798ef7d-11ff-4293-878c-a0429431ac48','2026-06-10 07:46:42',NULL,'CREATE','IN_PROGRESS','ExternalPostDeployTasks','overcloud-CellControllerServiceChain-2rvojby7tcbp-ExternalPostDeployTasks-sgxs5n7ku3a7','state changed','OS::Heat::Value',NULL,252),(516,'4c19a052-cf83-434d-8ffb-8ca394265686','91b09edf-7f19-488f-896a-b6248296e4e5','2026-06-10 07:46:42',NULL,'CREATE','IN_PROGRESS','ServiceNames','overcloud-ComputeServiceChain-xhvnas4abrxo-ServiceNames-5ncp7jndoft6','state changed','OS::Heat::Value',NULL,244),(517,'001f2d1c-f9f6-455d-bc9e-39bbef42ece8','91b09edf-7f19-488f-896a-b6248296e4e5','2026-06-10 07:46:42',NULL,'CREATE','COMPLETE','PuppetStepConfig','overcloud-ComputeServiceChain-xhvnas4abrxo-PuppetStepConfig-tpf56csg7emj','state changed','OS::Heat::Value',NULL,224),(518,'248bc14b-b16e-4058-bed5-0557dede08f0','63c9cc63-2dcd-4378-8459-4b9e0f6f08b8','2026-06-10 07:46:42',NULL,'CREATE','COMPLETE','ExternalDeployTasks','overcloud-BlockStorageServiceChain-m3ph455dvrx7-ExternalDeployTasks-egqcqyn6eo23','state changed','OS::Heat::Value',NULL,221),(519,'6439f557-a709-4a55-b237-db8701da0b57','3798ef7d-11ff-4293-878c-a0429431ac48','2026-06-10 07:46:42',NULL,'CREATE','COMPLETE','ExternalPostDeployTasks','overcloud-CellControllerServiceChain-2rvojby7tcbp-ExternalPostDeployTasks-sgxs5n7ku3a7','state changed','OS::Heat::Value',NULL,252),(520,'4f4332ae-0ece-418c-9660-951512a71e6e','6c6b9a1e-bed0-472c-af16-d27293da060e','2026-06-10 07:46:42',NULL,'CREATE','IN_PROGRESS','HostFirewallTasks','overcloud-CellControllerComputeServiceChain-5oe2tf36z5cg-HostFirewallTasks-hyknifastitw','state changed','OS::Heat::Value',NULL,246),(521,'80204e51-f2ff-45aa-9617-1d96d1f52126','63c9cc63-2dcd-4378-8459-4b9e0f6f08b8','2026-06-10 07:46:42',NULL,'CREATE','COMPLETE','HostFirewallTasks','overcloud-BlockStorageServiceChain-m3ph455dvrx7-HostFirewallTasks-qfnfp6mk667x','state changed','OS::Heat::Value',NULL,225),(522,'72ecdaef-9a7a-4d27-90f1-71fdd3301c85','8f6c9167-89dc-41b2-9c9e-3779bc4a7cea','2026-06-10 07:46:42',NULL,'CREATE','COMPLETE','PreUpgradeRollingTasks','overcloud-ObjectStorageServiceChain-dequd3rmhxkf-PreUpgradeRollingTasks-e5ns2cpeb3xl','state changed','OS::Heat::Value',NULL,227),(523,'11d62b41-84b5-4c76-9680-fe493c1b3461','63c9cc63-2dcd-4378-8459-4b9e0f6f08b8','2026-06-10 07:46:42',NULL,'CREATE','IN_PROGRESS','ServiceServerMetadataHook','overcloud-BlockStorageServiceChain-m3ph455dvrx7-ServiceServerMetadataHook-5pzgq56ypjqa','state changed','OS::TripleO::BlockStorageServiceServerMetadataHook',NULL,NULL),(524,'89027d35-83bc-44d6-9c65-0bf077f6fd3b','8f6c9167-89dc-41b2-9c9e-3779bc4a7cea','2026-06-10 07:46:42',NULL,'CREATE','IN_PROGRESS','UpgradeTasks','overcloud-ObjectStorageServiceChain-dequd3rmhxkf-UpgradeTasks-gg6rghizyqq3','state changed','OS::Heat::Value',NULL,250),(525,'fb2f06dd-2fd2-4b1a-a514-9ab02ae33a43','63c9cc63-2dcd-4378-8459-4b9e0f6f08b8','2026-06-10 07:46:42',NULL,'CREATE','IN_PROGRESS','DockerConfigScripts','overcloud-BlockStorageServiceChain-m3ph455dvrx7-DockerConfigScripts-4nbh2t3ekaw6','state changed','OS::Heat::Value',NULL,251),(526,'8064532d-9788-4ede-a661-fe2fab5fddc5','6c6b9a1e-bed0-472c-af16-d27293da060e','2026-06-10 07:46:42',NULL,'CREATE','COMPLETE','GlobalConfigSettings','overcloud-CellControllerComputeServiceChain-5oe2tf36z5cg-GlobalConfigSettings-y25j52xg3taw','state changed','OS::Heat::Value',NULL,229),(527,'ffcdcbc8-6e41-40f9-ae23-551502123bac','63c9cc63-2dcd-4378-8459-4b9e0f6f08b8','2026-06-10 07:46:42',NULL,'CREATE','COMPLETE','ExternalUpdateTasks','overcloud-BlockStorageServiceChain-m3ph455dvrx7-ExternalUpdateTasks-2h44xpq5xgaw','state changed','OS::Heat::Value',NULL,230),(528,'5b16b46d-6c2e-45b0-97e5-851e4f4f2f43','91b09edf-7f19-488f-896a-b6248296e4e5','2026-06-10 07:46:42',NULL,'CREATE','COMPLETE','ServiceConfigSettings','overcloud-ComputeServiceChain-xhvnas4abrxo-ServiceConfigSettings-hidiusvvpwwd','state changed','OS::Heat::Value',NULL,228),(529,'f3dd3233-6225-403f-afd1-1cf0ba44245e','63c9cc63-2dcd-4378-8459-4b9e0f6f08b8','2026-06-10 07:46:42',NULL,'CREATE','COMPLETE','KeystoneResourcesConfigs','overcloud-BlockStorageServiceChain-m3ph455dvrx7-KeystoneResourcesConfigs-lajge6ajcmee','state changed','OS::Heat::Value',NULL,232),(530,'aa752027-98d9-4592-8649-3941df9e2dcb','63c9cc63-2dcd-4378-8459-4b9e0f6f08b8','2026-06-10 07:46:42',NULL,'CREATE','IN_PROGRESS','UpdateTasks','overcloud-BlockStorageServiceChain-m3ph455dvrx7-UpdateTasks-woj6wcuo5mfb','state changed','OS::Heat::Value',NULL,249),(531,'83489393-0b23-42a6-9294-cf8e9916990b','6c6b9a1e-bed0-472c-af16-d27293da060e','2026-06-10 07:46:42',NULL,'CREATE','COMPLETE','DockerPuppetTasks','overcloud-CellControllerComputeServiceChain-5oe2tf36z5cg-DockerPuppetTasks-inbyaw7bnser','state changed','OS::Heat::Value',NULL,233),(532,'4774abad-a3df-4869-b7a0-709b770ad6f8','63c9cc63-2dcd-4378-8459-4b9e0f6f08b8','2026-06-10 07:46:42',NULL,'CREATE','IN_PROGRESS','ExternalPostDeployTasks','overcloud-BlockStorageServiceChain-m3ph455dvrx7-ExternalPostDeployTasks-jsuen7pywyd4','state changed','OS::Heat::Value',NULL,255),(533,'367588f4-7b35-482d-99a9-9c714b70f23e','8f6c9167-89dc-41b2-9c9e-3779bc4a7cea','2026-06-10 07:46:42',NULL,'CREATE','COMPLETE','ContainerPuppetTasks','overcloud-ObjectStorageServiceChain-dequd3rmhxkf-ContainerPuppetTasks-tz2plyf3guz2','state changed','OS::Heat::Value',NULL,234),(534,'59d57358-50ab-495e-9aef-ab5dd9f935bb','91b09edf-7f19-488f-896a-b6248296e4e5','2026-06-10 07:46:42',NULL,'CREATE','IN_PROGRESS','DockerPuppetTasks','overcloud-ComputeServiceChain-xhvnas4abrxo-DockerPuppetTasks-c52h3xphslnv','state changed','OS::Heat::Value',NULL,253),(535,'d6654142-b538-47fd-8d3a-a7a6faab6d04','91b09edf-7f19-488f-896a-b6248296e4e5','2026-06-10 07:46:42',NULL,'CREATE','COMPLETE','IpaRegistrationTasks','overcloud-ComputeServiceChain-xhvnas4abrxo-IpaRegistrationTasks-bnzpmnvgmzlg','state changed','OS::Heat::Value',NULL,237),(536,'4f4e6f11-9362-4ee8-8637-0b81e0011ef7','6c6b9a1e-bed0-472c-af16-d27293da060e','2026-06-10 07:46:42',NULL,'CREATE','IN_PROGRESS','AnsibleGroupVars','overcloud-CellControllerComputeServiceChain-5oe2tf36z5cg-AnsibleGroupVars-xiqr4k4cuwgz','state changed','OS::Heat::Value',NULL,256),(537,'71e40495-e227-433c-8bfa-d4767ed94046','63c9cc63-2dcd-4378-8459-4b9e0f6f08b8','2026-06-10 07:46:42',NULL,'CREATE','IN_PROGRESS','DockerPuppetTasks','overcloud-BlockStorageServiceChain-m3ph455dvrx7-DockerPuppetTasks-wmc2s6rbet56','state changed','OS::Heat::Value',NULL,254),(538,'c90ee27a-f502-4f9e-87fd-8fae325ca9ff','3798ef7d-11ff-4293-878c-a0429431ac48','2026-06-10 07:46:42',NULL,'CREATE','COMPLETE','HostPrepTasks','overcloud-CellControllerServiceChain-2rvojby7tcbp-HostPrepTasks-ixr2rzyxt4up','state changed','OS::Heat::Value',NULL,243),(539,'c7c3f88e-076a-451b-b4e0-2d304ce40aea','63c9cc63-2dcd-4378-8459-4b9e0f6f08b8','2026-06-10 07:46:42',NULL,'CREATE','COMPLETE','HostPrepTasks','overcloud-BlockStorageServiceChain-m3ph455dvrx7-HostPrepTasks-q2txyq3y3rib','state changed','OS::Heat::Value',NULL,239),(540,'c6226950-6347-416d-83a2-319f9877e5f8','3798ef7d-11ff-4293-878c-a0429431ac48','2026-06-10 07:46:42',NULL,'CREATE','IN_PROGRESS','AnsibleGroupVars','overcloud-CellControllerServiceChain-2rvojby7tcbp-AnsibleGroupVars-chc5mj2v47dv','state changed','OS::Heat::Value',NULL,260),(541,'86e30e77-04e2-4d6d-9cfa-28b3add78240','63c9cc63-2dcd-4378-8459-4b9e0f6f08b8','2026-06-10 07:46:42',NULL,'CREATE','COMPLETE','ServiceConfigSettings','overcloud-BlockStorageServiceChain-m3ph455dvrx7-ServiceConfigSettings-6hpdhdcdseeu','state changed','OS::Heat::Value',NULL,248),(542,'c9e165e9-0464-411f-9bcf-1670abe72c43','63c9cc63-2dcd-4378-8459-4b9e0f6f08b8','2026-06-10 07:46:42',NULL,'CREATE','COMPLETE','PreUpgradeRollingTasks','overcloud-BlockStorageServiceChain-m3ph455dvrx7-PreUpgradeRollingTasks-5jhvptfikxrn','state changed','OS::Heat::Value',NULL,240),(543,'36c39e0d-143c-4f1d-9205-55777b48b56a','63c9cc63-2dcd-4378-8459-4b9e0f6f08b8','2026-06-10 07:46:42',NULL,'CREATE','COMPLETE','UpgradeBatchTasks','overcloud-BlockStorageServiceChain-m3ph455dvrx7-UpgradeBatchTasks-nhh46ionp7jy','state changed','OS::Heat::Value',NULL,236),(544,'41579b89-1b3e-40af-a894-332ac68f27d9','91b09edf-7f19-488f-896a-b6248296e4e5','2026-06-10 07:46:42',NULL,'CREATE','IN_PROGRESS','PreUpgradeRollingTasks','overcloud-ComputeServiceChain-xhvnas4abrxo-PreUpgradeRollingTasks-xlq6s3c65bll','state changed','OS::Heat::Value',NULL,258),(545,'a64363e2-62ec-4068-84b0-7db779ff09b6','3798ef7d-11ff-4293-878c-a0429431ac48','2026-06-10 07:46:42',NULL,'CREATE','COMPLETE','AnsibleGroupVars','overcloud-CellControllerServiceChain-2rvojby7tcbp-AnsibleGroupVars-chc5mj2v47dv','state changed','OS::Heat::Value',NULL,260),(546,'cf2c840e-b36b-42c9-982e-151760034283','8f6c9167-89dc-41b2-9c9e-3779bc4a7cea','2026-06-10 07:46:42',NULL,'CREATE','IN_PROGRESS','ScaleTasks','overcloud-ObjectStorageServiceChain-dequd3rmhxkf-ScaleTasks-y25nal755uhz','state changed','OS::Heat::Value',NULL,257),(547,'67cec299-5566-411f-a8a7-67433aabc5e7','91b09edf-7f19-488f-896a-b6248296e4e5','2026-06-10 07:46:42',NULL,'CREATE','COMPLETE','ServiceNames','overcloud-ComputeServiceChain-xhvnas4abrxo-ServiceNames-5ncp7jndoft6','state changed','OS::Heat::Value',NULL,244),(548,'cce553b1-cb3f-43b0-bfbf-edb2a4163aac','63c9cc63-2dcd-4378-8459-4b9e0f6f08b8','2026-06-10 07:46:42',NULL,'CREATE','COMPLETE','PostUpdateTasks','overcloud-BlockStorageServiceChain-m3ph455dvrx7-PostUpdateTasks-nh4fodk3kkpk','state changed','OS::Heat::Value',NULL,241),(549,'a36afdd4-5ab8-453d-ab77-c80899f4af25','6c6b9a1e-bed0-472c-af16-d27293da060e','2026-06-10 07:46:43',NULL,'CREATE','IN_PROGRESS','ContainerPuppetTasks','overcloud-CellControllerComputeServiceChain-5oe2tf36z5cg-ContainerPuppetTasks-ozsu2hpxidtu','state changed','OS::Heat::Value',NULL,259),(550,'a04c0807-b414-45cf-90ab-5fed34f05ffc','6c6b9a1e-bed0-472c-af16-d27293da060e','2026-06-10 07:46:43',NULL,'CREATE','COMPLETE','HostFirewallTasks','overcloud-CellControllerComputeServiceChain-5oe2tf36z5cg-HostFirewallTasks-hyknifastitw','state changed','OS::Heat::Value',NULL,246),(551,'fcd8401c-f4ab-479e-ba15-eb9b261cf178','8f6c9167-89dc-41b2-9c9e-3779bc4a7cea','2026-06-10 07:46:43',NULL,'CREATE','COMPLETE','UpgradeTasks','overcloud-ObjectStorageServiceChain-dequd3rmhxkf-UpgradeTasks-gg6rghizyqq3','state changed','OS::Heat::Value',NULL,250),(552,'efdd239b-74ee-491b-91c8-470de70c5b94','3798ef7d-11ff-4293-878c-a0429431ac48','2026-06-10 07:46:43',NULL,'CREATE','IN_PROGRESS','UpgradeTasks','overcloud-CellControllerServiceChain-2rvojby7tcbp-UpgradeTasks-6s4krmxux63c','state changed','OS::Heat::Value',NULL,264),(553,'b2986034-ee8b-4040-8e66-01e4e44fc00e','63c9cc63-2dcd-4378-8459-4b9e0f6f08b8','2026-06-10 07:46:43',NULL,'CREATE','COMPLETE','DockerConfigScripts','overcloud-BlockStorageServiceChain-m3ph455dvrx7-DockerConfigScripts-4nbh2t3ekaw6','state changed','OS::Heat::Value',NULL,251),(554,'646cffe3-b25b-40af-97f9-d218a0ed5668','63c9cc63-2dcd-4378-8459-4b9e0f6f08b8','2026-06-10 07:46:43',NULL,'CREATE','COMPLETE','ServiceServerMetadataHook','f81c5ca6-80ba-40e7-99f1-c0e7bc346d0b','state changed','OS::TripleO::BlockStorageServiceServerMetadataHook',NULL,NULL),(555,'be2dc657-295a-4dc7-b6ac-086034fa1e69','63c9cc63-2dcd-4378-8459-4b9e0f6f08b8','2026-06-10 07:46:43',NULL,'CREATE','COMPLETE','ExternalPostDeployTasks','overcloud-BlockStorageServiceChain-m3ph455dvrx7-ExternalPostDeployTasks-jsuen7pywyd4','state changed','OS::Heat::Value',NULL,255),(556,'fbdaef8a-48fb-4684-82b1-0d1b6c6ca166','6c6b9a1e-bed0-472c-af16-d27293da060e','2026-06-10 07:46:43',NULL,'CREATE','COMPLETE','AnsibleGroupVars','overcloud-CellControllerComputeServiceChain-5oe2tf36z5cg-AnsibleGroupVars-xiqr4k4cuwgz','state changed','OS::Heat::Value',NULL,256),(557,'f417d59b-2e3c-4c56-b76b-57dcfea8ae76','3798ef7d-11ff-4293-878c-a0429431ac48','2026-06-10 07:46:43',NULL,'CREATE','COMPLETE','UpgradeTasks','overcloud-CellControllerServiceChain-2rvojby7tcbp-UpgradeTasks-6s4krmxux63c','state changed','OS::Heat::Value',NULL,264),(558,'a1a97732-91c1-4fc5-9d34-bd79bc5ec452','67c8c988-b2f5-467c-a3c6-b667d3637fef','2026-06-10 07:46:43',NULL,'CREATE','COMPLETE','overcloud-NetworkerServiceChain-ak2dppqa6der','67c8c988-b2f5-467c-a3c6-b667d3637fef','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(559,'fd412584-704b-4d33-8d98-178f70f20fe2','6c6b9a1e-bed0-472c-af16-d27293da060e','2026-06-10 07:46:43',NULL,'CREATE','IN_PROGRESS','HostPrepTasks','overcloud-CellControllerComputeServiceChain-5oe2tf36z5cg-HostPrepTasks-murotvjvhuu2','state changed','OS::Heat::Value',NULL,263),(560,'8aeff965-da42-4f75-9a70-c99d89e838ad','8f6c9167-89dc-41b2-9c9e-3779bc4a7cea','2026-06-10 07:46:43',NULL,'CREATE','IN_PROGRESS','KeystoneResourcesConfigs','overcloud-ObjectStorageServiceChain-dequd3rmhxkf-KeystoneResourcesConfigs-cdyq2mduzqld','state changed','OS::Heat::Value',NULL,261),(561,'99e48013-a448-4c7e-8e5b-4caeb7270733','91b09edf-7f19-488f-896a-b6248296e4e5','2026-06-10 07:46:43',NULL,'CREATE','IN_PROGRESS','ScaleTasks','overcloud-ComputeServiceChain-xhvnas4abrxo-ScaleTasks-4etpukimmde2','state changed','OS::Heat::Value',NULL,262),(562,'6ad33f53-744a-4e6f-a0e3-22cc510c86e7','63c9cc63-2dcd-4378-8459-4b9e0f6f08b8','2026-06-10 07:46:43',NULL,'CREATE','COMPLETE','UpdateTasks','overcloud-BlockStorageServiceChain-m3ph455dvrx7-UpdateTasks-woj6wcuo5mfb','state changed','OS::Heat::Value',NULL,249),(563,'cd7a174b-130e-45d6-b5a0-28ce11519069','63c9cc63-2dcd-4378-8459-4b9e0f6f08b8','2026-06-10 07:46:43',NULL,'CREATE','COMPLETE','DockerPuppetTasks','overcloud-BlockStorageServiceChain-m3ph455dvrx7-DockerPuppetTasks-wmc2s6rbet56','state changed','OS::Heat::Value',NULL,254),(564,'ac24886c-50fa-41f6-8402-31b2b5dd5b29','91b09edf-7f19-488f-896a-b6248296e4e5','2026-06-10 07:46:43',NULL,'CREATE','COMPLETE','DockerPuppetTasks','overcloud-ComputeServiceChain-xhvnas4abrxo-DockerPuppetTasks-c52h3xphslnv','state changed','OS::Heat::Value',NULL,253),(565,'0ad7f853-1a73-4dae-95cd-802ecd782234','91b09edf-7f19-488f-896a-b6248296e4e5','2026-06-10 07:46:43',NULL,'CREATE','IN_PROGRESS','ServiceServerMetadataHook','overcloud-ComputeServiceChain-xhvnas4abrxo-ServiceServerMetadataHook-wtz4jqvpkadt','state changed','OS::TripleO::ComputeServiceServerMetadataHook',NULL,NULL),(566,'42c1139b-95da-4584-877c-ff202afe65ff','91b09edf-7f19-488f-896a-b6248296e4e5','2026-06-10 07:46:43',NULL,'CREATE','COMPLETE','PreUpgradeRollingTasks','overcloud-ComputeServiceChain-xhvnas4abrxo-PreUpgradeRollingTasks-xlq6s3c65bll','state changed','OS::Heat::Value',NULL,258),(567,'c5fee8e6-10a0-4bbf-b428-bda833212d50','8f6c9167-89dc-41b2-9c9e-3779bc4a7cea','2026-06-10 07:46:43',NULL,'CREATE','IN_PROGRESS','FirewallRules','overcloud-ObjectStorageServiceChain-dequd3rmhxkf-FirewallRules-ahlqvoz2q6lv','state changed','OS::Heat::Value',NULL,267),(568,'504648b1-5cf6-428b-b010-e7c3d5dac6d7','91b09edf-7f19-488f-896a-b6248296e4e5','2026-06-10 07:46:43',NULL,'CREATE','IN_PROGRESS','KeystoneResourcesConfigs','overcloud-ComputeServiceChain-xhvnas4abrxo-KeystoneResourcesConfigs-5ntijhcmy2jl','state changed','OS::Heat::Value',NULL,266),(569,'7196877c-1d8d-47ec-96ce-bfa31d8cde96','6c6b9a1e-bed0-472c-af16-d27293da060e','2026-06-10 07:46:43',NULL,'CREATE','COMPLETE','ContainerPuppetTasks','overcloud-CellControllerComputeServiceChain-5oe2tf36z5cg-ContainerPuppetTasks-ozsu2hpxidtu','state changed','OS::Heat::Value',NULL,259),(570,'ec8dee6e-12f5-4069-bed3-3011351ab53b','8f6c9167-89dc-41b2-9c9e-3779bc4a7cea','2026-06-10 07:46:43',NULL,'CREATE','IN_PROGRESS','PreDeployStepTasks','overcloud-ObjectStorageServiceChain-dequd3rmhxkf-PreDeployStepTasks-lkzkdwa726rh','state changed','OS::Heat::Value',NULL,265),(571,'479fe5c4-7576-4a72-9661-75904a09dceb','91b09edf-7f19-488f-896a-b6248296e4e5','2026-06-10 07:46:43',NULL,'CREATE','COMPLETE','ServiceServerMetadataHook','fc50ea64-6018-48a1-b11a-c4b125247a64','state changed','OS::TripleO::ComputeServiceServerMetadataHook',NULL,NULL),(572,'131db9d4-2952-4ad5-ba52-4c02a96a3401','6c6b9a1e-bed0-472c-af16-d27293da060e','2026-06-10 07:46:43',NULL,'CREATE','COMPLETE','HostPrepTasks','overcloud-CellControllerComputeServiceChain-5oe2tf36z5cg-HostPrepTasks-murotvjvhuu2','state changed','OS::Heat::Value',NULL,263),(573,'b21a4c48-80d4-4cce-a2da-901d48b4c415','8f6c9167-89dc-41b2-9c9e-3779bc4a7cea','2026-06-10 07:46:43',NULL,'CREATE','COMPLETE','ScaleTasks','overcloud-ObjectStorageServiceChain-dequd3rmhxkf-ScaleTasks-y25nal755uhz','state changed','OS::Heat::Value',NULL,257),(574,'8da1b532-e13b-439d-a30f-0c3b3f181eab','91b09edf-7f19-488f-896a-b6248296e4e5','2026-06-10 07:46:43',NULL,'CREATE','IN_PROGRESS','ExternalPostDeployTasks','overcloud-ComputeServiceChain-xhvnas4abrxo-ExternalPostDeployTasks-pkushofn22yt','state changed','OS::Heat::Value',NULL,271),(575,'c5292b78-7af8-46cd-983f-7576646a0a4a','3798ef7d-11ff-4293-878c-a0429431ac48','2026-06-10 07:46:43',NULL,'CREATE','IN_PROGRESS','MonitoringSubscriptionsConfig','overcloud-CellControllerServiceChain-2rvojby7tcbp-MonitoringSubscriptionsConfig-77xrvexuli35','state changed','OS::Heat::Value',NULL,269),(576,'97d53678-2ad9-427a-8a6b-4a2b60eb9857','91b09edf-7f19-488f-896a-b6248296e4e5','2026-06-10 07:46:43',NULL,'CREATE','COMPLETE','ScaleTasks','overcloud-ComputeServiceChain-xhvnas4abrxo-ScaleTasks-4etpukimmde2','state changed','OS::Heat::Value',NULL,262),(577,'b1738c59-333f-440b-a134-a461859ab4ec','8f6c9167-89dc-41b2-9c9e-3779bc4a7cea','2026-06-10 07:46:43',NULL,'CREATE','COMPLETE','FirewallRules','overcloud-ObjectStorageServiceChain-dequd3rmhxkf-FirewallRules-ahlqvoz2q6lv','state changed','OS::Heat::Value',NULL,267),(578,'47c3fe5b-0c75-48e0-8669-1fe8bc29f3f2','8f6c9167-89dc-41b2-9c9e-3779bc4a7cea','2026-06-10 07:46:43',NULL,'CREATE','IN_PROGRESS','KollaConfig','overcloud-ObjectStorageServiceChain-dequd3rmhxkf-KollaConfig-xrnlifqbprjc','state changed','OS::Heat::Value',NULL,270),(579,'af1553a0-16f6-48d1-8d71-663ee87a56d4','91b09edf-7f19-488f-896a-b6248296e4e5','2026-06-10 07:46:43',NULL,'CREATE','COMPLETE','ExternalPostDeployTasks','overcloud-ComputeServiceChain-xhvnas4abrxo-ExternalPostDeployTasks-pkushofn22yt','state changed','OS::Heat::Value',NULL,271),(580,'8db30bb5-f4f4-4e27-a9ac-a738be1c9da1','6c6b9a1e-bed0-472c-af16-d27293da060e','2026-06-10 07:46:43',NULL,'CREATE','IN_PROGRESS','ExternalPostDeployTasks','overcloud-CellControllerComputeServiceChain-5oe2tf36z5cg-ExternalPostDeployTasks-hktrkafmuhij','state changed','OS::Heat::Value',NULL,268),(581,'05900dd0-1c65-4da1-a881-71898ee6a480','3798ef7d-11ff-4293-878c-a0429431ac48','2026-06-10 07:46:43',NULL,'CREATE','COMPLETE','MonitoringSubscriptionsConfig','overcloud-CellControllerServiceChain-2rvojby7tcbp-MonitoringSubscriptionsConfig-77xrvexuli35','state changed','OS::Heat::Value',NULL,269),(582,'72bbe6f9-4e51-4200-a1c1-f900ace38c7c','8f6c9167-89dc-41b2-9c9e-3779bc4a7cea','2026-06-10 07:46:43',NULL,'CREATE','IN_PROGRESS','GlobalConfigSettings','overcloud-ObjectStorageServiceChain-dequd3rmhxkf-GlobalConfigSettings-hbwn65fsilmu','state changed','OS::Heat::Value',NULL,273),(583,'c4629405-c5f9-43da-a112-d6c78600eeeb','91b09edf-7f19-488f-896a-b6248296e4e5','2026-06-10 07:46:43',NULL,'CREATE','COMPLETE','KeystoneResourcesConfigs','overcloud-ComputeServiceChain-xhvnas4abrxo-KeystoneResourcesConfigs-5ntijhcmy2jl','state changed','OS::Heat::Value',NULL,266),(584,'4a797be7-4155-45d8-aebc-2b5fa569994e','91b09edf-7f19-488f-896a-b6248296e4e5','2026-06-10 07:46:43',NULL,'CREATE','IN_PROGRESS','DeployStepsTasks','overcloud-ComputeServiceChain-xhvnas4abrxo-DeployStepsTasks-r6wcaja2ni62','state changed','OS::Heat::Value',NULL,275),(585,'8c614fbd-9c80-4b15-91d9-810d648cbf5b','8f6c9167-89dc-41b2-9c9e-3779bc4a7cea','2026-06-10 07:46:43',NULL,'CREATE','COMPLETE','KeystoneResourcesConfigs','overcloud-ObjectStorageServiceChain-dequd3rmhxkf-KeystoneResourcesConfigs-cdyq2mduzqld','state changed','OS::Heat::Value',NULL,261),(586,'0ea0c1c4-95d9-4c33-9993-c770e53aa552','6c6b9a1e-bed0-472c-af16-d27293da060e','2026-06-10 07:46:43',NULL,'CREATE','IN_PROGRESS','KollaConfig','overcloud-CellControllerComputeServiceChain-5oe2tf36z5cg-KollaConfig-wvwerhekbwsn','state changed','OS::Heat::Value',NULL,272),(587,'97ba7bec-1e24-4ee5-b620-4ce2b8b9cec8','91b09edf-7f19-488f-896a-b6248296e4e5','2026-06-10 07:46:43',NULL,'CREATE','COMPLETE','DeployStepsTasks','overcloud-ComputeServiceChain-xhvnas4abrxo-DeployStepsTasks-r6wcaja2ni62','state changed','OS::Heat::Value',NULL,275),(588,'2c19c2ef-0406-4c55-a043-4050b50bc5f1','8f6c9167-89dc-41b2-9c9e-3779bc4a7cea','2026-06-10 07:46:43',NULL,'CREATE','IN_PROGRESS','ServiceNames','overcloud-ObjectStorageServiceChain-dequd3rmhxkf-ServiceNames-yitwpdkx256b','state changed','OS::Heat::Value',NULL,279),(589,'90dd8eba-628f-436e-a099-71094dfd677e','8f6c9167-89dc-41b2-9c9e-3779bc4a7cea','2026-06-10 07:46:43',NULL,'CREATE','IN_PROGRESS','DockerConfigScripts','overcloud-ObjectStorageServiceChain-dequd3rmhxkf-DockerConfigScripts-qwag3api5ozn','state changed','OS::Heat::Value',NULL,274),(590,'5ba45a5a-1076-4f53-9b5b-b91bd361fdee','8f6c9167-89dc-41b2-9c9e-3779bc4a7cea','2026-06-10 07:46:43',NULL,'CREATE','COMPLETE','KollaConfig','overcloud-ObjectStorageServiceChain-dequd3rmhxkf-KollaConfig-xrnlifqbprjc','state changed','OS::Heat::Value',NULL,270),(591,'cb50a581-46b4-4478-9c20-1dbea8f885a3','8f6c9167-89dc-41b2-9c9e-3779bc4a7cea','2026-06-10 07:46:43',NULL,'CREATE','COMPLETE','ServiceNames','overcloud-ObjectStorageServiceChain-dequd3rmhxkf-ServiceNames-yitwpdkx256b','state changed','OS::Heat::Value',NULL,279),(592,'c1793020-7adc-4441-8dfb-27f16353ec16','6c6b9a1e-bed0-472c-af16-d27293da060e','2026-06-10 07:46:43',NULL,'CREATE','IN_PROGRESS','UpdateTasks','overcloud-CellControllerComputeServiceChain-5oe2tf36z5cg-UpdateTasks-7m5iacj5mkxb','state changed','OS::Heat::Value',NULL,277),(593,'6176ce96-8582-4ce3-b861-5d5c9f8df8ee','8f6c9167-89dc-41b2-9c9e-3779bc4a7cea','2026-06-10 07:46:43',NULL,'CREATE','COMPLETE','PreDeployStepTasks','overcloud-ObjectStorageServiceChain-dequd3rmhxkf-PreDeployStepTasks-lkzkdwa726rh','state changed','OS::Heat::Value',NULL,265),(594,'5eff6b72-5a9a-4c80-bad2-9aa17db0e3fc','8f6c9167-89dc-41b2-9c9e-3779bc4a7cea','2026-06-10 07:46:43',NULL,'CREATE','COMPLETE','GlobalConfigSettings','overcloud-ObjectStorageServiceChain-dequd3rmhxkf-GlobalConfigSettings-hbwn65fsilmu','state changed','OS::Heat::Value',NULL,273),(595,'26158f47-c24d-4c6f-8072-d74a87e57719','3798ef7d-11ff-4293-878c-a0429431ac48','2026-06-10 07:46:43',NULL,'CREATE','IN_PROGRESS','PreDeployStepTasks','overcloud-CellControllerServiceChain-2rvojby7tcbp-PreDeployStepTasks-dqqnd2zcz7w5','state changed','OS::Heat::Value',NULL,276),(596,'abcdd858-7465-401b-b361-7831f8930ef3','3798ef7d-11ff-4293-878c-a0429431ac48','2026-06-10 07:46:43',NULL,'CREATE','IN_PROGRESS','HostFirewallTasks','overcloud-CellControllerServiceChain-2rvojby7tcbp-HostFirewallTasks-7in5ppi4t35l','state changed','OS::Heat::Value',NULL,281),(597,'531f6028-9a08-43f7-8855-64ab227c78b2','6c6b9a1e-bed0-472c-af16-d27293da060e','2026-06-10 07:46:43',NULL,'CREATE','COMPLETE','UpdateTasks','overcloud-CellControllerComputeServiceChain-5oe2tf36z5cg-UpdateTasks-7m5iacj5mkxb','state changed','OS::Heat::Value',NULL,277),(598,'aa3fbc0b-9b08-474b-909a-66d26ec03edb','3798ef7d-11ff-4293-878c-a0429431ac48','2026-06-10 07:46:43',NULL,'CREATE','COMPLETE','HostFirewallTasks','overcloud-CellControllerServiceChain-2rvojby7tcbp-HostFirewallTasks-7in5ppi4t35l','state changed','OS::Heat::Value',NULL,281),(599,'b0129634-e559-4f02-b3bf-d51f06df6962','3798ef7d-11ff-4293-878c-a0429431ac48','2026-06-10 07:46:43',NULL,'CREATE','IN_PROGRESS','KeystoneResourcesConfigs','overcloud-CellControllerServiceChain-2rvojby7tcbp-KeystoneResourcesConfigs-row24h4qmajc','state changed','OS::Heat::Value',NULL,283),(600,'0d4354a0-d3a5-4fb7-9cd2-ca7a141c6fef','3798ef7d-11ff-4293-878c-a0429431ac48','2026-06-10 07:46:43',NULL,'CREATE','COMPLETE','KeystoneResourcesConfigs','overcloud-CellControllerServiceChain-2rvojby7tcbp-KeystoneResourcesConfigs-row24h4qmajc','state changed','OS::Heat::Value',NULL,283),(601,'0652e07d-a6f6-4bb3-a11b-8026c7bafdca','6c6b9a1e-bed0-472c-af16-d27293da060e','2026-06-10 07:46:43',NULL,'CREATE','COMPLETE','ExternalPostDeployTasks','overcloud-CellControllerComputeServiceChain-5oe2tf36z5cg-ExternalPostDeployTasks-hktrkafmuhij','state changed','OS::Heat::Value',NULL,268),(602,'9c5ca45f-e1ba-42bb-b97e-0a78fc8a464e','91b09edf-7f19-488f-896a-b6248296e4e5','2026-06-10 07:46:43',NULL,'CREATE','IN_PROGRESS','ContainerPuppetTasks','overcloud-ComputeServiceChain-xhvnas4abrxo-ContainerPuppetTasks-fvktbvagvovh','state changed','OS::Heat::Value',NULL,282),(603,'262232a1-c5c5-4683-8cfa-83548959d9ec','8f6c9167-89dc-41b2-9c9e-3779bc4a7cea','2026-06-10 07:46:43',NULL,'CREATE','IN_PROGRESS','HostPrepTasks','overcloud-ObjectStorageServiceChain-dequd3rmhxkf-HostPrepTasks-raxoniripeqf','state changed','OS::Heat::Value',NULL,280),(604,'0499ad3c-a68d-48fb-985a-117cfb9d57a1','91b09edf-7f19-488f-896a-b6248296e4e5','2026-06-10 07:46:43',NULL,'CREATE','IN_PROGRESS','HostPrepTasks','overcloud-ComputeServiceChain-xhvnas4abrxo-HostPrepTasks-d5po35m35d7z','state changed','OS::Heat::Value',NULL,284),(605,'ddac1084-ae1a-4bf5-8ccb-f0412a26d3de','6c6b9a1e-bed0-472c-af16-d27293da060e','2026-06-10 07:46:43',NULL,'CREATE','IN_PROGRESS','DockerConfigScripts','overcloud-CellControllerComputeServiceChain-5oe2tf36z5cg-DockerConfigScripts-3tiq3m33rhcr','state changed','OS::Heat::Value',NULL,286),(606,'b48522ce-f412-486e-b888-47df1853a9d9','6c6b9a1e-bed0-472c-af16-d27293da060e','2026-06-10 07:46:43',NULL,'CREATE','COMPLETE','KollaConfig','overcloud-CellControllerComputeServiceChain-5oe2tf36z5cg-KollaConfig-wvwerhekbwsn','state changed','OS::Heat::Value',NULL,272),(607,'7d7a484f-b6e4-4e48-aba1-df782b788055','8f6c9167-89dc-41b2-9c9e-3779bc4a7cea','2026-06-10 07:46:43',NULL,'CREATE','COMPLETE','DockerConfigScripts','overcloud-ObjectStorageServiceChain-dequd3rmhxkf-DockerConfigScripts-qwag3api5ozn','state changed','OS::Heat::Value',NULL,274),(608,'64285de6-d5b8-4020-a407-3ecd06c59e85','6c6b9a1e-bed0-472c-af16-d27293da060e','2026-06-10 07:46:43',NULL,'CREATE','COMPLETE','DockerConfigScripts','overcloud-CellControllerComputeServiceChain-5oe2tf36z5cg-DockerConfigScripts-3tiq3m33rhcr','state changed','OS::Heat::Value',NULL,286),(609,'e17f66d3-a930-4c4d-b92e-2afd65878cdc','6c6b9a1e-bed0-472c-af16-d27293da060e','2026-06-10 07:46:43',NULL,'CREATE','IN_PROGRESS','IpaRegistrationTasks','overcloud-CellControllerComputeServiceChain-5oe2tf36z5cg-IpaRegistrationTasks-cc6n7lcjsone','state changed','OS::Heat::Value',NULL,285),(610,'4c30175f-3d13-4748-9b53-1baa14249ed1','91b09edf-7f19-488f-896a-b6248296e4e5','2026-06-10 07:46:43',NULL,'CREATE','IN_PROGRESS','ExternalUpgradeTasks','overcloud-ComputeServiceChain-xhvnas4abrxo-ExternalUpgradeTasks-q2xwhc3dm3w4','state changed','OS::Heat::Value',NULL,287),(611,'e2dbe424-e6d3-4080-abe8-f2819908a463','3798ef7d-11ff-4293-878c-a0429431ac48','2026-06-10 07:46:43',NULL,'CREATE','COMPLETE','PreDeployStepTasks','overcloud-CellControllerServiceChain-2rvojby7tcbp-PreDeployStepTasks-dqqnd2zcz7w5','state changed','OS::Heat::Value',NULL,276),(612,'3d4ea75a-24cd-43c0-a78f-d05baf8abf3f','91b09edf-7f19-488f-896a-b6248296e4e5','2026-06-10 07:46:43',NULL,'CREATE','COMPLETE','ExternalUpgradeTasks','overcloud-ComputeServiceChain-xhvnas4abrxo-ExternalUpgradeTasks-q2xwhc3dm3w4','state changed','OS::Heat::Value',NULL,287),(613,'86c2c0e4-48e4-4d91-a4ae-5c64095029c2','3798ef7d-11ff-4293-878c-a0429431ac48','2026-06-10 07:46:43',NULL,'CREATE','IN_PROGRESS','DockerConfigScripts','overcloud-CellControllerServiceChain-2rvojby7tcbp-DockerConfigScripts-dqjb5wboipjx','state changed','OS::Heat::Value',NULL,290),(614,'ff498d07-46fb-4f4d-a580-4b7834c29673','8f6c9167-89dc-41b2-9c9e-3779bc4a7cea','2026-06-10 07:46:43',NULL,'CREATE','COMPLETE','HostPrepTasks','overcloud-ObjectStorageServiceChain-dequd3rmhxkf-HostPrepTasks-raxoniripeqf','state changed','OS::Heat::Value',NULL,280),(615,'b5d11892-90a3-4042-9a4c-39fb5a6aeb2b','91b09edf-7f19-488f-896a-b6248296e4e5','2026-06-10 07:46:43',NULL,'CREATE','COMPLETE','ContainerPuppetTasks','overcloud-ComputeServiceChain-xhvnas4abrxo-ContainerPuppetTasks-fvktbvagvovh','state changed','OS::Heat::Value',NULL,282),(616,'cf88f728-95de-4d4a-9208-e3fe6efcbaef','91b09edf-7f19-488f-896a-b6248296e4e5','2026-06-10 07:46:43',NULL,'CREATE','IN_PROGRESS','UpgradeTasks','overcloud-ComputeServiceChain-xhvnas4abrxo-UpgradeTasks-bessijvderoz','state changed','OS::Heat::Value',NULL,288),(617,'741fcf87-1f78-452b-b664-5cf59ebccb65','3798ef7d-11ff-4293-878c-a0429431ac48','2026-06-10 07:46:43',NULL,'CREATE','COMPLETE','DockerConfigScripts','overcloud-CellControllerServiceChain-2rvojby7tcbp-DockerConfigScripts-dqjb5wboipjx','state changed','OS::Heat::Value',NULL,290),(618,'8a37abee-71b2-45ed-8fa6-27788d53609e','91b09edf-7f19-488f-896a-b6248296e4e5','2026-06-10 07:46:43',NULL,'CREATE','COMPLETE','HostPrepTasks','overcloud-ComputeServiceChain-xhvnas4abrxo-HostPrepTasks-d5po35m35d7z','state changed','OS::Heat::Value',NULL,284),(619,'1845f29e-6dab-4ddf-90af-bf92fa17967e','6c6b9a1e-bed0-472c-af16-d27293da060e','2026-06-10 07:46:43',NULL,'CREATE','IN_PROGRESS','PuppetStepConfig','overcloud-CellControllerComputeServiceChain-5oe2tf36z5cg-PuppetStepConfig-ybdb4xn6zcz2','state changed','OS::Heat::Value',NULL,292),(620,'67e43ed0-9f6a-4562-b599-2f89bdb97725','6c6b9a1e-bed0-472c-af16-d27293da060e','2026-06-10 07:46:43',NULL,'CREATE','IN_PROGRESS','FirewallFrontendRules','overcloud-CellControllerComputeServiceChain-5oe2tf36z5cg-FirewallFrontendRules-ih2hztb5cely','state changed','OS::Heat::Value',NULL,291),(621,'799f44e5-dabc-49b8-9dca-570876b5f491','3798ef7d-11ff-4293-878c-a0429431ac48','2026-06-10 07:46:43',NULL,'CREATE','IN_PROGRESS','DeployStepsTasks','overcloud-CellControllerServiceChain-2rvojby7tcbp-DeployStepsTasks-5axog36yhnig','state changed','OS::Heat::Value',NULL,289),(622,'c0946d43-c2c3-4bd5-a131-068a67c8c0a6','6c6b9a1e-bed0-472c-af16-d27293da060e','2026-06-10 07:46:43',NULL,'CREATE','COMPLETE','PuppetStepConfig','overcloud-CellControllerComputeServiceChain-5oe2tf36z5cg-PuppetStepConfig-ybdb4xn6zcz2','state changed','OS::Heat::Value',NULL,292),(623,'739ccb44-1e85-497a-a884-3715a2de72c5','91b09edf-7f19-488f-896a-b6248296e4e5','2026-06-10 07:46:43',NULL,'CREATE','IN_PROGRESS','DockerConfigScripts','overcloud-ComputeServiceChain-xhvnas4abrxo-DockerConfigScripts-yfalnjvscejv','state changed','OS::Heat::Value',NULL,294),(624,'21bf11e4-069b-41bb-8c01-e9ceb7603e93','6c6b9a1e-bed0-472c-af16-d27293da060e','2026-06-10 07:46:43',NULL,'CREATE','COMPLETE','IpaRegistrationTasks','overcloud-CellControllerComputeServiceChain-5oe2tf36z5cg-IpaRegistrationTasks-cc6n7lcjsone','state changed','OS::Heat::Value',NULL,285),(625,'5d4bc5ed-4211-49fa-948a-79c7af12dd57','91b09edf-7f19-488f-896a-b6248296e4e5','2026-06-10 07:46:43',NULL,'CREATE','COMPLETE','DockerConfigScripts','overcloud-ComputeServiceChain-xhvnas4abrxo-DockerConfigScripts-yfalnjvscejv','state changed','OS::Heat::Value',NULL,294),(626,'722578ea-5d54-4b8f-be87-69db3b9b6963','91b09edf-7f19-488f-896a-b6248296e4e5','2026-06-10 07:46:43',NULL,'CREATE','COMPLETE','UpgradeTasks','overcloud-ComputeServiceChain-xhvnas4abrxo-UpgradeTasks-bessijvderoz','state changed','OS::Heat::Value',NULL,288),(627,'36dd8ac5-cfc4-428b-a373-7c80944d5da3','91b09edf-7f19-488f-896a-b6248296e4e5','2026-06-10 07:46:43',NULL,'CREATE','IN_PROGRESS','PuppetConfig','overcloud-ComputeServiceChain-xhvnas4abrxo-PuppetConfig-yy2qcwhy6zrm','state changed','OS::Heat::Value',NULL,293),(628,'2ddeb6e3-af57-461c-bab3-e94cbfdd58f7','3798ef7d-11ff-4293-878c-a0429431ac48','2026-06-10 07:46:43',NULL,'CREATE','IN_PROGRESS','KollaConfig','overcloud-CellControllerServiceChain-2rvojby7tcbp-KollaConfig-7t6axthzhmo4','state changed','OS::Heat::Value',NULL,296),(629,'07efff1e-537a-438a-908b-fee4b10cf0a2','3798ef7d-11ff-4293-878c-a0429431ac48','2026-06-10 07:46:43',NULL,'CREATE','IN_PROGRESS','ExternalDeployTasks','overcloud-CellControllerServiceChain-2rvojby7tcbp-ExternalDeployTasks-sfespz2b6y7z','state changed','OS::Heat::Value',NULL,295),(630,'9c5be65b-16ed-4ec0-b147-2c99e5d3d85d','6c6b9a1e-bed0-472c-af16-d27293da060e','2026-06-10 07:46:43',NULL,'CREATE','COMPLETE','FirewallFrontendRules','overcloud-CellControllerComputeServiceChain-5oe2tf36z5cg-FirewallFrontendRules-ih2hztb5cely','state changed','OS::Heat::Value',NULL,291),(631,'8559bad5-a9f5-4f91-836f-948ba2daa751','8f6c9167-89dc-41b2-9c9e-3779bc4a7cea','2026-06-10 07:46:43',NULL,'CREATE','COMPLETE','overcloud-ObjectStorageServiceChain-dequd3rmhxkf','8f6c9167-89dc-41b2-9c9e-3779bc4a7cea','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(632,'820cc86d-f297-45cc-8cde-9089925e1ccb','3798ef7d-11ff-4293-878c-a0429431ac48','2026-06-10 07:46:43',NULL,'CREATE','COMPLETE','KollaConfig','overcloud-CellControllerServiceChain-2rvojby7tcbp-KollaConfig-7t6axthzhmo4','state changed','OS::Heat::Value',NULL,296),(633,'a32e0350-8b61-4643-8721-2d8146419e54','3798ef7d-11ff-4293-878c-a0429431ac48','2026-06-10 07:46:43',NULL,'CREATE','COMPLETE','DeployStepsTasks','overcloud-CellControllerServiceChain-2rvojby7tcbp-DeployStepsTasks-5axog36yhnig','state changed','OS::Heat::Value',NULL,289),(634,'5558008a-969a-46e6-9fd5-54b9da05544b','6c6b9a1e-bed0-472c-af16-d27293da060e','2026-06-10 07:46:43',NULL,'CREATE','IN_PROGRESS','ExternalUpdateTasks','overcloud-CellControllerComputeServiceChain-5oe2tf36z5cg-ExternalUpdateTasks-puopelvvn3vd','state changed','OS::Heat::Value',NULL,297),(635,'34509bed-b958-43fc-bb37-31aa3cc46a6d','6c6b9a1e-bed0-472c-af16-d27293da060e','2026-06-10 07:46:43',NULL,'CREATE','IN_PROGRESS','MonitoringSubscriptionsConfig','overcloud-CellControllerComputeServiceChain-5oe2tf36z5cg-MonitoringSubscriptionsConfig-wyu75q6gmaco','state changed','OS::Heat::Value',NULL,300),(636,'1130d757-0d18-4e8f-8657-6ff8b6ad7a79','91b09edf-7f19-488f-896a-b6248296e4e5','2026-06-10 07:46:43',NULL,'CREATE','IN_PROGRESS','ExternalDeployTasks','overcloud-ComputeServiceChain-xhvnas4abrxo-ExternalDeployTasks-lyrf7hcwqohw','state changed','OS::Heat::Value',NULL,299),(637,'2ab5de38-4f0c-4f27-9a47-688d9e61fc71','6c6b9a1e-bed0-472c-af16-d27293da060e','2026-06-10 07:46:43',NULL,'CREATE','COMPLETE','MonitoringSubscriptionsConfig','overcloud-CellControllerComputeServiceChain-5oe2tf36z5cg-MonitoringSubscriptionsConfig-wyu75q6gmaco','state changed','OS::Heat::Value',NULL,300),(638,'23cfab0d-a73f-43bd-a9ad-ab7197945267','91b09edf-7f19-488f-896a-b6248296e4e5','2026-06-10 07:46:43',NULL,'CREATE','IN_PROGRESS','MonitoringSubscriptionsConfig','overcloud-ComputeServiceChain-xhvnas4abrxo-MonitoringSubscriptionsConfig-k7tp3jvju6bc','state changed','OS::Heat::Value',NULL,301),(639,'487e667c-1298-4e1a-bf68-aacbf1158e94','91b09edf-7f19-488f-896a-b6248296e4e5','2026-06-10 07:46:43',NULL,'CREATE','COMPLETE','PuppetConfig','overcloud-ComputeServiceChain-xhvnas4abrxo-PuppetConfig-yy2qcwhy6zrm','state changed','OS::Heat::Value',NULL,293),(640,'03bcce00-45d3-4b2d-bafd-3db631c6a721','3798ef7d-11ff-4293-878c-a0429431ac48','2026-06-10 07:46:43',NULL,'CREATE','COMPLETE','ExternalDeployTasks','overcloud-CellControllerServiceChain-2rvojby7tcbp-ExternalDeployTasks-sfespz2b6y7z','state changed','OS::Heat::Value',NULL,295),(641,'e27c3cb4-9542-413b-b398-265c3d30345f','91b09edf-7f19-488f-896a-b6248296e4e5','2026-06-10 07:46:43',NULL,'CREATE','COMPLETE','MonitoringSubscriptionsConfig','overcloud-ComputeServiceChain-xhvnas4abrxo-MonitoringSubscriptionsConfig-k7tp3jvju6bc','state changed','OS::Heat::Value',NULL,301),(642,'2f49e79f-922e-4f13-b91e-7426c8c3abf1','91b09edf-7f19-488f-896a-b6248296e4e5','2026-06-10 07:46:43',NULL,'CREATE','IN_PROGRESS','UpgradeBatchTasks','overcloud-ComputeServiceChain-xhvnas4abrxo-UpgradeBatchTasks-soht6j6abqqi','state changed','OS::Heat::Value',NULL,304),(643,'e1511b12-45df-4173-a0b9-93a06d0a454d','6c6b9a1e-bed0-472c-af16-d27293da060e','2026-06-10 07:46:43',NULL,'CREATE','IN_PROGRESS','DeployStepsTasks','overcloud-CellControllerComputeServiceChain-5oe2tf36z5cg-DeployStepsTasks-52anksrakjuf','state changed','OS::Heat::Value',NULL,303),(644,'1a0d4e1c-650d-44f3-b758-f6ce9a7299e5','3798ef7d-11ff-4293-878c-a0429431ac48','2026-06-10 07:46:43',NULL,'CREATE','IN_PROGRESS','ScaleTasks','overcloud-CellControllerServiceChain-2rvojby7tcbp-ScaleTasks-eexldf7nb4bb','state changed','OS::Heat::Value',NULL,302),(645,'f8aef844-cbce-4a5e-b1a5-6f2998cfc4e4','91b09edf-7f19-488f-896a-b6248296e4e5','2026-06-10 07:46:43',NULL,'CREATE','COMPLETE','UpgradeBatchTasks','overcloud-ComputeServiceChain-xhvnas4abrxo-UpgradeBatchTasks-soht6j6abqqi','state changed','OS::Heat::Value',NULL,304),(646,'362b841a-c0cf-4c2e-83bf-f5c18d3b4a24','2ee7a31b-abeb-4c25-930b-397eab924de7','2026-06-10 07:46:43',NULL,'CREATE','COMPLETE','overcloud-CephStorageServiceChain-zf4ksr3szeyt','2ee7a31b-abeb-4c25-930b-397eab924de7','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(647,'bab9e3bb-ed39-42ad-9333-0744b51a092d','6c6b9a1e-bed0-472c-af16-d27293da060e','2026-06-10 07:46:43',NULL,'CREATE','COMPLETE','ExternalUpdateTasks','overcloud-CellControllerComputeServiceChain-5oe2tf36z5cg-ExternalUpdateTasks-puopelvvn3vd','state changed','OS::Heat::Value',NULL,297),(648,'0e2fa690-8ca5-4fb9-9f77-39acfb1e51ac','91b09edf-7f19-488f-896a-b6248296e4e5','2026-06-10 07:46:43',NULL,'CREATE','COMPLETE','ExternalDeployTasks','overcloud-ComputeServiceChain-xhvnas4abrxo-ExternalDeployTasks-lyrf7hcwqohw','state changed','OS::Heat::Value',NULL,299),(649,'ac59afad-58ef-4c76-8c37-4b9ab35cd8d9','91b09edf-7f19-488f-896a-b6248296e4e5','2026-06-10 07:46:43',NULL,'CREATE','IN_PROGRESS','UpdateTasks','overcloud-ComputeServiceChain-xhvnas4abrxo-UpdateTasks-xa5oykxtozdf','state changed','OS::Heat::Value',NULL,305),(650,'c162b914-014e-40de-a4a6-8e6c2666b9ad','91b09edf-7f19-488f-896a-b6248296e4e5','2026-06-10 07:46:43',NULL,'CREATE','COMPLETE','UpdateTasks','overcloud-ComputeServiceChain-xhvnas4abrxo-UpdateTasks-xa5oykxtozdf','state changed','OS::Heat::Value',NULL,305),(651,'6d5bdf45-57c8-4f8e-a0c4-fa39f92aef68','6c6b9a1e-bed0-472c-af16-d27293da060e','2026-06-10 07:46:43',NULL,'CREATE','IN_PROGRESS','KeystoneResourcesConfigs','overcloud-CellControllerComputeServiceChain-5oe2tf36z5cg-KeystoneResourcesConfigs-hqthi7dvtkmg','state changed','OS::Heat::Value',NULL,308),(652,'fa0ce73f-be27-468c-b821-07f8566651d1','6c6b9a1e-bed0-472c-af16-d27293da060e','2026-06-10 07:46:43',NULL,'CREATE','COMPLETE','DeployStepsTasks','overcloud-CellControllerComputeServiceChain-5oe2tf36z5cg-DeployStepsTasks-52anksrakjuf','state changed','OS::Heat::Value',NULL,303),(653,'422a9f08-a126-4af4-a27e-33ac97025637','91b09edf-7f19-488f-896a-b6248296e4e5','2026-06-10 07:46:43',NULL,'CREATE','IN_PROGRESS','PostUpgradeTasks','overcloud-ComputeServiceChain-xhvnas4abrxo-PostUpgradeTasks-dlaotuwogrww','state changed','OS::Heat::Value',NULL,307),(654,'441b7b00-0d97-471f-88ec-ad1bdb4fb1eb','6c6b9a1e-bed0-472c-af16-d27293da060e','2026-06-10 07:46:43',NULL,'CREATE','COMPLETE','KeystoneResourcesConfigs','overcloud-CellControllerComputeServiceChain-5oe2tf36z5cg-KeystoneResourcesConfigs-hqthi7dvtkmg','state changed','OS::Heat::Value',NULL,308),(655,'c9372555-466b-4055-8cca-29544cf7e73d','3798ef7d-11ff-4293-878c-a0429431ac48','2026-06-10 07:46:43',NULL,'CREATE','COMPLETE','ScaleTasks','overcloud-CellControllerServiceChain-2rvojby7tcbp-ScaleTasks-eexldf7nb4bb','state changed','OS::Heat::Value',NULL,302),(656,'da0c48a4-5fd6-4747-8070-7d3ee3779341','6c6b9a1e-bed0-472c-af16-d27293da060e','2026-06-10 07:46:43',NULL,'CREATE','IN_PROGRESS','ServiceNames','overcloud-CellControllerComputeServiceChain-5oe2tf36z5cg-ServiceNames-6rmvyna2e2ul','state changed','OS::Heat::Value',NULL,306),(657,'44927f7a-e188-4d68-87b8-47209520b5c1','63c9cc63-2dcd-4378-8459-4b9e0f6f08b8','2026-06-10 07:46:43',NULL,'CREATE','COMPLETE','overcloud-BlockStorageServiceChain-m3ph455dvrx7','63c9cc63-2dcd-4378-8459-4b9e0f6f08b8','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(658,'b7bf1d66-7fc6-42f8-86cc-44fd29191cfb','6c6b9a1e-bed0-472c-af16-d27293da060e','2026-06-10 07:46:43',NULL,'CREATE','IN_PROGRESS','ServiceServerMetadataHook','overcloud-CellControllerComputeServiceChain-5oe2tf36z5cg-ServiceServerMetadataHook-gctrra2wrlpm','state changed','OS::TripleO::CellControllerComputeServiceServerMetadataHook',NULL,NULL),(659,'4f731027-4bcc-4105-a860-9c96fb3ac722','91b09edf-7f19-488f-896a-b6248296e4e5','2026-06-10 07:46:43',NULL,'CREATE','IN_PROGRESS','PreDeployStepTasks','overcloud-ComputeServiceChain-xhvnas4abrxo-PreDeployStepTasks-oyhact2iuddn','state changed','OS::Heat::Value',NULL,309),(660,'ee9dd26b-3a87-4125-883d-c076a1fa5066','91b09edf-7f19-488f-896a-b6248296e4e5','2026-06-10 07:46:43',NULL,'CREATE','COMPLETE','PostUpgradeTasks','overcloud-ComputeServiceChain-xhvnas4abrxo-PostUpgradeTasks-dlaotuwogrww','state changed','OS::Heat::Value',NULL,307),(661,'e02389ef-adbe-4ef1-8347-9837ca30a8ab','6c6b9a1e-bed0-472c-af16-d27293da060e','2026-06-10 07:46:43',NULL,'CREATE','COMPLETE','ServiceNames','overcloud-CellControllerComputeServiceChain-5oe2tf36z5cg-ServiceNames-6rmvyna2e2ul','state changed','OS::Heat::Value',NULL,306),(662,'89b6033e-f593-4e95-91ff-b9346d18a1e0','91b09edf-7f19-488f-896a-b6248296e4e5','2026-06-10 07:46:43',NULL,'CREATE','IN_PROGRESS','KollaConfig','overcloud-ComputeServiceChain-xhvnas4abrxo-KollaConfig-o2kjui4s4kwg','state changed','OS::Heat::Value',NULL,310),(663,'7f282fb5-0e1f-4c76-9f6b-019c07e5760e','6c6b9a1e-bed0-472c-af16-d27293da060e','2026-06-10 07:46:43',NULL,'CREATE','IN_PROGRESS','PostUpgradeTasks','overcloud-CellControllerComputeServiceChain-5oe2tf36z5cg-PostUpgradeTasks-ooddmefu67rr','state changed','OS::Heat::Value',NULL,312),(664,'373d91ae-30e0-4159-b153-55035657631e','3798ef7d-11ff-4293-878c-a0429431ac48','2026-06-10 07:46:43',NULL,'CREATE','COMPLETE','overcloud-CellControllerServiceChain-2rvojby7tcbp','3798ef7d-11ff-4293-878c-a0429431ac48','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(665,'0c77ec3c-53ce-474f-b139-503ea23a8212','6c6b9a1e-bed0-472c-af16-d27293da060e','2026-06-10 07:46:43',NULL,'CREATE','COMPLETE','ServiceServerMetadataHook','34941fb0-641f-43f8-aa56-f83264b8f911','state changed','OS::TripleO::CellControllerComputeServiceServerMetadataHook',NULL,NULL),(666,'d10d2fd3-cbdc-40ff-90f7-da6ff96a77f8','6c6b9a1e-bed0-472c-af16-d27293da060e','2026-06-10 07:46:43',NULL,'CREATE','IN_PROGRESS','FirewallRules','overcloud-CellControllerComputeServiceChain-5oe2tf36z5cg-FirewallRules-bjdkudkelrh2','state changed','OS::Heat::Value',NULL,313),(667,'45fee77b-f5af-4144-aa4b-3170aa2c075e','6c6b9a1e-bed0-472c-af16-d27293da060e','2026-06-10 07:46:43',NULL,'CREATE','COMPLETE','PostUpgradeTasks','overcloud-CellControllerComputeServiceChain-5oe2tf36z5cg-PostUpgradeTasks-ooddmefu67rr','state changed','OS::Heat::Value',NULL,312),(668,'f3523c90-56f3-44de-b434-2e8c2a69afd8','91b09edf-7f19-488f-896a-b6248296e4e5','2026-06-10 07:46:43',NULL,'CREATE','COMPLETE','PreDeployStepTasks','overcloud-ComputeServiceChain-xhvnas4abrxo-PreDeployStepTasks-oyhact2iuddn','state changed','OS::Heat::Value',NULL,309),(669,'a9da6a6a-389f-44b4-95f7-b5058067f1dc','91b09edf-7f19-488f-896a-b6248296e4e5','2026-06-10 07:46:43',NULL,'CREATE','IN_PROGRESS','PostUpdateTasks','overcloud-ComputeServiceChain-xhvnas4abrxo-PostUpdateTasks-xaqzzc35crgl','state changed','OS::Heat::Value',NULL,314),(670,'8fdfe34c-4995-4ddb-92bc-a04120adf422','91b09edf-7f19-488f-896a-b6248296e4e5','2026-06-10 07:46:43',NULL,'CREATE','COMPLETE','KollaConfig','overcloud-ComputeServiceChain-xhvnas4abrxo-KollaConfig-o2kjui4s4kwg','state changed','OS::Heat::Value',NULL,310),(671,'a436db88-10ee-4cdc-9a66-6bbeb284fc15','6c6b9a1e-bed0-472c-af16-d27293da060e','2026-06-10 07:46:43',NULL,'CREATE','COMPLETE','FirewallRules','overcloud-CellControllerComputeServiceChain-5oe2tf36z5cg-FirewallRules-bjdkudkelrh2','state changed','OS::Heat::Value',NULL,313),(672,'ba5e182b-d110-43ba-a760-210e19bf84bc','91b09edf-7f19-488f-896a-b6248296e4e5','2026-06-10 07:46:43',NULL,'CREATE','IN_PROGRESS','FirewallRules','overcloud-ComputeServiceChain-xhvnas4abrxo-FirewallRules-t7fawv637ime','state changed','OS::Heat::Value',NULL,315),(673,'44115b22-20e9-438b-ae10-37f3c495532b','91b09edf-7f19-488f-896a-b6248296e4e5','2026-06-10 07:46:43',NULL,'CREATE','IN_PROGRESS','HostFirewallTasks','overcloud-ComputeServiceChain-xhvnas4abrxo-HostFirewallTasks-m56elizhl5bk','state changed','OS::Heat::Value',NULL,316),(674,'66b0c89a-6a66-4082-a4ce-6cadf81a7ad4','91b09edf-7f19-488f-896a-b6248296e4e5','2026-06-10 07:46:43',NULL,'CREATE','COMPLETE','PostUpdateTasks','overcloud-ComputeServiceChain-xhvnas4abrxo-PostUpdateTasks-xaqzzc35crgl','state changed','OS::Heat::Value',NULL,314),(675,'af3ee114-e625-418d-8aa3-69f1bf3e7db9','91b09edf-7f19-488f-896a-b6248296e4e5','2026-06-10 07:46:43',NULL,'CREATE','COMPLETE','FirewallRules','overcloud-ComputeServiceChain-xhvnas4abrxo-FirewallRules-t7fawv637ime','state changed','OS::Heat::Value',NULL,315),(676,'050d3920-8163-4ab9-97bc-8318bdd3556f','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:43',NULL,'CREATE','COMPLETE','ObjectStorageServiceChain','8f6c9167-89dc-41b2-9c9e-3779bc4a7cea','state changed','OS::TripleO::ObjectStorageServices',NULL,79),(677,'883d9112-da08-4e66-8350-ad3700800eaf','91b09edf-7f19-488f-896a-b6248296e4e5','2026-06-10 07:46:43',NULL,'CREATE','COMPLETE','HostFirewallTasks','overcloud-ComputeServiceChain-xhvnas4abrxo-HostFirewallTasks-m56elizhl5bk','state changed','OS::Heat::Value',NULL,316),(678,'5f90ff03-fcd1-4aa9-a0a6-a51bd94cd58a','91b09edf-7f19-488f-896a-b6248296e4e5','2026-06-10 07:46:43',NULL,'CREATE','IN_PROGRESS','DockerConfig','overcloud-ComputeServiceChain-xhvnas4abrxo-DockerConfig-yl72i7omdgt2','state changed','OS::Heat::Value',NULL,318),(679,'a402be96-e9e8-4494-9065-3af3184d7378','91b09edf-7f19-488f-896a-b6248296e4e5','2026-06-10 07:46:43',NULL,'CREATE','IN_PROGRESS','AnsibleGroupVars','overcloud-ComputeServiceChain-xhvnas4abrxo-AnsibleGroupVars-vzetutmnkjpa','state changed','OS::Heat::Value',NULL,319),(680,'fa0ad5a0-1b1d-4dc2-962c-081857030daf','6c6b9a1e-bed0-472c-af16-d27293da060e','2026-06-10 07:46:43',NULL,'CREATE','COMPLETE','overcloud-CellControllerComputeServiceChain-5oe2tf36z5cg','6c6b9a1e-bed0-472c-af16-d27293da060e','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(681,'346d39dd-1be1-4662-a404-b7b774efcd9a','91b09edf-7f19-488f-896a-b6248296e4e5','2026-06-10 07:46:43',NULL,'CREATE','COMPLETE','DockerConfig','overcloud-ComputeServiceChain-xhvnas4abrxo-DockerConfig-yl72i7omdgt2','state changed','OS::Heat::Value',NULL,318),(682,'4f2845c2-70b1-45a3-b010-dd4589bd7dcd','91b09edf-7f19-488f-896a-b6248296e4e5','2026-06-10 07:46:43',NULL,'CREATE','COMPLETE','AnsibleGroupVars','overcloud-ComputeServiceChain-xhvnas4abrxo-AnsibleGroupVars-vzetutmnkjpa','state changed','OS::Heat::Value',NULL,319),(683,'90521e08-b67c-4fa3-83a8-1f8a5e13fc94','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:43',NULL,'CREATE','COMPLETE','CellControllerServiceChain','3798ef7d-11ff-4293-878c-a0429431ac48','state changed','OS::TripleO::CellControllerServices',NULL,82),(684,'0d668179-a77f-40db-99eb-8cde6d02c12f','91b09edf-7f19-488f-896a-b6248296e4e5','2026-06-10 07:46:44',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-xhvnas4abrxo','91b09edf-7f19-488f-896a-b6248296e4e5','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(685,'473dfcc6-268c-49d4-9929-04a1716fb008','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:44',NULL,'CREATE','COMPLETE','NetworkerServiceChain','67c8c988-b2f5-467c-a3c6-b667d3637fef','state changed','OS::TripleO::NetworkerServices',NULL,85),(686,'197c1cc3-4771-4e17-86fc-c587d28120e4','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:44',NULL,'CREATE','COMPLETE','BlockStorageServiceChain','63c9cc63-2dcd-4378-8459-4b9e0f6f08b8','state changed','OS::TripleO::BlockStorageServices',NULL,86),(687,'02ae736c-0b10-4f21-b553-b612f5594528','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:44',NULL,'CREATE','COMPLETE','CephStorageServiceChain','2ee7a31b-abeb-4c25-930b-397eab924de7','state changed','OS::TripleO::CephStorageServices',NULL,87),(688,'5e4acbec-07d5-4e5a-a3da-d7b9edaa0e54','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:44',NULL,'CREATE','IN_PROGRESS','ObjectStorageServiceChainRoleData','overcloud-ObjectStorageServiceChainRoleData-rfcdbbdiumg5','state changed','OS::Heat::Value',NULL,454),(689,'571d52c3-2dbe-4f7a-85d2-c811b95abf5c','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:44',NULL,'CREATE','IN_PROGRESS','CellControllerServiceChainRoleData','overcloud-CellControllerServiceChainRoleData-aadfdo5ule4j','state changed','OS::Heat::Value',NULL,455),(690,'8e038404-285c-4322-ad15-e691136a0d8c','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:44',NULL,'CREATE','COMPLETE','ObjectStorageServiceChainRoleData','overcloud-ObjectStorageServiceChainRoleData-rfcdbbdiumg5','state changed','OS::Heat::Value',NULL,454),(691,'bdb8d954-2700-4999-8f43-638cf806a4c6','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:44',NULL,'CREATE','COMPLETE','CellControllerServiceChainRoleData','overcloud-CellControllerServiceChainRoleData-aadfdo5ule4j','state changed','OS::Heat::Value',NULL,455),(692,'31e9abab-f38a-46bd-ba41-6686bb92f142','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:44',NULL,'CREATE','COMPLETE','CellControllerComputeServiceChain','6c6b9a1e-bed0-472c-af16-d27293da060e','state changed','OS::TripleO::CellControllerComputeServices',NULL,83),(693,'f94bed62-94e4-476b-b647-d5745b9b0c75','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:44',NULL,'CREATE','IN_PROGRESS','CephStorageServiceChainRoleData','overcloud-CephStorageServiceChainRoleData-zxzzdywx5jqj','state changed','OS::Heat::Value',NULL,479),(694,'8e170f6b-309b-44fd-b6ab-7c475ee3b9e0','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:44',NULL,'CREATE','COMPLETE','CephStorageServiceChainRoleData','overcloud-CephStorageServiceChainRoleData-zxzzdywx5jqj','state changed','OS::Heat::Value',NULL,479),(695,'349e602f-b848-4e21-ae63-a59a25765495','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:44',NULL,'CREATE','IN_PROGRESS','BlockStorageServiceChainRoleData','overcloud-BlockStorageServiceChainRoleData-6azxpzamuu3q','state changed','OS::Heat::Value',NULL,480),(696,'61434999-7208-4357-9381-296d75ff94c0','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:44',NULL,'CREATE','IN_PROGRESS','CellControllerServiceNames','overcloud-CellControllerServiceNames-qw4kqzakruzn','state changed','OS::Heat::Value',NULL,481),(697,'0bee546c-8b60-4769-a053-965e79dd2037','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:44',NULL,'CREATE','IN_PROGRESS','ObjectStorageServiceNames','overcloud-ObjectStorageServiceNames-audswo6k7vr6','state changed','OS::Heat::Value',NULL,484),(698,'2ea83719-a676-4a7d-88ee-42df9ec27b21','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:44',NULL,'CREATE','COMPLETE','CellControllerServiceNames','overcloud-CellControllerServiceNames-qw4kqzakruzn','state changed','OS::Heat::Value',NULL,481),(699,'b294c172-c94b-4226-8101-e38260ebd15d','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:44',NULL,'CREATE','COMPLETE','BlockStorageServiceChainRoleData','overcloud-BlockStorageServiceChainRoleData-6azxpzamuu3q','state changed','OS::Heat::Value',NULL,480),(700,'640f35d8-7d57-4540-ac77-824cef345965','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:44',NULL,'CREATE','COMPLETE','ObjectStorageServiceNames','overcloud-ObjectStorageServiceNames-audswo6k7vr6','state changed','OS::Heat::Value',NULL,484),(701,'971e95ae-2be8-44b5-8795-78341e150530','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:44',NULL,'CREATE','COMPLETE','ComputeServiceChain','91b09edf-7f19-488f-896a-b6248296e4e5','state changed','OS::TripleO::ComputeServices',NULL,81),(702,'8558af11-0331-48c2-ad96-c3e46f67456e','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:44',NULL,'CREATE','IN_PROGRESS','CephStorageServiceNames','overcloud-CephStorageServiceNames-47ujyzuztssb','state changed','OS::Heat::Value',NULL,496),(703,'3e971899-e0de-4265-8d42-4bed0c1ad021','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:44',NULL,'CREATE','IN_PROGRESS','ObjectStorage','overcloud-ObjectStorage-pcasrmzthmi6','state changed','OS::Heat::ResourceGroup',NULL,498),(704,'28745f70-bc54-482c-8fa9-abb32b5b7809','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:44',NULL,'CREATE','COMPLETE','CephStorageServiceNames','overcloud-CephStorageServiceNames-47ujyzuztssb','state changed','OS::Heat::Value',NULL,496),(705,'bb696ebd-7f01-4b66-9581-e14ccb571b99','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:44',NULL,'CREATE','IN_PROGRESS','NetworkerServiceChainRoleData','overcloud-NetworkerServiceChainRoleData-4ead3bfvmmnj','state changed','OS::Heat::Value',NULL,503),(706,'48776f9e-f4d9-4c7e-b9ed-d6b5a4da4c62','c63c9c22-62fa-4f3c-b8b0-88ecb5831d99','2026-06-10 07:46:45',NULL,'CREATE','IN_PROGRESS','overcloud-ObjectStorage-pcasrmzthmi6','c63c9c22-62fa-4f3c-b8b0-88ecb5831d99','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(707,'a1929d6f-db86-4d52-8899-68463c0a7c5d','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:45',NULL,'CREATE','COMPLETE','NetworkerServiceChainRoleData','overcloud-NetworkerServiceChainRoleData-4ead3bfvmmnj','state changed','OS::Heat::Value',NULL,503),(708,'b49cb35b-208c-4a03-bc05-fa2c75c20eff','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:45',NULL,'CREATE','IN_PROGRESS','BlockStorageServiceNames','overcloud-BlockStorageServiceNames-agmhvgtwu25a','state changed','OS::Heat::Value',NULL,505),(709,'dc7586c6-86c4-4d6e-beb2-998d13ae43bd','c63c9c22-62fa-4f3c-b8b0-88ecb5831d99','2026-06-10 07:46:45',NULL,'CREATE','COMPLETE','overcloud-ObjectStorage-pcasrmzthmi6','c63c9c22-62fa-4f3c-b8b0-88ecb5831d99','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(710,'2ab58499-0d35-4a42-ac00-9c92ad9f179f','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:45',NULL,'CREATE','COMPLETE','BlockStorageServiceNames','overcloud-BlockStorageServiceNames-agmhvgtwu25a','state changed','OS::Heat::Value',NULL,505),(711,'1e5bfc62-2de6-40bb-9a0b-c546086237d2','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:45',NULL,'CREATE','IN_PROGRESS','CellController','overcloud-CellController-m2usbqp6jrkz','state changed','OS::Heat::ResourceGroup',NULL,511),(712,'558021b7-a60d-4a96-8c4e-26ec5b494ea8','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:45',NULL,'CREATE','IN_PROGRESS','NetworkerServiceNames','overcloud-NetworkerServiceNames-2x3zbmdgmlsj','state changed','OS::Heat::Value',NULL,521),(713,'a0e559a5-3e75-4770-b9e8-4c012a2d8d1f','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:45',NULL,'CREATE','IN_PROGRESS','BlockStorage','overcloud-BlockStorage-2cuwc4g5m2g4','state changed','OS::Heat::ResourceGroup',NULL,523),(714,'0669dbde-39e4-4abc-8c74-fd51414a193b','617c14f3-d066-405b-ae18-39284ca64c6b','2026-06-10 07:46:45',NULL,'CREATE','IN_PROGRESS','overcloud-CellController-m2usbqp6jrkz','617c14f3-d066-405b-ae18-39284ca64c6b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(715,'14d5849f-8141-4410-9314-a954b77325fd','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:45',NULL,'CREATE','COMPLETE','NetworkerServiceNames','overcloud-NetworkerServiceNames-2x3zbmdgmlsj','state changed','OS::Heat::Value',NULL,521),(716,'9cd836d7-bd24-435c-94c2-4693a8275dfa','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:45',NULL,'CREATE','IN_PROGRESS','CephStorage','overcloud-CephStorage-hsfep4lr43fv','state changed','OS::Heat::ResourceGroup',NULL,530),(717,'11c5ccb5-64ed-415a-8830-b5e7f48b1651','617c14f3-d066-405b-ae18-39284ca64c6b','2026-06-10 07:46:45',NULL,'CREATE','COMPLETE','overcloud-CellController-m2usbqp6jrkz','617c14f3-d066-405b-ae18-39284ca64c6b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(718,'03a0dc5e-8195-4a83-883a-b9fb77646d78','46d49c6c-9298-4d45-ae83-0403f6f97e31','2026-06-10 07:46:45',NULL,'CREATE','IN_PROGRESS','overcloud-BlockStorage-2cuwc4g5m2g4','46d49c6c-9298-4d45-ae83-0403f6f97e31','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(719,'e73275b0-b0dd-4824-bddf-11ae0a106fca','8e957f11-d713-48b5-9fe1-3fca077b6cca','2026-06-10 07:46:45',NULL,'CREATE','IN_PROGRESS','overcloud-CephStorage-hsfep4lr43fv','8e957f11-d713-48b5-9fe1-3fca077b6cca','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(720,'174610e2-43e6-459d-b771-efe030640bab','46d49c6c-9298-4d45-ae83-0403f6f97e31','2026-06-10 07:46:45',NULL,'CREATE','COMPLETE','overcloud-BlockStorage-2cuwc4g5m2g4','46d49c6c-9298-4d45-ae83-0403f6f97e31','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(721,'41431504-85e2-44c6-b2d6-6d26c12deb3a','8e957f11-d713-48b5-9fe1-3fca077b6cca','2026-06-10 07:46:45',NULL,'CREATE','COMPLETE','overcloud-CephStorage-hsfep4lr43fv','8e957f11-d713-48b5-9fe1-3fca077b6cca','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(722,'43aa0fc0-bddc-4978-9298-61ecd9947a4b','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:45',NULL,'CREATE','IN_PROGRESS','Networker','overcloud-Networker-nnfspntbjc23','state changed','OS::Heat::ResourceGroup',NULL,557),(723,'c1cccc90-41aa-4df2-beac-0581177188d6','af73cc34-122c-4733-88b8-1887cca2d3de','2026-06-10 07:46:45',NULL,'CREATE','IN_PROGRESS','overcloud-Networker-nnfspntbjc23','af73cc34-122c-4733-88b8-1887cca2d3de','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(724,'d7b388fe-87ba-4f7d-adfc-a7d2e8f92b1b','af73cc34-122c-4733-88b8-1887cca2d3de','2026-06-10 07:46:45',NULL,'CREATE','COMPLETE','overcloud-Networker-nnfspntbjc23','af73cc34-122c-4733-88b8-1887cca2d3de','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(725,'fb389389-f3b2-429e-bc99-9a96e96640cf','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:45',NULL,'CREATE','IN_PROGRESS','CellControllerComputeServiceChainRoleData','overcloud-CellControllerComputeServiceChainRoleData-tj6xrfuwhpay','state changed','OS::Heat::Value',NULL,573),(726,'307a245e-023d-4db0-93e9-28b2783d737a','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:46:45',NULL,'CREATE','IN_PROGRESS','2','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-2-bkt35t54jp2p','state changed','OS::TripleO::Services::CeilometerAgentCentral',NULL,576),(727,'ebbde129-020b-4726-8dc1-60be36a33a73','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:45',NULL,'CREATE','COMPLETE','CellControllerComputeServiceChainRoleData','overcloud-CellControllerComputeServiceChainRoleData-tj6xrfuwhpay','state changed','OS::Heat::Value',NULL,573),(728,'508eb0f3-0440-4ebd-a116-97d5c0c78b07','a462a8f1-4e1d-4cba-bff8-3d67b3a09f4b','2026-06-10 07:46:45',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-2-bkt35t54jp2p','a462a8f1-4e1d-4cba-bff8-3d67b3a09f4b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(729,'f866b2e7-920e-4567-9746-cc4a8e602951','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:45',NULL,'CREATE','IN_PROGRESS','ComputeServiceChainRoleData','overcloud-ComputeServiceChainRoleData-66djzrzrpwsv','state changed','OS::Heat::Value',NULL,578),(730,'8f784c1c-bfc9-461e-be9f-dcdfeb4b45f1','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:45',NULL,'CREATE','COMPLETE','ComputeServiceChainRoleData','overcloud-ComputeServiceChainRoleData-66djzrzrpwsv','state changed','OS::Heat::Value',NULL,578),(731,'39553bc7-39d0-403c-bb90-6999d0ec086d','a462a8f1-4e1d-4cba-bff8-3d67b3a09f4b','2026-06-10 07:46:45',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-2-bkt35t54jp2p-RoleParametersValue-ajcxzyva5dbq','state changed','OS::Heat::Value',NULL,580),(732,'021f3005-1846-43c0-8071-61b3f586ee64','a462a8f1-4e1d-4cba-bff8-3d67b3a09f4b','2026-06-10 07:46:45',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-2-bkt35t54jp2p-RoleParametersValue-ajcxzyva5dbq','state changed','OS::Heat::Value',NULL,580),(733,'015d1d30-91d6-4ee8-8a9f-616ee46e6f14','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:45',NULL,'CREATE','IN_PROGRESS','CellControllerComputeServiceNames','overcloud-CellControllerComputeServiceNames-eylccxflkfsw','state changed','OS::Heat::Value',NULL,581),(734,'82e69e7e-a631-44d0-943b-4222fb6d3dc0','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:45',NULL,'CREATE','COMPLETE','CellControllerComputeServiceNames','overcloud-CellControllerComputeServiceNames-eylccxflkfsw','state changed','OS::Heat::Value',NULL,581),(735,'aba6fa22-13f8-4cef-91d2-f38d5cea556e','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:46',NULL,'CREATE','COMPLETE','ObjectStorage','c63c9c22-62fa-4f3c-b8b0-88ecb5831d99','state changed','OS::Heat::ResourceGroup',NULL,498),(736,'3d0e7f80-3967-406f-9d3d-69db6828de61','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:46',NULL,'CREATE','IN_PROGRESS','CellControllerCompute','overcloud-CellControllerCompute-av4ze62egkug','state changed','OS::Heat::ResourceGroup',NULL,583),(737,'7b073d9f-8c28-4595-b5fa-30514242b66b','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:46',NULL,'CREATE','IN_PROGRESS','ComputeServiceNames','overcloud-ComputeServiceNames-5ropiuyb4gbz','state changed','OS::Heat::Value',NULL,584),(738,'ed283588-41f5-45ef-b2fc-4d19ac43f8ce','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:46',NULL,'CREATE','COMPLETE','ComputeServiceNames','overcloud-ComputeServiceNames-5ropiuyb4gbz','state changed','OS::Heat::Value',NULL,584),(739,'61ad7350-6a74-41dd-9a9b-46d31ba88589','782dc17b-8707-4dc7-bb5d-156c8e9c4f39','2026-06-10 07:46:46',NULL,'CREATE','IN_PROGRESS','overcloud-CellControllerCompute-av4ze62egkug','782dc17b-8707-4dc7-bb5d-156c8e9c4f39','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(740,'d32e958e-24e3-4023-9215-d768cf624037','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:46',NULL,'CREATE','IN_PROGRESS','ObjectStorageNetworkHostnameMap','overcloud-ObjectStorageNetworkHostnameMap-j3umvblfxrsv','state changed','OS::Heat::Value',NULL,586),(741,'a18730c3-6489-47f1-98b4-f90cee09204f','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:46',NULL,'CREATE','COMPLETE','ObjectStorageNetworkHostnameMap','overcloud-ObjectStorageNetworkHostnameMap-j3umvblfxrsv','state changed','OS::Heat::Value',NULL,586),(742,'a252bc5c-58f0-465a-a865-32957f509bde','782dc17b-8707-4dc7-bb5d-156c8e9c4f39','2026-06-10 07:46:46',NULL,'CREATE','COMPLETE','overcloud-CellControllerCompute-av4ze62egkug','782dc17b-8707-4dc7-bb5d-156c8e9c4f39','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(743,'7b8c81c4-00c7-41fc-9257-a9ac617d22b6','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:46',NULL,'CREATE','IN_PROGRESS','ObjectStorageServers','overcloud-ObjectStorageServers-rfy7kd2iuxxa','state changed','OS::Heat::Value',NULL,587),(744,'cf584902-d6d3-4284-96a3-0a1f504d7997','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:46',NULL,'CREATE','COMPLETE','CellController','617c14f3-d066-405b-ae18-39284ca64c6b','state changed','OS::Heat::ResourceGroup',NULL,511),(745,'24499058-b33c-45ba-a0ab-5bd5c5226c8f','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:46',NULL,'CREATE','COMPLETE','ObjectStorageServers','overcloud-ObjectStorageServers-rfy7kd2iuxxa','state changed','OS::Heat::Value',NULL,587),(746,'4f9d2a36-b819-488d-83bd-972981dfc4f3','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:46',NULL,'CREATE','IN_PROGRESS','Compute','overcloud-Compute-j5zub3fwljis','state changed','OS::Heat::ResourceGroup',NULL,590),(747,'58e7d626-78a3-48b5-b450-baf36607912a','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:46',NULL,'CREATE','COMPLETE','BlockStorage','46d49c6c-9298-4d45-ae83-0403f6f97e31','state changed','OS::Heat::ResourceGroup',NULL,523),(748,'62a62dbb-b89d-4141-9909-9d98fa2edf8a','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:46',NULL,'CREATE','COMPLETE','CephStorage','8e957f11-d713-48b5-9fe1-3fca077b6cca','state changed','OS::Heat::ResourceGroup',NULL,530),(749,'286c1c0f-25d4-4eaa-a1cc-ffdc252957f1','b2dfbe3e-ac1e-4e29-9236-4ef4f9b26280','2026-06-10 07:46:46',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-j5zub3fwljis','b2dfbe3e-ac1e-4e29-9236-4ef4f9b26280','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(750,'27024aae-822c-4848-bcf4-ef209e70f03d','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:46',NULL,'CREATE','IN_PROGRESS','ObjectStorageIpListMap','overcloud-ObjectStorageIpListMap-wxg3v43nfkpj','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,593),(751,'0a894443-cdb5-4226-8d95-cdb4220a3005','b2dfbe3e-ac1e-4e29-9236-4ef4f9b26280','2026-06-10 07:46:46',NULL,'CREATE','COMPLETE','overcloud-Compute-j5zub3fwljis','b2dfbe3e-ac1e-4e29-9236-4ef4f9b26280','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(752,'76588455-3cf1-4331-9a61-9d02fc3cdcd5','67f38048-5b04-477e-a7f9-dfd12f92d20f','2026-06-10 07:46:46',NULL,'CREATE','IN_PROGRESS','overcloud-ObjectStorageIpListMap-wxg3v43nfkpj','67f38048-5b04-477e-a7f9-dfd12f92d20f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(753,'6609945e-7668-49f4-adca-3e963c1281fc','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:46',NULL,'CREATE','IN_PROGRESS','BlockStorageNetworkHostnameMap','overcloud-BlockStorageNetworkHostnameMap-dedweu7d2rl6','state changed','OS::Heat::Value',NULL,594),(754,'dcdabbf6-f1ce-457f-98c6-86f928c45cd5','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:46',NULL,'CREATE','COMPLETE','BlockStorageNetworkHostnameMap','overcloud-BlockStorageNetworkHostnameMap-dedweu7d2rl6','state changed','OS::Heat::Value',NULL,594),(755,'d8528873-7606-4cbb-b933-4e32296f5a5f','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:46',NULL,'CREATE','COMPLETE','Networker','af73cc34-122c-4733-88b8-1887cca2d3de','state changed','OS::Heat::ResourceGroup',NULL,557),(756,'f3360d1d-6994-4f3b-9eb7-3d2e45e43673','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:46',NULL,'CREATE','IN_PROGRESS','CephStorageServers','overcloud-CephStorageServers-tbcrdbvzrhfy','state changed','OS::Heat::Value',NULL,595),(757,'b235ab04-1e83-4d03-949f-bd0a14ef2592','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:46:46',NULL,'CREATE','IN_PROGRESS','1','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-1-znf2jw4uvaef','state changed','OS::TripleO::Services::CACerts',NULL,598),(758,'0301e216-32c1-4dd6-bd52-6bed2211624c','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:46',NULL,'CREATE','COMPLETE','CephStorageServers','overcloud-CephStorageServers-tbcrdbvzrhfy','state changed','OS::Heat::Value',NULL,595),(759,'e9246dcd-fa45-43e8-b10f-c9868dec704f','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:46',NULL,'CREATE','IN_PROGRESS','CellControllerNetworkHostnameMap','overcloud-CellControllerNetworkHostnameMap-jcq4kntv74cw','state changed','OS::Heat::Value',NULL,596),(760,'10f05af1-0d78-469a-bf9b-236a3a580727','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:46',NULL,'CREATE','IN_PROGRESS','CellControllerServers','overcloud-CellControllerServers-k5fsamgtug4q','state changed','OS::Heat::Value',NULL,599),(761,'0ded1059-70fb-4944-9ff6-a720dc4cb791','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:46',NULL,'CREATE','IN_PROGRESS','BlockStorageIpListMap','overcloud-BlockStorageIpListMap-hxc6fvi4pq6k','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,601),(762,'bf941c11-63b3-4a8a-b340-d2d620289a79','67f38048-5b04-477e-a7f9-dfd12f92d20f','2026-06-10 07:46:46',NULL,'CREATE','IN_PROGRESS','EnabledServicesValue','overcloud-ObjectStorageIpListMap-wxg3v43nfkpj-EnabledServicesValue-3jna2nlul2up','state changed','OS::Heat::Value',NULL,602),(763,'b3174b87-2f25-4f07-ae9e-9c2e09af889f','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:46',NULL,'CREATE','COMPLETE','CellControllerNetworkHostnameMap','overcloud-CellControllerNetworkHostnameMap-jcq4kntv74cw','state changed','OS::Heat::Value',NULL,596),(764,'bf8b900d-1e20-4c5d-8a78-348befb08e39','3a132a68-5ae5-4469-99a5-a98c11475623','2026-06-10 07:46:46',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-1-znf2jw4uvaef','3a132a68-5ae5-4469-99a5-a98c11475623','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(765,'0125afae-5bad-42a0-8aaf-5f2a80d8bddd','67f38048-5b04-477e-a7f9-dfd12f92d20f','2026-06-10 07:46:46',NULL,'CREATE','COMPLETE','EnabledServicesValue','overcloud-ObjectStorageIpListMap-wxg3v43nfkpj-EnabledServicesValue-3jna2nlul2up','state changed','OS::Heat::Value',NULL,602),(766,'96d1115f-baea-4d66-9fcf-658706e6701b','3a132a68-5ae5-4469-99a5-a98c11475623','2026-06-10 07:46:46',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-1-znf2jw4uvaef','3a132a68-5ae5-4469-99a5-a98c11475623','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(767,'2c304ebb-2a30-4809-b820-a62e4400afea','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:46',NULL,'CREATE','COMPLETE','CellControllerServers','overcloud-CellControllerServers-k5fsamgtug4q','state changed','OS::Heat::Value',NULL,599),(768,'be40aef8-aba3-4023-9238-a13b63902544','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:46',NULL,'CREATE','IN_PROGRESS','BlockStorageServers','overcloud-BlockStorageServers-yrnmnmhkzeip','state changed','OS::Heat::Value',NULL,604),(769,'2c00ff70-9672-4881-953d-f584209f86af','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:46:46',NULL,'CREATE','COMPLETE','1','3a132a68-5ae5-4469-99a5-a98c11475623','state changed','OS::TripleO::Services::CACerts',NULL,598),(770,'855fec7b-e9cf-4394-808a-7498a90a36cc','a462a8f1-4e1d-4cba-bff8-3d67b3a09f4b','2026-06-10 07:46:46',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-2-bkt35t54jp2p-ContainersCommon-ne5243mplgf2','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(771,'290f0da5-72e8-403d-a5eb-43fa5bed8e17','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:46',NULL,'CREATE','COMPLETE','BlockStorageServers','overcloud-BlockStorageServers-yrnmnmhkzeip','state changed','OS::Heat::Value',NULL,604),(772,'8a4816b9-6fa4-4826-ad40-cd94bac4863e','0e719f9d-9601-4914-922f-2e869bbb2974','2026-06-10 07:46:46',NULL,'CREATE','IN_PROGRESS','overcloud-BlockStorageIpListMap-hxc6fvi4pq6k','0e719f9d-9601-4914-922f-2e869bbb2974','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(773,'2c9ef42f-e164-4ab5-8e4e-854d0458230e','5d5d7ca3-27d1-4652-baec-6e426fcdf55d','2026-06-10 07:46:46',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-2-bkt35t54jp2p-ContainersCommon-ne5243mplgf2','5d5d7ca3-27d1-4652-baec-6e426fcdf55d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(774,'610fd0f8-57bc-4ade-8d3b-676fabc2bc42','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:46',NULL,'CREATE','IN_PROGRESS','CephStorageNetworkHostnameMap','overcloud-CephStorageNetworkHostnameMap-lj366trqeqrd','state changed','OS::Heat::Value',NULL,606),(775,'f3e1c4eb-4add-4832-b437-9818ca0ebbdd','5d5d7ca3-27d1-4652-baec-6e426fcdf55d','2026-06-10 07:46:46',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-2-bkt35t54jp2p-ContainersCommon-ne5243mplgf2','5d5d7ca3-27d1-4652-baec-6e426fcdf55d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(776,'43868b00-a252-4920-a1f0-755fa7cf90a6','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:46',NULL,'CREATE','COMPLETE','CephStorageNetworkHostnameMap','overcloud-CephStorageNetworkHostnameMap-lj366trqeqrd','state changed','OS::Heat::Value',NULL,606),(777,'f28bb772-45f5-4240-94f6-a632c1f5a1e3','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:46',NULL,'CREATE','IN_PROGRESS','NetworkerNetworkHostnameMap','overcloud-NetworkerNetworkHostnameMap-a46h5fs77xbi','state changed','OS::Heat::Value',NULL,610),(778,'9a76cac8-50fa-4d13-9412-f0c877657f46','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:47',NULL,'CREATE','COMPLETE','NetworkerNetworkHostnameMap','overcloud-NetworkerNetworkHostnameMap-a46h5fs77xbi','state changed','OS::Heat::Value',NULL,610),(779,'0a91e390-2667-4371-b1e8-74d74e2c34fb','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:47',NULL,'CREATE','IN_PROGRESS','CellControllerIpListMap','overcloud-CellControllerIpListMap-lz3v6z3loxky','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,611),(780,'3e644273-568f-4ffc-8be6-26747d223cd2','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:47',NULL,'CREATE','IN_PROGRESS','NetworkerServers','overcloud-NetworkerServers-ye24w5ibux5r','state changed','OS::Heat::Value',NULL,615),(781,'1911752a-ab83-4ca8-95b9-694f3fa7ec43','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:47',NULL,'CREATE','COMPLETE','NetworkerServers','overcloud-NetworkerServers-ye24w5ibux5r','state changed','OS::Heat::Value',NULL,615),(782,'a597d092-f2d8-490b-a798-4a4134ec0093','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:47',NULL,'CREATE','IN_PROGRESS','NetworkerIpListMap','overcloud-NetworkerIpListMap-ufamkc2bc23y','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,618),(783,'44e89907-f4a2-4760-9e09-46db4850bbb9','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:47',NULL,'CREATE','IN_PROGRESS','CephStorageIpListMap','overcloud-CephStorageIpListMap-l4dl5h2mgijc','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,620),(784,'165439f3-2991-4724-a4c2-35e13efe36f5','4eb141ca-7cf0-42bb-93f3-7ccc5e3a30db','2026-06-10 07:46:47',NULL,'CREATE','IN_PROGRESS','overcloud-CellControllerIpListMap-lz3v6z3loxky','4eb141ca-7cf0-42bb-93f3-7ccc5e3a30db','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(785,'e431a855-1eee-4ae0-a7ee-a37e381308b5','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:46:47',NULL,'CREATE','IN_PROGRESS','5','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-5-kzg656rhl3bw','state changed','OS::TripleO::Services::CinderBackup',NULL,621),(786,'efe5cd05-8a3e-46c5-ba72-fb5afcb19e77','254a24a0-b227-4c75-9fc2-b4fa2bc4dff3','2026-06-10 07:46:47',NULL,'CREATE','IN_PROGRESS','overcloud-NetworkerIpListMap-ufamkc2bc23y','254a24a0-b227-4c75-9fc2-b4fa2bc4dff3','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(787,'781160ce-8294-422a-9d4c-f381f7cbb270','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:47',NULL,'CREATE','COMPLETE','CellControllerCompute','782dc17b-8707-4dc7-bb5d-156c8e9c4f39','state changed','OS::Heat::ResourceGroup',NULL,583),(788,'62d73ede-8af1-4c50-8f1e-566ec1e581f2','0e719f9d-9601-4914-922f-2e869bbb2974','2026-06-10 07:46:47',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','overcloud-BlockStorageIpListMap-hxc6fvi4pq6k-NetIpMapValue-bbh2qftpxr6r','state changed','OS::Heat::Value',NULL,622),(789,'e91a342f-0243-4e82-a1d1-2fc661df9666','e7102b84-6009-4806-9c15-2a7140b1d4f2','2026-06-10 07:46:47',NULL,'CREATE','IN_PROGRESS','overcloud-CephStorageIpListMap-l4dl5h2mgijc','e7102b84-6009-4806-9c15-2a7140b1d4f2','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(790,'c05174e5-ea05-48d4-b6ad-d2cbba998586','bedfb749-12ac-460b-8295-8c4321354848','2026-06-10 07:46:47',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-5-kzg656rhl3bw','bedfb749-12ac-460b-8295-8c4321354848','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(791,'7c01f821-90db-4a4f-8ee4-8a2f6a873580','0e719f9d-9601-4914-922f-2e869bbb2974','2026-06-10 07:46:47',NULL,'CREATE','COMPLETE','NetIpMapValue','overcloud-BlockStorageIpListMap-hxc6fvi4pq6k-NetIpMapValue-bbh2qftpxr6r','state changed','OS::Heat::Value',NULL,622),(792,'7f0ba36d-5b1c-4ea8-ba46-76a79e8d4ce3','254a24a0-b227-4c75-9fc2-b4fa2bc4dff3','2026-06-10 07:46:47',NULL,'CREATE','IN_PROGRESS','EnabledServicesValue','overcloud-NetworkerIpListMap-ufamkc2bc23y-EnabledServicesValue-hhvxko25h4ii','state changed','OS::Heat::Value',NULL,623),(793,'73a6a288-074a-4236-b6aa-46209e8e1ff8','254a24a0-b227-4c75-9fc2-b4fa2bc4dff3','2026-06-10 07:46:47',NULL,'CREATE','COMPLETE','EnabledServicesValue','overcloud-NetworkerIpListMap-ufamkc2bc23y-EnabledServicesValue-hhvxko25h4ii','state changed','OS::Heat::Value',NULL,623),(794,'fa18fb1e-91c5-4161-be3e-825e231b68a5','4eb141ca-7cf0-42bb-93f3-7ccc5e3a30db','2026-06-10 07:46:47',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','overcloud-CellControllerIpListMap-lz3v6z3loxky-NetIpMapValue-gvzrlfjr4dkq','state changed','OS::Heat::Value',NULL,624),(795,'ba5ce5ea-60fc-4d4e-b897-1bc872a82c2e','4eb141ca-7cf0-42bb-93f3-7ccc5e3a30db','2026-06-10 07:46:47',NULL,'CREATE','COMPLETE','NetIpMapValue','overcloud-CellControllerIpListMap-lz3v6z3loxky-NetIpMapValue-gvzrlfjr4dkq','state changed','OS::Heat::Value',NULL,624),(796,'3fe4c64c-8854-42f2-a392-c1e4098f7512','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:47',NULL,'CREATE','IN_PROGRESS','CellControllerComputeNetworkHostnameMap','overcloud-CellControllerComputeNetworkHostnameMap-vmn6ufzabqdy','state changed','OS::Heat::Value',NULL,625),(797,'c8ddf740-80b3-403d-8978-c0705a039855','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:47',NULL,'CREATE','COMPLETE','Compute','b2dfbe3e-ac1e-4e29-9236-4ef4f9b26280','state changed','OS::Heat::ResourceGroup',NULL,590),(798,'735bde33-65f0-452e-9ea8-7899ad30ae6d','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:47',NULL,'CREATE','COMPLETE','CellControllerComputeNetworkHostnameMap','overcloud-CellControllerComputeNetworkHostnameMap-vmn6ufzabqdy','state changed','OS::Heat::Value',NULL,625),(799,'1c07e08d-9fad-45df-8976-ef011e1e994b','e7102b84-6009-4806-9c15-2a7140b1d4f2','2026-06-10 07:46:47',NULL,'CREATE','IN_PROGRESS','EnabledServicesValue','overcloud-CephStorageIpListMap-l4dl5h2mgijc-EnabledServicesValue-t44rgpxzyaqx','state changed','OS::Heat::Value',NULL,626),(800,'ee849e95-6c4c-495b-ae37-fa83c649ef77','e7102b84-6009-4806-9c15-2a7140b1d4f2','2026-06-10 07:46:47',NULL,'CREATE','COMPLETE','EnabledServicesValue','overcloud-CephStorageIpListMap-l4dl5h2mgijc-EnabledServicesValue-t44rgpxzyaqx','state changed','OS::Heat::Value',NULL,626),(801,'aa89ee37-b05a-4d17-9160-3bcc424a1634','bedfb749-12ac-460b-8295-8c4321354848','2026-06-10 07:46:47',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-5-kzg656rhl3bw-MySQLClient-tdk4qh5bowl6','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(802,'a9ae5759-3e9e-4114-8e4b-6108e2ceebed','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:47',NULL,'CREATE','IN_PROGRESS','CellControllerComputeIpListMap','overcloud-CellControllerComputeIpListMap-avc7i3k75545','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,629),(803,'3cd8b2b6-d9bd-45bf-84c4-8a08031d2f31','444cc84b-08d8-4703-8da7-01a7bafa3154','2026-06-10 07:46:47',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-5-kzg656rhl3bw-MySQLClient-tdk4qh5bowl6','444cc84b-08d8-4703-8da7-01a7bafa3154','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(804,'80c85117-55ca-4b4d-a649-ff8bd6f51241','444cc84b-08d8-4703-8da7-01a7bafa3154','2026-06-10 07:46:47',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-5-kzg656rhl3bw-MySQLClient-tdk4qh5bowl6','444cc84b-08d8-4703-8da7-01a7bafa3154','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(805,'81562cd1-d74d-4ffd-b40f-f7c706787a4f','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:47',NULL,'CREATE','IN_PROGRESS','ComputeServers','overcloud-ComputeServers-njtpcd2yaga2','state changed','OS::Heat::Value',NULL,631),(806,'ce2c6b52-9e5e-478e-8814-01b2e6efc25c','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:47',NULL,'CREATE','IN_PROGRESS','ComputeNetworkHostnameMap','overcloud-ComputeNetworkHostnameMap-yitpevjabnvz','state changed','OS::Heat::Value',NULL,632),(807,'c5c27be7-176a-4d23-9779-da8834fa99f6','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:47',NULL,'CREATE','IN_PROGRESS','CellControllerComputeServers','overcloud-CellControllerComputeServers-62y62iog6ofl','state changed','OS::Heat::Value',NULL,628),(808,'e7917662-61af-4fd8-8247-8b3c960a36c8','ab240d21-f359-4d48-95f1-2cd663b1902b','2026-06-10 07:46:47',NULL,'CREATE','IN_PROGRESS','overcloud-CellControllerComputeIpListMap-avc7i3k75545','ab240d21-f359-4d48-95f1-2cd663b1902b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(809,'da027e07-43b7-46c8-a7ac-810dffeb82cb','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:47',NULL,'CREATE','COMPLETE','ComputeServers','overcloud-ComputeServers-njtpcd2yaga2','state changed','OS::Heat::Value',NULL,631),(810,'54cb6ac9-50a8-4803-a51c-7bbb3892b922','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:47',NULL,'CREATE','COMPLETE','ComputeNetworkHostnameMap','overcloud-ComputeNetworkHostnameMap-yitpevjabnvz','state changed','OS::Heat::Value',NULL,632),(811,'05ebb49f-519c-484d-a68c-ae0f86b6a3be','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:46:47',NULL,'CREATE','IN_PROGRESS','3','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-3-7lkdyqj3pprk','state changed','OS::TripleO::Services::CeilometerAgentNotification',NULL,633),(812,'bdf69e39-ef17-44e0-8b7d-2f128d33b709','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:47',NULL,'CREATE','COMPLETE','CellControllerComputeServers','overcloud-CellControllerComputeServers-62y62iog6ofl','state changed','OS::Heat::Value',NULL,628),(813,'0f7b7318-5a43-4c59-aab6-d3f5173c87aa','ab240d21-f359-4d48-95f1-2cd663b1902b','2026-06-10 07:46:47',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','overcloud-CellControllerComputeIpListMap-avc7i3k75545-NetIpMapValue-eqbh7sihyav6','state changed','OS::Heat::Value',NULL,637),(814,'e10d22a0-a5ed-418f-9225-e879b9411150','ab240d21-f359-4d48-95f1-2cd663b1902b','2026-06-10 07:46:47',NULL,'CREATE','COMPLETE','NetIpMapValue','overcloud-CellControllerComputeIpListMap-avc7i3k75545-NetIpMapValue-eqbh7sihyav6','state changed','OS::Heat::Value',NULL,637),(815,'2947dfd2-abed-4df0-8300-7153486327b3','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:47',NULL,'CREATE','IN_PROGRESS','ComputeIpListMap','overcloud-ComputeIpListMap-zcx2l2ldnseh','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,638),(816,'29b4709f-1a75-4b33-ba66-6661386d0643','67f38048-5b04-477e-a7f9-dfd12f92d20f','2026-06-10 07:46:47',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','overcloud-ObjectStorageIpListMap-wxg3v43nfkpj-NetIpMapValue-g6l5xixmhb5b','state changed','OS::Heat::Value',NULL,639),(817,'e65d074b-ad00-431f-a354-57c51512b155','45c69ae5-5504-4501-9186-3762932567a6','2026-06-10 07:46:47',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-3-7lkdyqj3pprk','45c69ae5-5504-4501-9186-3762932567a6','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(818,'ba7348fc-4042-47a9-96d3-51ddbaeccbfd','67f38048-5b04-477e-a7f9-dfd12f92d20f','2026-06-10 07:46:47',NULL,'CREATE','COMPLETE','NetIpMapValue','overcloud-ObjectStorageIpListMap-wxg3v43nfkpj-NetIpMapValue-g6l5xixmhb5b','state changed','OS::Heat::Value',NULL,639),(819,'df38ed3f-0fe6-4d37-bdac-453343a4b77b','67f38048-5b04-477e-a7f9-dfd12f92d20f','2026-06-10 07:46:47',NULL,'CREATE','COMPLETE','overcloud-ObjectStorageIpListMap-wxg3v43nfkpj','67f38048-5b04-477e-a7f9-dfd12f92d20f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(820,'a3d1af22-a966-45e8-9a3b-89263a5ba426','49437250-a6f2-4830-8b51-cc5576ae9f7f','2026-06-10 07:46:47',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeIpListMap-zcx2l2ldnseh','49437250-a6f2-4830-8b51-cc5576ae9f7f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(821,'f4946a65-d128-4ad5-b419-38130905b716','a462a8f1-4e1d-4cba-bff8-3d67b3a09f4b','2026-06-10 07:46:47',NULL,'CREATE','COMPLETE','ContainersCommon','5d5d7ca3-27d1-4652-baec-6e426fcdf55d','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(822,'1972cb81-7367-42d1-8466-7590ab977b85','45c69ae5-5504-4501-9186-3762932567a6','2026-06-10 07:46:47',NULL,'CREATE','IN_PROGRESS','CeilometerServiceBase','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-3-7lkdyqj3pprk-CeilometerServiceBase-rmt77hbatz65','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-base-container-puppet.yaml',NULL,642),(823,'ed219250-5481-4ca5-a6ae-21c52a16f496','a462a8f1-4e1d-4cba-bff8-3d67b3a09f4b','2026-06-10 07:46:47',NULL,'CREATE','IN_PROGRESS','CeilometerServiceBase','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-2-bkt35t54jp2p-CeilometerServiceBase-3ix4cfctfh6g','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-base-container-puppet.yaml',NULL,641),(824,'129a0c81-8172-42de-8099-e97b7bef17a8','49437250-a6f2-4830-8b51-cc5576ae9f7f','2026-06-10 07:46:47',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','overcloud-ComputeIpListMap-zcx2l2ldnseh-NetIpMapValue-42yftrkxgrz7','state changed','OS::Heat::Value',NULL,643),(825,'bf681203-2aa1-4414-8b82-6ee75e0a1dd2','64b91140-6e47-41e2-9f4c-542c3e076380','2026-06-10 07:46:48',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-3-7lkdyqj3pprk-CeilometerServiceBase-rmt77hbatz65','64b91140-6e47-41e2-9f4c-542c3e076380','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(826,'a4b86f62-47b7-4115-9d26-192b8bc743bc','49437250-a6f2-4830-8b51-cc5576ae9f7f','2026-06-10 07:46:48',NULL,'CREATE','COMPLETE','NetIpMapValue','overcloud-ComputeIpListMap-zcx2l2ldnseh-NetIpMapValue-42yftrkxgrz7','state changed','OS::Heat::Value',NULL,643),(827,'6c5808aa-33f3-42b7-96ba-4e1bab35ba31','b057d4b6-3c92-44e1-8ef8-2b669e236daf','2026-06-10 07:46:48',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-2-bkt35t54jp2p-CeilometerServiceBase-3ix4cfctfh6g','b057d4b6-3c92-44e1-8ef8-2b669e236daf','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(828,'ba8e1ee5-38cd-418c-be05-22579f086e55','b057d4b6-3c92-44e1-8ef8-2b669e236daf','2026-06-10 07:46:48',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-2-bkt35t54jp2p-CeilometerServiceBase-3ix4cfctfh6g','b057d4b6-3c92-44e1-8ef8-2b669e236daf','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(829,'89eb7ed0-c07e-4dad-870e-36f51fb582f7','64b91140-6e47-41e2-9f4c-542c3e076380','2026-06-10 07:46:48',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-3-7lkdyqj3pprk-CeilometerServiceBase-rmt77hbatz65','64b91140-6e47-41e2-9f4c-542c3e076380','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(830,'e8730be2-3e60-4b18-a2f5-2bda6bf16471','0e719f9d-9601-4914-922f-2e869bbb2974','2026-06-10 07:46:48',NULL,'CREATE','IN_PROGRESS','EnabledServicesValue','overcloud-BlockStorageIpListMap-hxc6fvi4pq6k-EnabledServicesValue-qjlzfmxvxs6t','state changed','OS::Heat::Value',NULL,644),(831,'2280c90b-c80a-40c3-bebe-ade53fb83a79','0e719f9d-9601-4914-922f-2e869bbb2974','2026-06-10 07:46:48',NULL,'CREATE','COMPLETE','EnabledServicesValue','overcloud-BlockStorageIpListMap-hxc6fvi4pq6k-EnabledServicesValue-qjlzfmxvxs6t','state changed','OS::Heat::Value',NULL,644),(832,'6f31f033-8e11-48f7-ae6d-629d77005200','0e719f9d-9601-4914-922f-2e869bbb2974','2026-06-10 07:46:48',NULL,'CREATE','COMPLETE','overcloud-BlockStorageIpListMap-hxc6fvi4pq6k','0e719f9d-9601-4914-922f-2e869bbb2974','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(833,'46cb3afc-a412-42c8-ab6c-d3135da1e5c6','4eb141ca-7cf0-42bb-93f3-7ccc5e3a30db','2026-06-10 07:46:48',NULL,'CREATE','IN_PROGRESS','EnabledServicesValue','overcloud-CellControllerIpListMap-lz3v6z3loxky-EnabledServicesValue-ykpmcspwuq7e','state changed','OS::Heat::Value',NULL,645),(834,'6afbd7b7-a039-4b19-90bd-a633c7cad3ea','254a24a0-b227-4c75-9fc2-b4fa2bc4dff3','2026-06-10 07:46:48',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','overcloud-NetworkerIpListMap-ufamkc2bc23y-NetIpMapValue-tz7ticzb65kg','state changed','OS::Heat::Value',NULL,646),(835,'45377d57-73b2-4fb4-a54a-b9c1373061b4','4eb141ca-7cf0-42bb-93f3-7ccc5e3a30db','2026-06-10 07:46:48',NULL,'CREATE','COMPLETE','EnabledServicesValue','overcloud-CellControllerIpListMap-lz3v6z3loxky-EnabledServicesValue-ykpmcspwuq7e','state changed','OS::Heat::Value',NULL,645),(836,'714cd4a5-f146-4b84-8137-4c66c0e86e43','254a24a0-b227-4c75-9fc2-b4fa2bc4dff3','2026-06-10 07:46:48',NULL,'CREATE','COMPLETE','NetIpMapValue','overcloud-NetworkerIpListMap-ufamkc2bc23y-NetIpMapValue-tz7ticzb65kg','state changed','OS::Heat::Value',NULL,646),(837,'a506c596-8b7f-4c1b-94f0-48a9cb3ac4f0','4eb141ca-7cf0-42bb-93f3-7ccc5e3a30db','2026-06-10 07:46:48',NULL,'CREATE','COMPLETE','overcloud-CellControllerIpListMap-lz3v6z3loxky','4eb141ca-7cf0-42bb-93f3-7ccc5e3a30db','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(838,'826e2d44-286e-4a9c-999c-d55325974582','254a24a0-b227-4c75-9fc2-b4fa2bc4dff3','2026-06-10 07:46:48',NULL,'CREATE','COMPLETE','overcloud-NetworkerIpListMap-ufamkc2bc23y','254a24a0-b227-4c75-9fc2-b4fa2bc4dff3','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(839,'8a110cdc-6663-4d8b-b4f1-2d30156c813f','e7102b84-6009-4806-9c15-2a7140b1d4f2','2026-06-10 07:46:48',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','overcloud-CephStorageIpListMap-l4dl5h2mgijc-NetIpMapValue-x7huszqf6mmb','state changed','OS::Heat::Value',NULL,647),(840,'279f4348-39fc-4bb2-9efa-912c88b34e73','bedfb749-12ac-460b-8295-8c4321354848','2026-06-10 07:46:48',NULL,'CREATE','IN_PROGRESS','CinderCommon','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-5-kzg656rhl3bw-CinderCommon-swv4l7tdiudr','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml',NULL,NULL),(841,'17ba4c22-71a4-4cae-9dfe-71c526faabfe','e7102b84-6009-4806-9c15-2a7140b1d4f2','2026-06-10 07:46:48',NULL,'CREATE','COMPLETE','NetIpMapValue','overcloud-CephStorageIpListMap-l4dl5h2mgijc-NetIpMapValue-x7huszqf6mmb','state changed','OS::Heat::Value',NULL,647),(842,'9c4bbc0d-3b4e-451f-af2c-3895b395f304','e7102b84-6009-4806-9c15-2a7140b1d4f2','2026-06-10 07:46:48',NULL,'CREATE','COMPLETE','overcloud-CephStorageIpListMap-l4dl5h2mgijc','e7102b84-6009-4806-9c15-2a7140b1d4f2','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(843,'8c4d081e-9c31-4847-812e-088262a8620b','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:48',NULL,'CREATE','COMPLETE','ObjectStorageIpListMap','67f38048-5b04-477e-a7f9-dfd12f92d20f','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,593),(844,'a4ec069a-708e-4396-9dc4-1a76d0d5be1d','bedfb749-12ac-460b-8295-8c4321354848','2026-06-10 07:46:48',NULL,'CREATE','COMPLETE','MySQLClient','444cc84b-08d8-4703-8da7-01a7bafa3154','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(845,'d3a4e8f0-452c-432c-90b9-f7787aed4afd','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:46:48',NULL,'CREATE','IN_PROGRESS','0','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-0-2askb3iktxnc','state changed','OS::TripleO::Services::BootParams',NULL,648),(846,'74bec643-79ae-40ab-a5ef-d7d093651a37','ce40fea2-b70e-4789-8ca4-0f75fa3615fa','2026-06-10 07:46:48',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-5-kzg656rhl3bw-CinderCommon-swv4l7tdiudr','ce40fea2-b70e-4789-8ca4-0f75fa3615fa','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(847,'24c18620-5db3-4430-98b6-c9771d068917','33e03533-7011-411d-bc83-7e2725d50ee7','2026-06-10 07:46:48',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-0-2askb3iktxnc','33e03533-7011-411d-bc83-7e2725d50ee7','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(848,'9e921e4c-789d-41fa-87a3-cd6c40acd8cd','ab240d21-f359-4d48-95f1-2cd663b1902b','2026-06-10 07:46:48',NULL,'CREATE','IN_PROGRESS','EnabledServicesValue','overcloud-CellControllerComputeIpListMap-avc7i3k75545-EnabledServicesValue-pvaxnkarch5e','state changed','OS::Heat::Value',NULL,649),(849,'abed8398-636b-4283-afcd-38fa4fcf8816','ab240d21-f359-4d48-95f1-2cd663b1902b','2026-06-10 07:46:48',NULL,'CREATE','COMPLETE','EnabledServicesValue','overcloud-CellControllerComputeIpListMap-avc7i3k75545-EnabledServicesValue-pvaxnkarch5e','state changed','OS::Heat::Value',NULL,649),(850,'49bde7e0-1f58-4348-b1f3-0df6d7777aae','ab240d21-f359-4d48-95f1-2cd663b1902b','2026-06-10 07:46:48',NULL,'CREATE','COMPLETE','overcloud-CellControllerComputeIpListMap-avc7i3k75545','ab240d21-f359-4d48-95f1-2cd663b1902b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(851,'58e0fb59-9b73-4755-9c3e-71c6304158e0','ce40fea2-b70e-4789-8ca4-0f75fa3615fa','2026-06-10 07:46:48',NULL,'CREATE','IN_PROGRESS','CinderNVMeOF','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-5-kzg656rhl3bw-CinderCommon-swv4l7tdiudr-CinderNVMeOF-z3ddlq4pzebg','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(852,'6ee16b25-2604-41a8-9743-a89a6e178c1c','33e03533-7011-411d-bc83-7e2725d50ee7','2026-06-10 07:46:48',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-0-2askb3iktxnc-RoleParametersValue-mhewst2gk2g5','state changed','OS::Heat::Value',NULL,650),(853,'ec99f715-9c35-493f-8eee-0514dd842aa0','976f7a4a-fa1a-4fef-ac24-b77e6fe57772','2026-06-10 07:46:48',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-5-kzg656rhl3bw-CinderCommon-swv4l7tdiudr-CinderNVMeOF-z3ddlq4pzebg','976f7a4a-fa1a-4fef-ac24-b77e6fe57772','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(854,'43882b55-2fb6-4c98-b407-b04d1cd666f0','33e03533-7011-411d-bc83-7e2725d50ee7','2026-06-10 07:46:48',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-0-2askb3iktxnc-RoleParametersValue-mhewst2gk2g5','state changed','OS::Heat::Value',NULL,650),(855,'21c73d52-eda3-4390-a47d-61ed8b275664','976f7a4a-fa1a-4fef-ac24-b77e6fe57772','2026-06-10 07:46:48',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-5-kzg656rhl3bw-CinderCommon-swv4l7tdiudr-CinderNVMeOF-z3ddlq4pzebg','976f7a4a-fa1a-4fef-ac24-b77e6fe57772','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(856,'04bcc863-e87f-4c66-ac96-02c1f65ac7c1','33e03533-7011-411d-bc83-7e2725d50ee7','2026-06-10 07:46:48',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-0-2askb3iktxnc','33e03533-7011-411d-bc83-7e2725d50ee7','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(857,'ccd94712-80eb-4006-93d4-d20ed5e7bf95','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:48',NULL,'CREATE','COMPLETE','BlockStorageIpListMap','0e719f9d-9601-4914-922f-2e869bbb2974','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,601),(858,'f457defc-b8a7-45c6-b9fa-ef0bbb9ab432','45c69ae5-5504-4501-9186-3762932567a6','2026-06-10 07:46:48',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-3-7lkdyqj3pprk-RoleParametersValue-sali2iochyap','state changed','OS::Heat::Value',NULL,651),(859,'75ca2133-297e-4df9-b119-913e503ddb3a','45c69ae5-5504-4501-9186-3762932567a6','2026-06-10 07:46:48',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-3-7lkdyqj3pprk-RoleParametersValue-sali2iochyap','state changed','OS::Heat::Value',NULL,651),(860,'1abf2b1e-e527-4d43-8b49-87a6bae9ad98','49437250-a6f2-4830-8b51-cc5576ae9f7f','2026-06-10 07:46:48',NULL,'CREATE','IN_PROGRESS','EnabledServicesValue','overcloud-ComputeIpListMap-zcx2l2ldnseh-EnabledServicesValue-als45gqq2ryq','state changed','OS::Heat::Value',NULL,652),(861,'fc305646-d560-4eb0-8577-bab6035cca44','49437250-a6f2-4830-8b51-cc5576ae9f7f','2026-06-10 07:46:49',NULL,'CREATE','COMPLETE','EnabledServicesValue','overcloud-ComputeIpListMap-zcx2l2ldnseh-EnabledServicesValue-als45gqq2ryq','state changed','OS::Heat::Value',NULL,652),(862,'9a9976e6-d9a9-4a18-955d-bb9f605d85e6','49437250-a6f2-4830-8b51-cc5576ae9f7f','2026-06-10 07:46:49',NULL,'CREATE','COMPLETE','overcloud-ComputeIpListMap-zcx2l2ldnseh','49437250-a6f2-4830-8b51-cc5576ae9f7f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(863,'5f7064da-5dc6-48dc-b8e1-43caac5d59ce','a462a8f1-4e1d-4cba-bff8-3d67b3a09f4b','2026-06-10 07:46:49',NULL,'CREATE','COMPLETE','CeilometerServiceBase','b057d4b6-3c92-44e1-8ef8-2b669e236daf','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-base-container-puppet.yaml',NULL,641),(864,'f3efe89a-083e-43ad-a1ba-64f67ca28dcf','45c69ae5-5504-4501-9186-3762932567a6','2026-06-10 07:46:49',NULL,'CREATE','COMPLETE','CeilometerServiceBase','64b91140-6e47-41e2-9f4c-542c3e076380','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-base-container-puppet.yaml',NULL,642),(865,'2db53c79-0365-4c1c-8b40-1f6b6db952b8','a462a8f1-4e1d-4cba-bff8-3d67b3a09f4b','2026-06-10 07:46:49',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-2-bkt35t54jp2p','a462a8f1-4e1d-4cba-bff8-3d67b3a09f4b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(866,'0ad8be53-0db7-45f4-b569-e6ac985103dc','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:49',NULL,'CREATE','COMPLETE','CellControllerIpListMap','4eb141ca-7cf0-42bb-93f3-7ccc5e3a30db','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,611),(867,'ec1dbb5f-e2fa-4121-a990-12e1e02be0e8','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:49',NULL,'CREATE','COMPLETE','NetworkerIpListMap','254a24a0-b227-4c75-9fc2-b4fa2bc4dff3','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,618),(868,'78945179-9b72-430a-8903-0e6fa8cef54c','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:49',NULL,'CREATE','COMPLETE','CephStorageIpListMap','e7102b84-6009-4806-9c15-2a7140b1d4f2','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,620),(869,'ae098c69-0901-42e7-b581-8d1311c5d310','bedfb749-12ac-460b-8295-8c4321354848','2026-06-10 07:46:49',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-5-kzg656rhl3bw-ContainersCommon-aso3r5sng2ub','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(870,'c81aa371-cdc6-493c-938a-8f9a6b6ea9a0','0148b588-ddc3-4b6e-8c68-eb9be51a8151','2026-06-10 07:46:49',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-5-kzg656rhl3bw-ContainersCommon-aso3r5sng2ub','0148b588-ddc3-4b6e-8c68-eb9be51a8151','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(871,'236a20ca-8b23-4249-878e-1019fb055027','0148b588-ddc3-4b6e-8c68-eb9be51a8151','2026-06-10 07:46:49',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-5-kzg656rhl3bw-ContainersCommon-aso3r5sng2ub','0148b588-ddc3-4b6e-8c68-eb9be51a8151','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(872,'bb8551cf-07af-4e32-a1cf-e453409060d2','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:49',NULL,'CREATE','COMPLETE','CellControllerComputeIpListMap','ab240d21-f359-4d48-95f1-2cd663b1902b','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,629),(873,'f3c8f704-f2b5-4e49-8293-0559d1f7c1f6','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:46:49',NULL,'CREATE','COMPLETE','2','a462a8f1-4e1d-4cba-bff8-3d67b3a09f4b','state changed','OS::TripleO::Services::CeilometerAgentCentral',NULL,576),(874,'44487042-8374-4c71-a6e9-2455cf7e6993','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:46:49',NULL,'CREATE','COMPLETE','0','33e03533-7011-411d-bc83-7e2725d50ee7','state changed','OS::TripleO::Services::BootParams',NULL,648),(875,'2d2cbb63-333c-4702-9569-2bcb2cf3646b','ce40fea2-b70e-4789-8ca4-0f75fa3615fa','2026-06-10 07:46:49',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-5-kzg656rhl3bw-CinderCommon-swv4l7tdiudr-ContainersCommon-jkaiwygdkyeb','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(876,'8aebfc1e-40f0-4e3c-9977-8779486188fa','d34b0933-5a7f-470a-92da-22c34b1d37e8','2026-06-10 07:46:49',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-5-kzg656rhl3bw-CinderCommon-swv4l7tdiudr-ContainersCommon-jkaiwygdkyeb','d34b0933-5a7f-470a-92da-22c34b1d37e8','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(877,'385db6ec-6e07-4746-8c56-545371070203','ce40fea2-b70e-4789-8ca4-0f75fa3615fa','2026-06-10 07:46:49',NULL,'CREATE','COMPLETE','CinderNVMeOF','976f7a4a-fa1a-4fef-ac24-b77e6fe57772','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(878,'0d09cdfe-f0e2-4a06-9298-3e1402d58d09','45c69ae5-5504-4501-9186-3762932567a6','2026-06-10 07:46:49',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-3-7lkdyqj3pprk-ContainersCommon-ojvdn4qgxprz','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(879,'cddcc673-05ae-4375-9907-7e99871847fe','d34b0933-5a7f-470a-92da-22c34b1d37e8','2026-06-10 07:46:49',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-5-kzg656rhl3bw-CinderCommon-swv4l7tdiudr-ContainersCommon-jkaiwygdkyeb','d34b0933-5a7f-470a-92da-22c34b1d37e8','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(880,'95f13cd1-843f-4a23-8205-0361ce84fa95','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:46:49',NULL,'CREATE','COMPLETE','ComputeIpListMap','49437250-a6f2-4830-8b51-cc5576ae9f7f','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,638),(881,'45a67a47-6035-4938-9250-a91f16bb3f47','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:46:50',NULL,'CREATE','IN_PROGRESS','4','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-4-lmmwe7oeumhq','state changed','OS::TripleO::Services::CinderApi',NULL,659),(882,'5e23b331-f23b-4292-9799-1164cab6e208','d21463a2-1ac3-4c6c-bd49-1a9f89b821fb','2026-06-10 07:46:50',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-3-7lkdyqj3pprk-ContainersCommon-ojvdn4qgxprz','d21463a2-1ac3-4c6c-bd49-1a9f89b821fb','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(883,'50fc2493-9048-4d36-a867-0427ae9d63d5','d21463a2-1ac3-4c6c-bd49-1a9f89b821fb','2026-06-10 07:46:50',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-3-7lkdyqj3pprk-ContainersCommon-ojvdn4qgxprz','d21463a2-1ac3-4c6c-bd49-1a9f89b821fb','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(884,'b879d12f-e57f-4373-bdb6-6dbe9f95b52f','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:46:50',NULL,'CREATE','IN_PROGRESS','6','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-6-xtaibtgtfyxf','state changed','OS::TripleO::Services::CinderScheduler',NULL,660),(885,'791aeead-d5d9-4e10-82b6-75f5baa85175','9f86f081-2833-404e-b7e9-c37d22a9039a','2026-06-10 07:46:50',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-4-lmmwe7oeumhq','9f86f081-2833-404e-b7e9-c37d22a9039a','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(886,'3f78bcb6-f145-4360-b83d-627c5ab0eefb','94d425d6-e979-442e-9ced-f97d6ff4aeff','2026-06-10 07:46:50',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-6-xtaibtgtfyxf','94d425d6-e979-442e-9ced-f97d6ff4aeff','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(887,'4b5cedbc-3c98-4cdf-8afb-a8564763be69','94d425d6-e979-442e-9ced-f97d6ff4aeff','2026-06-10 07:46:50',NULL,'CREATE','IN_PROGRESS','CinderCommon','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-6-xtaibtgtfyxf-CinderCommon-znbkekbixkxy','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml',NULL,NULL),(888,'fbd81b01-29f5-40bb-a3b6-1c271876d69f','9f86f081-2833-404e-b7e9-c37d22a9039a','2026-06-10 07:46:50',NULL,'CREATE','IN_PROGRESS','CinderCommon','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-4-lmmwe7oeumhq-CinderCommon-klorghwwb2un','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml',NULL,NULL),(889,'3ec7fce7-1aba-4306-99ec-945e80cb450b','bedfb749-12ac-460b-8295-8c4321354848','2026-06-10 07:46:50',NULL,'CREATE','IN_PROGRESS','CinderBackupBase','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-5-kzg656rhl3bw-CinderBackupBase-czb6i5cj3vvx','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-container-puppet.yaml',NULL,661),(890,'cef9d8a9-14f8-49bc-9efa-4cb1a9f7fb8d','a77a59ca-98d3-42cd-b956-3105451f83e8','2026-06-10 07:46:50',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-6-xtaibtgtfyxf-CinderCommon-znbkekbixkxy','a77a59ca-98d3-42cd-b956-3105451f83e8','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(891,'14be89ae-c901-446f-8b63-1b4023a8bd40','7b2f8b31-0b3d-41d8-ad17-175eec1e9cd7','2026-06-10 07:46:50',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-4-lmmwe7oeumhq-CinderCommon-klorghwwb2un','7b2f8b31-0b3d-41d8-ad17-175eec1e9cd7','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(892,'c14b3a30-de5a-4002-8c1a-0c4c57e88157','be5dff6f-9852-4e4d-828d-565dd452586c','2026-06-10 07:46:50',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-5-kzg656rhl3bw-CinderBackupBase-czb6i5cj3vvx','be5dff6f-9852-4e4d-828d-565dd452586c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(893,'42db3a31-fc6d-419d-94a4-3a63a6c04a27','a77a59ca-98d3-42cd-b956-3105451f83e8','2026-06-10 07:46:50',NULL,'CREATE','IN_PROGRESS','CinderNVMeOF','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-6-xtaibtgtfyxf-CinderCommon-znbkekbixkxy-CinderNVMeOF-c42nk3rz4hcu','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(894,'cd3a303a-9d46-4a38-b69c-7b2678a9c278','ce2aeaba-ccc1-4807-b31d-f03e1c3fcbd8','2026-06-10 07:46:50',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-6-xtaibtgtfyxf-CinderCommon-znbkekbixkxy-CinderNVMeOF-c42nk3rz4hcu','ce2aeaba-ccc1-4807-b31d-f03e1c3fcbd8','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(895,'225b15ce-13e1-4409-a8c6-99221c0d968f','7b2f8b31-0b3d-41d8-ad17-175eec1e9cd7','2026-06-10 07:46:50',NULL,'CREATE','IN_PROGRESS','CinderNVMeOF','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-4-lmmwe7oeumhq-CinderCommon-klorghwwb2un-CinderNVMeOF-2fjd4eks64ue','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(896,'9ffe6b1b-6db4-42da-806c-066b5794e93b','bedfb749-12ac-460b-8295-8c4321354848','2026-06-10 07:46:50',NULL,'CREATE','COMPLETE','ContainersCommon','0148b588-ddc3-4b6e-8c68-eb9be51a8151','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(897,'66924e56-84d3-4919-b749-2e0cb3f2f3bf','ce2aeaba-ccc1-4807-b31d-f03e1c3fcbd8','2026-06-10 07:46:50',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-6-xtaibtgtfyxf-CinderCommon-znbkekbixkxy-CinderNVMeOF-c42nk3rz4hcu','ce2aeaba-ccc1-4807-b31d-f03e1c3fcbd8','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(898,'17c01a93-a711-4772-ae94-f949f7b83555','4b97ed00-2103-4f25-a7be-c78904114b7c','2026-06-10 07:46:50',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-4-lmmwe7oeumhq-CinderCommon-klorghwwb2un-CinderNVMeOF-2fjd4eks64ue','4b97ed00-2103-4f25-a7be-c78904114b7c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(899,'112e4d47-281f-4fd3-a61d-f74c9c3f792b','4b97ed00-2103-4f25-a7be-c78904114b7c','2026-06-10 07:46:50',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-4-lmmwe7oeumhq-CinderCommon-klorghwwb2un-CinderNVMeOF-2fjd4eks64ue','4b97ed00-2103-4f25-a7be-c78904114b7c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(900,'5a2edd12-79ac-4657-bf7a-5849781a77c6','be5dff6f-9852-4e4d-828d-565dd452586c','2026-06-10 07:46:50',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-5-kzg656rhl3bw-CinderBackupBase-czb6i5cj3vvx-ContainersCommon-klh4sx7uu4jg','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(901,'22c446b9-a58a-4abe-8826-84db4a70e460','659a024b-11f4-4c48-95b1-8ee6b6530726','2026-06-10 07:46:50',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-5-kzg656rhl3bw-CinderBackupBase-czb6i5cj3vvx-ContainersCommon-klh4sx7uu4jg','659a024b-11f4-4c48-95b1-8ee6b6530726','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(902,'ce48d62f-776f-48b9-ba2a-b7f050fa14d1','659a024b-11f4-4c48-95b1-8ee6b6530726','2026-06-10 07:46:50',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-5-kzg656rhl3bw-CinderBackupBase-czb6i5cj3vvx-ContainersCommon-klh4sx7uu4jg','659a024b-11f4-4c48-95b1-8ee6b6530726','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(903,'fbd63ab6-7fc6-4356-a54c-8523ce61e2b6','ce40fea2-b70e-4789-8ca4-0f75fa3615fa','2026-06-10 07:46:50',NULL,'CREATE','COMPLETE','ContainersCommon','d34b0933-5a7f-470a-92da-22c34b1d37e8','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(904,'cef1f9f4-adba-4369-8477-401baa37a679','ce40fea2-b70e-4789-8ca4-0f75fa3615fa','2026-06-10 07:46:50',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-5-kzg656rhl3bw-CinderCommon-swv4l7tdiudr','ce40fea2-b70e-4789-8ca4-0f75fa3615fa','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(905,'184ac242-7c06-4869-8613-658dfc197c5d','45c69ae5-5504-4501-9186-3762932567a6','2026-06-10 07:46:51',NULL,'CREATE','COMPLETE','ContainersCommon','d21463a2-1ac3-4c6c-bd49-1a9f89b821fb','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(906,'0d8e59cb-2380-44a4-86df-1995e907fb85','45c69ae5-5504-4501-9186-3762932567a6','2026-06-10 07:46:51',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-3-7lkdyqj3pprk','45c69ae5-5504-4501-9186-3762932567a6','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(907,'803aada2-d093-48ad-83aa-002ad19b869e','94d425d6-e979-442e-9ced-f97d6ff4aeff','2026-06-10 07:46:51',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-6-xtaibtgtfyxf-RoleParametersValue-fri2s5y3dvbd','state changed','OS::Heat::Value',NULL,662),(908,'98f6e009-cbb0-48d0-92bf-d7325d23beaf','94d425d6-e979-442e-9ced-f97d6ff4aeff','2026-06-10 07:46:51',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-6-xtaibtgtfyxf-RoleParametersValue-fri2s5y3dvbd','state changed','OS::Heat::Value',NULL,662),(909,'362a71b8-e39e-44dc-8fe5-6cdb808dc971','9f86f081-2833-404e-b7e9-c37d22a9039a','2026-06-10 07:46:51',NULL,'CREATE','IN_PROGRESS','ApacheServiceBase','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-4-lmmwe7oeumhq-ApacheServiceBase-oq2czojf4k75','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,663),(910,'5c6da9a5-7c70-46eb-b81e-bdedc0b9be76','bedfb749-12ac-460b-8295-8c4321354848','2026-06-10 07:46:51',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-5-kzg656rhl3bw-RoleParametersValue-fv5kqrejpd2x','state changed','OS::Heat::Value',NULL,664),(911,'c04d0291-3c06-41da-b8d6-2e2552e856a7','bedfb749-12ac-460b-8295-8c4321354848','2026-06-10 07:46:51',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-5-kzg656rhl3bw-RoleParametersValue-fv5kqrejpd2x','state changed','OS::Heat::Value',NULL,664),(912,'9616861d-2819-429e-a4c1-e0e7d5e25250','5065a7bc-c1da-4a33-9b71-eefe055c4a3f','2026-06-10 07:46:51',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-4-lmmwe7oeumhq-ApacheServiceBase-oq2czojf4k75','5065a7bc-c1da-4a33-9b71-eefe055c4a3f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(913,'85ddcf0e-b391-41d6-b710-7675f4f14205','a77a59ca-98d3-42cd-b956-3105451f83e8','2026-06-10 07:46:51',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-6-xtaibtgtfyxf-CinderCommon-znbkekbixkxy-ContainersCommon-romrrfmwzzfs','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(914,'a16780e2-3b58-4ad6-8e8d-50e00e57b7c5','5065a7bc-c1da-4a33-9b71-eefe055c4a3f','2026-06-10 07:46:51',NULL,'CREATE','IN_PROGRESS','ApacheNetworks','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-4-lmmwe7oeumhq-ApacheServiceBase-oq2czojf4k75-ApacheNetworks-jlqeb5fildwi','state changed','OS::Heat::Value',NULL,665),(915,'58e5662b-8dd0-4629-a793-a479ae76db63','7b2f8b31-0b3d-41d8-ad17-175eec1e9cd7','2026-06-10 07:46:51',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-4-lmmwe7oeumhq-CinderCommon-klorghwwb2un-ContainersCommon-3rvnzt6xu4vk','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(916,'5d2480ac-f143-44eb-8007-dd6a35608dad','5065a7bc-c1da-4a33-9b71-eefe055c4a3f','2026-06-10 07:46:51',NULL,'CREATE','COMPLETE','ApacheNetworks','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-4-lmmwe7oeumhq-ApacheServiceBase-oq2czojf4k75-ApacheNetworks-jlqeb5fildwi','state changed','OS::Heat::Value',NULL,665),(917,'c01e2c91-1f9a-4170-8259-aa37175db377','a77a59ca-98d3-42cd-b956-3105451f83e8','2026-06-10 07:46:51',NULL,'CREATE','COMPLETE','CinderNVMeOF','ce2aeaba-ccc1-4807-b31d-f03e1c3fcbd8','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(918,'3d9fb97d-eaa6-4713-9ab1-a41fffb17134','bb09f4d3-a823-44c5-9264-0c178c9c205e','2026-06-10 07:46:51',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-6-xtaibtgtfyxf-CinderCommon-znbkekbixkxy-ContainersCommon-romrrfmwzzfs','bb09f4d3-a823-44c5-9264-0c178c9c205e','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(919,'2a70242a-0309-43a8-8fc0-d76b6b621d4d','5065a7bc-c1da-4a33-9b71-eefe055c4a3f','2026-06-10 07:46:51',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-4-lmmwe7oeumhq-ApacheServiceBase-oq2czojf4k75','5065a7bc-c1da-4a33-9b71-eefe055c4a3f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(920,'42ea479d-5b5b-4d6f-9fb3-5e0e8a100b70','bb09f4d3-a823-44c5-9264-0c178c9c205e','2026-06-10 07:46:51',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-6-xtaibtgtfyxf-CinderCommon-znbkekbixkxy-ContainersCommon-romrrfmwzzfs','bb09f4d3-a823-44c5-9264-0c178c9c205e','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(921,'8f078aa8-a43f-4043-93af-413f95692193','4017d6fa-2104-4091-bb28-46e7a8dc2120','2026-06-10 07:46:51',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-4-lmmwe7oeumhq-CinderCommon-klorghwwb2un-ContainersCommon-3rvnzt6xu4vk','4017d6fa-2104-4091-bb28-46e7a8dc2120','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(922,'e27ad98e-2cc7-491c-8fca-b25d4a9e34f5','a77a59ca-98d3-42cd-b956-3105451f83e8','2026-06-10 07:46:51',NULL,'CREATE','COMPLETE','ContainersCommon','bb09f4d3-a823-44c5-9264-0c178c9c205e','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(923,'6fabc335-d231-4578-9aa8-f0ba9c6e25ad','7b2f8b31-0b3d-41d8-ad17-175eec1e9cd7','2026-06-10 07:46:51',NULL,'CREATE','COMPLETE','CinderNVMeOF','4b97ed00-2103-4f25-a7be-c78904114b7c','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(924,'e29b8ca1-8cad-4504-89ee-ce0ff87dc216','a77a59ca-98d3-42cd-b956-3105451f83e8','2026-06-10 07:46:51',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-6-xtaibtgtfyxf-CinderCommon-znbkekbixkxy','a77a59ca-98d3-42cd-b956-3105451f83e8','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(925,'2c811889-9b15-4645-a1cb-1218aac368cc','4017d6fa-2104-4091-bb28-46e7a8dc2120','2026-06-10 07:46:51',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-4-lmmwe7oeumhq-CinderCommon-klorghwwb2un-ContainersCommon-3rvnzt6xu4vk','4017d6fa-2104-4091-bb28-46e7a8dc2120','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(926,'7154f762-a46d-409d-b1b0-c395ea056ae7','bedfb749-12ac-460b-8295-8c4321354848','2026-06-10 07:46:51',NULL,'CREATE','COMPLETE','CinderCommon','ce40fea2-b70e-4789-8ca4-0f75fa3615fa','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml',NULL,NULL),(927,'628a7d4f-8b6f-47c5-b488-8bd14f1393a6','be5dff6f-9852-4e4d-828d-565dd452586c','2026-06-10 07:46:51',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-5-kzg656rhl3bw-CinderBackupBase-czb6i5cj3vvx-RoleParametersValue-pqaito7drxmo','state changed','OS::Heat::Value',NULL,666),(928,'175822b0-a856-4563-9bbe-5055e3843fca','be5dff6f-9852-4e4d-828d-565dd452586c','2026-06-10 07:46:51',NULL,'CREATE','COMPLETE','ContainersCommon','659a024b-11f4-4c48-95b1-8ee6b6530726','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(929,'73221027-4d84-4925-afce-255d15557493','be5dff6f-9852-4e4d-828d-565dd452586c','2026-06-10 07:46:51',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-5-kzg656rhl3bw-CinderBackupBase-czb6i5cj3vvx-RoleParametersValue-pqaito7drxmo','state changed','OS::Heat::Value',NULL,666),(930,'f12b240d-8795-421b-bef6-b5ef253bb75b','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:46:51',NULL,'CREATE','COMPLETE','3','45c69ae5-5504-4501-9186-3762932567a6','state changed','OS::TripleO::Services::CeilometerAgentNotification',NULL,633),(931,'e98c453d-5697-441c-b306-2bef09991341','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:46:52',NULL,'CREATE','IN_PROGRESS','7','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-7-oiqmy32peq6v','state changed','OS::TripleO::Services::CinderVolume',NULL,671),(932,'2f9f958d-7427-4eb9-b66e-ca343f387b20','289ebc27-4c63-4ac6-89a4-865c7a241fc8','2026-06-10 07:46:52',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-7-oiqmy32peq6v','289ebc27-4c63-4ac6-89a4-865c7a241fc8','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(933,'fd7a5280-1dbd-41f1-bb31-5bbd2db7aad5','94d425d6-e979-442e-9ced-f97d6ff4aeff','2026-06-10 07:46:52',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-6-xtaibtgtfyxf-MySQLClient-luvao2lfieqb','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(934,'199e382d-47ff-4038-b84a-3e1cd7e12d79','9f86f081-2833-404e-b7e9-c37d22a9039a','2026-06-10 07:46:52',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-4-lmmwe7oeumhq-ContainersCommon-igla7yqeg4bn','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(935,'59122f16-ecfa-4419-b08c-47a5e72c461c','f3e1038a-f5d6-4b1d-9c56-324ee58e51cb','2026-06-10 07:46:52',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-6-xtaibtgtfyxf-MySQLClient-luvao2lfieqb','f3e1038a-f5d6-4b1d-9c56-324ee58e51cb','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(936,'4e39b433-aa29-4ff0-9468-d2af382ebc24','289ebc27-4c63-4ac6-89a4-865c7a241fc8','2026-06-10 07:46:52',NULL,'CREATE','IN_PROGRESS','CinderCommon','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-7-oiqmy32peq6v-CinderCommon-nub2zqpb6bsd','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml',NULL,NULL),(937,'0384f3f1-47c9-4844-aa8f-dad4b8fa7e0b','9f86f081-2833-404e-b7e9-c37d22a9039a','2026-06-10 07:46:52',NULL,'CREATE','COMPLETE','ApacheServiceBase','5065a7bc-c1da-4a33-9b71-eefe055c4a3f','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,663),(938,'07241084-cc7d-4f27-aa86-12c1c1710292','94d425d6-e979-442e-9ced-f97d6ff4aeff','2026-06-10 07:46:52',NULL,'CREATE','COMPLETE','CinderCommon','a77a59ca-98d3-42cd-b956-3105451f83e8','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml',NULL,NULL),(939,'55c5937d-acbf-4b13-927a-362f62851eeb','f3e1038a-f5d6-4b1d-9c56-324ee58e51cb','2026-06-10 07:46:52',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-6-xtaibtgtfyxf-MySQLClient-luvao2lfieqb','f3e1038a-f5d6-4b1d-9c56-324ee58e51cb','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(940,'92af3af2-95d1-4c08-af2b-9b1548c33f26','f31cbbfa-0315-474b-9e2a-fff397583ef1','2026-06-10 07:46:52',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-4-lmmwe7oeumhq-ContainersCommon-igla7yqeg4bn','f31cbbfa-0315-474b-9e2a-fff397583ef1','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(941,'a1d41201-eee6-4726-a3ce-38354b5b130b','f31cbbfa-0315-474b-9e2a-fff397583ef1','2026-06-10 07:46:52',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-4-lmmwe7oeumhq-ContainersCommon-igla7yqeg4bn','f31cbbfa-0315-474b-9e2a-fff397583ef1','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(942,'2dc6e991-550e-4e02-a3fb-693589de4078','9f86f081-2833-404e-b7e9-c37d22a9039a','2026-06-10 07:46:52',NULL,'CREATE','COMPLETE','ContainersCommon','f31cbbfa-0315-474b-9e2a-fff397583ef1','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(943,'e7e99b1c-0aaa-48eb-a11d-36463676d417','9a5db92e-551d-4ad5-8e2f-018b30991914','2026-06-10 07:46:52',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-7-oiqmy32peq6v-CinderCommon-nub2zqpb6bsd','9a5db92e-551d-4ad5-8e2f-018b30991914','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(944,'f0c1316d-e3cd-4bcc-8693-a65f3da7d75b','9a5db92e-551d-4ad5-8e2f-018b30991914','2026-06-10 07:46:52',NULL,'CREATE','IN_PROGRESS','CinderNVMeOF','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-7-oiqmy32peq6v-CinderCommon-nub2zqpb6bsd-CinderNVMeOF-gl5kysvtlvqd','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(945,'cba7357d-3884-45c7-a3b9-b8766e4fbb2e','7b2f8b31-0b3d-41d8-ad17-175eec1e9cd7','2026-06-10 07:46:52',NULL,'CREATE','COMPLETE','ContainersCommon','4017d6fa-2104-4091-bb28-46e7a8dc2120','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(946,'c38de915-257e-47c4-a9c4-4f93ec91d7a2','be5dff6f-9852-4e4d-828d-565dd452586c','2026-06-10 07:46:52',NULL,'CREATE','IN_PROGRESS','CinderCommon','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-5-kzg656rhl3bw-CinderBackupBase-czb6i5cj3vvx-CinderCommon-fj2mmy3qqut4','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml',NULL,NULL),(947,'4b2064a4-7e65-49e2-9876-593838301390','7b2f8b31-0b3d-41d8-ad17-175eec1e9cd7','2026-06-10 07:46:52',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-4-lmmwe7oeumhq-CinderCommon-klorghwwb2un','7b2f8b31-0b3d-41d8-ad17-175eec1e9cd7','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(948,'ecda1ff3-0dd3-4a14-a343-b2703d822545','ea7680be-2756-4c96-91c9-b976c4b2c7c4','2026-06-10 07:46:52',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-7-oiqmy32peq6v-CinderCommon-nub2zqpb6bsd-CinderNVMeOF-gl5kysvtlvqd','ea7680be-2756-4c96-91c9-b976c4b2c7c4','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(949,'d6bd6a3f-42d4-40b0-a565-e90313e24605','ea7680be-2756-4c96-91c9-b976c4b2c7c4','2026-06-10 07:46:52',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-7-oiqmy32peq6v-CinderCommon-nub2zqpb6bsd-CinderNVMeOF-gl5kysvtlvqd','ea7680be-2756-4c96-91c9-b976c4b2c7c4','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(950,'a256ca37-4144-4521-8ae4-f4cb87bf5fec','45356985-3e9d-4e4a-9cb2-28e759e0f8fa','2026-06-10 07:46:52',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-5-kzg656rhl3bw-CinderBackupBase-czb6i5cj3vvx-CinderCommon-fj2mmy3qqut4','45356985-3e9d-4e4a-9cb2-28e759e0f8fa','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(951,'5767a7dd-7397-4ef9-9e85-10e4a2555302','45356985-3e9d-4e4a-9cb2-28e759e0f8fa','2026-06-10 07:46:52',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-5-kzg656rhl3bw-CinderBackupBase-czb6i5cj3vvx-CinderCommon-fj2mmy3qqut4-ContainersCommon-xg6c3clndmun','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(952,'53c490e8-8f7e-48a7-b60b-5335212f7a33','1a0055ee-0e3b-4763-9f8e-0939c4f8f6a0','2026-06-10 07:46:53',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-5-kzg656rhl3bw-CinderBackupBase-czb6i5cj3vvx-CinderCommon-fj2mmy3qqut4-ContainersCommon-xg6c3clndmun','1a0055ee-0e3b-4763-9f8e-0939c4f8f6a0','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(953,'507f3c47-6d60-48c4-b058-dfd7d72bfeae','1a0055ee-0e3b-4763-9f8e-0939c4f8f6a0','2026-06-10 07:46:53',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-5-kzg656rhl3bw-CinderBackupBase-czb6i5cj3vvx-CinderCommon-fj2mmy3qqut4-ContainersCommon-xg6c3clndmun','1a0055ee-0e3b-4763-9f8e-0939c4f8f6a0','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(954,'37082711-1f40-4d2d-9631-4310e8dd3676','94d425d6-e979-442e-9ced-f97d6ff4aeff','2026-06-10 07:46:53',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-6-xtaibtgtfyxf-ContainersCommon-awnsi4xnhekd','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(955,'dd907004-b84d-42ce-96a9-6f38faed16c4','9f86f081-2833-404e-b7e9-c37d22a9039a','2026-06-10 07:46:53',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-4-lmmwe7oeumhq-MySQLClient-dgge7lauvsz2','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(956,'e854a828-fd81-40ee-874a-aeae6d43b592','289ebc27-4c63-4ac6-89a4-865c7a241fc8','2026-06-10 07:46:53',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-7-oiqmy32peq6v-ContainersCommon-xjqnoqr6umzq','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(957,'38824d02-7f4d-47a5-9c0a-4215d0631aad','468de361-0efe-4309-94a3-cd87d404c1be','2026-06-10 07:46:53',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-6-xtaibtgtfyxf-ContainersCommon-awnsi4xnhekd','468de361-0efe-4309-94a3-cd87d404c1be','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(958,'3ef87251-b534-4d16-998b-beae3d3f7b70','468de361-0efe-4309-94a3-cd87d404c1be','2026-06-10 07:46:53',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-6-xtaibtgtfyxf-ContainersCommon-awnsi4xnhekd','468de361-0efe-4309-94a3-cd87d404c1be','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(959,'4b437ee6-d3ac-4dcc-98ae-30ab1e239922','9f86f081-2833-404e-b7e9-c37d22a9039a','2026-06-10 07:46:53',NULL,'CREATE','COMPLETE','CinderCommon','7b2f8b31-0b3d-41d8-ad17-175eec1e9cd7','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml',NULL,NULL),(960,'c1dc5773-5d90-46e2-84c5-b05628974f25','7b7586e6-e19f-472f-86a1-3e6870476216','2026-06-10 07:46:53',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-4-lmmwe7oeumhq-MySQLClient-dgge7lauvsz2','7b7586e6-e19f-472f-86a1-3e6870476216','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(961,'22cfb845-70c4-4ee8-bd5a-3e4cf3abe8c7','94d425d6-e979-442e-9ced-f97d6ff4aeff','2026-06-10 07:46:53',NULL,'CREATE','COMPLETE','MySQLClient','f3e1038a-f5d6-4b1d-9c56-324ee58e51cb','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(962,'74178bf6-608f-4494-8f0e-83cda86edcb6','c3f1f400-d0a1-4a2d-9e1d-2ca13c30da5c','2026-06-10 07:46:53',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-7-oiqmy32peq6v-ContainersCommon-xjqnoqr6umzq','c3f1f400-d0a1-4a2d-9e1d-2ca13c30da5c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(963,'968dbabc-5aad-4c9b-996a-fcfe92cbb49f','c3f1f400-d0a1-4a2d-9e1d-2ca13c30da5c','2026-06-10 07:46:53',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-7-oiqmy32peq6v-ContainersCommon-xjqnoqr6umzq','c3f1f400-d0a1-4a2d-9e1d-2ca13c30da5c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(964,'06e67d0d-a74f-449b-bb45-f18f3a7502a8','7b7586e6-e19f-472f-86a1-3e6870476216','2026-06-10 07:46:53',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-4-lmmwe7oeumhq-MySQLClient-dgge7lauvsz2','7b7586e6-e19f-472f-86a1-3e6870476216','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(965,'a47106b7-f383-4683-aa0e-870ecff7b17b','9a5db92e-551d-4ad5-8e2f-018b30991914','2026-06-10 07:46:53',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-7-oiqmy32peq6v-CinderCommon-nub2zqpb6bsd-ContainersCommon-6cddbovwjoh4','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(966,'02d52b4a-f6e5-451c-9590-149b21631b6a','be5dff6f-9852-4e4d-828d-565dd452586c','2026-06-10 07:46:53',NULL,'CREATE','IN_PROGRESS','CinderBase','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-5-kzg656rhl3bw-CinderBackupBase-czb6i5cj3vvx-CinderBase-adtn6dnievge','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-base.yaml',NULL,672),(967,'c95f6d25-eb50-4598-8dbf-128167041749','443ea005-dbdc-433c-bb5f-840d0a95a473','2026-06-10 07:46:53',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-7-oiqmy32peq6v-CinderCommon-nub2zqpb6bsd-ContainersCommon-6cddbovwjoh4','443ea005-dbdc-433c-bb5f-840d0a95a473','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(968,'2514a6b9-62a2-4a09-b1f7-ca9d45e9d421','9a5db92e-551d-4ad5-8e2f-018b30991914','2026-06-10 07:46:53',NULL,'CREATE','COMPLETE','CinderNVMeOF','ea7680be-2756-4c96-91c9-b976c4b2c7c4','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(969,'f70ee2a1-976d-4d3f-8100-dad3f94acf33','443ea005-dbdc-433c-bb5f-840d0a95a473','2026-06-10 07:46:53',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-7-oiqmy32peq6v-CinderCommon-nub2zqpb6bsd-ContainersCommon-6cddbovwjoh4','443ea005-dbdc-433c-bb5f-840d0a95a473','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(970,'4affe7a2-64d5-499b-b4f1-78d18bab3ae5','499dd282-d34d-4428-b9a2-9409608a1fff','2026-06-10 07:46:53',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-5-kzg656rhl3bw-CinderBackupBase-czb6i5cj3vvx-CinderBase-adtn6dnievge','499dd282-d34d-4428-b9a2-9409608a1fff','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(971,'14a6c283-202f-4044-99ea-8f62302f87f3','499dd282-d34d-4428-b9a2-9409608a1fff','2026-06-10 07:46:53',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-5-kzg656rhl3bw-CinderBackupBase-czb6i5cj3vvx-CinderBase-adtn6dnievge','499dd282-d34d-4428-b9a2-9409608a1fff','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(972,'ba571ec7-a9cc-4f60-8413-e0d2acc64b9c','45356985-3e9d-4e4a-9cb2-28e759e0f8fa','2026-06-10 07:46:53',NULL,'CREATE','IN_PROGRESS','CinderNVMeOF','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-5-kzg656rhl3bw-CinderBackupBase-czb6i5cj3vvx-CinderCommon-fj2mmy3qqut4-CinderNVMeOF-32kyhoapgbce','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(973,'d45a0697-e226-462d-b1a1-53394e0c9d81','a89c6624-192f-442e-8c8e-18ddb2f5fb5a','2026-06-10 07:46:54',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-5-kzg656rhl3bw-CinderBackupBase-czb6i5cj3vvx-CinderCommon-fj2mmy3qqut4-CinderNVMeOF-32kyhoapgbce','a89c6624-192f-442e-8c8e-18ddb2f5fb5a','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(974,'4d365b83-f554-48e1-93a6-7b31388a8df2','a89c6624-192f-442e-8c8e-18ddb2f5fb5a','2026-06-10 07:46:54',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-5-kzg656rhl3bw-CinderBackupBase-czb6i5cj3vvx-CinderCommon-fj2mmy3qqut4-CinderNVMeOF-32kyhoapgbce','a89c6624-192f-442e-8c8e-18ddb2f5fb5a','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(975,'9be6a286-efea-4c36-8a88-dee26999d435','45356985-3e9d-4e4a-9cb2-28e759e0f8fa','2026-06-10 07:46:54',NULL,'CREATE','COMPLETE','ContainersCommon','1a0055ee-0e3b-4763-9f8e-0939c4f8f6a0','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(976,'9dcbf5e3-3e06-40df-bf9a-333d2dd19ace','94d425d6-e979-442e-9ced-f97d6ff4aeff','2026-06-10 07:46:54',NULL,'CREATE','IN_PROGRESS','CinderBase','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-6-xtaibtgtfyxf-CinderBase-mueao4uzmxud','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-base.yaml',NULL,673),(977,'6fe2ed08-ef89-48fc-a6db-a5de9dca8587','9f86f081-2833-404e-b7e9-c37d22a9039a','2026-06-10 07:46:54',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-4-lmmwe7oeumhq-RoleParametersValue-xf5kjdlatbrs','state changed','OS::Heat::Value',NULL,674),(978,'d4b4340b-9226-4e98-ab88-c81a80a02288','9f86f081-2833-404e-b7e9-c37d22a9039a','2026-06-10 07:46:54',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-4-lmmwe7oeumhq-RoleParametersValue-xf5kjdlatbrs','state changed','OS::Heat::Value',NULL,674),(979,'a5778f13-23f1-411b-a0d3-9f807ce869f0','94d425d6-e979-442e-9ced-f97d6ff4aeff','2026-06-10 07:46:54',NULL,'CREATE','COMPLETE','ContainersCommon','468de361-0efe-4309-94a3-cd87d404c1be','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(980,'b8de8b76-6f7d-417f-8a10-59a94a13f4e6','289ebc27-4c63-4ac6-89a4-865c7a241fc8','2026-06-10 07:46:54',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-7-oiqmy32peq6v-RoleParametersValue-5eknd5f55zl3','state changed','OS::Heat::Value',NULL,675),(981,'92d82fa6-4364-4cd1-aae6-1b6cbf546a87','8da73a41-50e7-4bf5-930f-be6cfe41a8dc','2026-06-10 07:46:54',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-6-xtaibtgtfyxf-CinderBase-mueao4uzmxud','8da73a41-50e7-4bf5-930f-be6cfe41a8dc','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(982,'42d8d3f7-72c2-4158-9f2b-9e56449ce0a4','289ebc27-4c63-4ac6-89a4-865c7a241fc8','2026-06-10 07:46:54',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-7-oiqmy32peq6v-RoleParametersValue-5eknd5f55zl3','state changed','OS::Heat::Value',NULL,675),(983,'d7b37bd4-ab9c-45d9-912e-83b5b05fe26b','9f86f081-2833-404e-b7e9-c37d22a9039a','2026-06-10 07:46:54',NULL,'CREATE','COMPLETE','MySQLClient','7b7586e6-e19f-472f-86a1-3e6870476216','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(984,'36286445-1afc-43bc-ad51-183725119060','8da73a41-50e7-4bf5-930f-be6cfe41a8dc','2026-06-10 07:46:54',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-6-xtaibtgtfyxf-CinderBase-mueao4uzmxud','8da73a41-50e7-4bf5-930f-be6cfe41a8dc','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(985,'0e6a4a31-0930-41b8-b75b-ac6f581caa9d','289ebc27-4c63-4ac6-89a4-865c7a241fc8','2026-06-10 07:46:54',NULL,'CREATE','COMPLETE','ContainersCommon','c3f1f400-d0a1-4a2d-9e1d-2ca13c30da5c','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(986,'4f1a51d9-a345-46c0-8a61-0021ef0793f5','be5dff6f-9852-4e4d-828d-565dd452586c','2026-06-10 07:46:54',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-5-kzg656rhl3bw-CinderBackupBase-czb6i5cj3vvx-MySQLClient-6mndz53gkq3n','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(987,'53977f76-da69-4e79-9347-5a5e359168fd','6c60daa2-fe36-4ab1-8768-f12586b87f8e','2026-06-10 07:46:54',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-5-kzg656rhl3bw-CinderBackupBase-czb6i5cj3vvx-MySQLClient-6mndz53gkq3n','6c60daa2-fe36-4ab1-8768-f12586b87f8e','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(988,'0cb6196e-a7c3-4289-bb69-c1f1eba040e0','9a5db92e-551d-4ad5-8e2f-018b30991914','2026-06-10 07:46:54',NULL,'CREATE','COMPLETE','ContainersCommon','443ea005-dbdc-433c-bb5f-840d0a95a473','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(989,'3c0ad631-9484-45de-95e9-f1712055c5b7','6c60daa2-fe36-4ab1-8768-f12586b87f8e','2026-06-10 07:46:54',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-5-kzg656rhl3bw-CinderBackupBase-czb6i5cj3vvx-MySQLClient-6mndz53gkq3n','6c60daa2-fe36-4ab1-8768-f12586b87f8e','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(990,'1662c2e5-32ea-4275-ae11-23826bda15f7','be5dff6f-9852-4e4d-828d-565dd452586c','2026-06-10 07:46:54',NULL,'CREATE','COMPLETE','CinderBase','499dd282-d34d-4428-b9a2-9409608a1fff','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-base.yaml',NULL,672),(991,'178d1c82-c04a-4ee1-a010-6e6c6ca3b054','9a5db92e-551d-4ad5-8e2f-018b30991914','2026-06-10 07:46:54',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-7-oiqmy32peq6v-CinderCommon-nub2zqpb6bsd','9a5db92e-551d-4ad5-8e2f-018b30991914','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(992,'7bdcf0ba-63bd-4214-9fb6-bc4ea0deab1b','45356985-3e9d-4e4a-9cb2-28e759e0f8fa','2026-06-10 07:46:55',NULL,'CREATE','COMPLETE','CinderNVMeOF','a89c6624-192f-442e-8c8e-18ddb2f5fb5a','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(993,'5d7cc98a-8701-4afd-a49b-329a8198c570','45356985-3e9d-4e4a-9cb2-28e759e0f8fa','2026-06-10 07:46:55',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-5-kzg656rhl3bw-CinderBackupBase-czb6i5cj3vvx-CinderCommon-fj2mmy3qqut4','45356985-3e9d-4e4a-9cb2-28e759e0f8fa','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(994,'d6b97c7e-1d21-491d-9300-a27d2e1c8b08','9f86f081-2833-404e-b7e9-c37d22a9039a','2026-06-10 07:46:55',NULL,'CREATE','IN_PROGRESS','CinderBase','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-4-lmmwe7oeumhq-CinderBase-op4towz67ehq','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-base.yaml',NULL,676),(995,'e17686b7-ab15-4fa5-969a-10ed05623c86','289ebc27-4c63-4ac6-89a4-865c7a241fc8','2026-06-10 07:46:55',NULL,'CREATE','IN_PROGRESS','CinderBase','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-7-oiqmy32peq6v-CinderBase-4dbfjkawqkou','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml',NULL,677),(996,'afb7fd26-80c7-4a41-8463-c36143a89a99','cbff027b-8444-4a3a-8274-420b61aa26f8','2026-06-10 07:46:55',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-4-lmmwe7oeumhq-CinderBase-op4towz67ehq','cbff027b-8444-4a3a-8274-420b61aa26f8','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(997,'197a26f8-e0af-4c4a-9202-e3f5c8538cf5','cbff027b-8444-4a3a-8274-420b61aa26f8','2026-06-10 07:46:55',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-4-lmmwe7oeumhq-CinderBase-op4towz67ehq','cbff027b-8444-4a3a-8274-420b61aa26f8','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(998,'21523c80-5371-4057-a2b4-bf79e737c510','289ebc27-4c63-4ac6-89a4-865c7a241fc8','2026-06-10 07:46:55',NULL,'CREATE','COMPLETE','CinderCommon','9a5db92e-551d-4ad5-8e2f-018b30991914','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml',NULL,NULL),(999,'d91b79ba-c553-4d2c-9ecd-d37dfaba877b','94d425d6-e979-442e-9ced-f97d6ff4aeff','2026-06-10 07:46:55',NULL,'CREATE','COMPLETE','CinderBase','8da73a41-50e7-4bf5-930f-be6cfe41a8dc','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-base.yaml',NULL,673),(1000,'e63fc51f-1bdb-46af-8da0-35b53f6cb218','9f86f081-2833-404e-b7e9-c37d22a9039a','2026-06-10 07:46:55',NULL,'CREATE','COMPLETE','CinderBase','cbff027b-8444-4a3a-8274-420b61aa26f8','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-base.yaml',NULL,676),(1001,'bb680ff2-978a-48c8-95c7-bb591247aa85','5f24e136-5a11-4672-af28-4244bb2c623e','2026-06-10 07:46:55',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-7-oiqmy32peq6v-CinderBase-4dbfjkawqkou','5f24e136-5a11-4672-af28-4244bb2c623e','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1002,'933f5fa9-f08e-4d9c-8a0e-c1026d755f93','94d425d6-e979-442e-9ced-f97d6ff4aeff','2026-06-10 07:46:55',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-6-xtaibtgtfyxf','94d425d6-e979-442e-9ced-f97d6ff4aeff','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1003,'40d2a19a-8d68-48b8-bfb5-00937dd79ba2','9f86f081-2833-404e-b7e9-c37d22a9039a','2026-06-10 07:46:55',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-4-lmmwe7oeumhq','9f86f081-2833-404e-b7e9-c37d22a9039a','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1004,'e10bcbe6-a90b-458a-8646-0485423e12bf','be5dff6f-9852-4e4d-828d-565dd452586c','2026-06-10 07:46:55',NULL,'CREATE','COMPLETE','MySQLClient','6c60daa2-fe36-4ab1-8768-f12586b87f8e','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1005,'0a8989e8-baa1-4009-a8e1-c0f2d2cac27c','be5dff6f-9852-4e4d-828d-565dd452586c','2026-06-10 07:46:55',NULL,'CREATE','COMPLETE','CinderCommon','45356985-3e9d-4e4a-9cb2-28e759e0f8fa','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml',NULL,NULL),(1006,'6e254239-0c7b-4d95-944c-94b30181833c','be5dff6f-9852-4e4d-828d-565dd452586c','2026-06-10 07:46:55',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-5-kzg656rhl3bw-CinderBackupBase-czb6i5cj3vvx','be5dff6f-9852-4e4d-828d-565dd452586c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1007,'c18c561d-f0c3-4b73-971c-c8333adaef9e','5f24e136-5a11-4672-af28-4244bb2c623e','2026-06-10 07:46:56',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-7-oiqmy32peq6v-CinderBase-4dbfjkawqkou-ContainersCommon-ifnnfonjcukv','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1008,'ab2bdf62-f75a-4887-a9cd-852ce1dc7f0b','42c1fb5b-b52a-4009-85df-36b013ed108b','2026-06-10 07:46:56',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-7-oiqmy32peq6v-CinderBase-4dbfjkawqkou-ContainersCommon-ifnnfonjcukv','42c1fb5b-b52a-4009-85df-36b013ed108b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1009,'b6eefa44-157e-4efc-b8c5-911568d27de0','42c1fb5b-b52a-4009-85df-36b013ed108b','2026-06-10 07:46:56',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-7-oiqmy32peq6v-CinderBase-4dbfjkawqkou-ContainersCommon-ifnnfonjcukv','42c1fb5b-b52a-4009-85df-36b013ed108b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1010,'34b24f54-d6a1-46d9-b6e0-7028aa12fc5a','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:46:56',NULL,'CREATE','COMPLETE','4','9f86f081-2833-404e-b7e9-c37d22a9039a','state changed','OS::TripleO::Services::CinderApi',NULL,659),(1011,'919f6458-c44c-4177-8f89-4b6a9e9f1ec7','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:46:56',NULL,'CREATE','COMPLETE','6','94d425d6-e979-442e-9ced-f97d6ff4aeff','state changed','OS::TripleO::Services::CinderScheduler',NULL,660),(1012,'83b2c6e7-080c-41f2-80ae-152b3793f87a','289ebc27-4c63-4ac6-89a4-865c7a241fc8','2026-06-10 07:46:56',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-7-oiqmy32peq6v-MySQLClient-awdqxez5kr75','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1013,'b5fbc7ad-6e1d-4fb8-84a5-c670b4a90c2b','1d56bb2d-da3b-48e8-af51-01a3e74e60ee','2026-06-10 07:46:56',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-7-oiqmy32peq6v-MySQLClient-awdqxez5kr75','1d56bb2d-da3b-48e8-af51-01a3e74e60ee','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1014,'a12b17b3-b256-406f-bc07-144420c66601','1d56bb2d-da3b-48e8-af51-01a3e74e60ee','2026-06-10 07:46:56',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-7-oiqmy32peq6v-MySQLClient-awdqxez5kr75','1d56bb2d-da3b-48e8-af51-01a3e74e60ee','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1015,'ab6d83bf-9c6f-4b82-b1b4-f680942428e1','bedfb749-12ac-460b-8295-8c4321354848','2026-06-10 07:46:56',NULL,'CREATE','COMPLETE','CinderBackupBase','be5dff6f-9852-4e4d-828d-565dd452586c','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-container-puppet.yaml',NULL,661),(1016,'fe3bd16c-d3c9-4241-88b8-4012d0a274fd','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:46:56',NULL,'CREATE','IN_PROGRESS','8','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-8-ocbvlle566bf','state changed','OS::TripleO::Services::Clustercheck',NULL,693),(1017,'e5f1bee9-cb2c-49c3-a1c8-63a18e2e251d','bedfb749-12ac-460b-8295-8c4321354848','2026-06-10 07:46:56',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-5-kzg656rhl3bw','bedfb749-12ac-460b-8295-8c4321354848','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1018,'30d20db3-379d-4aa2-af36-ba7f040530cf','1cfe1bbb-ba1c-4fc4-93ec-1d7d7c6e5566','2026-06-10 07:46:56',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-8-ocbvlle566bf','1cfe1bbb-ba1c-4fc4-93ec-1d7d7c6e5566','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1019,'f9db5f2f-c401-4dc8-8b12-d21bf9e87431','5f24e136-5a11-4672-af28-4244bb2c623e','2026-06-10 07:46:57',NULL,'CREATE','IN_PROGRESS','CinderBase','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-7-oiqmy32peq6v-CinderBase-4dbfjkawqkou-CinderBase-llvj5mspemoa','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-base.yaml',NULL,695),(1020,'66f199f5-dd47-459b-9150-5d7b49b3cfb1','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:46:57',NULL,'CREATE','IN_PROGRESS','10','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-10-m54pp5unehzd','state changed','OS::TripleO::Services::ContainerImagePrepare',NULL,696),(1021,'39ec7cad-2e3c-4225-b018-ee9dd5b68cbd','1cfe1bbb-ba1c-4fc4-93ec-1d7d7c6e5566','2026-06-10 07:46:57',NULL,'CREATE','IN_PROGRESS','MysqlPuppetBase','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-8-ocbvlle566bf-MysqlPuppetBase-hurnxrkqbq7l','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml',NULL,697),(1022,'d3d3e4b1-102f-459d-888c-3f1fdda2efbb','b0a2645d-473f-44c1-ae71-91e120333136','2026-06-10 07:46:57',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-10-m54pp5unehzd','b0a2645d-473f-44c1-ae71-91e120333136','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1023,'fbfa6ef1-7063-4e36-9f03-f82a8b5f75b0','978876b6-7505-4fd5-94f0-0d70037acae0','2026-06-10 07:46:57',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-7-oiqmy32peq6v-CinderBase-4dbfjkawqkou-CinderBase-llvj5mspemoa','978876b6-7505-4fd5-94f0-0d70037acae0','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1024,'87ff6ff9-9db7-4e8a-a969-21a20c5405b9','5f24e136-5a11-4672-af28-4244bb2c623e','2026-06-10 07:46:57',NULL,'CREATE','COMPLETE','ContainersCommon','42c1fb5b-b52a-4009-85df-36b013ed108b','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1025,'6a5749be-8156-4fd6-821d-1e2677dca8eb','b0a2645d-473f-44c1-ae71-91e120333136','2026-06-10 07:46:57',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-10-m54pp5unehzd','b0a2645d-473f-44c1-ae71-91e120333136','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1026,'7552de91-d60e-4087-b94f-4a37e7ee4cf4','978876b6-7505-4fd5-94f0-0d70037acae0','2026-06-10 07:46:57',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-7-oiqmy32peq6v-CinderBase-4dbfjkawqkou-CinderBase-llvj5mspemoa','978876b6-7505-4fd5-94f0-0d70037acae0','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1027,'859c951f-5ff7-445e-ae5d-3ad13e8b7547','c8a451a7-ce58-46b8-a380-473671fb1ebf','2026-06-10 07:46:57',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-8-ocbvlle566bf-MysqlPuppetBase-hurnxrkqbq7l','c8a451a7-ce58-46b8-a380-473671fb1ebf','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1028,'baec5bb6-6740-41e3-9029-b2d6fdc7acdd','c8a451a7-ce58-46b8-a380-473671fb1ebf','2026-06-10 07:46:57',NULL,'CREATE','IN_PROGRESS','MysqlBase','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-8-ocbvlle566bf-MysqlPuppetBase-hurnxrkqbq7l-MysqlBase-crihagqtypkh','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-base.yaml',NULL,698),(1029,'8b106857-f60c-4ed3-a887-5f11b34c96cc','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:46:57',NULL,'CREATE','COMPLETE','5','bedfb749-12ac-460b-8295-8c4321354848','state changed','OS::TripleO::Services::CinderBackup',NULL,621),(1030,'11e8e2c2-d75c-4096-84a0-8af6fa921b6c','e45ab6a1-2709-4885-a9b3-6f43277892ed','2026-06-10 07:46:57',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-8-ocbvlle566bf-MysqlPuppetBase-hurnxrkqbq7l-MysqlBase-crihagqtypkh','e45ab6a1-2709-4885-a9b3-6f43277892ed','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1031,'3d1b329d-cdfc-4343-8e28-ec73f9708e8b','e45ab6a1-2709-4885-a9b3-6f43277892ed','2026-06-10 07:46:57',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-8-ocbvlle566bf-MysqlPuppetBase-hurnxrkqbq7l-MysqlBase-crihagqtypkh','e45ab6a1-2709-4885-a9b3-6f43277892ed','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1032,'1f005794-864e-4aba-bb9f-4b9b76e685f7','289ebc27-4c63-4ac6-89a4-865c7a241fc8','2026-06-10 07:46:57',NULL,'CREATE','COMPLETE','MySQLClient','1d56bb2d-da3b-48e8-af51-01a3e74e60ee','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1033,'147dfd65-0f06-4a42-aa75-7247a0b5a5fd','5f24e136-5a11-4672-af28-4244bb2c623e','2026-06-10 07:46:58',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-7-oiqmy32peq6v-CinderBase-4dbfjkawqkou-MySQLClient-au7veceap3eb','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1034,'b0c3ebeb-7218-4b5c-863c-b6275c11b6e0','1cfe1bbb-ba1c-4fc4-93ec-1d7d7c6e5566','2026-06-10 07:46:58',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-8-ocbvlle566bf-RoleParametersValue-2etcegebyq4w','state changed','OS::Heat::Value',NULL,710),(1035,'19fd7828-1d51-4b25-b537-faed47e5ad6e','1cfe1bbb-ba1c-4fc4-93ec-1d7d7c6e5566','2026-06-10 07:46:58',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-8-ocbvlle566bf-RoleParametersValue-2etcegebyq4w','state changed','OS::Heat::Value',NULL,710),(1036,'15157eba-0c86-4da9-98d2-9fca898ac4eb','afa68341-eed6-4412-88d3-b467a5a1e2a1','2026-06-10 07:46:58',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-7-oiqmy32peq6v-CinderBase-4dbfjkawqkou-MySQLClient-au7veceap3eb','afa68341-eed6-4412-88d3-b467a5a1e2a1','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1037,'3fa0218f-232c-4e63-a458-50cbebe5bf38','afa68341-eed6-4412-88d3-b467a5a1e2a1','2026-06-10 07:46:58',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-7-oiqmy32peq6v-CinderBase-4dbfjkawqkou-MySQLClient-au7veceap3eb','afa68341-eed6-4412-88d3-b467a5a1e2a1','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1038,'dbc07146-0f65-4876-89ac-be4eb5638ca5','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:46:58',NULL,'CREATE','COMPLETE','10','b0a2645d-473f-44c1-ae71-91e120333136','state changed','OS::TripleO::Services::ContainerImagePrepare',NULL,696),(1039,'88dad9d3-682e-4450-9414-cc30cec612da','5f24e136-5a11-4672-af28-4244bb2c623e','2026-06-10 07:46:58',NULL,'CREATE','COMPLETE','CinderBase','978876b6-7505-4fd5-94f0-0d70037acae0','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-base.yaml',NULL,695),(1040,'21762bd0-df1b-4e97-a74a-55434895c749','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:46:58',NULL,'CREATE','IN_PROGRESS','9','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-9-er4brv523k4m','state changed','OS::TripleO::Services::Collectd',NULL,716),(1041,'ff234e60-8d0b-4193-bbd2-d8835fc43034','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:46:58',NULL,'CREATE','IN_PROGRESS','14','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-14-shbd7zd6savu','state changed','OS::TripleO::Services::HeatApi',NULL,717),(1042,'4aac6545-b766-4bba-81ef-4c1ac2c3a52e','c8a451a7-ce58-46b8-a380-473671fb1ebf','2026-06-10 07:46:58',NULL,'CREATE','COMPLETE','MysqlBase','e45ab6a1-2709-4885-a9b3-6f43277892ed','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-base.yaml',NULL,698),(1043,'0b5e26c5-0a57-42e0-be98-ef4b2e2589f6','c8a451a7-ce58-46b8-a380-473671fb1ebf','2026-06-10 07:46:58',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-8-ocbvlle566bf-MysqlPuppetBase-hurnxrkqbq7l-RoleParametersValue-ynmp5p7xbfsl','state changed','OS::Heat::Value',NULL,718),(1044,'81e01b71-103d-49ba-9db7-502cc1127042','e70de086-fb2c-4aa2-8b11-59c84930a6f6','2026-06-10 07:46:58',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-9-er4brv523k4m','e70de086-fb2c-4aa2-8b11-59c84930a6f6','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1045,'a2ff457b-3bf9-4cb4-ae5b-17efd5f78d21','c8a451a7-ce58-46b8-a380-473671fb1ebf','2026-06-10 07:46:58',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-8-ocbvlle566bf-MysqlPuppetBase-hurnxrkqbq7l-RoleParametersValue-ynmp5p7xbfsl','state changed','OS::Heat::Value',NULL,718),(1046,'cadb48cb-8255-4191-85ca-5aa0afca96c6','d0af96c0-4929-4d5f-9766-c44617d8e95b','2026-06-10 07:46:58',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-14-shbd7zd6savu','d0af96c0-4929-4d5f-9766-c44617d8e95b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1047,'777d9742-1860-43fe-9fea-3ad5655d4f5a','e70de086-fb2c-4aa2-8b11-59c84930a6f6','2026-06-10 07:46:58',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-9-er4brv523k4m-ContainersCommon-td64chtvxflr','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1048,'019d7546-9602-4ef0-92ad-49176f1b3ff7','798ca1dd-5874-4ace-805f-692b78bac0b9','2026-06-10 07:46:58',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-9-er4brv523k4m-ContainersCommon-td64chtvxflr','798ca1dd-5874-4ace-805f-692b78bac0b9','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1049,'53277782-9efb-492e-a7c1-63eba001033f','d0af96c0-4929-4d5f-9766-c44617d8e95b','2026-06-10 07:46:58',NULL,'CREATE','IN_PROGRESS','HeatApiLogging','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-14-shbd7zd6savu-HeatApiLogging-smxpqoyp7vj7','state changed','OS::TripleO::Services::Logging::HeatApi',NULL,NULL),(1050,'ab72ec3c-79ad-4e3e-b2de-28e07f8a8528','798ca1dd-5874-4ace-805f-692b78bac0b9','2026-06-10 07:46:58',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-9-er4brv523k4m-ContainersCommon-td64chtvxflr','798ca1dd-5874-4ace-805f-692b78bac0b9','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1051,'2e0c689f-88e1-4eae-9542-76a362838477','5f75d94a-21aa-4e17-95da-c9c987ea1f1d','2026-06-10 07:46:58',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-14-shbd7zd6savu-HeatApiLogging-smxpqoyp7vj7','5f75d94a-21aa-4e17-95da-c9c987ea1f1d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1052,'4f4ec34b-797d-469d-9711-42a6b135d58e','5f75d94a-21aa-4e17-95da-c9c987ea1f1d','2026-06-10 07:46:58',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-14-shbd7zd6savu-HeatApiLogging-smxpqoyp7vj7','5f75d94a-21aa-4e17-95da-c9c987ea1f1d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1053,'33014a6f-2a51-47f4-b30c-349f4af55fbb','5f24e136-5a11-4672-af28-4244bb2c623e','2026-06-10 07:46:59',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-7-oiqmy32peq6v-CinderBase-4dbfjkawqkou-RoleParametersValue-3iqmld2kqra4','state changed','OS::Heat::Value',NULL,719),(1054,'43719e8b-6dee-47a8-8e36-cdff0b087d48','5f24e136-5a11-4672-af28-4244bb2c623e','2026-06-10 07:46:59',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-7-oiqmy32peq6v-CinderBase-4dbfjkawqkou-RoleParametersValue-3iqmld2kqra4','state changed','OS::Heat::Value',NULL,719),(1055,'9524fefa-c489-4e34-b7e9-0617e4026e5c','1cfe1bbb-ba1c-4fc4-93ec-1d7d7c6e5566','2026-06-10 07:46:59',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-8-ocbvlle566bf-ContainersCommon-xmoehdzw6pc7','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1056,'2528832d-70fb-44b8-bf5d-3afc844ab15a','38bef7f0-c419-4201-8610-9cf41115c3f9','2026-06-10 07:46:59',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-8-ocbvlle566bf-ContainersCommon-xmoehdzw6pc7','38bef7f0-c419-4201-8610-9cf41115c3f9','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1057,'21b850b4-3f85-4eca-84f2-839f3b2d7427','5f24e136-5a11-4672-af28-4244bb2c623e','2026-06-10 07:46:59',NULL,'CREATE','COMPLETE','MySQLClient','afa68341-eed6-4412-88d3-b467a5a1e2a1','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1058,'13f88fc4-6bd8-4d73-9a8f-692eeae43911','38bef7f0-c419-4201-8610-9cf41115c3f9','2026-06-10 07:46:59',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-8-ocbvlle566bf-ContainersCommon-xmoehdzw6pc7','38bef7f0-c419-4201-8610-9cf41115c3f9','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1059,'d3d403d6-8b27-447f-81aa-2f7aa01b03d3','c8a451a7-ce58-46b8-a380-473671fb1ebf','2026-06-10 07:46:59',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-8-ocbvlle566bf-MysqlPuppetBase-hurnxrkqbq7l-ContainersCommon-lh4d7h3kgs64','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1060,'1df08c10-f07e-4d75-ac03-1690f7520183','5af8888a-19b7-461e-a05b-6983b6c2bd11','2026-06-10 07:46:59',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-8-ocbvlle566bf-MysqlPuppetBase-hurnxrkqbq7l-ContainersCommon-lh4d7h3kgs64','5af8888a-19b7-461e-a05b-6983b6c2bd11','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1061,'267aecf5-bddb-43b1-bb1b-312e3f961ac3','5af8888a-19b7-461e-a05b-6983b6c2bd11','2026-06-10 07:46:59',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-8-ocbvlle566bf-MysqlPuppetBase-hurnxrkqbq7l-ContainersCommon-lh4d7h3kgs64','5af8888a-19b7-461e-a05b-6983b6c2bd11','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1062,'5e36d074-38da-4ff3-8910-aceabc16dc45','e70de086-fb2c-4aa2-8b11-59c84930a6f6','2026-06-10 07:46:59',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-9-er4brv523k4m-RoleParametersValue-2nz7urf7nbkt','state changed','OS::Heat::Value',NULL,720),(1063,'075548df-70e0-47f6-b15c-385795010bdd','e70de086-fb2c-4aa2-8b11-59c84930a6f6','2026-06-10 07:46:59',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-9-er4brv523k4m-RoleParametersValue-2nz7urf7nbkt','state changed','OS::Heat::Value',NULL,720),(1064,'58cf5862-2fc9-40ad-bd87-120db69068d5','d0af96c0-4929-4d5f-9766-c44617d8e95b','2026-06-10 07:46:59',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-14-shbd7zd6savu-ContainersCommon-3fkib4mnynn3','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1065,'85e137b2-7ff5-41cf-b400-cd2536293b1c','e70de086-fb2c-4aa2-8b11-59c84930a6f6','2026-06-10 07:46:59',NULL,'CREATE','COMPLETE','ContainersCommon','798ca1dd-5874-4ace-805f-692b78bac0b9','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1066,'78a0123f-6385-4326-87fc-7822077d00b5','e70de086-fb2c-4aa2-8b11-59c84930a6f6','2026-06-10 07:46:59',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-9-er4brv523k4m','e70de086-fb2c-4aa2-8b11-59c84930a6f6','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1067,'1ea77623-01b6-495c-a393-e5bb38ab775e','c20705b1-2be0-4f7e-931f-8204042de9b1','2026-06-10 07:46:59',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-14-shbd7zd6savu-ContainersCommon-3fkib4mnynn3','c20705b1-2be0-4f7e-931f-8204042de9b1','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1068,'eb932f03-4ae1-4efc-bc6f-a1b782868353','d0af96c0-4929-4d5f-9766-c44617d8e95b','2026-06-10 07:46:59',NULL,'CREATE','COMPLETE','HeatApiLogging','5f75d94a-21aa-4e17-95da-c9c987ea1f1d','state changed','OS::TripleO::Services::Logging::HeatApi',NULL,NULL),(1069,'4beeefa2-e996-4b6b-8c41-253e19424741','c20705b1-2be0-4f7e-931f-8204042de9b1','2026-06-10 07:46:59',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-14-shbd7zd6savu-ContainersCommon-3fkib4mnynn3','c20705b1-2be0-4f7e-931f-8204042de9b1','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1070,'b7e589ec-b400-4c46-a262-f176dfb524a6','5f24e136-5a11-4672-af28-4244bb2c623e','2026-06-10 07:47:00',NULL,'CREATE','IN_PROGRESS','CinderCommon','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-7-oiqmy32peq6v-CinderBase-4dbfjkawqkou-CinderCommon-sfdilfkqyxah','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml',NULL,NULL),(1071,'c54c33d4-b819-4740-99d9-70e5c60a424a','74069713-2b67-44dd-bbb7-0da95e07ef7f','2026-06-10 07:47:00',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-7-oiqmy32peq6v-CinderBase-4dbfjkawqkou-CinderCommon-sfdilfkqyxah','74069713-2b67-44dd-bbb7-0da95e07ef7f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1072,'d0927142-3876-49b1-8249-d8bc064ab649','1cfe1bbb-ba1c-4fc4-93ec-1d7d7c6e5566','2026-06-10 07:47:00',NULL,'CREATE','COMPLETE','ContainersCommon','38bef7f0-c419-4201-8610-9cf41115c3f9','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1073,'1dafc864-8d36-481b-aa34-32a20f92928c','74069713-2b67-44dd-bbb7-0da95e07ef7f','2026-06-10 07:47:00',NULL,'CREATE','IN_PROGRESS','CinderNVMeOF','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-7-oiqmy32peq6v-CinderBase-4dbfjkawqkou-CinderCommon-sfdilfkqyxah-CinderNVMeOF-tyjpjh33hozs','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(1074,'7f31462c-541e-4abe-816d-a4c71cc800c4','56eb06f5-6d8a-43e9-a571-9fbe6d20b18b','2026-06-10 07:47:00',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-7-oiqmy32peq6v-CinderBase-4dbfjkawqkou-CinderCommon-sfdilfkqyxah-CinderNVMeOF-tyjpjh33hozs','56eb06f5-6d8a-43e9-a571-9fbe6d20b18b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1075,'bc41f61a-4cfe-4a3e-b525-f36f5aef1a8f','56eb06f5-6d8a-43e9-a571-9fbe6d20b18b','2026-06-10 07:47:00',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-7-oiqmy32peq6v-CinderBase-4dbfjkawqkou-CinderCommon-sfdilfkqyxah-CinderNVMeOF-tyjpjh33hozs','56eb06f5-6d8a-43e9-a571-9fbe6d20b18b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1076,'885fdc79-d51a-4e80-b217-cfb6bb432344','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:47:00',NULL,'CREATE','COMPLETE','9','e70de086-fb2c-4aa2-8b11-59c84930a6f6','state changed','OS::TripleO::Services::Collectd',NULL,716),(1077,'b998f4fb-858c-407c-95e4-61cd1931ab2f','c8a451a7-ce58-46b8-a380-473671fb1ebf','2026-06-10 07:47:00',NULL,'CREATE','COMPLETE','ContainersCommon','5af8888a-19b7-461e-a05b-6983b6c2bd11','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1078,'77952dd6-574a-424a-95bb-f84a6c7dc36d','c8a451a7-ce58-46b8-a380-473671fb1ebf','2026-06-10 07:47:00',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-8-ocbvlle566bf-MysqlPuppetBase-hurnxrkqbq7l','c8a451a7-ce58-46b8-a380-473671fb1ebf','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1079,'f0d80946-3d89-4cd9-839a-952c60fe142d','d0af96c0-4929-4d5f-9766-c44617d8e95b','2026-06-10 07:47:00',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-14-shbd7zd6savu-RoleParametersValue-33kdavlyco33','state changed','OS::Heat::Value',NULL,723),(1080,'efeb63ed-ba17-4712-9de6-fdac27b047dc','d0af96c0-4929-4d5f-9766-c44617d8e95b','2026-06-10 07:47:00',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-14-shbd7zd6savu-RoleParametersValue-33kdavlyco33','state changed','OS::Heat::Value',NULL,723),(1081,'e41d1e77-23c6-4c41-9f34-42cd8ca2f4b0','d0af96c0-4929-4d5f-9766-c44617d8e95b','2026-06-10 07:47:00',NULL,'CREATE','COMPLETE','ContainersCommon','c20705b1-2be0-4f7e-931f-8204042de9b1','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1082,'a4a7077b-bcba-4bac-8c73-ed973d8bb4da','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:47:00',NULL,'CREATE','IN_PROGRESS','13','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-13-37l5o2ovm647','state changed','OS::TripleO::Services::HAproxy',NULL,725),(1083,'34ffc4a0-45c5-4bea-ac67-6b067e378e7d','881027ec-a070-404a-ae0b-f1f8d9ee6dff','2026-06-10 07:47:01',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-13-37l5o2ovm647','881027ec-a070-404a-ae0b-f1f8d9ee6dff','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1084,'891c18b8-0774-475e-a067-e09b859d16bb','74069713-2b67-44dd-bbb7-0da95e07ef7f','2026-06-10 07:47:01',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-7-oiqmy32peq6v-CinderBase-4dbfjkawqkou-CinderCommon-sfdilfkqyxah-ContainersCommon-neyt3io2cjsc','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1085,'733f801c-f689-4502-a63c-714a6a7ed566','1cfe1bbb-ba1c-4fc4-93ec-1d7d7c6e5566','2026-06-10 07:47:01',NULL,'CREATE','COMPLETE','MysqlPuppetBase','c8a451a7-ce58-46b8-a380-473671fb1ebf','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml',NULL,697),(1086,'e32a91fb-52ca-49b4-8209-0a04bfa39300','1cfe1bbb-ba1c-4fc4-93ec-1d7d7c6e5566','2026-06-10 07:47:01',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-8-ocbvlle566bf','1cfe1bbb-ba1c-4fc4-93ec-1d7d7c6e5566','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1087,'5b091e45-d423-4343-b125-cd5734b42f8e','881027ec-a070-404a-ae0b-f1f8d9ee6dff','2026-06-10 07:47:01',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-13-37l5o2ovm647-RoleParametersValue-ikb4cah26lnh','state changed','OS::Heat::Value',NULL,726),(1088,'907a00af-75fd-4098-90af-8f6f6b3f9a01','5663406c-09d4-4293-ba6b-2619967cda5e','2026-06-10 07:47:01',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-7-oiqmy32peq6v-CinderBase-4dbfjkawqkou-CinderCommon-sfdilfkqyxah-ContainersCommon-neyt3io2cjsc','5663406c-09d4-4293-ba6b-2619967cda5e','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1089,'d51a65e3-d122-4b73-906b-55fb25fcd500','881027ec-a070-404a-ae0b-f1f8d9ee6dff','2026-06-10 07:47:01',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-13-37l5o2ovm647-RoleParametersValue-ikb4cah26lnh','state changed','OS::Heat::Value',NULL,726),(1090,'60af0b71-240a-4539-bdd0-16861eb012b0','74069713-2b67-44dd-bbb7-0da95e07ef7f','2026-06-10 07:47:01',NULL,'CREATE','COMPLETE','CinderNVMeOF','56eb06f5-6d8a-43e9-a571-9fbe6d20b18b','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(1091,'5988dc7d-f572-401b-9306-5ffcc3762ac3','5663406c-09d4-4293-ba6b-2619967cda5e','2026-06-10 07:47:01',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-7-oiqmy32peq6v-CinderBase-4dbfjkawqkou-CinderCommon-sfdilfkqyxah-ContainersCommon-neyt3io2cjsc','5663406c-09d4-4293-ba6b-2619967cda5e','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1092,'2bdc43ae-9c76-4bc5-ba5b-e17843f7be60','d0af96c0-4929-4d5f-9766-c44617d8e95b','2026-06-10 07:47:01',NULL,'CREATE','IN_PROGRESS','ApacheServiceBase','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-14-shbd7zd6savu-ApacheServiceBase-tuczryvyz6kf','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,727),(1093,'3d3688c1-11b1-435b-a183-857bfe9a115a','ea48c9ed-6a8f-4c56-80de-d8bbb1be118d','2026-06-10 07:47:01',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-14-shbd7zd6savu-ApacheServiceBase-tuczryvyz6kf','ea48c9ed-6a8f-4c56-80de-d8bbb1be118d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1094,'f1121c8f-1c05-448d-9325-c4fddae766fd','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:47:02',NULL,'CREATE','COMPLETE','8','1cfe1bbb-ba1c-4fc4-93ec-1d7d7c6e5566','state changed','OS::TripleO::Services::Clustercheck',NULL,693),(1095,'11397914-718c-4749-81d7-3ac6efecfd72','ea48c9ed-6a8f-4c56-80de-d8bbb1be118d','2026-06-10 07:47:02',NULL,'CREATE','IN_PROGRESS','ApacheNetworks','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-14-shbd7zd6savu-ApacheServiceBase-tuczryvyz6kf-ApacheNetworks-f4jhx76wc5ku','state changed','OS::Heat::Value',NULL,728),(1096,'8de0349c-6739-4f27-bfec-ff30fa145264','ea48c9ed-6a8f-4c56-80de-d8bbb1be118d','2026-06-10 07:47:02',NULL,'CREATE','COMPLETE','ApacheNetworks','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-14-shbd7zd6savu-ApacheServiceBase-tuczryvyz6kf-ApacheNetworks-f4jhx76wc5ku','state changed','OS::Heat::Value',NULL,728),(1097,'fd10bdd2-1838-40f6-a7a9-2215d91eff74','ea48c9ed-6a8f-4c56-80de-d8bbb1be118d','2026-06-10 07:47:02',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-14-shbd7zd6savu-ApacheServiceBase-tuczryvyz6kf','ea48c9ed-6a8f-4c56-80de-d8bbb1be118d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1098,'32855b62-8d2b-46d5-a883-e7ddfe20c901','881027ec-a070-404a-ae0b-f1f8d9ee6dff','2026-06-10 07:47:02',NULL,'CREATE','IN_PROGRESS','HAProxyBase','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-13-37l5o2ovm647-HAProxyBase-f3gxc3qzmenl','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-container-puppet.yaml',NULL,734),(1099,'13a25568-836c-40fc-ae41-31950505d511','74069713-2b67-44dd-bbb7-0da95e07ef7f','2026-06-10 07:47:02',NULL,'CREATE','COMPLETE','ContainersCommon','5663406c-09d4-4293-ba6b-2619967cda5e','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1100,'56d050a6-1d2d-4406-bfb0-01218e36a829','74069713-2b67-44dd-bbb7-0da95e07ef7f','2026-06-10 07:47:02',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-7-oiqmy32peq6v-CinderBase-4dbfjkawqkou-CinderCommon-sfdilfkqyxah','74069713-2b67-44dd-bbb7-0da95e07ef7f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1101,'53661a96-8d13-43d8-a343-9dd9f4683ead','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:47:02',NULL,'CREATE','IN_PROGRESS','12','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-12-cjik4s3hygrq','state changed','OS::TripleO::Services::GlanceApiInternal',NULL,737),(1102,'dc20c740-231e-45c1-8094-4e62e5e84651','fe21e00f-a9f7-4834-b7e8-7dd5feb49ad1','2026-06-10 07:47:02',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-13-37l5o2ovm647-HAProxyBase-f3gxc3qzmenl','fe21e00f-a9f7-4834-b7e8-7dd5feb49ad1','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1103,'d086ed88-9676-4626-978f-97095bbb7591','cb4c493d-3e4d-4edc-841e-c5167c205102','2026-06-10 07:47:02',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-12-cjik4s3hygrq','cb4c493d-3e4d-4edc-841e-c5167c205102','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1104,'93104a0c-0503-48d2-98b2-2d2c35b15788','fe21e00f-a9f7-4834-b7e8-7dd5feb49ad1','2026-06-10 07:47:02',NULL,'CREATE','IN_PROGRESS','HAProxyInternalTLS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-13-37l5o2ovm647-HAProxyBase-f3gxc3qzmenl-HAProxyInternalTLS-yrly3nuaccn6','state changed','OS::TripleO::Services::HAProxyInternalTLS',NULL,NULL),(1105,'26d3634a-59ec-4e0d-83fc-362d1261e4f8','fe21e00f-a9f7-4834-b7e8-7dd5feb49ad1','2026-06-10 07:47:02',NULL,'CREATE','COMPLETE','HAProxyInternalTLS','7cedd688-65fc-481f-9137-06fabe6b61cf','state changed','OS::TripleO::Services::HAProxyInternalTLS',NULL,NULL),(1106,'1337eb57-adad-4843-aa3b-8ebc709f1b63','d0af96c0-4929-4d5f-9766-c44617d8e95b','2026-06-10 07:47:02',NULL,'CREATE','IN_PROGRESS','HeatBase','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-14-shbd7zd6savu-HeatBase-izvj5ft6gjfi','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-base-puppet.yaml',NULL,738),(1107,'d35b7dc5-eeae-4a04-bc28-9de220edd110','cb4c493d-3e4d-4edc-841e-c5167c205102','2026-06-10 07:47:02',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-12-cjik4s3hygrq-RoleParametersValue-i4bpfd65duwu','state changed','OS::Heat::Value',NULL,739),(1108,'8cc1521a-43f9-45f9-8896-f5e27ee62c4d','cb4c493d-3e4d-4edc-841e-c5167c205102','2026-06-10 07:47:02',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-12-cjik4s3hygrq-RoleParametersValue-i4bpfd65duwu','state changed','OS::Heat::Value',NULL,739),(1109,'76bdbe6f-70e2-4c0d-bbc0-39c6505dd82b','4c880784-85fe-4374-aef6-4d5a1ca079eb','2026-06-10 07:47:02',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-14-shbd7zd6savu-HeatBase-izvj5ft6gjfi','4c880784-85fe-4374-aef6-4d5a1ca079eb','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1110,'ef1deb56-60e8-431a-bc59-2a36179be7e4','4c880784-85fe-4374-aef6-4d5a1ca079eb','2026-06-10 07:47:02',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-14-shbd7zd6savu-HeatBase-izvj5ft6gjfi','4c880784-85fe-4374-aef6-4d5a1ca079eb','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1111,'2b40ddf4-c837-4286-ac56-c35cd9521ff2','d0af96c0-4929-4d5f-9766-c44617d8e95b','2026-06-10 07:47:02',NULL,'CREATE','COMPLETE','ApacheServiceBase','ea48c9ed-6a8f-4c56-80de-d8bbb1be118d','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,727),(1112,'2026825a-5b91-43ac-a869-ef62146ed472','5f24e136-5a11-4672-af28-4244bb2c623e','2026-06-10 07:47:03',NULL,'CREATE','COMPLETE','CinderCommon','74069713-2b67-44dd-bbb7-0da95e07ef7f','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml',NULL,NULL),(1113,'73956a37-389e-46dc-a70d-493a979c0b6e','5f24e136-5a11-4672-af28-4244bb2c623e','2026-06-10 07:47:03',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-7-oiqmy32peq6v-CinderBase-4dbfjkawqkou','5f24e136-5a11-4672-af28-4244bb2c623e','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1114,'e72042d2-5344-420c-a8b6-71b6a2e4f10a','881027ec-a070-404a-ae0b-f1f8d9ee6dff','2026-06-10 07:47:03',NULL,'CREATE','IN_PROGRESS','HAProxyPublicTLS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-13-37l5o2ovm647-HAProxyPublicTLS-tgwzo2xosx7b','state changed','OS::TripleO::Services::HAProxyPublicTLS',NULL,740),(1115,'64e4282b-1915-470b-b6a6-1834040447a2','eff2afcd-9554-44f8-b627-da396584063a','2026-06-10 07:47:03',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-13-37l5o2ovm647-HAProxyPublicTLS-tgwzo2xosx7b','eff2afcd-9554-44f8-b627-da396584063a','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1116,'e921bc74-b99b-405c-8170-4abde318d597','eff2afcd-9554-44f8-b627-da396584063a','2026-06-10 07:47:03',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-13-37l5o2ovm647-HAProxyPublicTLS-tgwzo2xosx7b','eff2afcd-9554-44f8-b627-da396584063a','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1117,'61c63544-ef62-46ac-9721-14ef6dccfaaf','fe21e00f-a9f7-4834-b7e8-7dd5feb49ad1','2026-06-10 07:47:03',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-13-37l5o2ovm647-HAProxyBase-f3gxc3qzmenl-RoleParametersValue-tpohjb22nyx2','state changed','OS::Heat::Value',NULL,741),(1118,'51001191-f310-48e6-b20c-3f752403dfe7','fe21e00f-a9f7-4834-b7e8-7dd5feb49ad1','2026-06-10 07:47:03',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-13-37l5o2ovm647-HAProxyBase-f3gxc3qzmenl-RoleParametersValue-tpohjb22nyx2','state changed','OS::Heat::Value',NULL,741),(1119,'8ef89073-3ec1-417c-b539-9abef99ac11d','cb4c493d-3e4d-4edc-841e-c5167c205102','2026-06-10 07:47:03',NULL,'CREATE','IN_PROGRESS','GlanceLogging','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-12-cjik4s3hygrq-GlanceLogging-zpgb76mqaj76','state changed','OS::TripleO::Services::Logging::GlanceApi',NULL,NULL),(1120,'6bd20e5b-b57e-4b63-9826-156ff030e08e','289ebc27-4c63-4ac6-89a4-865c7a241fc8','2026-06-10 07:47:03',NULL,'CREATE','COMPLETE','CinderBase','5f24e136-5a11-4672-af28-4244bb2c623e','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml',NULL,677),(1121,'c56ed2f5-bb12-4b9b-bbf5-94f6fbbadc2c','289ebc27-4c63-4ac6-89a4-865c7a241fc8','2026-06-10 07:47:03',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-7-oiqmy32peq6v','289ebc27-4c63-4ac6-89a4-865c7a241fc8','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1122,'984fcfc7-710a-4e3d-b7f0-1f706ceeac5e','7bbdb5c8-fae3-481a-9518-e26b13e3eb41','2026-06-10 07:47:03',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-12-cjik4s3hygrq-GlanceLogging-zpgb76mqaj76','7bbdb5c8-fae3-481a-9518-e26b13e3eb41','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1123,'b4e16e0f-6f49-4703-87e8-8b0aa1972f99','d0af96c0-4929-4d5f-9766-c44617d8e95b','2026-06-10 07:47:03',NULL,'CREATE','COMPLETE','HeatBase','4c880784-85fe-4374-aef6-4d5a1ca079eb','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-base-puppet.yaml',NULL,738),(1124,'59718ef8-8148-4d08-9639-6d69173740f4','d0af96c0-4929-4d5f-9766-c44617d8e95b','2026-06-10 07:47:03',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-14-shbd7zd6savu','d0af96c0-4929-4d5f-9766-c44617d8e95b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1125,'cef6dd37-7f13-4b97-9c33-67c5ead98bcc','7bbdb5c8-fae3-481a-9518-e26b13e3eb41','2026-06-10 07:47:03',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-12-cjik4s3hygrq-GlanceLogging-zpgb76mqaj76-RoleParametersValue-6cmf3qqsvbhf','state changed','OS::Heat::Value',NULL,742),(1126,'f996c2cc-7790-4aa9-97f5-70419855d5d5','7bbdb5c8-fae3-481a-9518-e26b13e3eb41','2026-06-10 07:47:03',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-12-cjik4s3hygrq-GlanceLogging-zpgb76mqaj76-RoleParametersValue-6cmf3qqsvbhf','state changed','OS::Heat::Value',NULL,742),(1127,'f67fe6fd-2253-4960-ac57-100b3a0ae5ea','7bbdb5c8-fae3-481a-9518-e26b13e3eb41','2026-06-10 07:47:03',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-12-cjik4s3hygrq-GlanceLogging-zpgb76mqaj76','7bbdb5c8-fae3-481a-9518-e26b13e3eb41','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1128,'9e49d084-7bd5-4f36-a2db-8d4cbc2b493b','881027ec-a070-404a-ae0b-f1f8d9ee6dff','2026-06-10 07:47:04',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-13-37l5o2ovm647-ContainersCommon-t3mqsiysf2fx','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1129,'e6ee0735-1397-4747-97c0-a1cd6b795269','bf543581-1314-4fc9-a64b-0a72b6d0392b','2026-06-10 07:47:04',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-13-37l5o2ovm647-ContainersCommon-t3mqsiysf2fx','bf543581-1314-4fc9-a64b-0a72b6d0392b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1130,'15e66035-f0d7-495f-a818-322534b61e1f','bf543581-1314-4fc9-a64b-0a72b6d0392b','2026-06-10 07:47:04',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-13-37l5o2ovm647-ContainersCommon-t3mqsiysf2fx','bf543581-1314-4fc9-a64b-0a72b6d0392b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1131,'806ccd09-3fad-47bb-8ce3-a658a399ca73','881027ec-a070-404a-ae0b-f1f8d9ee6dff','2026-06-10 07:47:04',NULL,'CREATE','COMPLETE','HAProxyPublicTLS','eff2afcd-9554-44f8-b627-da396584063a','state changed','OS::TripleO::Services::HAProxyPublicTLS',NULL,740),(1132,'05053bde-bda2-45ec-ab28-6e89f3a06f38','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:47:04',NULL,'CREATE','COMPLETE','7','289ebc27-4c63-4ac6-89a4-865c7a241fc8','state changed','OS::TripleO::Services::CinderVolume',NULL,671),(1133,'ac096e8b-103b-4b47-aa8d-126887b1df9c','fe21e00f-a9f7-4834-b7e8-7dd5feb49ad1','2026-06-10 07:47:04',NULL,'CREATE','IN_PROGRESS','HAProxyLogging','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-13-37l5o2ovm647-HAProxyBase-f3gxc3qzmenl-HAProxyLogging-rlpdmgvgnphb','state changed','OS::TripleO::Services::Logging::HAProxy',NULL,NULL),(1134,'6145328c-2c0a-40a3-bdfb-ef549df7e1dd','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:47:04',NULL,'CREATE','COMPLETE','14','d0af96c0-4929-4d5f-9766-c44617d8e95b','state changed','OS::TripleO::Services::HeatApi',NULL,717),(1135,'9e548f10-e10d-44ef-aedd-d97107a5140a','cb4c493d-3e4d-4edc-841e-c5167c205102','2026-06-10 07:47:04',NULL,'CREATE','IN_PROGRESS','GlanceApi','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-12-cjik4s3hygrq-GlanceApi-kz6ya2v4spqd','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml',NULL,747),(1136,'2c953a17-179f-452d-8d46-1a451215507f','30870f67-66f8-42ef-b609-a704711e6d8e','2026-06-10 07:47:04',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-13-37l5o2ovm647-HAProxyBase-f3gxc3qzmenl-HAProxyLogging-rlpdmgvgnphb','30870f67-66f8-42ef-b609-a704711e6d8e','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1137,'5dd3681e-0ecc-46e4-b606-b53f55680182','30870f67-66f8-42ef-b609-a704711e6d8e','2026-06-10 07:47:04',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-13-37l5o2ovm647-HAProxyBase-f3gxc3qzmenl-HAProxyLogging-rlpdmgvgnphb','30870f67-66f8-42ef-b609-a704711e6d8e','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1138,'0eb7616b-60b8-4150-ac8c-597710a42434','cb4c493d-3e4d-4edc-841e-c5167c205102','2026-06-10 07:47:04',NULL,'CREATE','COMPLETE','GlanceLogging','7bbdb5c8-fae3-481a-9518-e26b13e3eb41','state changed','OS::TripleO::Services::Logging::GlanceApi',NULL,NULL),(1139,'4fa9bc65-df09-4e4f-b487-0c35b851fc4d','da1a8d11-800e-431b-a957-5187bceb4ad3','2026-06-10 07:47:04',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-12-cjik4s3hygrq-GlanceApi-kz6ya2v4spqd','da1a8d11-800e-431b-a957-5187bceb4ad3','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1140,'4cb5f78c-1855-40dc-864e-7730df996eca','da1a8d11-800e-431b-a957-5187bceb4ad3','2026-06-10 07:47:05',NULL,'CREATE','IN_PROGRESS','CinderNVMeOF','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-12-cjik4s3hygrq-GlanceApi-kz6ya2v4spqd-CinderNVMeOF-6kiog3r4t2hx','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(1141,'6a0f0b2d-d362-4cbb-9a3b-c8d628ccdb41','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:47:05',NULL,'CREATE','IN_PROGRESS','18','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-18-lwpvns2ubcl4','state changed','OS::TripleO::Services::Horizon',NULL,761),(1142,'fce90e98-7394-4f91-bbc4-35c47873e7b5','4baf976c-523c-4745-a9f5-7f2394c30bcf','2026-06-10 07:47:05',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-12-cjik4s3hygrq-GlanceApi-kz6ya2v4spqd-CinderNVMeOF-6kiog3r4t2hx','4baf976c-523c-4745-a9f5-7f2394c30bcf','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1143,'2e21af10-6237-46fc-a6d2-fa210cd16c1f','881027ec-a070-404a-ae0b-f1f8d9ee6dff','2026-06-10 07:47:05',NULL,'CREATE','IN_PROGRESS','HAProxyInternalTLS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-13-37l5o2ovm647-HAProxyInternalTLS-hzmuziioydlw','state changed','OS::TripleO::Services::HAProxyInternalTLS',NULL,NULL),(1144,'c5d57e44-9069-4df6-9470-e99d551ade1e','d358f831-563b-4fa5-84d2-bad0225d3c69','2026-06-10 07:47:05',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-18-lwpvns2ubcl4','d358f831-563b-4fa5-84d2-bad0225d3c69','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1145,'fc3b1ba5-446a-4813-a928-424caefb9cc7','4baf976c-523c-4745-a9f5-7f2394c30bcf','2026-06-10 07:47:05',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-12-cjik4s3hygrq-GlanceApi-kz6ya2v4spqd-CinderNVMeOF-6kiog3r4t2hx','4baf976c-523c-4745-a9f5-7f2394c30bcf','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1146,'88c451ce-1b06-4eb3-9e68-89e78f2a1baa','881027ec-a070-404a-ae0b-f1f8d9ee6dff','2026-06-10 07:47:05',NULL,'CREATE','COMPLETE','HAProxyInternalTLS','2c7c3296-7073-4780-ad52-cf9c9b24709d','state changed','OS::TripleO::Services::HAProxyInternalTLS',NULL,NULL),(1147,'7a238a24-f462-49d2-b606-35fc3a7039e4','881027ec-a070-404a-ae0b-f1f8d9ee6dff','2026-06-10 07:47:05',NULL,'CREATE','COMPLETE','ContainersCommon','bf543581-1314-4fc9-a64b-0a72b6d0392b','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1148,'51c8ba47-618b-4688-a06a-d1acd184eb60','d358f831-563b-4fa5-84d2-bad0225d3c69','2026-06-10 07:47:05',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-18-lwpvns2ubcl4-RoleParametersValue-ieodrolmgsxv','state changed','OS::Heat::Value',NULL,766),(1149,'8d06451d-0cc4-400c-9ecc-8f5bd21b43c9','d358f831-563b-4fa5-84d2-bad0225d3c69','2026-06-10 07:47:05',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-18-lwpvns2ubcl4-RoleParametersValue-ieodrolmgsxv','state changed','OS::Heat::Value',NULL,766),(1150,'2dabb65d-9fd6-45cc-bd6d-01f1319d0368','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:47:05',NULL,'CREATE','IN_PROGRESS','11','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-11-j7a4znyn2wn6','state changed','OS::TripleO::Services::GlanceApi',NULL,768),(1151,'47f9fe13-8d8e-4cec-bcb5-987a8993d6e9','fe21e00f-a9f7-4834-b7e8-7dd5feb49ad1','2026-06-10 07:47:05',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-13-37l5o2ovm647-HAProxyBase-f3gxc3qzmenl-ContainersCommon-2lg7ucyo6656','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1152,'d3ae9875-fe85-4b5a-99b9-b2bc4d03bac5','f6c15622-904b-4880-9467-e43ac3ae3d95','2026-06-10 07:47:05',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-11-j7a4znyn2wn6','f6c15622-904b-4880-9467-e43ac3ae3d95','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1153,'451e46aa-3931-4942-b356-950ddd4624e7','f9b064a0-affa-4ca1-bcf8-8741712a57a5','2026-06-10 07:47:05',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-13-37l5o2ovm647-HAProxyBase-f3gxc3qzmenl-ContainersCommon-2lg7ucyo6656','f9b064a0-affa-4ca1-bcf8-8741712a57a5','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1154,'396688e2-8fa3-47b8-a4ed-6d26d1986b2a','cb4c493d-3e4d-4edc-841e-c5167c205102','2026-06-10 07:47:05',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-12-cjik4s3hygrq-MySQLClient-qrg6z2j5zm47','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1155,'2740f463-41db-41dd-9ae9-a22cabebbe22','f9b064a0-affa-4ca1-bcf8-8741712a57a5','2026-06-10 07:47:05',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-13-37l5o2ovm647-HAProxyBase-f3gxc3qzmenl-ContainersCommon-2lg7ucyo6656','f9b064a0-affa-4ca1-bcf8-8741712a57a5','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1156,'7d367f0f-c58a-433a-8686-ee38245f0bc5','fe21e00f-a9f7-4834-b7e8-7dd5feb49ad1','2026-06-10 07:47:05',NULL,'CREATE','COMPLETE','HAProxyLogging','30870f67-66f8-42ef-b609-a704711e6d8e','state changed','OS::TripleO::Services::Logging::HAProxy',NULL,NULL),(1157,'b4843dea-5f6d-4c06-9c19-d87c119a39ca','2dd66185-7d0b-416e-9184-ccbc19353bef','2026-06-10 07:47:05',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-12-cjik4s3hygrq-MySQLClient-qrg6z2j5zm47','2dd66185-7d0b-416e-9184-ccbc19353bef','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1158,'e63c2b36-0fcb-40be-b2a7-570ef70ffa3a','2dd66185-7d0b-416e-9184-ccbc19353bef','2026-06-10 07:47:05',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-12-cjik4s3hygrq-MySQLClient-qrg6z2j5zm47','2dd66185-7d0b-416e-9184-ccbc19353bef','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1159,'f1e7a45f-e4f4-4091-a661-1dcd567562ea','f6c15622-904b-4880-9467-e43ac3ae3d95','2026-06-10 07:47:06',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-11-j7a4znyn2wn6-ContainersCommon-dtkt6ls2n6ci','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1160,'ab950a97-08e5-469b-a9c4-56c2d37ea166','d7daf4f4-49cc-472f-89a6-58d0a333cae2','2026-06-10 07:47:06',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-11-j7a4znyn2wn6-ContainersCommon-dtkt6ls2n6ci','d7daf4f4-49cc-472f-89a6-58d0a333cae2','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1161,'14b871e3-b630-4136-a4c6-5569e5d53868','d7daf4f4-49cc-472f-89a6-58d0a333cae2','2026-06-10 07:47:06',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-11-j7a4znyn2wn6-ContainersCommon-dtkt6ls2n6ci','d7daf4f4-49cc-472f-89a6-58d0a333cae2','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1162,'84dbf7cc-0b97-4f3b-9a40-143d96f2a382','da1a8d11-800e-431b-a957-5187bceb4ad3','2026-06-10 07:47:06',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-12-cjik4s3hygrq-GlanceApi-kz6ya2v4spqd-MySQLClient-uay5ugsmvynd','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1163,'1231b6cf-5884-452f-8d00-14b3fb45360c','077f626a-5003-4141-9a57-a6586953a058','2026-06-10 07:47:06',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-12-cjik4s3hygrq-GlanceApi-kz6ya2v4spqd-MySQLClient-uay5ugsmvynd','077f626a-5003-4141-9a57-a6586953a058','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1164,'f3b2661c-7df1-4834-bf81-80bdbee0f480','077f626a-5003-4141-9a57-a6586953a058','2026-06-10 07:47:06',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-12-cjik4s3hygrq-GlanceApi-kz6ya2v4spqd-MySQLClient-uay5ugsmvynd','077f626a-5003-4141-9a57-a6586953a058','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1165,'e455cb39-8ee8-4c71-b8e7-0c4b86911312','da1a8d11-800e-431b-a957-5187bceb4ad3','2026-06-10 07:47:06',NULL,'CREATE','COMPLETE','CinderNVMeOF','4baf976c-523c-4745-a9f5-7f2394c30bcf','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(1166,'a6cc30cb-ec13-49f1-aa44-f48e37cf661a','d358f831-563b-4fa5-84d2-bad0225d3c69','2026-06-10 07:47:06',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-18-lwpvns2ubcl4-ContainersCommon-et7qe5cr3ivv','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1167,'baf527c9-4c75-4c55-b94e-8dd90aae74f2','8e560757-33be-424f-a60d-ccf4d0e33179','2026-06-10 07:47:06',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-18-lwpvns2ubcl4-ContainersCommon-et7qe5cr3ivv','8e560757-33be-424f-a60d-ccf4d0e33179','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1168,'cbb3d1ea-789d-4694-8976-52d12916a70b','8e560757-33be-424f-a60d-ccf4d0e33179','2026-06-10 07:47:06',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-18-lwpvns2ubcl4-ContainersCommon-et7qe5cr3ivv','8e560757-33be-424f-a60d-ccf4d0e33179','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1169,'c1557a02-4aff-4171-957b-c3c06f175b8e','fe21e00f-a9f7-4834-b7e8-7dd5feb49ad1','2026-06-10 07:47:06',NULL,'CREATE','IN_PROGRESS','HAProxyPublicTLS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-13-37l5o2ovm647-HAProxyBase-f3gxc3qzmenl-HAProxyPublicTLS-vizpzjk27fec','state changed','OS::TripleO::Services::HAProxyPublicTLS',NULL,769),(1170,'60c0c557-4534-41d3-bbe3-44039d8bc6c3','2dff292a-7fae-47b5-9767-4e4168de95af','2026-06-10 07:47:06',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-13-37l5o2ovm647-HAProxyBase-f3gxc3qzmenl-HAProxyPublicTLS-vizpzjk27fec','2dff292a-7fae-47b5-9767-4e4168de95af','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1171,'9a6b2b3b-8798-4b1a-9610-ad8e2979dc13','2dff292a-7fae-47b5-9767-4e4168de95af','2026-06-10 07:47:06',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-13-37l5o2ovm647-HAProxyBase-f3gxc3qzmenl-HAProxyPublicTLS-vizpzjk27fec','2dff292a-7fae-47b5-9767-4e4168de95af','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1172,'ee4ed046-75a5-4271-85af-4a509c7b7b31','fe21e00f-a9f7-4834-b7e8-7dd5feb49ad1','2026-06-10 07:47:06',NULL,'CREATE','COMPLETE','ContainersCommon','f9b064a0-affa-4ca1-bcf8-8741712a57a5','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1173,'bddd7268-9d66-421d-a691-3d97b4e1be61','cb4c493d-3e4d-4edc-841e-c5167c205102','2026-06-10 07:47:06',NULL,'CREATE','COMPLETE','MySQLClient','2dd66185-7d0b-416e-9184-ccbc19353bef','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1174,'049cd322-403f-40f9-8764-39e744ce5040','f6c15622-904b-4880-9467-e43ac3ae3d95','2026-06-10 07:47:07',NULL,'CREATE','IN_PROGRESS','TLSProxyBase','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-11-j7a4znyn2wn6-TLSProxyBase-dfxjuhs75ul6','state changed','OS::TripleO::Services::TLSProxyBase',NULL,NULL),(1175,'34def9b7-6f66-46bd-8ff3-47aadd51789a','f6c15622-904b-4880-9467-e43ac3ae3d95','2026-06-10 07:47:07',NULL,'CREATE','COMPLETE','TLSProxyBase','20f6c4ef-97d5-460d-be0a-b88d0ebb2a4b','state changed','OS::TripleO::Services::TLSProxyBase',NULL,NULL),(1176,'016c32c9-1d0d-4bc5-9927-14a60a39ff51','f6c15622-904b-4880-9467-e43ac3ae3d95','2026-06-10 07:47:07',NULL,'CREATE','COMPLETE','ContainersCommon','d7daf4f4-49cc-472f-89a6-58d0a333cae2','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1177,'e7c6518e-6653-4dfc-8972-2a66b94a2c64','da1a8d11-800e-431b-a957-5187bceb4ad3','2026-06-10 07:47:07',NULL,'CREATE','IN_PROGRESS','GlanceLogging','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-12-cjik4s3hygrq-GlanceApi-kz6ya2v4spqd-GlanceLogging-n3mlwmgndcun','state changed','OS::TripleO::Services::Logging::GlanceApi',NULL,NULL),(1178,'61586805-1c5e-4499-9498-4186659b7ffb','f2ba0abc-ef37-40b6-a606-2f144014de72','2026-06-10 07:47:07',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-12-cjik4s3hygrq-GlanceApi-kz6ya2v4spqd-GlanceLogging-n3mlwmgndcun','f2ba0abc-ef37-40b6-a606-2f144014de72','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1179,'bb23d941-0f77-43fc-bcf8-d7c4eab05dfa','da1a8d11-800e-431b-a957-5187bceb4ad3','2026-06-10 07:47:07',NULL,'CREATE','COMPLETE','MySQLClient','077f626a-5003-4141-9a57-a6586953a058','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1180,'b73d02e5-d4e2-4ac8-81fe-0dfb04927c96','f2ba0abc-ef37-40b6-a606-2f144014de72','2026-06-10 07:47:07',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-12-cjik4s3hygrq-GlanceApi-kz6ya2v4spqd-GlanceLogging-n3mlwmgndcun-RoleParametersValue-rq4o3hv4gnel','state changed','OS::Heat::Value',NULL,770),(1181,'8cad114c-2bc7-4eca-a493-f428c3e3374e','f2ba0abc-ef37-40b6-a606-2f144014de72','2026-06-10 07:47:07',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-12-cjik4s3hygrq-GlanceApi-kz6ya2v4spqd-GlanceLogging-n3mlwmgndcun-RoleParametersValue-rq4o3hv4gnel','state changed','OS::Heat::Value',NULL,770),(1182,'fd48d71c-30ca-484f-9a82-47453a9daa76','f2ba0abc-ef37-40b6-a606-2f144014de72','2026-06-10 07:47:07',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-12-cjik4s3hygrq-GlanceApi-kz6ya2v4spqd-GlanceLogging-n3mlwmgndcun','f2ba0abc-ef37-40b6-a606-2f144014de72','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1183,'7c375e86-03fd-4cf1-8668-3bef90f3ca12','d358f831-563b-4fa5-84d2-bad0225d3c69','2026-06-10 07:47:07',NULL,'CREATE','COMPLETE','ContainersCommon','8e560757-33be-424f-a60d-ccf4d0e33179','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1184,'e229773d-c698-4b20-be15-4967e8a4fbae','d358f831-563b-4fa5-84d2-bad0225d3c69','2026-06-10 07:47:07',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-18-lwpvns2ubcl4','d358f831-563b-4fa5-84d2-bad0225d3c69','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1185,'f7e409e5-256c-46ef-b0c1-965a7a9158e3','fe21e00f-a9f7-4834-b7e8-7dd5feb49ad1','2026-06-10 07:47:07',NULL,'CREATE','COMPLETE','HAProxyPublicTLS','2dff292a-7fae-47b5-9767-4e4168de95af','state changed','OS::TripleO::Services::HAProxyPublicTLS',NULL,769),(1186,'a5c2c1ad-3c58-48d0-85e9-8c03b6f8e958','fe21e00f-a9f7-4834-b7e8-7dd5feb49ad1','2026-06-10 07:47:07',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-13-37l5o2ovm647-HAProxyBase-f3gxc3qzmenl','fe21e00f-a9f7-4834-b7e8-7dd5feb49ad1','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1187,'053b3db4-b89f-46dc-98e3-9afc9cad1712','f6c15622-904b-4880-9467-e43ac3ae3d95','2026-06-10 07:47:08',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-11-j7a4znyn2wn6-RoleParametersValue-bwjjvztltw7k','state changed','OS::Heat::Value',NULL,771),(1188,'1f1b0e44-2862-4b5a-a20e-f1113f5bc14a','f6c15622-904b-4880-9467-e43ac3ae3d95','2026-06-10 07:47:08',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-11-j7a4znyn2wn6-RoleParametersValue-bwjjvztltw7k','state changed','OS::Heat::Value',NULL,771),(1189,'e0ba1cdf-b808-43a4-9165-d071041d6d11','da1a8d11-800e-431b-a957-5187bceb4ad3','2026-06-10 07:47:08',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-12-cjik4s3hygrq-GlanceApi-kz6ya2v4spqd-ContainersCommon-jilmqztg3gjh','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1190,'a6b43ac9-2277-4d4e-bb5e-eca0ca332cc8','c0b79be5-a619-4724-bfce-e47360ba18b9','2026-06-10 07:47:08',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-12-cjik4s3hygrq-GlanceApi-kz6ya2v4spqd-ContainersCommon-jilmqztg3gjh','c0b79be5-a619-4724-bfce-e47360ba18b9','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1191,'23c3255a-6e56-4e36-aac6-8abbdf967521','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:47:08',NULL,'CREATE','COMPLETE','18','d358f831-563b-4fa5-84d2-bad0225d3c69','state changed','OS::TripleO::Services::Horizon',NULL,761),(1192,'d570a598-7a81-4f6f-b0e1-6232b16995a6','c0b79be5-a619-4724-bfce-e47360ba18b9','2026-06-10 07:47:08',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-12-cjik4s3hygrq-GlanceApi-kz6ya2v4spqd-ContainersCommon-jilmqztg3gjh','c0b79be5-a619-4724-bfce-e47360ba18b9','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1193,'d99ab436-686d-4051-b434-1018d70ca13d','da1a8d11-800e-431b-a957-5187bceb4ad3','2026-06-10 07:47:08',NULL,'CREATE','COMPLETE','GlanceLogging','f2ba0abc-ef37-40b6-a606-2f144014de72','state changed','OS::TripleO::Services::Logging::GlanceApi',NULL,NULL),(1194,'10f2d587-22f1-40fe-9628-d734c8b99bba','881027ec-a070-404a-ae0b-f1f8d9ee6dff','2026-06-10 07:47:08',NULL,'CREATE','COMPLETE','HAProxyBase','fe21e00f-a9f7-4834-b7e8-7dd5feb49ad1','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-container-puppet.yaml',NULL,734),(1195,'92a4f897-802b-4154-a715-48f705016ec3','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:47:08',NULL,'CREATE','IN_PROGRESS','22','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-22-r63vfhvld6uy','state changed','OS::TripleO::Services::ManilaApi',NULL,775),(1196,'fd137895-1bc9-44f2-aec2-2e8cda29fdb2','881027ec-a070-404a-ae0b-f1f8d9ee6dff','2026-06-10 07:47:08',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-13-37l5o2ovm647','881027ec-a070-404a-ae0b-f1f8d9ee6dff','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1197,'9b84b3c5-9045-4d01-9feb-0634843fdc9a','1af83448-4fa2-412d-a329-e5aca18a9be4','2026-06-10 07:47:08',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-22-r63vfhvld6uy','1af83448-4fa2-412d-a329-e5aca18a9be4','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1198,'affea93e-a3d9-487d-bc44-24432176dd2d','1af83448-4fa2-412d-a329-e5aca18a9be4','2026-06-10 07:47:09',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-22-r63vfhvld6uy-MySQLClient-7yzqt2xogb4i','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1199,'d1036a38-7c9e-431a-8908-1dc6237f2624','f6c15622-904b-4880-9467-e43ac3ae3d95','2026-06-10 07:47:09',NULL,'CREATE','IN_PROGRESS','GlanceLogging','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-11-j7a4znyn2wn6-GlanceLogging-pjorey4ens5y','state changed','OS::TripleO::Services::Logging::GlanceApi',NULL,NULL),(1200,'254e677d-e564-4a1e-8694-e2409858ea28','2262bd61-80ea-442f-bfbe-756acad279b1','2026-06-10 07:47:09',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-11-j7a4znyn2wn6-GlanceLogging-pjorey4ens5y','2262bd61-80ea-442f-bfbe-756acad279b1','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1201,'4ab987b4-ede3-41d9-8e52-f96993745fa6','accb5680-62d2-4ccd-843f-3518df609d67','2026-06-10 07:47:09',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-22-r63vfhvld6uy-MySQLClient-7yzqt2xogb4i','accb5680-62d2-4ccd-843f-3518df609d67','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1202,'44cd5baa-15e9-47fc-82a8-68f27aac3cb4','accb5680-62d2-4ccd-843f-3518df609d67','2026-06-10 07:47:09',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-22-r63vfhvld6uy-MySQLClient-7yzqt2xogb4i','accb5680-62d2-4ccd-843f-3518df609d67','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1203,'e5a56e8b-ab16-439f-8993-125a0e4c0981','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:47:09',NULL,'CREATE','COMPLETE','13','881027ec-a070-404a-ae0b-f1f8d9ee6dff','state changed','OS::TripleO::Services::HAproxy',NULL,725),(1204,'e3356abe-0e0b-448d-a20a-3b275edfc01d','da1a8d11-800e-431b-a957-5187bceb4ad3','2026-06-10 07:47:09',NULL,'CREATE','IN_PROGRESS','TLSProxyBase','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-12-cjik4s3hygrq-GlanceApi-kz6ya2v4spqd-TLSProxyBase-scpfifkgyvfo','state changed','OS::TripleO::Services::TLSProxyBase',NULL,NULL),(1205,'47663a0f-5cc5-4746-a884-6a71135084ed','2262bd61-80ea-442f-bfbe-756acad279b1','2026-06-10 07:47:09',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-11-j7a4znyn2wn6-GlanceLogging-pjorey4ens5y-RoleParametersValue-er7orbrstiux','state changed','OS::Heat::Value',NULL,776),(1206,'2c00ca1b-75cf-44ef-81d0-6bd9a7c2cff8','2262bd61-80ea-442f-bfbe-756acad279b1','2026-06-10 07:47:09',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-11-j7a4znyn2wn6-GlanceLogging-pjorey4ens5y-RoleParametersValue-er7orbrstiux','state changed','OS::Heat::Value',NULL,776),(1207,'f9a0bb4e-a5d8-45eb-860d-e59a54cbaeee','da1a8d11-800e-431b-a957-5187bceb4ad3','2026-06-10 07:47:09',NULL,'CREATE','COMPLETE','TLSProxyBase','c58372e0-b813-4eeb-b031-c1568417acd5','state changed','OS::TripleO::Services::TLSProxyBase',NULL,NULL),(1208,'59fe0225-6bc5-492e-ab75-0b821a9833e4','2262bd61-80ea-442f-bfbe-756acad279b1','2026-06-10 07:47:09',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-11-j7a4znyn2wn6-GlanceLogging-pjorey4ens5y','2262bd61-80ea-442f-bfbe-756acad279b1','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1209,'44458fa6-aca9-4425-917d-609c93d9595e','da1a8d11-800e-431b-a957-5187bceb4ad3','2026-06-10 07:47:09',NULL,'CREATE','COMPLETE','ContainersCommon','c0b79be5-a619-4724-bfce-e47360ba18b9','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1210,'2e35cdf8-8363-4e1c-b338-c4d48e08e7b7','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:47:09',NULL,'CREATE','IN_PROGRESS','17','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-17-5u3pxgvn5wiv','state changed','OS::TripleO::Services::HeatEngine',NULL,787),(1211,'a96e2f11-cf9d-4a96-8f7e-f5f83fdf6c65','3bed5218-b075-4775-bea9-2f366483fb09','2026-06-10 07:47:09',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-17-5u3pxgvn5wiv','3bed5218-b075-4775-bea9-2f366483fb09','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1212,'93dd9622-53c1-428e-ab62-652269775531','f6c15622-904b-4880-9467-e43ac3ae3d95','2026-06-10 07:47:10',NULL,'CREATE','IN_PROGRESS','CinderNVMeOF','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-11-j7a4znyn2wn6-CinderNVMeOF-5awjyvpfluti','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(1213,'9b9b0ae4-be0b-4d51-9606-bee6234b5a97','1af83448-4fa2-412d-a329-e5aca18a9be4','2026-06-10 07:47:10',NULL,'CREATE','IN_PROGRESS','ManilaBase','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-22-r63vfhvld6uy-ManilaBase-2momamgasynv','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-base.yaml',NULL,788),(1214,'b669cf34-a0a0-4e54-b855-f4dca6771787','f5faee50-f312-4f0a-a670-8cba317b2335','2026-06-10 07:47:10',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-11-j7a4znyn2wn6-CinderNVMeOF-5awjyvpfluti','f5faee50-f312-4f0a-a670-8cba317b2335','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1215,'1713b590-c7bb-466b-b297-953a053b7752','ac133662-0be0-4f75-be4f-060c7453f309','2026-06-10 07:47:10',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-22-r63vfhvld6uy-ManilaBase-2momamgasynv','ac133662-0be0-4f75-be4f-060c7453f309','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1216,'7f0824af-7ab0-4ae2-b1cc-8cc8f1ed2566','f6c15622-904b-4880-9467-e43ac3ae3d95','2026-06-10 07:47:10',NULL,'CREATE','COMPLETE','GlanceLogging','2262bd61-80ea-442f-bfbe-756acad279b1','state changed','OS::TripleO::Services::Logging::GlanceApi',NULL,NULL),(1217,'76011d89-0d22-4579-be98-346607d3a57a','f5faee50-f312-4f0a-a670-8cba317b2335','2026-06-10 07:47:10',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-11-j7a4znyn2wn6-CinderNVMeOF-5awjyvpfluti','f5faee50-f312-4f0a-a670-8cba317b2335','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1218,'75169ee4-d5bc-46e8-a7ea-eec024e18fc0','1af83448-4fa2-412d-a329-e5aca18a9be4','2026-06-10 07:47:10',NULL,'CREATE','COMPLETE','MySQLClient','accb5680-62d2-4ccd-843f-3518df609d67','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1219,'04a9d367-176f-4ae2-a7ea-694a3d04c8f6','ac133662-0be0-4f75-be4f-060c7453f309','2026-06-10 07:47:10',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-22-r63vfhvld6uy-ManilaBase-2momamgasynv','ac133662-0be0-4f75-be4f-060c7453f309','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1220,'ee2895ae-8c08-4545-9f08-cb8e2d36d33b','3bed5218-b075-4775-bea9-2f366483fb09','2026-06-10 07:47:10',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-17-5u3pxgvn5wiv-ContainersCommon-lecoxbf2czv6','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1221,'7a7fb18e-11c7-479c-9cdf-da7f92ee7375','287dc076-3be5-4287-b550-9f1ed20b80fe','2026-06-10 07:47:10',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-17-5u3pxgvn5wiv-ContainersCommon-lecoxbf2czv6','287dc076-3be5-4287-b550-9f1ed20b80fe','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1222,'04f5f770-2163-4291-bbe5-6934d06571e4','da1a8d11-800e-431b-a957-5187bceb4ad3','2026-06-10 07:47:10',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-12-cjik4s3hygrq-GlanceApi-kz6ya2v4spqd-RoleParametersValue-rp7f5hg6whff','state changed','OS::Heat::Value',NULL,789),(1223,'98e08ae1-21b5-4252-8746-2ed5563181be','287dc076-3be5-4287-b550-9f1ed20b80fe','2026-06-10 07:47:10',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-17-5u3pxgvn5wiv-ContainersCommon-lecoxbf2czv6','287dc076-3be5-4287-b550-9f1ed20b80fe','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1224,'bc3124fb-8bc4-41cc-ad41-7bc0abcd315a','da1a8d11-800e-431b-a957-5187bceb4ad3','2026-06-10 07:47:10',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-12-cjik4s3hygrq-GlanceApi-kz6ya2v4spqd-RoleParametersValue-rp7f5hg6whff','state changed','OS::Heat::Value',NULL,789),(1225,'bcff895a-0c35-466b-a61c-8d76267b77f3','da1a8d11-800e-431b-a957-5187bceb4ad3','2026-06-10 07:47:10',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-12-cjik4s3hygrq-GlanceApi-kz6ya2v4spqd','da1a8d11-800e-431b-a957-5187bceb4ad3','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1226,'e3360030-ae75-47da-b87a-f07ac1d5b19c','1af83448-4fa2-412d-a329-e5aca18a9be4','2026-06-10 07:47:11',NULL,'CREATE','IN_PROGRESS','ApacheServiceBase','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-22-r63vfhvld6uy-ApacheServiceBase-dtczvjtphugx','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,790),(1227,'173661ad-287e-488b-8788-184f71cc9b01','f6c15622-904b-4880-9467-e43ac3ae3d95','2026-06-10 07:47:11',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-11-j7a4znyn2wn6-MySQLClient-5fgkujyohaox','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1228,'8de61bab-9376-4213-9843-59458b879dad','cb4c493d-3e4d-4edc-841e-c5167c205102','2026-06-10 07:47:11',NULL,'CREATE','COMPLETE','GlanceApi','da1a8d11-800e-431b-a957-5187bceb4ad3','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml',NULL,747),(1229,'5d469335-e748-431d-ab78-264bace38920','97d90804-d222-4de8-8e4d-385061d5574f','2026-06-10 07:47:11',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-22-r63vfhvld6uy-ApacheServiceBase-dtczvjtphugx','97d90804-d222-4de8-8e4d-385061d5574f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1230,'a4783e8a-a960-4753-b82d-7f7f425cdfd4','cb4c493d-3e4d-4edc-841e-c5167c205102','2026-06-10 07:47:11',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-12-cjik4s3hygrq','cb4c493d-3e4d-4edc-841e-c5167c205102','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1231,'e34120e3-c903-4878-a4e6-4bf424b3b4c5','f6c15622-904b-4880-9467-e43ac3ae3d95','2026-06-10 07:47:11',NULL,'CREATE','COMPLETE','CinderNVMeOF','f5faee50-f312-4f0a-a670-8cba317b2335','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(1232,'7ee2024a-67d6-48e2-bc71-4f39883505f8','69f25bbe-cf1a-4594-afa6-819331baa61f','2026-06-10 07:47:11',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-11-j7a4znyn2wn6-MySQLClient-5fgkujyohaox','69f25bbe-cf1a-4594-afa6-819331baa61f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1233,'e49de7b5-51b2-4a2d-8d2a-3e7a41d87624','1af83448-4fa2-412d-a329-e5aca18a9be4','2026-06-10 07:47:11',NULL,'CREATE','COMPLETE','ManilaBase','ac133662-0be0-4f75-be4f-060c7453f309','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-base.yaml',NULL,788),(1234,'e0d4b1f7-b644-44d4-9820-a5e376bec1ee','69f25bbe-cf1a-4594-afa6-819331baa61f','2026-06-10 07:47:11',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-11-j7a4znyn2wn6-MySQLClient-5fgkujyohaox','69f25bbe-cf1a-4594-afa6-819331baa61f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1235,'aa96739b-4678-4a77-bf3e-ff186a835738','3bed5218-b075-4775-bea9-2f366483fb09','2026-06-10 07:47:11',NULL,'CREATE','IN_PROGRESS','HeatBase','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-17-5u3pxgvn5wiv-HeatBase-6ywr4usmmzwc','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-base-puppet.yaml',NULL,791),(1236,'6eb3efed-18e3-4752-8c9a-717233e61724','3bed5218-b075-4775-bea9-2f366483fb09','2026-06-10 07:47:11',NULL,'CREATE','COMPLETE','ContainersCommon','287dc076-3be5-4287-b550-9f1ed20b80fe','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1237,'0e97ca73-8be9-4c98-8ecc-3f45fcfc22c3','97d90804-d222-4de8-8e4d-385061d5574f','2026-06-10 07:47:11',NULL,'CREATE','IN_PROGRESS','ApacheNetworks','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-22-r63vfhvld6uy-ApacheServiceBase-dtczvjtphugx-ApacheNetworks-r2qtt7227tbb','state changed','OS::Heat::Value',NULL,792),(1238,'eab6fc9a-dc01-4153-b91c-ea5af4f08f86','97d90804-d222-4de8-8e4d-385061d5574f','2026-06-10 07:47:11',NULL,'CREATE','COMPLETE','ApacheNetworks','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-22-r63vfhvld6uy-ApacheServiceBase-dtczvjtphugx-ApacheNetworks-r2qtt7227tbb','state changed','OS::Heat::Value',NULL,792),(1239,'b5c1ee53-8a43-42fb-b50f-e33e5f54e67e','8cead355-d913-4cc9-8bcf-30706825189d','2026-06-10 07:47:11',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-17-5u3pxgvn5wiv-HeatBase-6ywr4usmmzwc','8cead355-d913-4cc9-8bcf-30706825189d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1240,'45a248b7-7bd3-4dc3-afe3-160d8289463c','97d90804-d222-4de8-8e4d-385061d5574f','2026-06-10 07:47:11',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-22-r63vfhvld6uy-ApacheServiceBase-dtczvjtphugx','97d90804-d222-4de8-8e4d-385061d5574f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1241,'ef0f49dc-f038-4454-86ed-4bf625b96a0f','8cead355-d913-4cc9-8bcf-30706825189d','2026-06-10 07:47:11',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-17-5u3pxgvn5wiv-HeatBase-6ywr4usmmzwc','8cead355-d913-4cc9-8bcf-30706825189d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1242,'68e3dfd5-3b20-4c76-aa5f-afc486275a2b','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:47:11',NULL,'CREATE','COMPLETE','12','cb4c493d-3e4d-4edc-841e-c5167c205102','state changed','OS::TripleO::Services::GlanceApiInternal',NULL,737),(1243,'61eacf4b-8188-42fc-8409-42a2bfb1a704','1af83448-4fa2-412d-a329-e5aca18a9be4','2026-06-10 07:47:12',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-22-r63vfhvld6uy-ContainersCommon-osvi3ixoczfd','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1244,'dcff9022-3417-4afc-aaec-845662c84343','8431f9f5-26c8-42e6-aafd-b0751886c9fd','2026-06-10 07:47:12',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-22-r63vfhvld6uy-ContainersCommon-osvi3ixoczfd','8431f9f5-26c8-42e6-aafd-b0751886c9fd','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1245,'2b3dc366-435d-43e7-a650-b8c3a76b0c6d','8431f9f5-26c8-42e6-aafd-b0751886c9fd','2026-06-10 07:47:12',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-22-r63vfhvld6uy-ContainersCommon-osvi3ixoczfd','8431f9f5-26c8-42e6-aafd-b0751886c9fd','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1246,'fc6ff2c1-d57b-40eb-9dd5-cf6d569a4c6b','3bed5218-b075-4775-bea9-2f366483fb09','2026-06-10 07:47:12',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-17-5u3pxgvn5wiv-MySQLClient-wnamj7ny7pzv','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1247,'6db151b4-7f97-455a-9220-419c4720c5eb','f6c15622-904b-4880-9467-e43ac3ae3d95','2026-06-10 07:47:12',NULL,'CREATE','COMPLETE','MySQLClient','69f25bbe-cf1a-4594-afa6-819331baa61f','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1248,'188e8b22-abcd-4162-a752-c56e9ba177a5','1af83448-4fa2-412d-a329-e5aca18a9be4','2026-06-10 07:47:12',NULL,'CREATE','COMPLETE','ApacheServiceBase','97d90804-d222-4de8-8e4d-385061d5574f','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,790),(1249,'da91c215-1838-4770-903e-f97d9bcaf5fe','f6c15622-904b-4880-9467-e43ac3ae3d95','2026-06-10 07:47:12',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-11-j7a4znyn2wn6','f6c15622-904b-4880-9467-e43ac3ae3d95','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1250,'b4effcb9-21ae-4b8f-8375-c18e837bcdc2','622e9755-a215-4aaa-811a-28fc2a6e3d51','2026-06-10 07:47:12',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-17-5u3pxgvn5wiv-MySQLClient-wnamj7ny7pzv','622e9755-a215-4aaa-811a-28fc2a6e3d51','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1251,'195cf362-7fca-42d7-8d38-bc85ee5dd25b','622e9755-a215-4aaa-811a-28fc2a6e3d51','2026-06-10 07:47:12',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-17-5u3pxgvn5wiv-MySQLClient-wnamj7ny7pzv','622e9755-a215-4aaa-811a-28fc2a6e3d51','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1252,'b54e5b91-6c5f-4107-8150-46eb83741ab8','3bed5218-b075-4775-bea9-2f366483fb09','2026-06-10 07:47:12',NULL,'CREATE','COMPLETE','HeatBase','8cead355-d913-4cc9-8bcf-30706825189d','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-base-puppet.yaml',NULL,791),(1253,'ae0e94a8-fb42-4ca0-bb6a-63e1b7044b9f','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:47:12',NULL,'CREATE','IN_PROGRESS','16','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-16-lp7bgul2g4za','state changed','OS::TripleO::Services::HeatApiCfn',NULL,806),(1254,'783f8df2-4be8-4e5e-9a4f-279e42a6fc11','3f938799-6b6d-42a8-8729-c3aacf864a32','2026-06-10 07:47:12',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-16-lp7bgul2g4za','3f938799-6b6d-42a8-8729-c3aacf864a32','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1255,'b0c2651c-622c-4bcc-aaea-a6a913600074','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:47:12',NULL,'CREATE','COMPLETE','11','f6c15622-904b-4880-9467-e43ac3ae3d95','state changed','OS::TripleO::Services::GlanceApi',NULL,768),(1256,'9788a5a9-2139-4362-9d57-ff8bb54b72d7','3f938799-6b6d-42a8-8729-c3aacf864a32','2026-06-10 07:47:12',NULL,'CREATE','IN_PROGRESS','ApacheServiceBase','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-16-lp7bgul2g4za-ApacheServiceBase-l5m7nie4n43y','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,807),(1257,'d6191c7b-6e6f-470c-a08a-c5d884814cbe','1af83448-4fa2-412d-a329-e5aca18a9be4','2026-06-10 07:47:13',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-22-r63vfhvld6uy-RoleParametersValue-cjndwxi4vbcn','state changed','OS::Heat::Value',NULL,808),(1258,'43f1b27d-ee5f-41e7-932f-3293d72a2bd2','62c3fa60-0e88-4f44-b9c0-b9a19c459d28','2026-06-10 07:47:13',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-16-lp7bgul2g4za-ApacheServiceBase-l5m7nie4n43y','62c3fa60-0e88-4f44-b9c0-b9a19c459d28','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1259,'63c7883a-b92d-43e5-a8d1-3cbb69778f87','1af83448-4fa2-412d-a329-e5aca18a9be4','2026-06-10 07:47:13',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-22-r63vfhvld6uy-RoleParametersValue-cjndwxi4vbcn','state changed','OS::Heat::Value',NULL,808),(1260,'ba794d82-27a4-42f8-b2b1-f458cb46b67e','1af83448-4fa2-412d-a329-e5aca18a9be4','2026-06-10 07:47:13',NULL,'CREATE','COMPLETE','ContainersCommon','8431f9f5-26c8-42e6-aafd-b0751886c9fd','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1261,'cbc7b347-f0ab-4725-a741-3ae73d756e79','62c3fa60-0e88-4f44-b9c0-b9a19c459d28','2026-06-10 07:47:13',NULL,'CREATE','IN_PROGRESS','ApacheNetworks','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-16-lp7bgul2g4za-ApacheServiceBase-l5m7nie4n43y-ApacheNetworks-zllovbzhwvde','state changed','OS::Heat::Value',NULL,812),(1262,'fb6b3145-c5d4-447c-a912-8cc9ff500361','62c3fa60-0e88-4f44-b9c0-b9a19c459d28','2026-06-10 07:47:13',NULL,'CREATE','COMPLETE','ApacheNetworks','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-16-lp7bgul2g4za-ApacheServiceBase-l5m7nie4n43y-ApacheNetworks-zllovbzhwvde','state changed','OS::Heat::Value',NULL,812),(1263,'4a9f578b-85ab-4101-a7e1-18ec217d461f','1af83448-4fa2-412d-a329-e5aca18a9be4','2026-06-10 07:47:13',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-22-r63vfhvld6uy','1af83448-4fa2-412d-a329-e5aca18a9be4','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1264,'58d8d3ec-db3d-4fad-a82a-ce15e9147bbf','3bed5218-b075-4775-bea9-2f366483fb09','2026-06-10 07:47:13',NULL,'CREATE','IN_PROGRESS','HeatEngineLogging','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-17-5u3pxgvn5wiv-HeatEngineLogging-3ubiftr4rmxo','state changed','OS::TripleO::Services::Logging::HeatEngine',NULL,NULL),(1265,'2d127ee0-e8f6-42db-b51b-d528e53ee122','62c3fa60-0e88-4f44-b9c0-b9a19c459d28','2026-06-10 07:47:13',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-16-lp7bgul2g4za-ApacheServiceBase-l5m7nie4n43y','62c3fa60-0e88-4f44-b9c0-b9a19c459d28','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1266,'296b7817-62b6-4c8e-b424-3be653243944','322d8879-d11b-4878-8788-f47da62e9631','2026-06-10 07:47:13',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-17-5u3pxgvn5wiv-HeatEngineLogging-3ubiftr4rmxo','322d8879-d11b-4878-8788-f47da62e9631','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1267,'df266f07-525c-48ba-8b9f-712037c977e1','3bed5218-b075-4775-bea9-2f366483fb09','2026-06-10 07:47:13',NULL,'CREATE','COMPLETE','MySQLClient','622e9755-a215-4aaa-811a-28fc2a6e3d51','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1268,'e6351c71-1421-41ba-a752-52352982008a','322d8879-d11b-4878-8788-f47da62e9631','2026-06-10 07:47:13',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-17-5u3pxgvn5wiv-HeatEngineLogging-3ubiftr4rmxo-RoleParametersValue-wn5tbtel4m4w','state changed','OS::Heat::Value',NULL,818),(1269,'ddd4211b-463e-48f9-98be-61f9a6ba9bd2','322d8879-d11b-4878-8788-f47da62e9631','2026-06-10 07:47:13',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-17-5u3pxgvn5wiv-HeatEngineLogging-3ubiftr4rmxo-RoleParametersValue-wn5tbtel4m4w','state changed','OS::Heat::Value',NULL,818),(1270,'bf48b6ff-571d-4ad2-af75-48355db75316','322d8879-d11b-4878-8788-f47da62e9631','2026-06-10 07:47:13',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-17-5u3pxgvn5wiv-HeatEngineLogging-3ubiftr4rmxo','322d8879-d11b-4878-8788-f47da62e9631','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1271,'f822a70f-332e-4d1d-99a8-aff91bc3cfe2','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:47:13',NULL,'CREATE','IN_PROGRESS','15','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-15-u35h7wizj6jw','state changed','OS::TripleO::Services::HeatApiCloudwatch',NULL,819),(1272,'aac46522-01e8-4f3e-8d27-0829675aea47','3dfffee8-5d17-4fa2-a8ab-ede701228a9e','2026-06-10 07:47:13',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-15-u35h7wizj6jw','3dfffee8-5d17-4fa2-a8ab-ede701228a9e','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1273,'883c898c-f672-4ac6-9f8a-2f6de21d8589','3dfffee8-5d17-4fa2-a8ab-ede701228a9e','2026-06-10 07:47:13',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-15-u35h7wizj6jw','3dfffee8-5d17-4fa2-a8ab-ede701228a9e','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1274,'d64b29b7-ed7c-438e-bb83-8b40591c369f','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:47:13',NULL,'CREATE','COMPLETE','15','3dfffee8-5d17-4fa2-a8ab-ede701228a9e','state changed','OS::TripleO::Services::HeatApiCloudwatch',NULL,819),(1275,'3167e8e0-4654-4d3e-9a1d-bbd287b05c0f','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:47:13',NULL,'CREATE','COMPLETE','22','1af83448-4fa2-412d-a329-e5aca18a9be4','state changed','OS::TripleO::Services::ManilaApi',NULL,775),(1276,'90a5d579-e0e4-4f70-88b2-74c0b910cbbf','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:47:13',NULL,'CREATE','IN_PROGRESS','19','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-19-ky2lrk6oc2mm','state changed','OS::TripleO::Services::Iscsid',NULL,821),(1277,'b405c3e5-e933-46b2-9cdc-18d74ec0f3c3','099f290f-c85b-46c3-b19b-93bfc825bbf9','2026-06-10 07:47:13',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-19-ky2lrk6oc2mm','099f290f-c85b-46c3-b19b-93bfc825bbf9','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1278,'3fc52bd7-55df-47a6-8cc9-0154448dd96f','3f938799-6b6d-42a8-8729-c3aacf864a32','2026-06-10 07:47:14',NULL,'CREATE','IN_PROGRESS','HeatApiCfnLogging','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-16-lp7bgul2g4za-HeatApiCfnLogging-ecegpynihwi2','state changed','OS::TripleO::Services::Logging::HeatApiCfn',NULL,NULL),(1279,'b1995392-68a4-47d5-8198-7147c1e7b6f6','099f290f-c85b-46c3-b19b-93bfc825bbf9','2026-06-10 07:47:14',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-19-ky2lrk6oc2mm-RoleParametersValue-y245deqk7fns','state changed','OS::Heat::Value',NULL,823),(1280,'7c1a309c-b19e-4f47-bb6b-e021ba51da17','eb423eea-4ae8-4d30-ab7b-bdf7f5d27c98','2026-06-10 07:47:14',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-16-lp7bgul2g4za-HeatApiCfnLogging-ecegpynihwi2','eb423eea-4ae8-4d30-ab7b-bdf7f5d27c98','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1281,'8f5ec32d-2f73-4543-95e7-0934e7cd58f5','099f290f-c85b-46c3-b19b-93bfc825bbf9','2026-06-10 07:47:14',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-19-ky2lrk6oc2mm-RoleParametersValue-y245deqk7fns','state changed','OS::Heat::Value',NULL,823),(1282,'ed2a9e83-e633-4d93-a655-78ff175d9b59','3f938799-6b6d-42a8-8729-c3aacf864a32','2026-06-10 07:47:14',NULL,'CREATE','COMPLETE','ApacheServiceBase','62c3fa60-0e88-4f44-b9c0-b9a19c459d28','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,807),(1283,'ec5e236c-fdd9-492d-9f30-41aabee8639a','eb423eea-4ae8-4d30-ab7b-bdf7f5d27c98','2026-06-10 07:47:14',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-16-lp7bgul2g4za-HeatApiCfnLogging-ecegpynihwi2','eb423eea-4ae8-4d30-ab7b-bdf7f5d27c98','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1284,'fbd120f1-96c0-4445-bd7e-88eb86c97f7e','3bed5218-b075-4775-bea9-2f366483fb09','2026-06-10 07:47:14',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-17-5u3pxgvn5wiv-RoleParametersValue-rjw2bubs4nch','state changed','OS::Heat::Value',NULL,828),(1285,'15c2c540-637e-43f1-9e77-a254e3e81a3b','3bed5218-b075-4775-bea9-2f366483fb09','2026-06-10 07:47:14',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-17-5u3pxgvn5wiv-RoleParametersValue-rjw2bubs4nch','state changed','OS::Heat::Value',NULL,828),(1286,'347c2d16-8840-44c9-b0e4-2029d8e21159','3bed5218-b075-4775-bea9-2f366483fb09','2026-06-10 07:47:14',NULL,'CREATE','COMPLETE','HeatEngineLogging','322d8879-d11b-4878-8788-f47da62e9631','state changed','OS::TripleO::Services::Logging::HeatEngine',NULL,NULL),(1287,'43b23c30-2edf-4b00-bd5a-cd88740dcf48','3bed5218-b075-4775-bea9-2f366483fb09','2026-06-10 07:47:14',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-17-5u3pxgvn5wiv','3bed5218-b075-4775-bea9-2f366483fb09','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1288,'b0557829-632b-4a6e-80d0-2a3e0dd92908','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:47:14',NULL,'CREATE','IN_PROGRESS','26','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-26-ssziha5wefwd','state changed','OS::TripleO::Services::Memcached',NULL,831),(1289,'b2c0cdc3-f046-4eca-9815-430ee240f810','dc00d3b1-4076-44b0-bb65-3effc8367b9f','2026-06-10 07:47:14',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-26-ssziha5wefwd','dc00d3b1-4076-44b0-bb65-3effc8367b9f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1290,'347e7ab0-1b85-4d6d-b512-e903b53fd13f','dc00d3b1-4076-44b0-bb65-3effc8367b9f','2026-06-10 07:47:14',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-26-ssziha5wefwd-RoleParametersValue-lbsrizaxp2mq','state changed','OS::Heat::Value',NULL,832),(1291,'725aecf9-5441-4133-8c7e-cd42ad73cb24','dc00d3b1-4076-44b0-bb65-3effc8367b9f','2026-06-10 07:47:14',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-26-ssziha5wefwd-RoleParametersValue-lbsrizaxp2mq','state changed','OS::Heat::Value',NULL,832),(1292,'5dd08d2c-859b-4c57-b967-7dae8475cda1','3f938799-6b6d-42a8-8729-c3aacf864a32','2026-06-10 07:47:14',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-16-lp7bgul2g4za-ContainersCommon-tgwclijufrfu','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1293,'75d2a2b9-68eb-4781-88aa-5a0bd0ab5c82','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:47:15',NULL,'CREATE','COMPLETE','17','3bed5218-b075-4775-bea9-2f366483fb09','state changed','OS::TripleO::Services::HeatEngine',NULL,787),(1294,'8e78e4c0-dd79-4da7-8427-9e8694397435','4d762c98-0869-4d4a-92aa-7e97ebccd112','2026-06-10 07:47:15',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-16-lp7bgul2g4za-ContainersCommon-tgwclijufrfu','4d762c98-0869-4d4a-92aa-7e97ebccd112','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1295,'6f8a9af5-d44e-4548-bf0f-a7949750aa97','099f290f-c85b-46c3-b19b-93bfc825bbf9','2026-06-10 07:47:15',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-19-ky2lrk6oc2mm-ContainersCommon-e4kckbg4skbt','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1296,'f047c5f8-b4bb-4daf-a8f4-0f1b89be45e9','4d762c98-0869-4d4a-92aa-7e97ebccd112','2026-06-10 07:47:15',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-16-lp7bgul2g4za-ContainersCommon-tgwclijufrfu','4d762c98-0869-4d4a-92aa-7e97ebccd112','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1297,'7576d967-a7f2-4928-bd34-8f699ec3d4c9','3f938799-6b6d-42a8-8729-c3aacf864a32','2026-06-10 07:47:15',NULL,'CREATE','COMPLETE','HeatApiCfnLogging','eb423eea-4ae8-4d30-ab7b-bdf7f5d27c98','state changed','OS::TripleO::Services::Logging::HeatApiCfn',NULL,NULL),(1298,'6e27a43e-0f0b-48c2-92a2-5b119a8d2d9d','30d7db61-37fb-4562-abce-badc6fcb337e','2026-06-10 07:47:15',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-19-ky2lrk6oc2mm-ContainersCommon-e4kckbg4skbt','30d7db61-37fb-4562-abce-badc6fcb337e','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1299,'9e8dfb43-df07-4e35-8e81-812448a78c34','30d7db61-37fb-4562-abce-badc6fcb337e','2026-06-10 07:47:15',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-19-ky2lrk6oc2mm-ContainersCommon-e4kckbg4skbt','30d7db61-37fb-4562-abce-badc6fcb337e','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1300,'25bb11cb-055c-43e6-81be-374cfd0959f9','3f938799-6b6d-42a8-8729-c3aacf864a32','2026-06-10 07:47:15',NULL,'CREATE','COMPLETE','ContainersCommon','4d762c98-0869-4d4a-92aa-7e97ebccd112','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1301,'12cdecd8-c621-4148-be65-074a9489cb79','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:47:15',NULL,'CREATE','IN_PROGRESS','21','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-21-ldg5hdqqvq7n','state changed','OS::TripleO::Services::Keystone',NULL,840),(1302,'8ef7614c-9000-41f2-893f-7510206b3e3c','dc00d3b1-4076-44b0-bb65-3effc8367b9f','2026-06-10 07:47:15',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-26-ssziha5wefwd-ContainersCommon-hq4gsrkcstke','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1303,'d22886d5-bdd9-47ce-a030-7e6083ecc65c','bf3e8cdb-eabf-45d5-97f9-fae9820c3fa4','2026-06-10 07:47:15',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-21-ldg5hdqqvq7n','bf3e8cdb-eabf-45d5-97f9-fae9820c3fa4','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1304,'d4ad4d3a-f81d-456d-92d3-43a20f964424','9252f25f-a77a-4626-83a4-5f8cb6b92182','2026-06-10 07:47:15',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-26-ssziha5wefwd-ContainersCommon-hq4gsrkcstke','9252f25f-a77a-4626-83a4-5f8cb6b92182','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1305,'2a98775a-e83d-4e0e-a04d-3182fad3ea0c','9252f25f-a77a-4626-83a4-5f8cb6b92182','2026-06-10 07:47:15',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-26-ssziha5wefwd-ContainersCommon-hq4gsrkcstke','9252f25f-a77a-4626-83a4-5f8cb6b92182','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1306,'76699f74-dc1d-424a-944f-cd990cb36baf','bf3e8cdb-eabf-45d5-97f9-fae9820c3fa4','2026-06-10 07:47:15',NULL,'CREATE','IN_PROGRESS','ApacheServiceBase','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-21-ldg5hdqqvq7n-ApacheServiceBase-mxk6uz3nhtmi','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,841),(1307,'d0ee4f0d-b851-4ab0-9814-96c8b32e7a71','3f938799-6b6d-42a8-8729-c3aacf864a32','2026-06-10 07:47:15',NULL,'CREATE','IN_PROGRESS','HeatBase','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-16-lp7bgul2g4za-HeatBase-5kltahmhscjc','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-base-puppet.yaml',NULL,842),(1308,'e8417e2a-54af-40bb-81c3-4ede56a87094','1524ab0e-19f7-49db-bdfe-b3aa7f219d52','2026-06-10 07:47:16',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-21-ldg5hdqqvq7n-ApacheServiceBase-mxk6uz3nhtmi','1524ab0e-19f7-49db-bdfe-b3aa7f219d52','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1309,'e07d0ecc-81d2-4f95-bd2f-627cff0cb3d3','8d1da76c-5c33-479b-81a0-6e982640405b','2026-06-10 07:47:16',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-16-lp7bgul2g4za-HeatBase-5kltahmhscjc','8d1da76c-5c33-479b-81a0-6e982640405b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1310,'6510415f-c1b4-4b41-aed7-6e4dfcf5fafd','8d1da76c-5c33-479b-81a0-6e982640405b','2026-06-10 07:47:16',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-16-lp7bgul2g4za-HeatBase-5kltahmhscjc','8d1da76c-5c33-479b-81a0-6e982640405b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1311,'ffa621fd-1623-4e49-aacc-da94908f1b35','1524ab0e-19f7-49db-bdfe-b3aa7f219d52','2026-06-10 07:47:16',NULL,'CREATE','IN_PROGRESS','ApacheNetworks','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-21-ldg5hdqqvq7n-ApacheServiceBase-mxk6uz3nhtmi-ApacheNetworks-trux4hsn3abm','state changed','OS::Heat::Value',NULL,843),(1312,'5ad757fd-0bc0-4a3a-b877-758f34873058','099f290f-c85b-46c3-b19b-93bfc825bbf9','2026-06-10 07:47:16',NULL,'CREATE','COMPLETE','ContainersCommon','30d7db61-37fb-4562-abce-badc6fcb337e','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1313,'07f4dfd4-5117-4ee6-8921-e15d99252ac3','1524ab0e-19f7-49db-bdfe-b3aa7f219d52','2026-06-10 07:47:16',NULL,'CREATE','COMPLETE','ApacheNetworks','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-21-ldg5hdqqvq7n-ApacheServiceBase-mxk6uz3nhtmi-ApacheNetworks-trux4hsn3abm','state changed','OS::Heat::Value',NULL,843),(1314,'be095fcf-165a-4ae0-87fb-d42663453ab5','099f290f-c85b-46c3-b19b-93bfc825bbf9','2026-06-10 07:47:16',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-19-ky2lrk6oc2mm','099f290f-c85b-46c3-b19b-93bfc825bbf9','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1315,'5c48010c-e590-409d-a450-afb9049eda3b','1524ab0e-19f7-49db-bdfe-b3aa7f219d52','2026-06-10 07:47:16',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-21-ldg5hdqqvq7n-ApacheServiceBase-mxk6uz3nhtmi','1524ab0e-19f7-49db-bdfe-b3aa7f219d52','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1316,'428903c5-7d19-4520-830b-24a2ac7134c1','dc00d3b1-4076-44b0-bb65-3effc8367b9f','2026-06-10 07:47:16',NULL,'CREATE','COMPLETE','ContainersCommon','9252f25f-a77a-4626-83a4-5f8cb6b92182','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1317,'d12682f4-2241-4972-bec2-6123c93e41ff','dc00d3b1-4076-44b0-bb65-3effc8367b9f','2026-06-10 07:47:16',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-26-ssziha5wefwd','dc00d3b1-4076-44b0-bb65-3effc8367b9f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1318,'dfd1923a-dab2-452c-b0b3-c84b69249abb','bf3e8cdb-eabf-45d5-97f9-fae9820c3fa4','2026-06-10 07:47:16',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-21-ldg5hdqqvq7n-ContainersCommon-lk6jbjau3td2','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1319,'a24996be-0d5a-41be-83f5-ef5c9fc80508','3f938799-6b6d-42a8-8729-c3aacf864a32','2026-06-10 07:47:16',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-16-lp7bgul2g4za-RoleParametersValue-2ro4huyv7yz7','state changed','OS::Heat::Value',NULL,844),(1320,'b1e2d96c-0d10-4035-8133-896a3c85f8ed','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:47:16',NULL,'CREATE','COMPLETE','19','099f290f-c85b-46c3-b19b-93bfc825bbf9','state changed','OS::TripleO::Services::Iscsid',NULL,821),(1321,'7b8381d0-7e25-4636-8320-484cea37ab5f','3f938799-6b6d-42a8-8729-c3aacf864a32','2026-06-10 07:47:16',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-16-lp7bgul2g4za-RoleParametersValue-2ro4huyv7yz7','state changed','OS::Heat::Value',NULL,844),(1322,'ca1fc2c2-1693-4de6-b227-8ead7845fd71','77f625b7-58db-445c-8f35-2a9ac29b39bc','2026-06-10 07:47:17',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-21-ldg5hdqqvq7n-ContainersCommon-lk6jbjau3td2','77f625b7-58db-445c-8f35-2a9ac29b39bc','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1323,'141843c4-32fd-4955-b505-0a7807250bcd','77f625b7-58db-445c-8f35-2a9ac29b39bc','2026-06-10 07:47:17',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-21-ldg5hdqqvq7n-ContainersCommon-lk6jbjau3td2','77f625b7-58db-445c-8f35-2a9ac29b39bc','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1324,'7023e23a-7cf4-420b-bb22-3abe5dcc8d94','bf3e8cdb-eabf-45d5-97f9-fae9820c3fa4','2026-06-10 07:47:17',NULL,'CREATE','COMPLETE','ApacheServiceBase','1524ab0e-19f7-49db-bdfe-b3aa7f219d52','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,841),(1325,'9e55e718-c9d3-4d47-83ce-4a51099f083c','3f938799-6b6d-42a8-8729-c3aacf864a32','2026-06-10 07:47:17',NULL,'CREATE','COMPLETE','HeatBase','8d1da76c-5c33-479b-81a0-6e982640405b','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-base-puppet.yaml',NULL,842),(1326,'f0055cde-0b0b-4df4-8873-b8efee5a5d61','3f938799-6b6d-42a8-8729-c3aacf864a32','2026-06-10 07:47:17',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-16-lp7bgul2g4za','3f938799-6b6d-42a8-8729-c3aacf864a32','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1327,'28eb95f1-b46e-4b22-b356-d2370b70ebd7','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:47:17',NULL,'CREATE','IN_PROGRESS','23','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-23-qe4ms76ujcro','state changed','OS::TripleO::Services::ManilaBackendCephFs',NULL,848),(1328,'5e5451fe-2b62-4a44-9c90-e30ffe6ad4f8','bc7c2f35-7872-4f4d-895f-89cb2f437c19','2026-06-10 07:47:17',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-23-qe4ms76ujcro','bc7c2f35-7872-4f4d-895f-89cb2f437c19','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1329,'eaf941c2-3167-4847-8300-69d043d11de7','bc7c2f35-7872-4f4d-895f-89cb2f437c19','2026-06-10 07:47:17',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-23-qe4ms76ujcro','bc7c2f35-7872-4f4d-895f-89cb2f437c19','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1330,'e5760095-ea7c-41ac-93c2-516ae4ef658b','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:47:17',NULL,'CREATE','COMPLETE','26','dc00d3b1-4076-44b0-bb65-3effc8367b9f','state changed','OS::TripleO::Services::Memcached',NULL,831),(1331,'b8a259c5-e715-43c2-974b-19e3b77e897c','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:47:17',NULL,'CREATE','COMPLETE','16','3f938799-6b6d-42a8-8729-c3aacf864a32','state changed','OS::TripleO::Services::HeatApiCfn',NULL,806),(1332,'3bce4017-d721-4e72-93ae-be834886016f','bf3e8cdb-eabf-45d5-97f9-fae9820c3fa4','2026-06-10 07:47:17',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-21-ldg5hdqqvq7n-MySQLClient-iumdmf4lqj6s','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1333,'da8b872b-cd88-4abc-a5e9-ac07a2b152cc','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:47:17',NULL,'CREATE','IN_PROGRESS','30','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-30-o2os7b4qg2w2','state changed','OS::TripleO::Services::NeutronApi',NULL,852),(1334,'46923789-3b70-488a-9551-ce6e40110334','bf5e0ca3-c2d9-4832-af78-18f57e57cab8','2026-06-10 07:47:18',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-21-ldg5hdqqvq7n-MySQLClient-iumdmf4lqj6s','bf5e0ca3-c2d9-4832-af78-18f57e57cab8','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1335,'bc38ad16-dc73-4e98-92e7-4036f26b4afa','bf5e0ca3-c2d9-4832-af78-18f57e57cab8','2026-06-10 07:47:18',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-21-ldg5hdqqvq7n-MySQLClient-iumdmf4lqj6s','bf5e0ca3-c2d9-4832-af78-18f57e57cab8','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1336,'a1dc5140-12c2-4940-bae9-60d5a48a6397','bf3e8cdb-eabf-45d5-97f9-fae9820c3fa4','2026-06-10 07:47:18',NULL,'CREATE','COMPLETE','ContainersCommon','77f625b7-58db-445c-8f35-2a9ac29b39bc','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1337,'1ef087b2-d0d4-4237-8196-3543f663b286','b615122b-be9a-4cf3-ac8b-7af70976fda0','2026-06-10 07:47:18',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-30-o2os7b4qg2w2','b615122b-be9a-4cf3-ac8b-7af70976fda0','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1338,'357fb4fd-bfba-4883-b313-f6a61f3c4330','b615122b-be9a-4cf3-ac8b-7af70976fda0','2026-06-10 07:47:18',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-30-o2os7b4qg2w2-MySQLClient-3vcczwf4trom','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1339,'b401ce90-da93-43e7-a06d-e6be37222685','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:47:18',NULL,'CREATE','IN_PROGRESS','20','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-20-xhu4hoielntq','state changed','OS::TripleO::Services::Kernel',NULL,860),(1340,'cf627841-bb37-4cad-bc12-3c86c2867311','adb04aeb-a5b9-4312-a9e9-f9dc161e9bef','2026-06-10 07:47:18',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-30-o2os7b4qg2w2-MySQLClient-3vcczwf4trom','adb04aeb-a5b9-4312-a9e9-f9dc161e9bef','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1341,'bd208b0e-ef0d-479e-82b6-a1a9496bed8e','adb04aeb-a5b9-4312-a9e9-f9dc161e9bef','2026-06-10 07:47:18',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-30-o2os7b4qg2w2-MySQLClient-3vcczwf4trom','adb04aeb-a5b9-4312-a9e9-f9dc161e9bef','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1342,'b2246392-28da-4bb4-8e84-bb74b7ee375a','8a2e99d9-1986-4e5f-98d3-a05380524a2c','2026-06-10 07:47:18',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-20-xhu4hoielntq','8a2e99d9-1986-4e5f-98d3-a05380524a2c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1343,'96b0e331-530b-44d9-8de2-04a3a0c7dd50','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:47:18',NULL,'CREATE','COMPLETE','23','bc7c2f35-7872-4f4d-895f-89cb2f437c19','state changed','OS::TripleO::Services::ManilaBackendCephFs',NULL,848),(1344,'358e4e3d-56fc-4684-b531-c4ee2f590f9c','8a2e99d9-1986-4e5f-98d3-a05380524a2c','2026-06-10 07:47:18',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-20-xhu4hoielntq-RoleParametersValue-wf6ngnlpzbxu','state changed','OS::Heat::Value',NULL,861),(1345,'b7d38091-3fb1-4b1f-8fed-68c62fbbe11a','8a2e99d9-1986-4e5f-98d3-a05380524a2c','2026-06-10 07:47:18',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-20-xhu4hoielntq-RoleParametersValue-wf6ngnlpzbxu','state changed','OS::Heat::Value',NULL,861),(1346,'dc27d755-3ac6-431c-bd12-6c6dbcb3f4b2','8a2e99d9-1986-4e5f-98d3-a05380524a2c','2026-06-10 07:47:18',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-20-xhu4hoielntq','8a2e99d9-1986-4e5f-98d3-a05380524a2c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1347,'94e3e17a-b065-4790-a103-01eef861a275','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:47:18',NULL,'CREATE','IN_PROGRESS','27','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-27-jaddzvswcy4z','state changed','OS::TripleO::Services::MetricsQdr',NULL,863),(1348,'5f967de7-fe30-45eb-896e-53f17fae14e1','0194fd08-dfd7-405b-9d64-72b99c58da8c','2026-06-10 07:47:18',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-27-jaddzvswcy4z','0194fd08-dfd7-405b-9d64-72b99c58da8c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1349,'7e3c0cdc-f690-44f4-9624-5002512d787d','bf3e8cdb-eabf-45d5-97f9-fae9820c3fa4','2026-06-10 07:47:18',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-21-ldg5hdqqvq7n-RoleParametersValue-btrjlxxfi2f4','state changed','OS::Heat::Value',NULL,864),(1350,'999e29d2-0995-4afd-bc94-6429d2942ba8','bf3e8cdb-eabf-45d5-97f9-fae9820c3fa4','2026-06-10 07:47:18',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-21-ldg5hdqqvq7n-RoleParametersValue-btrjlxxfi2f4','state changed','OS::Heat::Value',NULL,864),(1351,'369ae007-c58d-4bb4-aa48-caae1e7ecdcf','0194fd08-dfd7-405b-9d64-72b99c58da8c','2026-06-10 07:47:19',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-27-jaddzvswcy4z-ContainersCommon-c63omu6it6c7','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1352,'9a285ca4-0258-4526-b18b-327d33402182','bf3e8cdb-eabf-45d5-97f9-fae9820c3fa4','2026-06-10 07:47:19',NULL,'CREATE','COMPLETE','MySQLClient','bf5e0ca3-c2d9-4832-af78-18f57e57cab8','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1353,'7e85b613-74a5-4945-a027-c0845bcfc854','323581d5-bcbb-45c3-8038-3eb07c360141','2026-06-10 07:47:19',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-27-jaddzvswcy4z-ContainersCommon-c63omu6it6c7','323581d5-bcbb-45c3-8038-3eb07c360141','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1354,'f49ff719-c6f0-440f-af12-19a89d3c3606','323581d5-bcbb-45c3-8038-3eb07c360141','2026-06-10 07:47:19',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-27-jaddzvswcy4z-ContainersCommon-c63omu6it6c7','323581d5-bcbb-45c3-8038-3eb07c360141','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1355,'37f43a23-6c6b-4d7d-8fde-2c579143cb7a','b615122b-be9a-4cf3-ac8b-7af70976fda0','2026-06-10 07:47:19',NULL,'CREATE','IN_PROGRESS','NeutronBase','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-30-o2os7b4qg2w2-NeutronBase-bgy5ugy2ki3g','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-base.yaml',NULL,865),(1356,'16dcad91-c71a-43b9-854b-7cb97c77469f','b615122b-be9a-4cf3-ac8b-7af70976fda0','2026-06-10 07:47:19',NULL,'CREATE','COMPLETE','MySQLClient','adb04aeb-a5b9-4312-a9e9-f9dc161e9bef','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1357,'a2f7893c-c413-4dda-b571-7ea111dccf99','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:47:19',NULL,'CREATE','COMPLETE','20','8a2e99d9-1986-4e5f-98d3-a05380524a2c','state changed','OS::TripleO::Services::Kernel',NULL,860),(1358,'996e6f6a-9d35-4834-8ab6-95b4f660be18','cbb13d26-b0c6-446a-838c-d4faaae2ac3d','2026-06-10 07:47:19',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-30-o2os7b4qg2w2-NeutronBase-bgy5ugy2ki3g','cbb13d26-b0c6-446a-838c-d4faaae2ac3d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1359,'17ecf6bf-07c0-45ac-9eea-60d8ec5f3076','cbb13d26-b0c6-446a-838c-d4faaae2ac3d','2026-06-10 07:47:19',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-30-o2os7b4qg2w2-NeutronBase-bgy5ugy2ki3g','cbb13d26-b0c6-446a-838c-d4faaae2ac3d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1360,'df2d0944-ace2-4aca-a75a-57f8919d35df','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:47:19',NULL,'CREATE','IN_PROGRESS','24','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-24-3ddzd2oskcsd','state changed','OS::TripleO::Services::ManilaScheduler',NULL,868),(1361,'6b12e2fc-bf86-487c-b534-0c4f7ec67f13','86f17c08-d220-42ef-9072-ee1339559c0a','2026-06-10 07:47:19',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-24-3ddzd2oskcsd','86f17c08-d220-42ef-9072-ee1339559c0a','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1362,'de1eab15-01e7-4794-b987-80eed8326f93','bf3e8cdb-eabf-45d5-97f9-fae9820c3fa4','2026-06-10 07:47:19',NULL,'CREATE','IN_PROGRESS','KeystoneLogging','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-21-ldg5hdqqvq7n-KeystoneLogging-jq7bgup5lebq','state changed','OS::TripleO::Services::Logging::Keystone',NULL,NULL),(1363,'9e6f0d4d-227f-4a98-b0a9-5c3809b67c82','136201f4-7a74-42aa-a5af-3ff4a5b78786','2026-06-10 07:47:20',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-21-ldg5hdqqvq7n-KeystoneLogging-jq7bgup5lebq','136201f4-7a74-42aa-a5af-3ff4a5b78786','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1364,'47d722ec-8549-4c03-94dc-391385977736','0194fd08-dfd7-405b-9d64-72b99c58da8c','2026-06-10 07:47:20',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-27-jaddzvswcy4z-RoleParametersValue-uvygap2lbcqo','state changed','OS::Heat::Value',NULL,869),(1365,'1447d3a5-b459-4c69-9d34-a50886abcbca','0194fd08-dfd7-405b-9d64-72b99c58da8c','2026-06-10 07:47:20',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-27-jaddzvswcy4z-RoleParametersValue-uvygap2lbcqo','state changed','OS::Heat::Value',NULL,869),(1366,'195fa575-daa6-4032-99a4-7f3048ff509f','86f17c08-d220-42ef-9072-ee1339559c0a','2026-06-10 07:47:20',NULL,'CREATE','IN_PROGRESS','ManilaBase','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-24-3ddzd2oskcsd-ManilaBase-v3a6yr6jfetm','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-base.yaml',NULL,870),(1367,'6ed113c8-e3cb-49b2-8e39-1f928697cdd1','136201f4-7a74-42aa-a5af-3ff4a5b78786','2026-06-10 07:47:20',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-21-ldg5hdqqvq7n-KeystoneLogging-jq7bgup5lebq-RoleParametersValue-ord3bqbjdcqi','state changed','OS::Heat::Value',NULL,871),(1368,'a1cf113c-f615-4be1-a333-655df6cc95a0','0194fd08-dfd7-405b-9d64-72b99c58da8c','2026-06-10 07:47:20',NULL,'CREATE','COMPLETE','ContainersCommon','323581d5-bcbb-45c3-8038-3eb07c360141','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1369,'3bce52ec-2210-4c2e-9d2b-caedde403e84','0194fd08-dfd7-405b-9d64-72b99c58da8c','2026-06-10 07:47:20',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-27-jaddzvswcy4z','0194fd08-dfd7-405b-9d64-72b99c58da8c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1370,'5aa93b2d-ba6e-410e-ad5b-0d9d3c839a1d','136201f4-7a74-42aa-a5af-3ff4a5b78786','2026-06-10 07:47:20',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-21-ldg5hdqqvq7n-KeystoneLogging-jq7bgup5lebq-RoleParametersValue-ord3bqbjdcqi','state changed','OS::Heat::Value',NULL,871),(1371,'5fb1c454-d514-48b6-a797-ca114fe7b5eb','78722d8e-3347-4b8f-a637-4a4c53f92f96','2026-06-10 07:47:20',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-24-3ddzd2oskcsd-ManilaBase-v3a6yr6jfetm','78722d8e-3347-4b8f-a637-4a4c53f92f96','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1372,'2013576d-cf6a-4aac-b791-bdf66a476599','136201f4-7a74-42aa-a5af-3ff4a5b78786','2026-06-10 07:47:20',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-21-ldg5hdqqvq7n-KeystoneLogging-jq7bgup5lebq','136201f4-7a74-42aa-a5af-3ff4a5b78786','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1373,'563bae0e-9dbc-48dc-9091-3b64362af12c','78722d8e-3347-4b8f-a637-4a4c53f92f96','2026-06-10 07:47:20',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-24-3ddzd2oskcsd-ManilaBase-v3a6yr6jfetm','78722d8e-3347-4b8f-a637-4a4c53f92f96','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1374,'2d88cfd7-cd23-4502-9784-7a4405513d54','b615122b-be9a-4cf3-ac8b-7af70976fda0','2026-06-10 07:47:20',NULL,'CREATE','IN_PROGRESS','TLSProxyBase','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-30-o2os7b4qg2w2-TLSProxyBase-tihyvybv2kkf','state changed','OS::TripleO::Services::TLSProxyBase',NULL,NULL),(1375,'281ba9e7-4779-478c-ad49-2d5b8c10a7af','b615122b-be9a-4cf3-ac8b-7af70976fda0','2026-06-10 07:47:20',NULL,'CREATE','COMPLETE','TLSProxyBase','1fc8e418-80cf-4569-9847-26f6c128e0bb','state changed','OS::TripleO::Services::TLSProxyBase',NULL,NULL),(1376,'3a77c024-2187-4803-9373-c04a6c9e4ace','b615122b-be9a-4cf3-ac8b-7af70976fda0','2026-06-10 07:47:20',NULL,'CREATE','COMPLETE','NeutronBase','cbb13d26-b0c6-446a-838c-d4faaae2ac3d','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-base.yaml',NULL,865),(1377,'906c0d62-79c0-4988-bff8-ba11e530d92d','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:47:20',NULL,'CREATE','COMPLETE','27','0194fd08-dfd7-405b-9d64-72b99c58da8c','state changed','OS::TripleO::Services::MetricsQdr',NULL,863),(1378,'ce6f3995-cc73-444e-ada6-859bf345c64b','bf3e8cdb-eabf-45d5-97f9-fae9820c3fa4','2026-06-10 07:47:21',NULL,'CREATE','COMPLETE','KeystoneLogging','136201f4-7a74-42aa-a5af-3ff4a5b78786','state changed','OS::TripleO::Services::Logging::Keystone',NULL,NULL),(1379,'59bedc44-ef86-40dc-a899-e9d4374609e6','bf3e8cdb-eabf-45d5-97f9-fae9820c3fa4','2026-06-10 07:47:21',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-21-ldg5hdqqvq7n','bf3e8cdb-eabf-45d5-97f9-fae9820c3fa4','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1380,'04cc8297-2ca6-4920-820c-8b929d2bcc70','86f17c08-d220-42ef-9072-ee1339559c0a','2026-06-10 07:47:21',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-24-3ddzd2oskcsd-MySQLClient-brath4qag5gn','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1381,'58ba9c1b-f157-4e90-9c5e-e0c1fc1643e3','392f5813-da9d-4286-b945-b2e335cc07fe','2026-06-10 07:47:21',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-24-3ddzd2oskcsd-MySQLClient-brath4qag5gn','392f5813-da9d-4286-b945-b2e335cc07fe','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1382,'b2d570ef-67b1-4cb2-a51c-d2d58b85d86a','392f5813-da9d-4286-b945-b2e335cc07fe','2026-06-10 07:47:21',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-24-3ddzd2oskcsd-MySQLClient-brath4qag5gn','392f5813-da9d-4286-b945-b2e335cc07fe','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1383,'73e9d955-3bd6-4a0b-b097-89de0ed50694','86f17c08-d220-42ef-9072-ee1339559c0a','2026-06-10 07:47:21',NULL,'CREATE','COMPLETE','ManilaBase','78722d8e-3347-4b8f-a637-4a4c53f92f96','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-base.yaml',NULL,870),(1384,'76b266da-41a2-40a6-b1be-7271f6ed0056','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:47:21',NULL,'CREATE','IN_PROGRESS','31','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-31-ul3y4x5e2xex','state changed','OS::TripleO::Services::NeutronCorePlugin',NULL,875),(1385,'0a957089-d96a-4c95-b522-f7e4e35822cc','b615122b-be9a-4cf3-ac8b-7af70976fda0','2026-06-10 07:47:21',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-30-o2os7b4qg2w2-RoleParametersValue-r7xoeadymbvb','state changed','OS::Heat::Value',NULL,876),(1386,'fe8be809-c95f-4cc6-bb76-9342c962bf6e','ca02b483-23f0-4e11-acdc-6e9af2a656bd','2026-06-10 07:47:21',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-31-ul3y4x5e2xex','ca02b483-23f0-4e11-acdc-6e9af2a656bd','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1387,'14055b22-84b6-4d36-b72e-02f2d0b8331a','b615122b-be9a-4cf3-ac8b-7af70976fda0','2026-06-10 07:47:21',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-30-o2os7b4qg2w2-RoleParametersValue-r7xoeadymbvb','state changed','OS::Heat::Value',NULL,876),(1388,'10787080-3229-4928-bb6d-af235fa2b335','ca02b483-23f0-4e11-acdc-6e9af2a656bd','2026-06-10 07:47:21',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-31-ul3y4x5e2xex-RoleParametersValue-e6yfutvr3u3n','state changed','OS::Heat::Value',NULL,877),(1389,'e5959568-cbb8-42fc-98fd-1e44e76d043b','ca02b483-23f0-4e11-acdc-6e9af2a656bd','2026-06-10 07:47:21',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-31-ul3y4x5e2xex-RoleParametersValue-e6yfutvr3u3n','state changed','OS::Heat::Value',NULL,877),(1390,'2f34cd33-fedc-457b-8458-5d2dc164d1ab','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:47:21',NULL,'CREATE','COMPLETE','21','bf3e8cdb-eabf-45d5-97f9-fae9820c3fa4','state changed','OS::TripleO::Services::Keystone',NULL,840),(1391,'fa09b70e-6c14-4369-abc6-e6c95b6b0419','86f17c08-d220-42ef-9072-ee1339559c0a','2026-06-10 07:47:22',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-24-3ddzd2oskcsd-ContainersCommon-4wkdpl3omten','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1392,'b97a64b1-c50e-4fc3-bf58-3f3f34b2f378','86f17c08-d220-42ef-9072-ee1339559c0a','2026-06-10 07:47:22',NULL,'CREATE','COMPLETE','MySQLClient','392f5813-da9d-4286-b945-b2e335cc07fe','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1393,'1fa35539-c73c-4859-afe6-950bdc4cf335','8364c3b9-666e-44a4-838f-5508a76b3928','2026-06-10 07:47:22',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-24-3ddzd2oskcsd-ContainersCommon-4wkdpl3omten','8364c3b9-666e-44a4-838f-5508a76b3928','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1394,'08a5e624-b964-415a-9cc4-d11a48f39c82','8364c3b9-666e-44a4-838f-5508a76b3928','2026-06-10 07:47:22',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-24-3ddzd2oskcsd-ContainersCommon-4wkdpl3omten','8364c3b9-666e-44a4-838f-5508a76b3928','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1395,'785dfbab-bd19-4993-a0fc-ae50b612e449','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:47:22',NULL,'CREATE','IN_PROGRESS','25','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-25-ljommtpr6eis','state changed','OS::TripleO::Services::ManilaShare',NULL,886),(1396,'d445e740-33e2-4221-a047-fdf938fb18e9','b615122b-be9a-4cf3-ac8b-7af70976fda0','2026-06-10 07:47:22',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-30-o2os7b4qg2w2-ContainersCommon-pz76ih3jqbhs','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1397,'8c97a202-2d72-4f4b-a6d4-40466d06aeea','0601b2f0-5a80-44bb-961f-422a8f6ca342','2026-06-10 07:47:22',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-30-o2os7b4qg2w2-ContainersCommon-pz76ih3jqbhs','0601b2f0-5a80-44bb-961f-422a8f6ca342','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1398,'5e842367-d9c9-4fc6-8e6e-a27d2d33d323','0601b2f0-5a80-44bb-961f-422a8f6ca342','2026-06-10 07:47:22',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-30-o2os7b4qg2w2-ContainersCommon-pz76ih3jqbhs','0601b2f0-5a80-44bb-961f-422a8f6ca342','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1399,'f07eff06-942f-4b19-85b6-8d4464005f5f','b51091f7-c31a-4f40-83e2-e9e49a9c5e15','2026-06-10 07:47:22',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-25-ljommtpr6eis','b51091f7-c31a-4f40-83e2-e9e49a9c5e15','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1400,'adff0b9a-1cec-4bba-9139-2438a1099f33','ca02b483-23f0-4e11-acdc-6e9af2a656bd','2026-06-10 07:47:22',NULL,'CREATE','IN_PROGRESS','NeutronBase','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-31-ul3y4x5e2xex-NeutronBase-xagn73wwkco6','state changed','OS::TripleO::Services::NeutronMl2PluginBase',NULL,887),(1401,'65a3eccd-dd6e-4439-b0bf-80fa025afa1f','b51091f7-c31a-4f40-83e2-e9e49a9c5e15','2026-06-10 07:47:22',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-25-ljommtpr6eis-MySQLClient-fwvo6lndkwla','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1402,'ee25672a-6dbe-454b-8304-01c2bcdc3415','4ddfd8d4-df1b-4b7c-9973-0a6a84a5ed0e','2026-06-10 07:47:22',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-31-ul3y4x5e2xex-NeutronBase-xagn73wwkco6','4ddfd8d4-df1b-4b7c-9973-0a6a84a5ed0e','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1403,'282d9b86-cdb9-46ef-8c2b-6098ce9165a8','fa2ef86b-7e53-466d-9190-72276b66d291','2026-06-10 07:47:22',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-25-ljommtpr6eis-MySQLClient-fwvo6lndkwla','fa2ef86b-7e53-466d-9190-72276b66d291','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1404,'c4f207be-6186-443f-9ea0-1591115810d5','fa2ef86b-7e53-466d-9190-72276b66d291','2026-06-10 07:47:22',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-25-ljommtpr6eis-MySQLClient-fwvo6lndkwla','fa2ef86b-7e53-466d-9190-72276b66d291','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1405,'b1339bba-9870-41bb-a669-e4f829c9332b','4ddfd8d4-df1b-4b7c-9973-0a6a84a5ed0e','2026-06-10 07:47:22',NULL,'CREATE','IN_PROGRESS','NeutronMl2Base','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-31-ul3y4x5e2xex-NeutronBase-xagn73wwkco6-NeutronMl2Base-sct3irkc2ws6','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2.yaml',NULL,888),(1406,'963ebe9a-a98d-4e41-ba1d-18ff054f7e18','4239961d-d12f-418f-a7f2-95ad737b4e0b','2026-06-10 07:47:22',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-31-ul3y4x5e2xex-NeutronBase-xagn73wwkco6-NeutronMl2Base-sct3irkc2ws6','4239961d-d12f-418f-a7f2-95ad737b4e0b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1407,'31b9c16e-1ab8-4bd8-9532-764e159896fe','4239961d-d12f-418f-a7f2-95ad737b4e0b','2026-06-10 07:47:22',NULL,'CREATE','IN_PROGRESS','NeutronBase','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-31-ul3y4x5e2xex-NeutronBase-xagn73wwkco6-NeutronMl2Base-sct3irkc2ws6-NeutronBase-fyl6wch5xizt','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-base.yaml',NULL,889),(1408,'9bf295d4-2666-4862-942c-8544d59baf0f','4f8aaf46-19f2-4a7a-bac5-bca6ee8c3007','2026-06-10 07:47:22',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-31-ul3y4x5e2xex-NeutronBase-xagn73wwkco6-NeutronMl2Base-sct3irkc2ws6-NeutronBase-fyl6wch5xizt','4f8aaf46-19f2-4a7a-bac5-bca6ee8c3007','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1409,'be22ccf0-3dd5-4f78-b0e0-b5e2512ac6d2','4f8aaf46-19f2-4a7a-bac5-bca6ee8c3007','2026-06-10 07:47:23',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-31-ul3y4x5e2xex-NeutronBase-xagn73wwkco6-NeutronMl2Base-sct3irkc2ws6-NeutronBase-fyl6wch5xizt','4f8aaf46-19f2-4a7a-bac5-bca6ee8c3007','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1410,'99ee899c-f0e2-4175-8b18-ec282ab55ef9','86f17c08-d220-42ef-9072-ee1339559c0a','2026-06-10 07:47:23',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-24-3ddzd2oskcsd-RoleParametersValue-dycsvxzsa6gf','state changed','OS::Heat::Value',NULL,890),(1411,'71fbdd98-af73-494f-a764-b5d138b9675d','86f17c08-d220-42ef-9072-ee1339559c0a','2026-06-10 07:47:23',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-24-3ddzd2oskcsd-RoleParametersValue-dycsvxzsa6gf','state changed','OS::Heat::Value',NULL,890),(1412,'b4950019-a28d-4912-869b-12ddf28e6f43','86f17c08-d220-42ef-9072-ee1339559c0a','2026-06-10 07:47:23',NULL,'CREATE','COMPLETE','ContainersCommon','8364c3b9-666e-44a4-838f-5508a76b3928','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1413,'0e8281eb-eec0-4413-a882-dccd412afae4','86f17c08-d220-42ef-9072-ee1339559c0a','2026-06-10 07:47:23',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-24-3ddzd2oskcsd','86f17c08-d220-42ef-9072-ee1339559c0a','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1414,'24f83cb7-3fe5-4854-802f-8b73294eb789','b615122b-be9a-4cf3-ac8b-7af70976fda0','2026-06-10 07:47:23',NULL,'CREATE','IN_PROGRESS','NeutronLogging','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-30-o2os7b4qg2w2-NeutronLogging-2z2sk6b5di7c','state changed','OS::TripleO::Services::Logging::NeutronApi',NULL,891),(1415,'54a9d1a0-bb5d-44f8-a065-91a9bac6d7a4','2a416a6f-eaec-4939-beb9-369733ec4a85','2026-06-10 07:47:23',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-30-o2os7b4qg2w2-NeutronLogging-2z2sk6b5di7c','2a416a6f-eaec-4939-beb9-369733ec4a85','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1416,'52a7e088-dc51-4350-9381-f35cade20e66','b615122b-be9a-4cf3-ac8b-7af70976fda0','2026-06-10 07:47:23',NULL,'CREATE','COMPLETE','ContainersCommon','0601b2f0-5a80-44bb-961f-422a8f6ca342','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1417,'97607b77-2f75-4211-9a9e-401c3a50d6f0','2a416a6f-eaec-4939-beb9-369733ec4a85','2026-06-10 07:47:23',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-30-o2os7b4qg2w2-NeutronLogging-2z2sk6b5di7c-RoleParametersValue-preagxu67o5v','state changed','OS::Heat::Value',NULL,892),(1418,'bc0c86ec-6a2f-46b5-97d5-ffe02e764c04','2a416a6f-eaec-4939-beb9-369733ec4a85','2026-06-10 07:47:23',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-30-o2os7b4qg2w2-NeutronLogging-2z2sk6b5di7c-RoleParametersValue-preagxu67o5v','state changed','OS::Heat::Value',NULL,892),(1419,'ec99432a-2456-4107-8290-4fd2636537d7','2a416a6f-eaec-4939-beb9-369733ec4a85','2026-06-10 07:47:23',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-30-o2os7b4qg2w2-NeutronLogging-2z2sk6b5di7c','2a416a6f-eaec-4939-beb9-369733ec4a85','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1420,'1748c59a-0473-4985-86ae-ff0897526e2c','b51091f7-c31a-4f40-83e2-e9e49a9c5e15','2026-06-10 07:47:23',NULL,'CREATE','IN_PROGRESS','ManilaCommon','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-25-ljommtpr6eis-ManilaCommon-nb2t3vi2ppni','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-common.yaml',NULL,NULL),(1421,'536e3c82-2b6e-49c5-9b8a-514d869f47bc','4a29ae55-5f57-4fe7-9a71-fb0e3dc76eaf','2026-06-10 07:47:23',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-25-ljommtpr6eis-ManilaCommon-nb2t3vi2ppni','4a29ae55-5f57-4fe7-9a71-fb0e3dc76eaf','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1422,'b314e75c-f43d-453d-8c9c-f20ce8308a64','b51091f7-c31a-4f40-83e2-e9e49a9c5e15','2026-06-10 07:47:23',NULL,'CREATE','COMPLETE','MySQLClient','fa2ef86b-7e53-466d-9190-72276b66d291','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1423,'9e2ec8f2-eedc-44d8-987c-ae9fa4fab168','4a29ae55-5f57-4fe7-9a71-fb0e3dc76eaf','2026-06-10 07:47:23',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-25-ljommtpr6eis-ManilaCommon-nb2t3vi2ppni-ContainersCommon-v4m22cnbrzfy','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1424,'ea237112-ca92-456a-a582-496814cc431b','4ed16063-374a-4a59-9eb5-56b4c8ea2fcf','2026-06-10 07:47:23',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-25-ljommtpr6eis-ManilaCommon-nb2t3vi2ppni-ContainersCommon-v4m22cnbrzfy','4ed16063-374a-4a59-9eb5-56b4c8ea2fcf','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1425,'cc54ae0e-3249-4dcb-9cd4-9f1da3c42a0d','4ed16063-374a-4a59-9eb5-56b4c8ea2fcf','2026-06-10 07:47:23',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-25-ljommtpr6eis-ManilaCommon-nb2t3vi2ppni-ContainersCommon-v4m22cnbrzfy','4ed16063-374a-4a59-9eb5-56b4c8ea2fcf','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1426,'aca7abc0-fb39-489c-b47b-8ae9137b0d32','4239961d-d12f-418f-a7f2-95ad737b4e0b','2026-06-10 07:47:24',NULL,'CREATE','COMPLETE','NeutronBase','4f8aaf46-19f2-4a7a-bac5-bca6ee8c3007','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-base.yaml',NULL,889),(1427,'c37991c3-941c-48c2-9a7d-9e0232b78a25','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:47:24',NULL,'CREATE','COMPLETE','24','86f17c08-d220-42ef-9072-ee1339559c0a','state changed','OS::TripleO::Services::ManilaScheduler',NULL,868),(1428,'fc1aca5e-b08e-4037-ba16-58b502043f57','4239961d-d12f-418f-a7f2-95ad737b4e0b','2026-06-10 07:47:24',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-31-ul3y4x5e2xex-NeutronBase-xagn73wwkco6-NeutronMl2Base-sct3irkc2ws6','4239961d-d12f-418f-a7f2-95ad737b4e0b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1429,'c75f54d2-1414-4a33-b935-2266ab418af5','b615122b-be9a-4cf3-ac8b-7af70976fda0','2026-06-10 07:47:24',NULL,'CREATE','COMPLETE','NeutronLogging','2a416a6f-eaec-4939-beb9-369733ec4a85','state changed','OS::TripleO::Services::Logging::NeutronApi',NULL,891),(1430,'dcf0e666-767c-46c9-ba1e-309397fa2e10','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:47:24',NULL,'CREATE','IN_PROGRESS','28','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-28-t42x64kqxu3d','state changed','OS::TripleO::Services::MySQL',NULL,898),(1431,'804dfccc-1c06-494e-b44a-fb51ceca5866','b615122b-be9a-4cf3-ac8b-7af70976fda0','2026-06-10 07:47:24',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-30-o2os7b4qg2w2','b615122b-be9a-4cf3-ac8b-7af70976fda0','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1432,'b0f869c1-60c7-4d97-a1e4-ed83dbd9624b','4a66f648-f9fe-4685-8eed-126a7d158b84','2026-06-10 07:47:24',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-28-t42x64kqxu3d','4a66f648-f9fe-4685-8eed-126a7d158b84','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1433,'4e3570d4-6a0d-4bef-82bf-7142b959bba9','b51091f7-c31a-4f40-83e2-e9e49a9c5e15','2026-06-10 07:47:24',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-25-ljommtpr6eis-ContainersCommon-uuvcxofl7i2f','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1434,'df137bd1-2e66-4fb9-b303-5a891a168bd7','138656e1-d85d-4652-884d-03a2a1c01f50','2026-06-10 07:47:24',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-25-ljommtpr6eis-ContainersCommon-uuvcxofl7i2f','138656e1-d85d-4652-884d-03a2a1c01f50','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1435,'2bf09840-0304-40b5-bcce-6d46f7fced26','4a66f648-f9fe-4685-8eed-126a7d158b84','2026-06-10 07:47:24',NULL,'CREATE','IN_PROGRESS','MysqlBase','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-28-t42x64kqxu3d-MysqlBase-z52zhhtwlpe5','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-base.yaml',NULL,899),(1436,'84467cb6-da67-4871-9146-018627476c03','138656e1-d85d-4652-884d-03a2a1c01f50','2026-06-10 07:47:24',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-25-ljommtpr6eis-ContainersCommon-uuvcxofl7i2f','138656e1-d85d-4652-884d-03a2a1c01f50','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1437,'94b8fc1c-d44c-4035-8026-82eb03592f0e','4ddfd8d4-df1b-4b7c-9973-0a6a84a5ed0e','2026-06-10 07:47:24',NULL,'CREATE','COMPLETE','NeutronMl2Base','4239961d-d12f-418f-a7f2-95ad737b4e0b','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2.yaml',NULL,888),(1438,'b72b36e4-a9e6-481f-8f8a-7950f79b2bdb','58fb7ce7-9a93-4711-b36c-0f495c179e35','2026-06-10 07:47:24',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-28-t42x64kqxu3d-MysqlBase-z52zhhtwlpe5','58fb7ce7-9a93-4711-b36c-0f495c179e35','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1439,'babe2506-34ff-4171-9cf8-47f4f9630d7b','4ddfd8d4-df1b-4b7c-9973-0a6a84a5ed0e','2026-06-10 07:47:24',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-31-ul3y4x5e2xex-NeutronBase-xagn73wwkco6','4ddfd8d4-df1b-4b7c-9973-0a6a84a5ed0e','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1440,'d91f66b9-1934-47b4-afeb-08f74e4e3883','58fb7ce7-9a93-4711-b36c-0f495c179e35','2026-06-10 07:47:24',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-28-t42x64kqxu3d-MysqlBase-z52zhhtwlpe5','58fb7ce7-9a93-4711-b36c-0f495c179e35','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1441,'68af0fda-4765-4410-9dfe-6e874798339d','4a29ae55-5f57-4fe7-9a71-fb0e3dc76eaf','2026-06-10 07:47:24',NULL,'CREATE','COMPLETE','ContainersCommon','4ed16063-374a-4a59-9eb5-56b4c8ea2fcf','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1442,'c690c5c6-df5a-4d5c-b1c9-fcc8d8796e85','4a29ae55-5f57-4fe7-9a71-fb0e3dc76eaf','2026-06-10 07:47:24',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-25-ljommtpr6eis-ManilaCommon-nb2t3vi2ppni','4a29ae55-5f57-4fe7-9a71-fb0e3dc76eaf','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1443,'15466d2f-445f-4c91-9125-87067e765549','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:47:25',NULL,'CREATE','COMPLETE','30','b615122b-be9a-4cf3-ac8b-7af70976fda0','state changed','OS::TripleO::Services::NeutronApi',NULL,852),(1444,'7de0038e-4a9e-4a0b-89ad-a985f551bd98','b51091f7-c31a-4f40-83e2-e9e49a9c5e15','2026-06-10 07:47:25',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-25-ljommtpr6eis-RoleParametersValue-z2jeyfcu7elv','state changed','OS::Heat::Value',NULL,908),(1445,'32040eff-c725-412e-b66d-1b41d1d14ca0','b51091f7-c31a-4f40-83e2-e9e49a9c5e15','2026-06-10 07:47:25',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-25-ljommtpr6eis-RoleParametersValue-z2jeyfcu7elv','state changed','OS::Heat::Value',NULL,908),(1446,'cc769889-5317-4b4e-b5d1-18a26e15e933','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:47:25',NULL,'CREATE','IN_PROGRESS','34','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-34-p5tk45ipniwj','state changed','OS::TripleO::Services::NovaMetadata',NULL,909),(1447,'e95c88c7-cb31-4de5-8476-95a7a65ec39b','ca02b483-23f0-4e11-acdc-6e9af2a656bd','2026-06-10 07:47:25',NULL,'CREATE','COMPLETE','NeutronBase','4ddfd8d4-df1b-4b7c-9973-0a6a84a5ed0e','state changed','OS::TripleO::Services::NeutronMl2PluginBase',NULL,887),(1448,'966eb054-127c-4499-9a9b-57c0cd2b4093','b51091f7-c31a-4f40-83e2-e9e49a9c5e15','2026-06-10 07:47:25',NULL,'CREATE','COMPLETE','ManilaCommon','4a29ae55-5f57-4fe7-9a71-fb0e3dc76eaf','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-common.yaml',NULL,NULL),(1449,'6a809116-cada-4c3a-9a5b-c0a90f9a865b','ca02b483-23f0-4e11-acdc-6e9af2a656bd','2026-06-10 07:47:25',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-31-ul3y4x5e2xex','ca02b483-23f0-4e11-acdc-6e9af2a656bd','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1450,'0e078047-bec3-4171-a979-7f7dff7dd83f','b51091f7-c31a-4f40-83e2-e9e49a9c5e15','2026-06-10 07:47:25',NULL,'CREATE','COMPLETE','ContainersCommon','138656e1-d85d-4652-884d-03a2a1c01f50','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1451,'6c58d31d-89c7-459f-b470-358074451133','4a66f648-f9fe-4685-8eed-126a7d158b84','2026-06-10 07:47:25',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-28-t42x64kqxu3d-RoleParametersValue-qtpl5lim6ylc','state changed','OS::Heat::Value',NULL,910),(1452,'05c0cf9f-6a90-4359-b20e-1b3a8296c967','215acfc9-9e95-4690-873e-292bc8e38b34','2026-06-10 07:47:25',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-34-p5tk45ipniwj','215acfc9-9e95-4690-873e-292bc8e38b34','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1453,'cc35f8cc-c05c-4007-aa8b-a952d8304f4c','4a66f648-f9fe-4685-8eed-126a7d158b84','2026-06-10 07:47:25',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-28-t42x64kqxu3d-RoleParametersValue-qtpl5lim6ylc','state changed','OS::Heat::Value',NULL,910),(1454,'78f80a04-1fec-4f68-ab4e-a2d888726329','4a66f648-f9fe-4685-8eed-126a7d158b84','2026-06-10 07:47:25',NULL,'CREATE','COMPLETE','MysqlBase','58fb7ce7-9a93-4711-b36c-0f495c179e35','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-base.yaml',NULL,899),(1455,'7c02fcd5-d534-4fd0-81c4-a8a0749f701f','215acfc9-9e95-4690-873e-292bc8e38b34','2026-06-10 07:47:26',NULL,'CREATE','IN_PROGRESS','NovaBase','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-34-p5tk45ipniwj-NovaBase-4cn7k6xy5cel','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml',NULL,911),(1456,'5c8042bf-7eec-4813-b9bb-0a2c8eb141fe','c59ec585-c6ff-4361-9aff-0becec6b5422','2026-06-10 07:47:26',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-34-p5tk45ipniwj-NovaBase-4cn7k6xy5cel','c59ec585-c6ff-4361-9aff-0becec6b5422','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1457,'d67e2911-5880-4f2a-bbd9-f81823eda44f','c59ec585-c6ff-4361-9aff-0becec6b5422','2026-06-10 07:47:26',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-34-p5tk45ipniwj-NovaBase-4cn7k6xy5cel-RoleParametersValue-mwoxmsk37vhg','state changed','OS::Heat::Value',NULL,912),(1458,'89b68a1e-3e8c-4b65-ac52-9b678cdece4a','c59ec585-c6ff-4361-9aff-0becec6b5422','2026-06-10 07:47:26',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-34-p5tk45ipniwj-NovaBase-4cn7k6xy5cel-RoleParametersValue-mwoxmsk37vhg','state changed','OS::Heat::Value',NULL,912),(1459,'815bc5bb-03c9-491f-a989-f34d708f3c5f','c59ec585-c6ff-4361-9aff-0becec6b5422','2026-06-10 07:47:26',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-34-p5tk45ipniwj-NovaBase-4cn7k6xy5cel','c59ec585-c6ff-4361-9aff-0becec6b5422','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1460,'f8321d11-add4-449e-8814-300b48a73cc8','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:47:26',NULL,'CREATE','COMPLETE','31','ca02b483-23f0-4e11-acdc-6e9af2a656bd','state changed','OS::TripleO::Services::NeutronCorePlugin',NULL,875),(1461,'22ba3497-09fa-44c4-911b-545e21169ea9','b51091f7-c31a-4f40-83e2-e9e49a9c5e15','2026-06-10 07:47:26',NULL,'CREATE','IN_PROGRESS','ManilaShareContainerBase','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-25-ljommtpr6eis-ManilaShareContainerBase-pu7rqrzutypb','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-container-puppet.yaml',NULL,914),(1462,'9e8aff19-407d-4e01-b27e-1323a3a76937','a3fb1c80-f5c6-4b86-9e96-f56d2396cd43','2026-06-10 07:47:26',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-25-ljommtpr6eis-ManilaShareContainerBase-pu7rqrzutypb','a3fb1c80-f5c6-4b86-9e96-f56d2396cd43','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1463,'cb602bb5-e10b-497b-a5b0-33e2108c9257','4a66f648-f9fe-4685-8eed-126a7d158b84','2026-06-10 07:47:26',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-28-t42x64kqxu3d-ContainersCommon-znu7fwh3ryb7','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1464,'74d48914-d1bd-418b-9ffe-cd1f7a9ab41b','d0149500-5003-4939-9c14-42a6cd2ae590','2026-06-10 07:47:26',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-28-t42x64kqxu3d-ContainersCommon-znu7fwh3ryb7','d0149500-5003-4939-9c14-42a6cd2ae590','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1465,'5db79591-5249-4b49-b238-2956e1d15f54','d0149500-5003-4939-9c14-42a6cd2ae590','2026-06-10 07:47:26',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-28-t42x64kqxu3d-ContainersCommon-znu7fwh3ryb7','d0149500-5003-4939-9c14-42a6cd2ae590','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1466,'54353a53-c9e7-4c1c-bcff-3da1b772aa41','a3fb1c80-f5c6-4b86-9e96-f56d2396cd43','2026-06-10 07:47:26',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-25-ljommtpr6eis-ManilaShareContainerBase-pu7rqrzutypb-RoleParametersValue-5bghlecd7jhn','state changed','OS::Heat::Value',NULL,919),(1467,'a52ab957-3875-48ac-aae4-a891d4606da5','a3fb1c80-f5c6-4b86-9e96-f56d2396cd43','2026-06-10 07:47:26',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-25-ljommtpr6eis-ManilaShareContainerBase-pu7rqrzutypb-RoleParametersValue-5bghlecd7jhn','state changed','OS::Heat::Value',NULL,919),(1468,'c36be54a-e5da-4077-ad3b-0dd4c4e72c4e','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:47:27',NULL,'CREATE','IN_PROGRESS','35','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-35-e66bicrr3i26','state changed','OS::TripleO::Services::NovaScheduler',NULL,920),(1469,'dfc66d13-8f83-4f07-931d-5432074b49f2','8a944490-696b-47e8-8faa-f824482b1288','2026-06-10 07:47:27',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-35-e66bicrr3i26','8a944490-696b-47e8-8faa-f824482b1288','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1470,'f00775e0-3d15-46eb-aa6a-6e8d60595d62','215acfc9-9e95-4690-873e-292bc8e38b34','2026-06-10 07:47:27',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-34-p5tk45ipniwj-ContainersCommon-ta2zyz57jy3d','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1471,'47cc9eb9-72c5-4b50-97e2-d170f557aede','0a18fe07-b93f-4b06-be33-dab6f94fb66d','2026-06-10 07:47:27',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-34-p5tk45ipniwj-ContainersCommon-ta2zyz57jy3d','0a18fe07-b93f-4b06-be33-dab6f94fb66d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1472,'268f37fa-b89f-40fe-ad00-783b55fe003d','215acfc9-9e95-4690-873e-292bc8e38b34','2026-06-10 07:47:27',NULL,'CREATE','COMPLETE','NovaBase','c59ec585-c6ff-4361-9aff-0becec6b5422','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml',NULL,911),(1473,'1ac2ebad-4010-4f65-b17e-f8081999af5f','0a18fe07-b93f-4b06-be33-dab6f94fb66d','2026-06-10 07:47:27',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-34-p5tk45ipniwj-ContainersCommon-ta2zyz57jy3d','0a18fe07-b93f-4b06-be33-dab6f94fb66d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1474,'e92ee5f1-c9a7-43e8-9cc8-98caf48c3b6c','8a944490-696b-47e8-8faa-f824482b1288','2026-06-10 07:47:27',NULL,'CREATE','IN_PROGRESS','NovaBase','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-35-e66bicrr3i26-NovaBase-jbew4ae4hkiw','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml',NULL,921),(1475,'c68dc836-0ff8-4fff-bc10-cb86ae09218d','8c78cf9b-ace5-4c72-919e-6e99f63eff42','2026-06-10 07:47:27',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-35-e66bicrr3i26-NovaBase-jbew4ae4hkiw','8c78cf9b-ace5-4c72-919e-6e99f63eff42','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1476,'924c96a0-1ae3-4029-9ba4-f2ca35155de5','8c78cf9b-ace5-4c72-919e-6e99f63eff42','2026-06-10 07:47:27',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-35-e66bicrr3i26-NovaBase-jbew4ae4hkiw-RoleParametersValue-zs5id55eavhx','state changed','OS::Heat::Value',NULL,922),(1477,'b65344ab-abf4-47ff-9f0f-d7e75699ad18','8c78cf9b-ace5-4c72-919e-6e99f63eff42','2026-06-10 07:47:27',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-35-e66bicrr3i26-NovaBase-jbew4ae4hkiw-RoleParametersValue-zs5id55eavhx','state changed','OS::Heat::Value',NULL,922),(1478,'932c54a0-c7f7-430a-8495-8927e5ed6a4f','8c78cf9b-ace5-4c72-919e-6e99f63eff42','2026-06-10 07:47:27',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-35-e66bicrr3i26-NovaBase-jbew4ae4hkiw','8c78cf9b-ace5-4c72-919e-6e99f63eff42','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1479,'2bdccd89-8846-4112-ac91-19072732b4ba','4a66f648-f9fe-4685-8eed-126a7d158b84','2026-06-10 07:47:27',NULL,'CREATE','COMPLETE','ContainersCommon','d0149500-5003-4939-9c14-42a6cd2ae590','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1480,'09b36a8e-23aa-47de-a242-885d188bd34a','4a66f648-f9fe-4685-8eed-126a7d158b84','2026-06-10 07:47:27',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-28-t42x64kqxu3d','4a66f648-f9fe-4685-8eed-126a7d158b84','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1481,'a80daf83-3a17-49b4-9f8d-8eb1ef21853e','a3fb1c80-f5c6-4b86-9e96-f56d2396cd43','2026-06-10 07:47:27',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-25-ljommtpr6eis-ManilaShareContainerBase-pu7rqrzutypb-ContainersCommon-yslr4z44vn5h','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1482,'bbe1fbe3-2e95-4c0e-ac46-214cfcee8e31','4ad50840-6fb2-4111-a2e8-3b048a7a7fe6','2026-06-10 07:47:28',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-25-ljommtpr6eis-ManilaShareContainerBase-pu7rqrzutypb-ContainersCommon-yslr4z44vn5h','4ad50840-6fb2-4111-a2e8-3b048a7a7fe6','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1483,'158b3ac8-ebb9-4e86-ade8-808b69c8c24b','4ad50840-6fb2-4111-a2e8-3b048a7a7fe6','2026-06-10 07:47:28',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-25-ljommtpr6eis-ManilaShareContainerBase-pu7rqrzutypb-ContainersCommon-yslr4z44vn5h','4ad50840-6fb2-4111-a2e8-3b048a7a7fe6','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1484,'c5c212cb-c703-42be-bb99-1f13547f0a27','215acfc9-9e95-4690-873e-292bc8e38b34','2026-06-10 07:47:28',NULL,'CREATE','IN_PROGRESS','NovaApiDBClient','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-34-p5tk45ipniwj-NovaApiDBClient-f5dc2ylcygjx','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-apidb-client-puppet.yaml',NULL,923),(1485,'0a1b2a00-fc91-49d5-a594-fc6b8afd3e7f','a72e507f-1508-4738-8041-eb67b56756a9','2026-06-10 07:47:28',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-34-p5tk45ipniwj-NovaApiDBClient-f5dc2ylcygjx','a72e507f-1508-4738-8041-eb67b56756a9','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1486,'cfa64f59-3cbb-44b2-8bc1-b7ff272801d1','215acfc9-9e95-4690-873e-292bc8e38b34','2026-06-10 07:47:28',NULL,'CREATE','COMPLETE','ContainersCommon','0a18fe07-b93f-4b06-be33-dab6f94fb66d','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1487,'361bd899-2a2b-49cf-a5c9-b736e958e80a','a72e507f-1508-4738-8041-eb67b56756a9','2026-06-10 07:47:28',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-34-p5tk45ipniwj-NovaApiDBClient-f5dc2ylcygjx','a72e507f-1508-4738-8041-eb67b56756a9','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1488,'80c3c623-14fd-4d11-8868-236c4dfaca74','8a944490-696b-47e8-8faa-f824482b1288','2026-06-10 07:47:28',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-35-e66bicrr3i26-RoleParametersValue-eumraszataxo','state changed','OS::Heat::Value',NULL,924),(1489,'a6310600-e7d2-4dd8-8247-a479390e4d45','8a944490-696b-47e8-8faa-f824482b1288','2026-06-10 07:47:28',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-35-e66bicrr3i26-RoleParametersValue-eumraszataxo','state changed','OS::Heat::Value',NULL,924),(1490,'155654b1-3f3d-4c24-92e0-ae2082908cc9','8a944490-696b-47e8-8faa-f824482b1288','2026-06-10 07:47:28',NULL,'CREATE','COMPLETE','NovaBase','8c78cf9b-ace5-4c72-919e-6e99f63eff42','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml',NULL,921),(1491,'f3c9ccf5-add0-4ba8-9d15-73293528c042','8a944490-696b-47e8-8faa-f824482b1288','2026-06-10 07:47:28',NULL,'CREATE','IN_PROGRESS','NovaLogging','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-35-e66bicrr3i26-NovaLogging-eiqupjjtt4go','state changed','OS::TripleO::Services::Logging::NovaCommon',NULL,926),(1492,'220c7a41-c78b-4c07-9611-2af1281750a0','3dfeaefc-14f8-4a1d-8e13-45a0f773c014','2026-06-10 07:47:28',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-35-e66bicrr3i26-NovaLogging-eiqupjjtt4go','3dfeaefc-14f8-4a1d-8e13-45a0f773c014','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1493,'7e37e8e2-8547-4def-802d-3739dfc6c580','3dfeaefc-14f8-4a1d-8e13-45a0f773c014','2026-06-10 07:47:28',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-35-e66bicrr3i26-NovaLogging-eiqupjjtt4go-RoleParametersValue-cncvxhqwoq5j','state changed','OS::Heat::Value',NULL,927),(1494,'95947051-4163-4dc7-ad51-2585dceebd4d','3dfeaefc-14f8-4a1d-8e13-45a0f773c014','2026-06-10 07:47:28',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-35-e66bicrr3i26-NovaLogging-eiqupjjtt4go-RoleParametersValue-cncvxhqwoq5j','state changed','OS::Heat::Value',NULL,927),(1495,'83397e5b-a955-4cf4-8c7f-15f651c50752','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:47:28',NULL,'CREATE','COMPLETE','28','4a66f648-f9fe-4685-8eed-126a7d158b84','state changed','OS::TripleO::Services::MySQL',NULL,898),(1496,'505d651f-896f-4053-8d5a-6b95287e3914','a3fb1c80-f5c6-4b86-9e96-f56d2396cd43','2026-06-10 07:47:28',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-25-ljommtpr6eis-ManilaShareContainerBase-pu7rqrzutypb-MySQLClient-ll5bevhcgekc','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1497,'c1939bb8-f9ee-4dbd-b563-612150f7ae48','1145016c-66b0-45c4-b231-31f335b2e004','2026-06-10 07:47:29',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-25-ljommtpr6eis-ManilaShareContainerBase-pu7rqrzutypb-MySQLClient-ll5bevhcgekc','1145016c-66b0-45c4-b231-31f335b2e004','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1498,'8a6f5e7c-07ea-48dc-809d-e9b85d1c2db0','1145016c-66b0-45c4-b231-31f335b2e004','2026-06-10 07:47:29',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-25-ljommtpr6eis-ManilaShareContainerBase-pu7rqrzutypb-MySQLClient-ll5bevhcgekc','1145016c-66b0-45c4-b231-31f335b2e004','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1499,'a60de4cd-452c-479f-8cf5-b4786fcf0ae6','a3fb1c80-f5c6-4b86-9e96-f56d2396cd43','2026-06-10 07:47:29',NULL,'CREATE','COMPLETE','ContainersCommon','4ad50840-6fb2-4111-a2e8-3b048a7a7fe6','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1500,'64c824d1-0fde-49c4-b209-eb9836a1f1bb','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:47:29',NULL,'CREATE','IN_PROGRESS','32','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-32-c2r76ecujhxx','state changed','OS::TripleO::Services::NovaApi',NULL,932),(1501,'a7501f07-22df-49b9-bef5-4635f9153094','215acfc9-9e95-4690-873e-292bc8e38b34','2026-06-10 07:47:29',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-34-p5tk45ipniwj-RoleParametersValue-erk4grnrn5kj','state changed','OS::Heat::Value',NULL,933),(1502,'41f4061a-ee1b-4468-8d35-e6436a45c7b7','215acfc9-9e95-4690-873e-292bc8e38b34','2026-06-10 07:47:29',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-34-p5tk45ipniwj-RoleParametersValue-erk4grnrn5kj','state changed','OS::Heat::Value',NULL,933),(1503,'1b3d8461-c4b9-4730-9476-b357b787a54c','215acfc9-9e95-4690-873e-292bc8e38b34','2026-06-10 07:47:29',NULL,'CREATE','COMPLETE','NovaApiDBClient','a72e507f-1508-4738-8041-eb67b56756a9','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-apidb-client-puppet.yaml',NULL,923),(1504,'193888ae-f673-4b5c-81c0-1dbc3d6b512b','9992790d-de4e-4292-bf9e-5d01cb86d54e','2026-06-10 07:47:29',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-32-c2r76ecujhxx','9992790d-de4e-4292-bf9e-5d01cb86d54e','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1505,'3c922081-a766-4ccc-962d-d68dcd0e93a1','8a944490-696b-47e8-8faa-f824482b1288','2026-06-10 07:47:29',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-35-e66bicrr3i26-ContainersCommon-v5h57uaymjny','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1506,'cd6c6a90-0e3e-422e-9690-4a8963e34a18','bccdc8c4-d94b-46a7-b9f0-f2b4826e532d','2026-06-10 07:47:29',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-35-e66bicrr3i26-ContainersCommon-v5h57uaymjny','bccdc8c4-d94b-46a7-b9f0-f2b4826e532d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1507,'0eed76ab-1fff-4e89-a1e6-f33d4da6ec25','bccdc8c4-d94b-46a7-b9f0-f2b4826e532d','2026-06-10 07:47:29',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-35-e66bicrr3i26-ContainersCommon-v5h57uaymjny','bccdc8c4-d94b-46a7-b9f0-f2b4826e532d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1508,'c52144e5-3491-40a8-8b5c-352bc539e181','9992790d-de4e-4292-bf9e-5d01cb86d54e','2026-06-10 07:47:29',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-32-c2r76ecujhxx-MySQLClient-rvk5gyp4zdwe','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1509,'8d7b99d6-3863-46f5-a1d7-c1a7e943329a','1ce18460-4ffc-47e5-aa40-5de682ae586a','2026-06-10 07:47:29',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-32-c2r76ecujhxx-MySQLClient-rvk5gyp4zdwe','1ce18460-4ffc-47e5-aa40-5de682ae586a','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1510,'9e5f68fa-769f-4142-9814-b9bead3e4213','1ce18460-4ffc-47e5-aa40-5de682ae586a','2026-06-10 07:47:29',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-32-c2r76ecujhxx-MySQLClient-rvk5gyp4zdwe','1ce18460-4ffc-47e5-aa40-5de682ae586a','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1511,'ccef1f70-cd35-4eaf-8e20-b2b84c0b7843','3dfeaefc-14f8-4a1d-8e13-45a0f773c014','2026-06-10 07:47:29',NULL,'CREATE','IN_PROGRESS','InitLogContainerName','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-35-e66bicrr3i26-NovaLogging-eiqupjjtt4go-InitLogContainerName-42zcanddd3nz','state changed','OS::Heat::Value',NULL,934),(1512,'e35801bb-e806-4194-8df7-ed2ef4677d22','3dfeaefc-14f8-4a1d-8e13-45a0f773c014','2026-06-10 07:47:29',NULL,'CREATE','COMPLETE','InitLogContainerName','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-35-e66bicrr3i26-NovaLogging-eiqupjjtt4go-InitLogContainerName-42zcanddd3nz','state changed','OS::Heat::Value',NULL,934),(1513,'308b16c4-e0bb-48ba-af2d-f6ca4c2b29dd','3dfeaefc-14f8-4a1d-8e13-45a0f773c014','2026-06-10 07:47:29',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-35-e66bicrr3i26-NovaLogging-eiqupjjtt4go','3dfeaefc-14f8-4a1d-8e13-45a0f773c014','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1514,'642dec8d-d039-4a1c-a257-cea9169ca294','a3fb1c80-f5c6-4b86-9e96-f56d2396cd43','2026-06-10 07:47:29',NULL,'CREATE','IN_PROGRESS','ManilaShareCommon','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-25-ljommtpr6eis-ManilaShareContainerBase-pu7rqrzutypb-ManilaShareCommon-kanzifz3q6n4','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-common.yaml',NULL,NULL),(1515,'c68b6ece-623c-48b9-a050-18e076b59b92','a3f7e7c5-4c7e-41e3-abb2-06bde3460a58','2026-06-10 07:47:30',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-25-ljommtpr6eis-ManilaShareContainerBase-pu7rqrzutypb-ManilaShareCommon-kanzifz3q6n4','a3f7e7c5-4c7e-41e3-abb2-06bde3460a58','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1516,'af0e2d89-079b-4d12-b609-72605c79737b','a3fb1c80-f5c6-4b86-9e96-f56d2396cd43','2026-06-10 07:47:30',NULL,'CREATE','COMPLETE','MySQLClient','1145016c-66b0-45c4-b231-31f335b2e004','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1517,'667ac930-d8ed-4894-83db-044a3f4c6623','a3f7e7c5-4c7e-41e3-abb2-06bde3460a58','2026-06-10 07:47:30',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-25-ljommtpr6eis-ManilaShareContainerBase-pu7rqrzutypb-ManilaShareCommon-kanzifz3q6n4-ContainersCommon-kcw6cgic6vkw','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1518,'bce35ee5-a2ec-4e62-b954-dfc5802efda2','104ad83b-71df-447b-a249-a6dcf8c4fe5c','2026-06-10 07:47:30',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-25-ljommtpr6eis-ManilaShareContainerBase-pu7rqrzutypb-ManilaShareCommon-kanzifz3q6n4-ContainersCommon-kcw6cgic6vkw','104ad83b-71df-447b-a249-a6dcf8c4fe5c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1519,'b5fadea1-23ca-49bf-acb0-bcb384271bb3','104ad83b-71df-447b-a249-a6dcf8c4fe5c','2026-06-10 07:47:30',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-25-ljommtpr6eis-ManilaShareContainerBase-pu7rqrzutypb-ManilaShareCommon-kanzifz3q6n4-ContainersCommon-kcw6cgic6vkw','104ad83b-71df-447b-a249-a6dcf8c4fe5c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1520,'a68063a3-cf27-4fc6-9336-92228e4a6eca','215acfc9-9e95-4690-873e-292bc8e38b34','2026-06-10 07:47:30',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-34-p5tk45ipniwj-MySQLClient-xqffj2ujeun2','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1521,'59f54448-1c82-4727-8a29-3ca6328d17f3','c32248a8-4169-444a-8697-54a3da6d26db','2026-06-10 07:47:30',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-34-p5tk45ipniwj-MySQLClient-xqffj2ujeun2','c32248a8-4169-444a-8697-54a3da6d26db','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1522,'b1a93791-0583-415f-b105-a0510b5775b3','c32248a8-4169-444a-8697-54a3da6d26db','2026-06-10 07:47:30',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-34-p5tk45ipniwj-MySQLClient-xqffj2ujeun2','c32248a8-4169-444a-8697-54a3da6d26db','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1523,'878ce971-872c-4579-8820-33639c427edd','8a944490-696b-47e8-8faa-f824482b1288','2026-06-10 07:47:30',NULL,'CREATE','IN_PROGRESS','NovaApiDBClient','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-35-e66bicrr3i26-NovaApiDBClient-baxxnev676t3','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-apidb-client-puppet.yaml',NULL,935),(1524,'b94455cf-d2c1-494b-b422-4c730df39f81','68a79eb1-c268-40f2-b515-a02410d57c3a','2026-06-10 07:47:30',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-35-e66bicrr3i26-NovaApiDBClient-baxxnev676t3','68a79eb1-c268-40f2-b515-a02410d57c3a','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1525,'505d58b8-1a04-4830-84a4-137e4d486d7f','8a944490-696b-47e8-8faa-f824482b1288','2026-06-10 07:47:30',NULL,'CREATE','COMPLETE','ContainersCommon','bccdc8c4-d94b-46a7-b9f0-f2b4826e532d','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1526,'b1adc93c-ce07-4dbc-beec-901be8b7520c','68a79eb1-c268-40f2-b515-a02410d57c3a','2026-06-10 07:47:30',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-35-e66bicrr3i26-NovaApiDBClient-baxxnev676t3','68a79eb1-c268-40f2-b515-a02410d57c3a','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1527,'8aa15ad3-410b-483f-b83d-43518bc31896','9992790d-de4e-4292-bf9e-5d01cb86d54e','2026-06-10 07:47:30',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-32-c2r76ecujhxx-RoleParametersValue-ay5l2x3boe57','state changed','OS::Heat::Value',NULL,936),(1528,'9352e40e-3b97-4e29-835a-caab427d589c','8a944490-696b-47e8-8faa-f824482b1288','2026-06-10 07:47:30',NULL,'CREATE','COMPLETE','NovaLogging','3dfeaefc-14f8-4a1d-8e13-45a0f773c014','state changed','OS::TripleO::Services::Logging::NovaCommon',NULL,926),(1529,'6b02ea89-bf9b-48d7-94b5-26444d82244d','9992790d-de4e-4292-bf9e-5d01cb86d54e','2026-06-10 07:47:30',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-32-c2r76ecujhxx-RoleParametersValue-ay5l2x3boe57','state changed','OS::Heat::Value',NULL,936),(1530,'42d34b5b-f015-4ef8-ba18-7bcc80866243','9992790d-de4e-4292-bf9e-5d01cb86d54e','2026-06-10 07:47:30',NULL,'CREATE','COMPLETE','MySQLClient','1ce18460-4ffc-47e5-aa40-5de682ae586a','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1531,'f224969f-c736-4fde-97af-1ead262726fc','a3fb1c80-f5c6-4b86-9e96-f56d2396cd43','2026-06-10 07:47:30',NULL,'CREATE','IN_PROGRESS','ManilaBase','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-25-ljommtpr6eis-ManilaShareContainerBase-pu7rqrzutypb-ManilaBase-wys27yb7bynf','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-base.yaml',NULL,937),(1532,'b4a702f2-74a1-4283-a75d-085db6a01eca','e00fa085-58ad-4430-8277-3f402b87c2a2','2026-06-10 07:47:31',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-25-ljommtpr6eis-ManilaShareContainerBase-pu7rqrzutypb-ManilaBase-wys27yb7bynf','e00fa085-58ad-4430-8277-3f402b87c2a2','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1533,'b1c4c1a4-5acb-430c-b5b3-a7c28ccd5996','e00fa085-58ad-4430-8277-3f402b87c2a2','2026-06-10 07:47:31',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-25-ljommtpr6eis-ManilaShareContainerBase-pu7rqrzutypb-ManilaBase-wys27yb7bynf','e00fa085-58ad-4430-8277-3f402b87c2a2','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1534,'49aaebbc-1b99-480e-a31d-d59bde0e91bd','a3f7e7c5-4c7e-41e3-abb2-06bde3460a58','2026-06-10 07:47:31',NULL,'CREATE','COMPLETE','ContainersCommon','104ad83b-71df-447b-a249-a6dcf8c4fe5c','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1535,'2677c6e6-7b2e-44af-ad1b-eb7b3feb87e9','a3f7e7c5-4c7e-41e3-abb2-06bde3460a58','2026-06-10 07:47:31',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-25-ljommtpr6eis-ManilaShareContainerBase-pu7rqrzutypb-ManilaShareCommon-kanzifz3q6n4','a3f7e7c5-4c7e-41e3-abb2-06bde3460a58','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1536,'bfb137d0-1eb0-4867-a9bc-f11964778bd5','215acfc9-9e95-4690-873e-292bc8e38b34','2026-06-10 07:47:31',NULL,'CREATE','IN_PROGRESS','NovaDBClient','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-34-p5tk45ipniwj-NovaDBClient-qmoy55hm5rfu','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-db-client-puppet.yaml',NULL,938),(1537,'66648f3c-813b-4e9d-af69-a1fe0667363d','35e70c8e-6958-438c-9015-b0bdf46b0970','2026-06-10 07:47:31',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-34-p5tk45ipniwj-NovaDBClient-qmoy55hm5rfu','35e70c8e-6958-438c-9015-b0bdf46b0970','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1538,'ff80a07c-77f3-4438-b3ce-6b08e6bdf874','215acfc9-9e95-4690-873e-292bc8e38b34','2026-06-10 07:47:31',NULL,'CREATE','COMPLETE','MySQLClient','c32248a8-4169-444a-8697-54a3da6d26db','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1539,'05ff76b1-8ce1-4a77-85de-be7693383d63','35e70c8e-6958-438c-9015-b0bdf46b0970','2026-06-10 07:47:31',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-34-p5tk45ipniwj-NovaDBClient-qmoy55hm5rfu','35e70c8e-6958-438c-9015-b0bdf46b0970','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1540,'208fced9-fbcf-4f2d-86b3-ac622eebf07d','8a944490-696b-47e8-8faa-f824482b1288','2026-06-10 07:47:31',NULL,'CREATE','IN_PROGRESS','NovaDBClient','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-35-e66bicrr3i26-NovaDBClient-q3t3lotwapez','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-db-client-puppet.yaml',NULL,939),(1541,'f107ef19-4f73-43f1-930a-c579ced03097','823314b6-d4dc-47c8-a511-1c56e2e5607a','2026-06-10 07:47:31',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-35-e66bicrr3i26-NovaDBClient-q3t3lotwapez','823314b6-d4dc-47c8-a511-1c56e2e5607a','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1542,'9faac570-63a3-4963-ad56-0769dda4753f','8a944490-696b-47e8-8faa-f824482b1288','2026-06-10 07:47:31',NULL,'CREATE','COMPLETE','NovaApiDBClient','68a79eb1-c268-40f2-b515-a02410d57c3a','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-apidb-client-puppet.yaml',NULL,935),(1543,'cbd0b92d-c5c5-4655-8c6f-7cfbee16d03a','823314b6-d4dc-47c8-a511-1c56e2e5607a','2026-06-10 07:47:31',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-35-e66bicrr3i26-NovaDBClient-q3t3lotwapez','823314b6-d4dc-47c8-a511-1c56e2e5607a','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1544,'73b10b75-5255-479f-8c89-bdd5afe97ada','9992790d-de4e-4292-bf9e-5d01cb86d54e','2026-06-10 07:47:31',NULL,'CREATE','IN_PROGRESS','NovaApiLogging','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-32-c2r76ecujhxx-NovaApiLogging-nevrxowvq4sf','state changed','OS::TripleO::Services::Logging::NovaApi',NULL,NULL),(1545,'d0e48658-8fe2-4f50-b3aa-f4b94ef9e961','a2d9e57a-95ef-414f-a01f-892a183a3f02','2026-06-10 07:47:31',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-32-c2r76ecujhxx-NovaApiLogging-nevrxowvq4sf','a2d9e57a-95ef-414f-a01f-892a183a3f02','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1546,'842ffb93-8543-4a57-8c29-67bdc1adf5e2','a2d9e57a-95ef-414f-a01f-892a183a3f02','2026-06-10 07:47:31',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-32-c2r76ecujhxx-NovaApiLogging-nevrxowvq4sf-RoleParametersValue-o2bj3imtq6lp','state changed','OS::Heat::Value',NULL,940),(1547,'0b711429-1110-4bfb-8d2b-a8811a45b2b9','a2d9e57a-95ef-414f-a01f-892a183a3f02','2026-06-10 07:47:31',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-32-c2r76ecujhxx-NovaApiLogging-nevrxowvq4sf-RoleParametersValue-o2bj3imtq6lp','state changed','OS::Heat::Value',NULL,940),(1548,'eb72e965-9eb3-4d4a-9580-64361d92c797','a2d9e57a-95ef-414f-a01f-892a183a3f02','2026-06-10 07:47:31',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-32-c2r76ecujhxx-NovaApiLogging-nevrxowvq4sf','a2d9e57a-95ef-414f-a01f-892a183a3f02','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1549,'a25ec520-7692-426c-a230-50a99d3e25c2','a3fb1c80-f5c6-4b86-9e96-f56d2396cd43','2026-06-10 07:47:32',NULL,'CREATE','COMPLETE','ManilaShareCommon','a3f7e7c5-4c7e-41e3-abb2-06bde3460a58','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-common.yaml',NULL,NULL),(1550,'9f8c3cca-d232-4b8b-81e5-46613b0c4c1e','a3fb1c80-f5c6-4b86-9e96-f56d2396cd43','2026-06-10 07:47:32',NULL,'CREATE','COMPLETE','ManilaBase','e00fa085-58ad-4430-8277-3f402b87c2a2','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-base.yaml',NULL,937),(1551,'97c300c8-1e0e-4f23-8052-51a4e39c83ba','a3fb1c80-f5c6-4b86-9e96-f56d2396cd43','2026-06-10 07:47:32',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-25-ljommtpr6eis-ManilaShareContainerBase-pu7rqrzutypb','a3fb1c80-f5c6-4b86-9e96-f56d2396cd43','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1552,'4810d1f2-136f-493b-bd07-7faa965b12d6','215acfc9-9e95-4690-873e-292bc8e38b34','2026-06-10 07:47:32',NULL,'CREATE','IN_PROGRESS','NovaMetadataLogging','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-34-p5tk45ipniwj-NovaMetadataLogging-frxvsthxljji','state changed','OS::TripleO::Services::Logging::NovaMetadata',NULL,NULL),(1553,'b8fe4ffb-a1df-46c6-8e6c-a5141c6f9784','3f580889-6427-4d54-a4d9-2c6b7945e51d','2026-06-10 07:47:32',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-34-p5tk45ipniwj-NovaMetadataLogging-frxvsthxljji','3f580889-6427-4d54-a4d9-2c6b7945e51d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1554,'5f182166-681e-456a-bfc4-9b3dd702dacd','8a944490-696b-47e8-8faa-f824482b1288','2026-06-10 07:47:32',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-35-e66bicrr3i26-MySQLClient-io4xur6ogxs3','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1555,'faca2270-9a14-459e-961d-500003a67c9d','215acfc9-9e95-4690-873e-292bc8e38b34','2026-06-10 07:47:32',NULL,'CREATE','COMPLETE','NovaDBClient','35e70c8e-6958-438c-9015-b0bdf46b0970','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-db-client-puppet.yaml',NULL,938),(1556,'a80c3e45-30b3-4e25-995d-01b73a94e497','46a507ff-f1c1-4fdd-a077-671fa9bc58cd','2026-06-10 07:47:32',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-35-e66bicrr3i26-MySQLClient-io4xur6ogxs3','46a507ff-f1c1-4fdd-a077-671fa9bc58cd','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1557,'205431cf-bc9a-4583-b8be-7d546773b5ca','46a507ff-f1c1-4fdd-a077-671fa9bc58cd','2026-06-10 07:47:32',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-35-e66bicrr3i26-MySQLClient-io4xur6ogxs3','46a507ff-f1c1-4fdd-a077-671fa9bc58cd','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1558,'91f82d78-959c-47a0-9c14-f092ee8ed76f','3f580889-6427-4d54-a4d9-2c6b7945e51d','2026-06-10 07:47:32',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-34-p5tk45ipniwj-NovaMetadataLogging-frxvsthxljji-RoleParametersValue-iza3tve6rzyb','state changed','OS::Heat::Value',NULL,941),(1559,'838a470f-9132-43e2-ba8b-d33a961b4e42','3f580889-6427-4d54-a4d9-2c6b7945e51d','2026-06-10 07:47:32',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-34-p5tk45ipniwj-NovaMetadataLogging-frxvsthxljji-RoleParametersValue-iza3tve6rzyb','state changed','OS::Heat::Value',NULL,941),(1560,'16daf15f-c9f1-4222-ab14-30ff8e4a49ea','3f580889-6427-4d54-a4d9-2c6b7945e51d','2026-06-10 07:47:32',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-34-p5tk45ipniwj-NovaMetadataLogging-frxvsthxljji','3f580889-6427-4d54-a4d9-2c6b7945e51d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1561,'4b10ffe4-ff36-48ae-8bf0-d2b5213c8df9','8a944490-696b-47e8-8faa-f824482b1288','2026-06-10 07:47:32',NULL,'CREATE','COMPLETE','NovaDBClient','823314b6-d4dc-47c8-a511-1c56e2e5607a','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-db-client-puppet.yaml',NULL,939),(1562,'6b1a72e9-b74d-4d95-aa66-5162f7ef3e4e','9992790d-de4e-4292-bf9e-5d01cb86d54e','2026-06-10 07:47:32',NULL,'CREATE','IN_PROGRESS','NovaBase','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-32-c2r76ecujhxx-NovaBase-doouyznei45c','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml',NULL,942),(1563,'37babf6b-d5d0-47b7-aa57-0b9aa0c4896c','040fb7d4-4ebd-47e8-b19e-4e667466113d','2026-06-10 07:47:32',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-32-c2r76ecujhxx-NovaBase-doouyznei45c','040fb7d4-4ebd-47e8-b19e-4e667466113d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1564,'c794f1b0-9a71-4ba0-ad2d-dd0160a2f635','9992790d-de4e-4292-bf9e-5d01cb86d54e','2026-06-10 07:47:32',NULL,'CREATE','COMPLETE','NovaApiLogging','a2d9e57a-95ef-414f-a01f-892a183a3f02','state changed','OS::TripleO::Services::Logging::NovaApi',NULL,NULL),(1565,'6231b54a-4130-4ab2-8ddb-533867abdc5c','040fb7d4-4ebd-47e8-b19e-4e667466113d','2026-06-10 07:47:32',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-32-c2r76ecujhxx-NovaBase-doouyznei45c-RoleParametersValue-b5ev4znnzpu2','state changed','OS::Heat::Value',NULL,943),(1566,'59e451bb-3eff-4940-82ff-154a33ec48fb','040fb7d4-4ebd-47e8-b19e-4e667466113d','2026-06-10 07:47:32',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-32-c2r76ecujhxx-NovaBase-doouyznei45c-RoleParametersValue-b5ev4znnzpu2','state changed','OS::Heat::Value',NULL,943),(1567,'720bff0f-fd17-415b-9cc5-d2d813608432','b51091f7-c31a-4f40-83e2-e9e49a9c5e15','2026-06-10 07:47:32',NULL,'CREATE','COMPLETE','ManilaShareContainerBase','a3fb1c80-f5c6-4b86-9e96-f56d2396cd43','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-container-puppet.yaml',NULL,914),(1568,'134423a5-fe5a-45d7-be0c-5b97404e2099','040fb7d4-4ebd-47e8-b19e-4e667466113d','2026-06-10 07:47:32',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-32-c2r76ecujhxx-NovaBase-doouyznei45c','040fb7d4-4ebd-47e8-b19e-4e667466113d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1569,'cb0a0a56-ef15-4d9e-8b7e-148d0d80f86c','b51091f7-c31a-4f40-83e2-e9e49a9c5e15','2026-06-10 07:47:32',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-25-ljommtpr6eis','b51091f7-c31a-4f40-83e2-e9e49a9c5e15','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1570,'22d68848-f924-4031-a713-0842221b44f4','215acfc9-9e95-4690-873e-292bc8e38b34','2026-06-10 07:47:33',NULL,'CREATE','IN_PROGRESS','ApacheServiceBase','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-34-p5tk45ipniwj-ApacheServiceBase-o3h7xangqeok','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,944),(1571,'0df572c8-b347-4c7d-be64-af93c3663702','fd91ae8d-d17d-4e0e-b0e0-ee6f3752f573','2026-06-10 07:47:33',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-34-p5tk45ipniwj-ApacheServiceBase-o3h7xangqeok','fd91ae8d-d17d-4e0e-b0e0-ee6f3752f573','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1572,'82111428-d426-41cb-8b1e-b29e2a8d9710','215acfc9-9e95-4690-873e-292bc8e38b34','2026-06-10 07:47:33',NULL,'CREATE','COMPLETE','NovaMetadataLogging','3f580889-6427-4d54-a4d9-2c6b7945e51d','state changed','OS::TripleO::Services::Logging::NovaMetadata',NULL,NULL),(1573,'1581be87-8f30-4aad-85a4-5391da0ac614','fd91ae8d-d17d-4e0e-b0e0-ee6f3752f573','2026-06-10 07:47:33',NULL,'CREATE','IN_PROGRESS','ApacheNetworks','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-34-p5tk45ipniwj-ApacheServiceBase-o3h7xangqeok-ApacheNetworks-mxgcvtixweua','state changed','OS::Heat::Value',NULL,945),(1574,'73dde5e9-297f-4627-9cdb-e76f05a5e79f','8a944490-696b-47e8-8faa-f824482b1288','2026-06-10 07:47:33',NULL,'CREATE','COMPLETE','MySQLClient','46a507ff-f1c1-4fdd-a077-671fa9bc58cd','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1575,'052e58dd-32a9-4e9f-8aa6-4782a0fae620','fd91ae8d-d17d-4e0e-b0e0-ee6f3752f573','2026-06-10 07:47:33',NULL,'CREATE','COMPLETE','ApacheNetworks','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-34-p5tk45ipniwj-ApacheServiceBase-o3h7xangqeok-ApacheNetworks-mxgcvtixweua','state changed','OS::Heat::Value',NULL,945),(1576,'0ca4b8a7-8f90-4680-9262-27ad29b114c8','8a944490-696b-47e8-8faa-f824482b1288','2026-06-10 07:47:33',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-35-e66bicrr3i26','8a944490-696b-47e8-8faa-f824482b1288','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1577,'dfeda824-ae67-4892-ba84-cd5de1cd1d9e','fd91ae8d-d17d-4e0e-b0e0-ee6f3752f573','2026-06-10 07:47:33',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-34-p5tk45ipniwj-ApacheServiceBase-o3h7xangqeok','fd91ae8d-d17d-4e0e-b0e0-ee6f3752f573','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1578,'0442c3eb-49c1-48ac-bbfa-d436c70326cb','9992790d-de4e-4292-bf9e-5d01cb86d54e','2026-06-10 07:47:33',NULL,'CREATE','IN_PROGRESS','ApacheServiceBase','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-32-c2r76ecujhxx-ApacheServiceBase-f2nspwwd4uir','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,946),(1579,'ebe84f13-5370-489d-95cd-e3113fd8491b','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:47:33',NULL,'CREATE','COMPLETE','25','b51091f7-c31a-4f40-83e2-e9e49a9c5e15','state changed','OS::TripleO::Services::ManilaShare',NULL,886),(1580,'e31255d6-1e19-4e05-baf3-c4516b0fd4a0','8ea54d3e-f9ff-485e-85b6-4127f2db8aee','2026-06-10 07:47:33',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-32-c2r76ecujhxx-ApacheServiceBase-f2nspwwd4uir','8ea54d3e-f9ff-485e-85b6-4127f2db8aee','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1581,'0fbe1312-3eb5-4344-9829-9d3050540f23','9992790d-de4e-4292-bf9e-5d01cb86d54e','2026-06-10 07:47:33',NULL,'CREATE','COMPLETE','NovaBase','040fb7d4-4ebd-47e8-b19e-4e667466113d','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml',NULL,942),(1582,'f40cbf6f-aa19-4c23-bc43-5180cd725a86','8ea54d3e-f9ff-485e-85b6-4127f2db8aee','2026-06-10 07:47:33',NULL,'CREATE','IN_PROGRESS','ApacheNetworks','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-32-c2r76ecujhxx-ApacheServiceBase-f2nspwwd4uir-ApacheNetworks-siiuvg4u6yt2','state changed','OS::Heat::Value',NULL,947),(1583,'8b99c7b2-c5c3-4ed7-800e-37d74e4f8274','8ea54d3e-f9ff-485e-85b6-4127f2db8aee','2026-06-10 07:47:33',NULL,'CREATE','COMPLETE','ApacheNetworks','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-32-c2r76ecujhxx-ApacheServiceBase-f2nspwwd4uir-ApacheNetworks-siiuvg4u6yt2','state changed','OS::Heat::Value',NULL,947),(1584,'2ad81f05-e727-43e8-89fc-f78d4f1c51d4','8ea54d3e-f9ff-485e-85b6-4127f2db8aee','2026-06-10 07:47:33',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-32-c2r76ecujhxx-ApacheServiceBase-f2nspwwd4uir','8ea54d3e-f9ff-485e-85b6-4127f2db8aee','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1585,'4ded55c0-fca2-45cd-905a-f8f7c31e6299','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:47:34',NULL,'CREATE','COMPLETE','35','8a944490-696b-47e8-8faa-f824482b1288','state changed','OS::TripleO::Services::NovaScheduler',NULL,920),(1586,'d10591b8-c5e5-4149-88ef-c8a847276374','215acfc9-9e95-4690-873e-292bc8e38b34','2026-06-10 07:47:34',NULL,'CREATE','COMPLETE','ApacheServiceBase','fd91ae8d-d17d-4e0e-b0e0-ee6f3752f573','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,944),(1587,'047a7bb2-bdb6-4445-b778-a4559a4c9942','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:47:34',NULL,'CREATE','IN_PROGRESS','29','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-29-tb2tajzrjfcg','state changed','OS::TripleO::Services::MySQLClient',NULL,963),(1588,'7dcc0eb8-26c0-4551-b09d-7ffd03a2f770','215acfc9-9e95-4690-873e-292bc8e38b34','2026-06-10 07:47:34',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-34-p5tk45ipniwj','215acfc9-9e95-4690-873e-292bc8e38b34','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1589,'a7d92be6-a866-4128-8f4d-5245bf3fe8c0','9992790d-de4e-4292-bf9e-5d01cb86d54e','2026-06-10 07:47:34',NULL,'CREATE','IN_PROGRESS','NovaDBClient','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-32-c2r76ecujhxx-NovaDBClient-cuzwmjt27aoc','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-db-client-puppet.yaml',NULL,965),(1590,'41f401d5-fe06-4bf0-8bb7-0825fcf43d6b','c81482d6-8048-474a-8a31-2392cfb266d9','2026-06-10 07:47:34',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-29-tb2tajzrjfcg','c81482d6-8048-474a-8a31-2392cfb266d9','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1591,'f6c5c6e7-453c-4c38-935a-a6188748e944','c81482d6-8048-474a-8a31-2392cfb266d9','2026-06-10 07:47:34',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-29-tb2tajzrjfcg','c81482d6-8048-474a-8a31-2392cfb266d9','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1592,'cdb26b1f-e6e9-4698-a435-29e7c248eb3a','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:47:34',NULL,'CREATE','COMPLETE','29','c81482d6-8048-474a-8a31-2392cfb266d9','state changed','OS::TripleO::Services::MySQLClient',NULL,963),(1593,'a66f74c4-27e1-4a32-8146-22c225375fc9','9992790d-de4e-4292-bf9e-5d01cb86d54e','2026-06-10 07:47:34',NULL,'CREATE','COMPLETE','ApacheServiceBase','8ea54d3e-f9ff-485e-85b6-4127f2db8aee','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,946),(1594,'b6809a3d-b196-48d3-8342-01b1bb612841','d5bfa8b7-9a44-4955-a359-ba2159ad00df','2026-06-10 07:47:34',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-32-c2r76ecujhxx-NovaDBClient-cuzwmjt27aoc','d5bfa8b7-9a44-4955-a359-ba2159ad00df','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1595,'bed8add4-9d80-49b3-96c8-2fbaed5c6bd1','d5bfa8b7-9a44-4955-a359-ba2159ad00df','2026-06-10 07:47:34',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-32-c2r76ecujhxx-NovaDBClient-cuzwmjt27aoc','d5bfa8b7-9a44-4955-a359-ba2159ad00df','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1596,'0e42bb44-e4d6-41f6-b86d-a85ab7d49ad3','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:47:34',NULL,'CREATE','COMPLETE','34','215acfc9-9e95-4690-873e-292bc8e38b34','state changed','OS::TripleO::Services::NovaMetadata',NULL,909),(1597,'85ade694-3b61-4078-9288-51d310489a56','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:47:34',NULL,'CREATE','IN_PROGRESS','33','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-33-ob72esncd4x2','state changed','OS::TripleO::Services::NovaConductor',NULL,974),(1598,'0c6098ff-0772-4e4c-b9be-33cd47d77afb','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:47:35',NULL,'CREATE','IN_PROGRESS','39','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-39-7ecbreydn4by','state changed','OS::TripleO::Services::OVNController',NULL,975),(1599,'d75087ca-6c22-48c0-a79b-32470d1aac48','978d701a-5388-4e32-9c1c-3f1a1994d915','2026-06-10 07:47:35',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-39-7ecbreydn4by','978d701a-5388-4e32-9c1c-3f1a1994d915','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1600,'10c97e17-a724-4335-8b2c-8ff1593c27a6','4b31b488-1e56-4612-9993-8a5977a9c688','2026-06-10 07:47:35',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-33-ob72esncd4x2','4b31b488-1e56-4612-9993-8a5977a9c688','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1601,'cff70b4f-2f17-407b-8e44-68b53e711775','978d701a-5388-4e32-9c1c-3f1a1994d915','2026-06-10 07:47:35',NULL,'CREATE','IN_PROGRESS','OVNBridgeMappingsValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-39-7ecbreydn4by-OVNBridgeMappingsValue-2dywkhpgw6ao','state changed','OS::Heat::Value',NULL,982),(1602,'b4457258-bbc7-47ef-9d4b-ea5e5a6db16a','978d701a-5388-4e32-9c1c-3f1a1994d915','2026-06-10 07:47:35',NULL,'CREATE','COMPLETE','OVNBridgeMappingsValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-39-7ecbreydn4by-OVNBridgeMappingsValue-2dywkhpgw6ao','state changed','OS::Heat::Value',NULL,982),(1603,'eb7757ff-a462-4fa8-9e40-fd29790dd4c0','4b31b488-1e56-4612-9993-8a5977a9c688','2026-06-10 07:47:35',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-33-ob72esncd4x2-ContainersCommon-2p7dnlstov4r','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1604,'bbabb18b-7cf0-4b9e-8cae-a8f564af65ad','4fd6cf21-20ed-4ac9-82cd-007fbbb34ebb','2026-06-10 07:47:35',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-33-ob72esncd4x2-ContainersCommon-2p7dnlstov4r','4fd6cf21-20ed-4ac9-82cd-007fbbb34ebb','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1605,'6be0b17a-8c52-4bf9-a1d8-355d0e1f690b','4fd6cf21-20ed-4ac9-82cd-007fbbb34ebb','2026-06-10 07:47:35',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-33-ob72esncd4x2-ContainersCommon-2p7dnlstov4r','4fd6cf21-20ed-4ac9-82cd-007fbbb34ebb','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1606,'9965e399-abcd-4112-95da-34c35a04c259','9992790d-de4e-4292-bf9e-5d01cb86d54e','2026-06-10 07:47:35',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-32-c2r76ecujhxx-ContainersCommon-kxlo5z2odljj','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1607,'ad3c8d0c-092f-4e72-97af-934fabaa111c','7a55d762-2344-4cc0-8ee0-2a6924719206','2026-06-10 07:47:35',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-32-c2r76ecujhxx-ContainersCommon-kxlo5z2odljj','7a55d762-2344-4cc0-8ee0-2a6924719206','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1608,'9b1099eb-a24e-4fe9-9f47-609ede41d8bf','7a55d762-2344-4cc0-8ee0-2a6924719206','2026-06-10 07:47:35',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-32-c2r76ecujhxx-ContainersCommon-kxlo5z2odljj','7a55d762-2344-4cc0-8ee0-2a6924719206','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1609,'685dad42-97ad-4673-a3ab-5168110be18b','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:47:35',NULL,'CREATE','IN_PROGRESS','38','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-38-pbkutxh4547q','state changed','OS::TripleO::Services::OVNDBs',NULL,989),(1610,'966684a7-5ac2-4d43-bbfb-ec4494809958','0d721de3-bab6-4aec-b5d5-f09bdfa8bad8','2026-06-10 07:47:35',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-38-pbkutxh4547q','0d721de3-bab6-4aec-b5d5-f09bdfa8bad8','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1611,'af49547a-7f12-4a43-b4c4-2ed750e1b192','9992790d-de4e-4292-bf9e-5d01cb86d54e','2026-06-10 07:47:35',NULL,'CREATE','COMPLETE','NovaDBClient','d5bfa8b7-9a44-4955-a359-ba2159ad00df','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-db-client-puppet.yaml',NULL,965),(1612,'796178b8-0ee8-4f25-9969-3b2fc185778e','0d721de3-bab6-4aec-b5d5-f09bdfa8bad8','2026-06-10 07:47:35',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-38-pbkutxh4547q-ContainersCommon-buzg3t4tubmb','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1613,'cb64ddac-57d2-4476-bc90-a20f83999876','1575ecb6-a0c1-49b3-8441-5b9da8598bb1','2026-06-10 07:47:36',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-38-pbkutxh4547q-ContainersCommon-buzg3t4tubmb','1575ecb6-a0c1-49b3-8441-5b9da8598bb1','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1614,'653ac2ef-ee3b-4379-b754-41da27e0dbf1','1575ecb6-a0c1-49b3-8441-5b9da8598bb1','2026-06-10 07:47:36',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-38-pbkutxh4547q-ContainersCommon-buzg3t4tubmb','1575ecb6-a0c1-49b3-8441-5b9da8598bb1','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1615,'b8fca5bf-07b6-4e32-80a0-d1ae74f9520a','978d701a-5388-4e32-9c1c-3f1a1994d915','2026-06-10 07:47:36',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-39-7ecbreydn4by-RoleParametersValue-by6a6ru5na3g','state changed','OS::Heat::Value',NULL,990),(1616,'e04d28a9-a9a8-49cd-af23-4767de0608cc','978d701a-5388-4e32-9c1c-3f1a1994d915','2026-06-10 07:47:36',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-39-7ecbreydn4by-RoleParametersValue-by6a6ru5na3g','state changed','OS::Heat::Value',NULL,990),(1617,'2bf25df6-306e-4cee-b644-659a6b9ed9f8','4b31b488-1e56-4612-9993-8a5977a9c688','2026-06-10 07:47:36',NULL,'CREATE','IN_PROGRESS','NovaApiDBClient','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-33-ob72esncd4x2-NovaApiDBClient-6oj6wdkngglr','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-apidb-client-puppet.yaml',NULL,991),(1618,'47a9ac65-ee68-4f73-b39d-864a7e21b43f','e1cf333c-e1b7-4823-bbf7-675513f6a86a','2026-06-10 07:47:36',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-33-ob72esncd4x2-NovaApiDBClient-6oj6wdkngglr','e1cf333c-e1b7-4823-bbf7-675513f6a86a','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1619,'4d9e48d3-24bc-4eb2-a59b-a267e2ff0fff','e1cf333c-e1b7-4823-bbf7-675513f6a86a','2026-06-10 07:47:36',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-33-ob72esncd4x2-NovaApiDBClient-6oj6wdkngglr','e1cf333c-e1b7-4823-bbf7-675513f6a86a','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1620,'b2f83f98-cd05-4849-a31c-9c5d0b8f7e6f','4b31b488-1e56-4612-9993-8a5977a9c688','2026-06-10 07:47:36',NULL,'CREATE','COMPLETE','ContainersCommon','4fd6cf21-20ed-4ac9-82cd-007fbbb34ebb','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1621,'a726bff4-07c5-43f5-8e58-bb260dd0e3e4','9992790d-de4e-4292-bf9e-5d01cb86d54e','2026-06-10 07:47:36',NULL,'CREATE','IN_PROGRESS','NovaApiDBClient','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-32-c2r76ecujhxx-NovaApiDBClient-kl32cdjpaxwh','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-apidb-client-puppet.yaml',NULL,992),(1622,'74197ba0-6dee-4a2f-aed6-9841e81b1507','bfe700df-e823-44ca-94ea-fed6978d3139','2026-06-10 07:47:36',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-32-c2r76ecujhxx-NovaApiDBClient-kl32cdjpaxwh','bfe700df-e823-44ca-94ea-fed6978d3139','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1623,'e5812709-3516-4f7d-93ed-e6a1d729584a','bfe700df-e823-44ca-94ea-fed6978d3139','2026-06-10 07:47:36',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-32-c2r76ecujhxx-NovaApiDBClient-kl32cdjpaxwh','bfe700df-e823-44ca-94ea-fed6978d3139','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1624,'a469a6de-99c2-4334-a859-628884c14563','9992790d-de4e-4292-bf9e-5d01cb86d54e','2026-06-10 07:47:36',NULL,'CREATE','COMPLETE','ContainersCommon','7a55d762-2344-4cc0-8ee0-2a6924719206','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1625,'7298265b-934f-4a4e-b326-79cc7d0f2a30','0d721de3-bab6-4aec-b5d5-f09bdfa8bad8','2026-06-10 07:47:36',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-38-pbkutxh4547q-RoleParametersValue-4l2jmhyboi3t','state changed','OS::Heat::Value',NULL,993),(1626,'f894a5dd-be14-4fdc-a178-3ac405c0f64d','0d721de3-bab6-4aec-b5d5-f09bdfa8bad8','2026-06-10 07:47:36',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-38-pbkutxh4547q-RoleParametersValue-4l2jmhyboi3t','state changed','OS::Heat::Value',NULL,993),(1627,'e2661f9d-8a3f-4ff4-a4bc-9a704d15787a','0d721de3-bab6-4aec-b5d5-f09bdfa8bad8','2026-06-10 07:47:37',NULL,'CREATE','COMPLETE','ContainersCommon','1575ecb6-a0c1-49b3-8441-5b9da8598bb1','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1628,'f6a0db24-f6f0-4062-b32e-ff091f9ba22a','0d721de3-bab6-4aec-b5d5-f09bdfa8bad8','2026-06-10 07:47:37',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-38-pbkutxh4547q','0d721de3-bab6-4aec-b5d5-f09bdfa8bad8','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1629,'c6342e9b-1c67-48ff-95f7-9106e70673ff','978d701a-5388-4e32-9c1c-3f1a1994d915','2026-06-10 07:47:37',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-39-7ecbreydn4by-ContainersCommon-efuxttzyyfat','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1630,'74231465-daff-4b4b-bdce-af2003abc7a0','8a332ef7-dcf6-471f-b4a6-611255437d5c','2026-06-10 07:47:37',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-39-7ecbreydn4by-ContainersCommon-efuxttzyyfat','8a332ef7-dcf6-471f-b4a6-611255437d5c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1631,'9b076d66-a845-48b8-9315-7aa9dc9a7f51','8a332ef7-dcf6-471f-b4a6-611255437d5c','2026-06-10 07:47:37',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-39-7ecbreydn4by-ContainersCommon-efuxttzyyfat','8a332ef7-dcf6-471f-b4a6-611255437d5c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1632,'b706e018-6e5d-45c5-91fc-dbdf0843035e','4b31b488-1e56-4612-9993-8a5977a9c688','2026-06-10 07:47:37',NULL,'CREATE','IN_PROGRESS','NovaBase','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-33-ob72esncd4x2-NovaBase-yq4wuwnq7rbp','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml',NULL,994),(1633,'0540c3d5-210a-4524-ac3b-f00d76c7697e','56ecffe5-5d3b-4912-b8c2-c5ddb4b8321d','2026-06-10 07:47:37',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-33-ob72esncd4x2-NovaBase-yq4wuwnq7rbp','56ecffe5-5d3b-4912-b8c2-c5ddb4b8321d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1634,'7f4b7d08-a28d-44b7-9c2e-66c6ad4e5b60','4b31b488-1e56-4612-9993-8a5977a9c688','2026-06-10 07:47:37',NULL,'CREATE','COMPLETE','NovaApiDBClient','e1cf333c-e1b7-4823-bbf7-675513f6a86a','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-apidb-client-puppet.yaml',NULL,991),(1635,'88d2a90f-1697-4237-a705-2700c20d7d96','56ecffe5-5d3b-4912-b8c2-c5ddb4b8321d','2026-06-10 07:47:37',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-33-ob72esncd4x2-NovaBase-yq4wuwnq7rbp-RoleParametersValue-4v26w4quuua5','state changed','OS::Heat::Value',NULL,995),(1636,'220fc977-2b2f-49aa-8cce-31bfa944dbf5','56ecffe5-5d3b-4912-b8c2-c5ddb4b8321d','2026-06-10 07:47:37',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-33-ob72esncd4x2-NovaBase-yq4wuwnq7rbp-RoleParametersValue-4v26w4quuua5','state changed','OS::Heat::Value',NULL,995),(1637,'99ca994c-44a8-4164-b062-bf61208ab505','56ecffe5-5d3b-4912-b8c2-c5ddb4b8321d','2026-06-10 07:47:37',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-33-ob72esncd4x2-NovaBase-yq4wuwnq7rbp','56ecffe5-5d3b-4912-b8c2-c5ddb4b8321d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1638,'1f5d32f2-dd29-49d7-85ad-c301f682a2f1','9992790d-de4e-4292-bf9e-5d01cb86d54e','2026-06-10 07:47:37',NULL,'CREATE','COMPLETE','NovaApiDBClient','bfe700df-e823-44ca-94ea-fed6978d3139','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-apidb-client-puppet.yaml',NULL,992),(1639,'b62942fb-1e56-4fc2-90e1-52c5ecdeed46','9992790d-de4e-4292-bf9e-5d01cb86d54e','2026-06-10 07:47:37',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-32-c2r76ecujhxx','9992790d-de4e-4292-bf9e-5d01cb86d54e','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1640,'4e60b0c6-32c4-4dbb-b527-9add646d3bd1','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:47:37',NULL,'CREATE','COMPLETE','38','0d721de3-bab6-4aec-b5d5-f09bdfa8bad8','state changed','OS::TripleO::Services::OVNDBs',NULL,989),(1641,'37f6666c-2303-47e8-b4a6-899cb7453fa6','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:47:38',NULL,'CREATE','IN_PROGRESS','42','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-42-exxek32kfenk','state changed','OS::TripleO::Services::OsloMessagingRpc',NULL,999),(1642,'d2f749ee-3757-406c-ac4b-8d155e5e8b51','cca51e41-63cb-479b-9ab5-a0d9ebe7ac16','2026-06-10 07:47:38',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-42-exxek32kfenk','cca51e41-63cb-479b-9ab5-a0d9ebe7ac16','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1643,'af8ff4f9-ae53-49d0-bfd9-950d1992e1d2','4b31b488-1e56-4612-9993-8a5977a9c688','2026-06-10 07:47:38',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-33-ob72esncd4x2-RoleParametersValue-cfnlgu4e6wys','state changed','OS::Heat::Value',NULL,1000),(1644,'ddf0b55a-aa1f-4a67-af79-bd146c70283e','978d701a-5388-4e32-9c1c-3f1a1994d915','2026-06-10 07:47:38',NULL,'CREATE','COMPLETE','ContainersCommon','8a332ef7-dcf6-471f-b4a6-611255437d5c','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1645,'bca2f331-ac9b-4dc0-af0b-f23879538368','4b31b488-1e56-4612-9993-8a5977a9c688','2026-06-10 07:47:38',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-33-ob72esncd4x2-RoleParametersValue-cfnlgu4e6wys','state changed','OS::Heat::Value',NULL,1000),(1646,'c4c8f190-b629-41ff-913b-89e5f5700046','978d701a-5388-4e32-9c1c-3f1a1994d915','2026-06-10 07:47:38',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-39-7ecbreydn4by','978d701a-5388-4e32-9c1c-3f1a1994d915','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1647,'a12f0022-e480-4192-a22c-881e65059bfe','4b31b488-1e56-4612-9993-8a5977a9c688','2026-06-10 07:47:38',NULL,'CREATE','IN_PROGRESS','NovaLogging','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-33-ob72esncd4x2-NovaLogging-pkqb6pdalifv','state changed','OS::TripleO::Services::Logging::NovaCommon',NULL,1002),(1648,'3637398f-fe30-42ec-aa33-8053a4566ef6','4b31b488-1e56-4612-9993-8a5977a9c688','2026-06-10 07:47:38',NULL,'CREATE','COMPLETE','NovaBase','56ecffe5-5d3b-4912-b8c2-c5ddb4b8321d','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml',NULL,994),(1649,'3ca6f5fa-75ed-4b75-99a5-68ad3b1cadd1','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:47:38',NULL,'CREATE','COMPLETE','32','9992790d-de4e-4292-bf9e-5d01cb86d54e','state changed','OS::TripleO::Services::NovaApi',NULL,932),(1650,'804327d5-9678-4466-ac1f-92b5e058c68d','cca51e41-63cb-479b-9ab5-a0d9ebe7ac16','2026-06-10 07:47:38',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-42-exxek32kfenk-RoleParametersValue-hubsxv5loghf','state changed','OS::Heat::Value',NULL,1003),(1651,'2cf34dc1-8254-4f08-ad7d-77ab816e91bb','cca51e41-63cb-479b-9ab5-a0d9ebe7ac16','2026-06-10 07:47:38',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-42-exxek32kfenk-RoleParametersValue-hubsxv5loghf','state changed','OS::Heat::Value',NULL,1003),(1652,'c59744d4-182d-4d59-8410-10f55f77d646','0fa9f7a6-1c00-4a44-b91f-56134120bef7','2026-06-10 07:47:38',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-33-ob72esncd4x2-NovaLogging-pkqb6pdalifv','0fa9f7a6-1c00-4a44-b91f-56134120bef7','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1653,'9a6aee83-7b1c-4b76-a4a8-8983fca00a56','0fa9f7a6-1c00-4a44-b91f-56134120bef7','2026-06-10 07:47:38',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-33-ob72esncd4x2-NovaLogging-pkqb6pdalifv-RoleParametersValue-ciumnjbuwbph','state changed','OS::Heat::Value',NULL,1005),(1654,'8295b979-0f45-4681-80b7-e6fa1a7224ba','0fa9f7a6-1c00-4a44-b91f-56134120bef7','2026-06-10 07:47:38',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-33-ob72esncd4x2-NovaLogging-pkqb6pdalifv-RoleParametersValue-ciumnjbuwbph','state changed','OS::Heat::Value',NULL,1005),(1655,'ae191ac7-2472-45e8-9905-c9a7a9fb4f3d','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:47:39',NULL,'CREATE','COMPLETE','39','978d701a-5388-4e32-9c1c-3f1a1994d915','state changed','OS::TripleO::Services::OVNController',NULL,975),(1656,'3fd21acb-7ca5-47e0-8436-5bf3ea9cb21d','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:47:39',NULL,'CREATE','IN_PROGRESS','36','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-36-eofuay66fese','state changed','OS::TripleO::Services::NovaVncProxy',NULL,1017),(1657,'f77ec0f7-8d26-49bf-9b01-925ee200d4fb','4b31b488-1e56-4612-9993-8a5977a9c688','2026-06-10 07:47:39',NULL,'CREATE','IN_PROGRESS','NovaDBClient','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-33-ob72esncd4x2-NovaDBClient-k7mn6vuyhxts','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-db-client-puppet.yaml',NULL,1019),(1658,'bc1afca6-7961-4099-bb53-62fa9599f2ee','ba3c6718-9591-4616-ae76-7a2c2e98be3a','2026-06-10 07:47:39',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-33-ob72esncd4x2-NovaDBClient-k7mn6vuyhxts','ba3c6718-9591-4616-ae76-7a2c2e98be3a','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1659,'bf795be4-26b6-4f4a-bb9e-870632c1f338','d0e46978-3a99-4c7d-8a36-3f0027c0129f','2026-06-10 07:47:39',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-36-eofuay66fese','d0e46978-3a99-4c7d-8a36-3f0027c0129f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1660,'1d31946c-676f-4217-a6cf-267d4f2a358e','cca51e41-63cb-479b-9ab5-a0d9ebe7ac16','2026-06-10 07:47:39',NULL,'CREATE','IN_PROGRESS','RabbitmqBase','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-42-exxek32kfenk-RabbitmqBase-ksfebxuhvig4','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-container-puppet.yaml',NULL,1023),(1661,'41d9b3e1-93da-4d88-ba52-ad47ded3b5e0','52a8df48-852e-4b17-80a6-9be1908f88f1','2026-06-10 07:47:39',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-42-exxek32kfenk-RabbitmqBase-ksfebxuhvig4','52a8df48-852e-4b17-80a6-9be1908f88f1','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1662,'6a34c169-f312-4571-92da-f42b12241bb3','ba3c6718-9591-4616-ae76-7a2c2e98be3a','2026-06-10 07:47:39',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-33-ob72esncd4x2-NovaDBClient-k7mn6vuyhxts','ba3c6718-9591-4616-ae76-7a2c2e98be3a','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1663,'32520f46-a047-4998-9fb4-eafe48150710','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:47:39',NULL,'CREATE','IN_PROGRESS','43','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-43-kxqsffskd7jv','state changed','OS::TripleO::Services::OsloMessagingNotify',NULL,1024),(1664,'e5ce1a10-dbf2-4f38-a5f5-40dfdd8f8269','0fa9f7a6-1c00-4a44-b91f-56134120bef7','2026-06-10 07:47:39',NULL,'CREATE','IN_PROGRESS','InitLogContainerName','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-33-ob72esncd4x2-NovaLogging-pkqb6pdalifv-InitLogContainerName-77nqgstv5pu7','state changed','OS::Heat::Value',NULL,1025),(1665,'95710867-a881-48f7-a9ba-dae5a9e5b07b','d0e46978-3a99-4c7d-8a36-3f0027c0129f','2026-06-10 07:47:39',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-36-eofuay66fese-RoleParametersValue-73tsdh2rgogb','state changed','OS::Heat::Value',NULL,1026),(1666,'acc7571d-030c-4ce9-bb73-ff920aff92d8','0fa9f7a6-1c00-4a44-b91f-56134120bef7','2026-06-10 07:47:39',NULL,'CREATE','COMPLETE','InitLogContainerName','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-33-ob72esncd4x2-NovaLogging-pkqb6pdalifv-InitLogContainerName-77nqgstv5pu7','state changed','OS::Heat::Value',NULL,1025),(1667,'9f86a721-0d6c-415f-9968-d3a66b5d39ad','d0e46978-3a99-4c7d-8a36-3f0027c0129f','2026-06-10 07:47:39',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-36-eofuay66fese-RoleParametersValue-73tsdh2rgogb','state changed','OS::Heat::Value',NULL,1026),(1668,'561950c2-72e4-4f14-9a93-8fcb591e4e29','0fa9f7a6-1c00-4a44-b91f-56134120bef7','2026-06-10 07:47:39',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-33-ob72esncd4x2-NovaLogging-pkqb6pdalifv','0fa9f7a6-1c00-4a44-b91f-56134120bef7','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1669,'478ac9df-560a-40ac-83d0-9ad5a4f22993','9daadef0-212d-4adc-95a8-39ed4822b165','2026-06-10 07:47:39',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-43-kxqsffskd7jv','9daadef0-212d-4adc-95a8-39ed4822b165','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1670,'02a0cc4a-9666-46d3-af37-6ea60694e3aa','52a8df48-852e-4b17-80a6-9be1908f88f1','2026-06-10 07:47:39',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-42-exxek32kfenk-RabbitmqBase-ksfebxuhvig4-RoleParametersValue-yxdhxijm6w7h','state changed','OS::Heat::Value',NULL,1029),(1671,'0247444d-b07e-4b43-b18c-d130c8a902bf','d0e46978-3a99-4c7d-8a36-3f0027c0129f','2026-06-10 07:47:39',NULL,'CREATE','IN_PROGRESS','NovaLogging','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-36-eofuay66fese-NovaLogging-zdyiufe2hihk','state changed','OS::TripleO::Services::Logging::NovaCommon',NULL,1028),(1672,'b4229859-3543-4e25-8ab5-2fa3623cd604','52a8df48-852e-4b17-80a6-9be1908f88f1','2026-06-10 07:47:39',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-42-exxek32kfenk-RabbitmqBase-ksfebxuhvig4-RoleParametersValue-yxdhxijm6w7h','state changed','OS::Heat::Value',NULL,1029),(1673,'ae850991-8a45-4276-8057-778abb1b5319','7448b120-63bd-483f-9318-7a89b3e498dc','2026-06-10 07:47:39',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-36-eofuay66fese-NovaLogging-zdyiufe2hihk','7448b120-63bd-483f-9318-7a89b3e498dc','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1674,'5ec52e6b-7fd7-4ac8-a9aa-de5e076c87c8','9daadef0-212d-4adc-95a8-39ed4822b165','2026-06-10 07:47:39',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-43-kxqsffskd7jv-ContainersCommon-vtnkaxxek4mf','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1675,'b0b61577-afac-495f-8f63-3068d06a00a5','2b54a3c3-68b2-4490-a0f4-2ff419e5ef41','2026-06-10 07:47:40',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-43-kxqsffskd7jv-ContainersCommon-vtnkaxxek4mf','2b54a3c3-68b2-4490-a0f4-2ff419e5ef41','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1676,'930c6dd1-450d-4ab4-8247-aecbd8ea61a5','2b54a3c3-68b2-4490-a0f4-2ff419e5ef41','2026-06-10 07:47:40',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-43-kxqsffskd7jv-ContainersCommon-vtnkaxxek4mf','2b54a3c3-68b2-4490-a0f4-2ff419e5ef41','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1677,'d0cbc1bd-9122-442c-b2e6-e5b9654ecbcf','7448b120-63bd-483f-9318-7a89b3e498dc','2026-06-10 07:47:40',NULL,'CREATE','IN_PROGRESS','InitLogContainerName','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-36-eofuay66fese-NovaLogging-zdyiufe2hihk-InitLogContainerName-qc6254lxusvp','state changed','OS::Heat::Value',NULL,1030),(1678,'7801df52-6f6e-4bbc-b707-375137f8f193','7448b120-63bd-483f-9318-7a89b3e498dc','2026-06-10 07:47:40',NULL,'CREATE','COMPLETE','InitLogContainerName','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-36-eofuay66fese-NovaLogging-zdyiufe2hihk-InitLogContainerName-qc6254lxusvp','state changed','OS::Heat::Value',NULL,1030),(1679,'baf99f8e-b7b3-4781-9cd3-fe426d1df570','4b31b488-1e56-4612-9993-8a5977a9c688','2026-06-10 07:47:40',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-33-ob72esncd4x2-MySQLClient-kjvq3dvux45e','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1680,'b6909781-2e1c-444b-8b40-9b4c1b5f887f','d316cf23-ad51-4482-9186-c873e37679ea','2026-06-10 07:47:40',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-33-ob72esncd4x2-MySQLClient-kjvq3dvux45e','d316cf23-ad51-4482-9186-c873e37679ea','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1681,'af2243ea-3191-46d9-8d3b-f05cfd205507','d316cf23-ad51-4482-9186-c873e37679ea','2026-06-10 07:47:40',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-33-ob72esncd4x2-MySQLClient-kjvq3dvux45e','d316cf23-ad51-4482-9186-c873e37679ea','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1682,'12f94c0a-4f07-4f91-a228-be2af5596167','4b31b488-1e56-4612-9993-8a5977a9c688','2026-06-10 07:47:40',NULL,'CREATE','COMPLETE','NovaDBClient','ba3c6718-9591-4616-ae76-7a2c2e98be3a','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-db-client-puppet.yaml',NULL,1019),(1683,'fc8f36bb-398d-4b1f-adbb-41d9ba60b8ca','cca51e41-63cb-479b-9ab5-a0d9ebe7ac16','2026-06-10 07:47:40',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-42-exxek32kfenk-ContainersCommon-w7oz5pw7awtk','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1684,'9837cce9-315a-4e11-8664-59c63a18f4c0','fc333270-a1dd-41af-93d7-9ae563200971','2026-06-10 07:47:40',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-42-exxek32kfenk-ContainersCommon-w7oz5pw7awtk','fc333270-a1dd-41af-93d7-9ae563200971','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1685,'f4b51151-c13e-467e-b8f7-c88365b900db','4b31b488-1e56-4612-9993-8a5977a9c688','2026-06-10 07:47:40',NULL,'CREATE','COMPLETE','NovaLogging','0fa9f7a6-1c00-4a44-b91f-56134120bef7','state changed','OS::TripleO::Services::Logging::NovaCommon',NULL,1002),(1686,'f76b209e-7b22-4e5b-a53f-c57c5312c6b9','fc333270-a1dd-41af-93d7-9ae563200971','2026-06-10 07:47:40',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-42-exxek32kfenk-ContainersCommon-w7oz5pw7awtk','fc333270-a1dd-41af-93d7-9ae563200971','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1687,'936fe2c4-58c0-42dd-bee5-b970944f0baf','d0e46978-3a99-4c7d-8a36-3f0027c0129f','2026-06-10 07:47:40',NULL,'CREATE','IN_PROGRESS','NovaBase','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-36-eofuay66fese-NovaBase-74fk5tq7fixt','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml',NULL,1031),(1688,'933d7f3c-9a70-460b-b554-7536ec314554','c62edf5b-a81d-40b1-8daa-4ce3fb80433d','2026-06-10 07:47:40',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-36-eofuay66fese-NovaBase-74fk5tq7fixt','c62edf5b-a81d-40b1-8daa-4ce3fb80433d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1689,'d24f72aa-2a6c-4aa1-a1ec-052736bdedf5','52a8df48-852e-4b17-80a6-9be1908f88f1','2026-06-10 07:47:40',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-42-exxek32kfenk-RabbitmqBase-ksfebxuhvig4-ContainersCommon-gf6rlhop2yli','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1690,'a3ff838b-e0c2-4f05-b97e-36563a51009d','505f4fc0-48a4-4932-9e18-4273de13a2ff','2026-06-10 07:47:40',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-42-exxek32kfenk-RabbitmqBase-ksfebxuhvig4-ContainersCommon-gf6rlhop2yli','505f4fc0-48a4-4932-9e18-4273de13a2ff','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1691,'23ef84e1-edd3-4675-8215-308a7007d8e9','c62edf5b-a81d-40b1-8daa-4ce3fb80433d','2026-06-10 07:47:40',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-36-eofuay66fese-NovaBase-74fk5tq7fixt-RoleParametersValue-lip32m5bk2kt','state changed','OS::Heat::Value',NULL,1032),(1692,'1855606b-96ca-4c65-810b-446e9c93efc6','505f4fc0-48a4-4932-9e18-4273de13a2ff','2026-06-10 07:47:40',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-42-exxek32kfenk-RabbitmqBase-ksfebxuhvig4-ContainersCommon-gf6rlhop2yli','505f4fc0-48a4-4932-9e18-4273de13a2ff','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1693,'b938c1cb-71b7-493f-a5d9-a87926c98992','c62edf5b-a81d-40b1-8daa-4ce3fb80433d','2026-06-10 07:47:40',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-36-eofuay66fese-NovaBase-74fk5tq7fixt-RoleParametersValue-lip32m5bk2kt','state changed','OS::Heat::Value',NULL,1032),(1694,'9c414f86-08ac-4ab2-804f-59df41c0eaf5','c62edf5b-a81d-40b1-8daa-4ce3fb80433d','2026-06-10 07:47:40',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-36-eofuay66fese-NovaBase-74fk5tq7fixt','c62edf5b-a81d-40b1-8daa-4ce3fb80433d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1695,'43b59610-0d1e-4b17-9346-7cae768e41fa','9daadef0-212d-4adc-95a8-39ed4822b165','2026-06-10 07:47:41',NULL,'CREATE','COMPLETE','ContainersCommon','2b54a3c3-68b2-4490-a0f4-2ff419e5ef41','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1696,'b31d6f2a-933d-4f5e-b011-2973bab3b2b5','9daadef0-212d-4adc-95a8-39ed4822b165','2026-06-10 07:47:41',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-43-kxqsffskd7jv','9daadef0-212d-4adc-95a8-39ed4822b165','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1697,'8e251c0c-814b-4d4a-b287-dbaa362fd7e2','7448b120-63bd-483f-9318-7a89b3e498dc','2026-06-10 07:47:41',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-36-eofuay66fese-NovaLogging-zdyiufe2hihk-RoleParametersValue-y2vqbzri2ass','state changed','OS::Heat::Value',NULL,1033),(1698,'dbc41937-9b12-4231-b3de-80fb589af9d7','7448b120-63bd-483f-9318-7a89b3e498dc','2026-06-10 07:47:41',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-36-eofuay66fese-NovaLogging-zdyiufe2hihk-RoleParametersValue-y2vqbzri2ass','state changed','OS::Heat::Value',NULL,1033),(1699,'30ce2c48-3f86-46b1-a4a1-39bb15140d48','7448b120-63bd-483f-9318-7a89b3e498dc','2026-06-10 07:47:41',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-36-eofuay66fese-NovaLogging-zdyiufe2hihk','7448b120-63bd-483f-9318-7a89b3e498dc','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1700,'bf6b2741-4aab-442f-a972-71a50c1da744','4b31b488-1e56-4612-9993-8a5977a9c688','2026-06-10 07:47:41',NULL,'CREATE','COMPLETE','MySQLClient','d316cf23-ad51-4482-9186-c873e37679ea','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1701,'786a0980-eafb-4385-a9c4-8175c15311a1','4b31b488-1e56-4612-9993-8a5977a9c688','2026-06-10 07:47:41',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-33-ob72esncd4x2','4b31b488-1e56-4612-9993-8a5977a9c688','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1702,'82d290d7-ecd1-4ee7-8b77-816e6b012567','cca51e41-63cb-479b-9ab5-a0d9ebe7ac16','2026-06-10 07:47:41',NULL,'CREATE','COMPLETE','ContainersCommon','fc333270-a1dd-41af-93d7-9ae563200971','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1703,'3613ad70-2678-4302-83aa-ea8598190f6e','d0e46978-3a99-4c7d-8a36-3f0027c0129f','2026-06-10 07:47:41',NULL,'CREATE','IN_PROGRESS','NovaDBClient','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-36-eofuay66fese-NovaDBClient-g575mnfkonde','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-db-client-puppet.yaml',NULL,1034),(1704,'de2fd474-adb3-4982-8f6b-be7f1e4c0770','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:47:41',NULL,'CREATE','COMPLETE','43','9daadef0-212d-4adc-95a8-39ed4822b165','state changed','OS::TripleO::Services::OsloMessagingNotify',NULL,1024),(1705,'45e6fdbf-6cb4-46fa-b7de-eaf2f75889c2','463ab561-d930-429f-b128-ade5db759e61','2026-06-10 07:47:41',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-36-eofuay66fese-NovaDBClient-g575mnfkonde','463ab561-d930-429f-b128-ade5db759e61','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1706,'61482ad7-55ba-416d-907c-b38472c996c4','52a8df48-852e-4b17-80a6-9be1908f88f1','2026-06-10 07:47:41',NULL,'CREATE','IN_PROGRESS','RabbitMQServiceBase','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-42-exxek32kfenk-RabbitmqBase-ksfebxuhvig4-RabbitMQServiceBase-xlk52p6ltk6r','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-container-puppet.yaml',NULL,1035),(1707,'5e9fe88f-596c-477a-9e5c-206bffcd8568','d0e46978-3a99-4c7d-8a36-3f0027c0129f','2026-06-10 07:47:41',NULL,'CREATE','COMPLETE','NovaBase','c62edf5b-a81d-40b1-8daa-4ce3fb80433d','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml',NULL,1031),(1708,'32649be8-a64d-49ee-9c7d-8a696996a294','463ab561-d930-429f-b128-ade5db759e61','2026-06-10 07:47:41',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-36-eofuay66fese-NovaDBClient-g575mnfkonde','463ab561-d930-429f-b128-ade5db759e61','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1709,'c775b4c9-b1fa-4acb-b4fb-5060881c25b4','24122958-e2e4-4f92-ab69-e5f365fee071','2026-06-10 07:47:41',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-42-exxek32kfenk-RabbitmqBase-ksfebxuhvig4-RabbitMQServiceBase-xlk52p6ltk6r','24122958-e2e4-4f92-ab69-e5f365fee071','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1710,'3171e88d-4b75-4d8d-9a16-a91fd6608328','52a8df48-852e-4b17-80a6-9be1908f88f1','2026-06-10 07:47:41',NULL,'CREATE','COMPLETE','ContainersCommon','505f4fc0-48a4-4932-9e18-4273de13a2ff','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1711,'ea59819d-e77a-4078-9732-0090036914bb','d0e46978-3a99-4c7d-8a36-3f0027c0129f','2026-06-10 07:47:42',NULL,'CREATE','COMPLETE','NovaLogging','7448b120-63bd-483f-9318-7a89b3e498dc','state changed','OS::TripleO::Services::Logging::NovaCommon',NULL,1028),(1712,'4f054d30-84d0-459e-8525-b054045ca316','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:47:42',NULL,'CREATE','IN_PROGRESS','47','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-47-pygrqzuox2hb','state changed','OS::TripleO::Services::Snmp',NULL,1038),(1713,'944c2637-7862-4aa6-bca5-f6708882d3d1','3bbb88d2-c384-49d5-ac5d-db24b6f72868','2026-06-10 07:47:42',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-47-pygrqzuox2hb','3bbb88d2-c384-49d5-ac5d-db24b6f72868','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1714,'3d1eee7a-3007-4086-929d-871ae1fd7d0a','24122958-e2e4-4f92-ab69-e5f365fee071','2026-06-10 07:47:42',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-42-exxek32kfenk-RabbitmqBase-ksfebxuhvig4-RabbitMQServiceBase-xlk52p6ltk6r-ContainersCommon-72bbextvm4f2','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1715,'c84e4783-fba7-48ea-88a4-4d2b33954528','3bbb88d2-c384-49d5-ac5d-db24b6f72868','2026-06-10 07:47:42',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-47-pygrqzuox2hb','3bbb88d2-c384-49d5-ac5d-db24b6f72868','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1716,'92e05f7a-112d-4f94-952a-a5f2934a41df','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:47:42',NULL,'CREATE','COMPLETE','33','4b31b488-1e56-4612-9993-8a5977a9c688','state changed','OS::TripleO::Services::NovaConductor',NULL,974),(1717,'274c97f0-986f-4529-8731-f0f5e370e738','a923eec2-a0f2-4347-b6a6-a4b1e9a21303','2026-06-10 07:47:42',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-42-exxek32kfenk-RabbitmqBase-ksfebxuhvig4-RabbitMQServiceBase-xlk52p6ltk6r-ContainersCommon-72bbextvm4f2','a923eec2-a0f2-4347-b6a6-a4b1e9a21303','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1718,'c4bcd513-9473-431b-a5cf-0f71559ffb66','a923eec2-a0f2-4347-b6a6-a4b1e9a21303','2026-06-10 07:47:42',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-42-exxek32kfenk-RabbitmqBase-ksfebxuhvig4-RabbitMQServiceBase-xlk52p6ltk6r-ContainersCommon-72bbextvm4f2','a923eec2-a0f2-4347-b6a6-a4b1e9a21303','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1719,'77b2b619-33ed-4cae-b016-dd31064c3674','d0e46978-3a99-4c7d-8a36-3f0027c0129f','2026-06-10 07:47:42',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-36-eofuay66fese-MySQLClient-wdnizzmqbuwj','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1720,'85006d18-da46-488e-baea-4b68aef7e948','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:47:42',NULL,'CREATE','IN_PROGRESS','37','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-37-ft2dejhjgamz','state changed','OS::TripleO::Services::ContainersLogrotateCrond',NULL,1049),(1721,'05330506-378e-45c1-9385-46bff446fc21','91a4a66d-c717-4d84-8658-150414786161','2026-06-10 07:47:42',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-36-eofuay66fese-MySQLClient-wdnizzmqbuwj','91a4a66d-c717-4d84-8658-150414786161','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1722,'36ce1732-1e1c-4bca-b966-d488a9538787','91a4a66d-c717-4d84-8658-150414786161','2026-06-10 07:47:42',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-36-eofuay66fese-MySQLClient-wdnizzmqbuwj','91a4a66d-c717-4d84-8658-150414786161','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1723,'0896d7b1-a08c-4084-89a2-b8bc831ef037','d0e46978-3a99-4c7d-8a36-3f0027c0129f','2026-06-10 07:47:42',NULL,'CREATE','COMPLETE','NovaDBClient','463ab561-d930-429f-b128-ade5db759e61','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-db-client-puppet.yaml',NULL,1034),(1724,'df4b4c0b-ffbf-436f-8a31-f427e8b542d1','328bb989-2993-4762-9e1e-35e55b801e4e','2026-06-10 07:47:42',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-37-ft2dejhjgamz','328bb989-2993-4762-9e1e-35e55b801e4e','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1725,'72c45c98-1e48-46f6-a8ad-15eb6b26eba2','328bb989-2993-4762-9e1e-35e55b801e4e','2026-06-10 07:47:43',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-37-ft2dejhjgamz-RoleParametersValue-dbjhmgghwj6d','state changed','OS::Heat::Value',NULL,1050),(1726,'74109849-9902-424b-aa3e-2db86f53282e','328bb989-2993-4762-9e1e-35e55b801e4e','2026-06-10 07:47:43',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-37-ft2dejhjgamz-RoleParametersValue-dbjhmgghwj6d','state changed','OS::Heat::Value',NULL,1050),(1727,'2cb9043e-bd11-4a4e-b6af-d636f70eb376','24122958-e2e4-4f92-ab69-e5f365fee071','2026-06-10 07:47:43',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-42-exxek32kfenk-RabbitmqBase-ksfebxuhvig4-RabbitMQServiceBase-xlk52p6ltk6r-RoleParametersValue-qzijueqcoplp','state changed','OS::Heat::Value',NULL,1051),(1728,'5c3e4800-3937-4f8c-830c-905a445f19e4','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:47:43',NULL,'CREATE','COMPLETE','47','3bbb88d2-c384-49d5-ac5d-db24b6f72868','state changed','OS::TripleO::Services::Snmp',NULL,1038),(1729,'aae2f57e-9f64-4a10-b499-9d8d4a553125','24122958-e2e4-4f92-ab69-e5f365fee071','2026-06-10 07:47:43',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-42-exxek32kfenk-RabbitmqBase-ksfebxuhvig4-RabbitMQServiceBase-xlk52p6ltk6r-RoleParametersValue-qzijueqcoplp','state changed','OS::Heat::Value',NULL,1051),(1730,'932a8439-bf4f-48c3-8243-bbc3bf62abc6','24122958-e2e4-4f92-ab69-e5f365fee071','2026-06-10 07:47:43',NULL,'CREATE','COMPLETE','ContainersCommon','a923eec2-a0f2-4347-b6a6-a4b1e9a21303','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1731,'c5c20389-537e-49fd-ac84-58484fd8ab14','24122958-e2e4-4f92-ab69-e5f365fee071','2026-06-10 07:47:43',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-42-exxek32kfenk-RabbitmqBase-ksfebxuhvig4-RabbitMQServiceBase-xlk52p6ltk6r','24122958-e2e4-4f92-ab69-e5f365fee071','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1732,'444be22f-0864-47af-8c73-2a78b38711af','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:47:43',NULL,'CREATE','IN_PROGRESS','51','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-51-vv7f5ncxyj2p','state changed','OS::TripleO::Services::SwiftStorage',NULL,1053),(1733,'cced3ac1-a588-4ab0-82e3-2debe1598c1d','5755438d-2121-4ba8-a53a-a070ff1070f9','2026-06-10 07:47:43',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-51-vv7f5ncxyj2p','5755438d-2121-4ba8-a53a-a070ff1070f9','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1734,'f92c6fbc-0b78-44bc-bda5-11bdca040daa','d0e46978-3a99-4c7d-8a36-3f0027c0129f','2026-06-10 07:47:43',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-36-eofuay66fese-ContainersCommon-eldqxp5uzwnw','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1735,'18a8bdea-700b-41df-9af1-560f392664d0','5755438d-2121-4ba8-a53a-a070ff1070f9','2026-06-10 07:47:43',NULL,'CREATE','IN_PROGRESS','SwiftBase','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-51-vv7f5ncxyj2p-SwiftBase-ne3ttjhfs7rc','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-base.yaml',NULL,1054),(1736,'52fa471c-6f46-4b29-ad48-9341efb5483c','0fae2ee9-13de-4f9d-af3b-02b7d77860a7','2026-06-10 07:47:43',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-51-vv7f5ncxyj2p-SwiftBase-ne3ttjhfs7rc','0fae2ee9-13de-4f9d-af3b-02b7d77860a7','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1737,'0e8dee8f-f74f-45fb-b861-b7d227516b5d','bf5cad7a-fcf5-40b4-a9c9-846d47e7b007','2026-06-10 07:47:43',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-36-eofuay66fese-ContainersCommon-eldqxp5uzwnw','bf5cad7a-fcf5-40b4-a9c9-846d47e7b007','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1738,'47897973-310f-495f-a016-e8418cc47d63','0fae2ee9-13de-4f9d-af3b-02b7d77860a7','2026-06-10 07:47:43',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-51-vv7f5ncxyj2p-SwiftBase-ne3ttjhfs7rc','0fae2ee9-13de-4f9d-af3b-02b7d77860a7','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1739,'8090b7d9-c48a-40d5-9e13-6a0bb1012d54','bf5cad7a-fcf5-40b4-a9c9-846d47e7b007','2026-06-10 07:47:43',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-36-eofuay66fese-ContainersCommon-eldqxp5uzwnw','bf5cad7a-fcf5-40b4-a9c9-846d47e7b007','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1740,'14d41caf-4864-4d28-bacd-3b5328e9d9b2','d0e46978-3a99-4c7d-8a36-3f0027c0129f','2026-06-10 07:47:43',NULL,'CREATE','COMPLETE','MySQLClient','91a4a66d-c717-4d84-8658-150414786161','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1741,'b7572e7e-1cf5-4e3b-a8ac-9de5c41173a1','52a8df48-852e-4b17-80a6-9be1908f88f1','2026-06-10 07:47:44',NULL,'CREATE','COMPLETE','RabbitMQServiceBase','24122958-e2e4-4f92-ab69-e5f365fee071','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-container-puppet.yaml',NULL,1035),(1742,'4f5a3720-3521-44c1-b965-6b76395ccd42','52a8df48-852e-4b17-80a6-9be1908f88f1','2026-06-10 07:47:44',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-42-exxek32kfenk-RabbitmqBase-ksfebxuhvig4','52a8df48-852e-4b17-80a6-9be1908f88f1','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1743,'826594fa-c688-4120-b702-2e1a56d63bf7','328bb989-2993-4762-9e1e-35e55b801e4e','2026-06-10 07:47:44',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-37-ft2dejhjgamz-ContainersCommon-7mmt3v6igoq5','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1744,'077fa912-6dfd-42d8-8224-09cea4e8c2a3','5daf5f91-bfe4-4a3e-ad37-82c4a788e1b2','2026-06-10 07:47:44',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-37-ft2dejhjgamz-ContainersCommon-7mmt3v6igoq5','5daf5f91-bfe4-4a3e-ad37-82c4a788e1b2','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1745,'58c64da0-b80d-4cdd-ba1d-5c74217d08a3','5daf5f91-bfe4-4a3e-ad37-82c4a788e1b2','2026-06-10 07:47:44',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-37-ft2dejhjgamz-ContainersCommon-7mmt3v6igoq5','5daf5f91-bfe4-4a3e-ad37-82c4a788e1b2','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1746,'728da95f-1fbe-4612-88b0-33c4cd0a4044','cca51e41-63cb-479b-9ab5-a0d9ebe7ac16','2026-06-10 07:47:44',NULL,'CREATE','COMPLETE','RabbitmqBase','52a8df48-852e-4b17-80a6-9be1908f88f1','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-container-puppet.yaml',NULL,1023),(1747,'a6a2c9a1-784f-441c-b189-a458c4f9074a','5755438d-2121-4ba8-a53a-a070ff1070f9','2026-06-10 07:47:44',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-51-vv7f5ncxyj2p-RoleParametersValue-p3za6ptbwi3h','state changed','OS::Heat::Value',NULL,1055),(1748,'279fedda-aa50-430c-be31-838cf6ccca63','cca51e41-63cb-479b-9ab5-a0d9ebe7ac16','2026-06-10 07:47:44',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-42-exxek32kfenk','cca51e41-63cb-479b-9ab5-a0d9ebe7ac16','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1749,'09e74c56-4474-49b0-85d3-35aa42f750d7','5755438d-2121-4ba8-a53a-a070ff1070f9','2026-06-10 07:47:44',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-51-vv7f5ncxyj2p-RoleParametersValue-p3za6ptbwi3h','state changed','OS::Heat::Value',NULL,1055),(1750,'e0974ff3-0234-4379-989b-51aa32ae94c6','5755438d-2121-4ba8-a53a-a070ff1070f9','2026-06-10 07:47:44',NULL,'CREATE','COMPLETE','SwiftBase','0fae2ee9-13de-4f9d-af3b-02b7d77860a7','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-base.yaml',NULL,1054),(1751,'3bdb3bb2-61a4-4233-b4a4-579e6dace7c3','d0e46978-3a99-4c7d-8a36-3f0027c0129f','2026-06-10 07:47:44',NULL,'CREATE','COMPLETE','ContainersCommon','bf5cad7a-fcf5-40b4-a9c9-846d47e7b007','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1752,'b7cd3459-e363-4d83-b01d-89a3314a1cd9','d0e46978-3a99-4c7d-8a36-3f0027c0129f','2026-06-10 07:47:44',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-36-eofuay66fese','d0e46978-3a99-4c7d-8a36-3f0027c0129f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1753,'a6537aac-dd0a-43e7-8d03-1868aaaba73b','328bb989-2993-4762-9e1e-35e55b801e4e','2026-06-10 07:47:45',NULL,'CREATE','COMPLETE','ContainersCommon','5daf5f91-bfe4-4a3e-ad37-82c4a788e1b2','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1754,'14f3e78a-eb4d-467d-8e74-bffd3db7ed99','328bb989-2993-4762-9e1e-35e55b801e4e','2026-06-10 07:47:45',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-37-ft2dejhjgamz','328bb989-2993-4762-9e1e-35e55b801e4e','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1755,'6d6c1588-b6db-424a-9bed-3bf035c4395b','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:47:45',NULL,'CREATE','COMPLETE','42','cca51e41-63cb-479b-9ab5-a0d9ebe7ac16','state changed','OS::TripleO::Services::OsloMessagingRpc',NULL,999),(1756,'444fae31-6358-45ad-b014-d5c2e626aae3','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:47:45',NULL,'CREATE','COMPLETE','36','d0e46978-3a99-4c7d-8a36-3f0027c0129f','state changed','OS::TripleO::Services::NovaVncProxy',NULL,1017),(1757,'608be660-2207-4453-b7f2-3ba1ae327a77','5755438d-2121-4ba8-a53a-a070ff1070f9','2026-06-10 07:47:45',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-51-vv7f5ncxyj2p-ContainersCommon-3sumfdtjpjsj','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1758,'88f93caa-fd42-428e-9e26-231e6a04ff69','7af7a5d1-574b-4d2b-aa9c-4b46cc8c79de','2026-06-10 07:47:45',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-51-vv7f5ncxyj2p-ContainersCommon-3sumfdtjpjsj','7af7a5d1-574b-4d2b-aa9c-4b46cc8c79de','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1759,'1b15be91-4042-436b-b393-a1271e862e33','7af7a5d1-574b-4d2b-aa9c-4b46cc8c79de','2026-06-10 07:47:45',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-51-vv7f5ncxyj2p-ContainersCommon-3sumfdtjpjsj','7af7a5d1-574b-4d2b-aa9c-4b46cc8c79de','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1760,'3c3241f5-be00-4e0c-a611-f169d4d7a98a','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:47:46',NULL,'CREATE','COMPLETE','37','328bb989-2993-4762-9e1e-35e55b801e4e','state changed','OS::TripleO::Services::ContainersLogrotateCrond',NULL,1049),(1761,'c2a0ac61-9c79-4820-bfd7-149af4781f76','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:47:46',NULL,'CREATE','IN_PROGRESS','46','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-46-idbtfvbyqdvu','state changed','OS::TripleO::Services::Rsyslog',NULL,1073),(1762,'5c65232e-612c-4552-afdd-73d3a86ecf26','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:47:46',NULL,'CREATE','IN_PROGRESS','40','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-40-rymqidyospsq','state changed','OS::TripleO::Services::Pacemaker',NULL,1078),(1763,'a61b1bec-c6aa-4593-9835-f684b471fe52','12f4deb7-b90f-43eb-af49-237b45c5213b','2026-06-10 07:47:46',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-46-idbtfvbyqdvu','12f4deb7-b90f-43eb-af49-237b45c5213b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1764,'4a53a522-fc54-4740-b2bf-e0b53a853e9f','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:47:46',NULL,'CREATE','IN_PROGRESS','41','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-41-e3ru4kpideja','state changed','OS::TripleO::Services::PlacementApi',NULL,1079),(1765,'2c656d47-0e62-4b24-befd-f02eedd9e42a','f38c267b-03a3-455d-8ebc-a26bed393ed3','2026-06-10 07:47:46',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-40-rymqidyospsq','f38c267b-03a3-455d-8ebc-a26bed393ed3','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1766,'90ecc1c9-7f1c-47f9-be5b-dbc89fd7de5b','ee995dbd-b039-414a-bb95-9d4c0abe29e6','2026-06-10 07:47:46',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-41-e3ru4kpideja','ee995dbd-b039-414a-bb95-9d4c0abe29e6','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1767,'0ba6ccd2-b1fa-414e-8af9-7079becfeea5','f38c267b-03a3-455d-8ebc-a26bed393ed3','2026-06-10 07:47:46',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-40-rymqidyospsq','f38c267b-03a3-455d-8ebc-a26bed393ed3','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1768,'1a6d7223-1595-4b41-a8c8-bf524a662e73','12f4deb7-b90f-43eb-af49-237b45c5213b','2026-06-10 07:47:46',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-46-idbtfvbyqdvu-RoleParametersValue-xzbu7urkiqn5','state changed','OS::Heat::Value',NULL,1080),(1769,'fc80d23e-be13-4e6f-a7d1-dd3f5bc6327e','12f4deb7-b90f-43eb-af49-237b45c5213b','2026-06-10 07:47:46',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-46-idbtfvbyqdvu-RoleParametersValue-xzbu7urkiqn5','state changed','OS::Heat::Value',NULL,1080),(1770,'8b250dce-1127-471e-b174-0533661e741a','ee995dbd-b039-414a-bb95-9d4c0abe29e6','2026-06-10 07:47:46',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-41-e3ru4kpideja-RoleParametersValue-cjnlxae7tpsn','state changed','OS::Heat::Value',NULL,1081),(1771,'0aa177c3-5abd-48e1-aeff-a3902851cd76','ee995dbd-b039-414a-bb95-9d4c0abe29e6','2026-06-10 07:47:46',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-41-e3ru4kpideja-RoleParametersValue-cjnlxae7tpsn','state changed','OS::Heat::Value',NULL,1081),(1772,'e7b64147-311d-46f7-abbb-c4a7b2c61c46','5755438d-2121-4ba8-a53a-a070ff1070f9','2026-06-10 07:47:46',NULL,'CREATE','COMPLETE','ContainersCommon','7af7a5d1-574b-4d2b-aa9c-4b46cc8c79de','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1773,'b8f22dcd-daff-422b-9c59-685f01428add','5755438d-2121-4ba8-a53a-a070ff1070f9','2026-06-10 07:47:46',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-51-vv7f5ncxyj2p','5755438d-2121-4ba8-a53a-a070ff1070f9','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1774,'6e29156b-1280-4bd9-b975-d118fd658317','12f4deb7-b90f-43eb-af49-237b45c5213b','2026-06-10 07:47:47',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-46-idbtfvbyqdvu-ContainersCommon-lm6kfvrtupb3','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1775,'02541cb0-04dc-4a01-bbeb-622549fc2766','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:47:47',NULL,'CREATE','COMPLETE','40','f38c267b-03a3-455d-8ebc-a26bed393ed3','state changed','OS::TripleO::Services::Pacemaker',NULL,1078),(1776,'984a0848-425e-4f92-ae66-1a811a6f545f','ee995dbd-b039-414a-bb95-9d4c0abe29e6','2026-06-10 07:47:47',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-41-e3ru4kpideja-MySQLClient-dppkprvt44wf','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1777,'6d8de52f-3f44-48c3-a033-b6d3a7388bda','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:47:47',NULL,'CREATE','COMPLETE','51','5755438d-2121-4ba8-a53a-a070ff1070f9','state changed','OS::TripleO::Services::SwiftStorage',NULL,1053),(1778,'aa788123-1341-438b-a29b-8e584092cfa6','e5bd182e-69ff-4a1c-af03-6cd0e8dfd9fd','2026-06-10 07:47:47',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-46-idbtfvbyqdvu-ContainersCommon-lm6kfvrtupb3','e5bd182e-69ff-4a1c-af03-6cd0e8dfd9fd','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1779,'100d8a7f-bb24-44ba-8a18-04e0f0912ba5','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:47:47',NULL,'CREATE','IN_PROGRESS','44','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-44-ky6lhf5udaps','state changed','OS::TripleO::Services::Podman',NULL,1083),(1780,'62859632-b8af-44ae-ad7d-8e12731000fe','97be4f74-ebce-4e6c-9a4e-8b113585868f','2026-06-10 07:47:47',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-41-e3ru4kpideja-MySQLClient-dppkprvt44wf','97be4f74-ebce-4e6c-9a4e-8b113585868f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1781,'7c34dea8-1296-4fc2-8884-7e8e98314204','97be4f74-ebce-4e6c-9a4e-8b113585868f','2026-06-10 07:47:47',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-41-e3ru4kpideja-MySQLClient-dppkprvt44wf','97be4f74-ebce-4e6c-9a4e-8b113585868f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1782,'04de0bba-b542-4457-9817-2b1df6e58366','e5bd182e-69ff-4a1c-af03-6cd0e8dfd9fd','2026-06-10 07:47:47',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-46-idbtfvbyqdvu-ContainersCommon-lm6kfvrtupb3','e5bd182e-69ff-4a1c-af03-6cd0e8dfd9fd','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1783,'65333d10-65f0-4303-b66f-4bb0e4f24f6d','12f4deb7-b90f-43eb-af49-237b45c5213b','2026-06-10 07:47:47',NULL,'CREATE','COMPLETE','ContainersCommon','e5bd182e-69ff-4a1c-af03-6cd0e8dfd9fd','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1784,'d22ff91c-0325-4aeb-925f-27e9129378dd','87c94329-bdb1-4c3d-8075-ac82a7d654b0','2026-06-10 07:47:47',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-44-ky6lhf5udaps','87c94329-bdb1-4c3d-8075-ac82a7d654b0','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1785,'09c8a579-1160-4c39-b941-ddb6f90684c1','12f4deb7-b90f-43eb-af49-237b45c5213b','2026-06-10 07:47:47',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-46-idbtfvbyqdvu','12f4deb7-b90f-43eb-af49-237b45c5213b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1786,'a78fc420-a719-42de-a365-1b478c170e72','87c94329-bdb1-4c3d-8075-ac82a7d654b0','2026-06-10 07:47:47',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-44-ky6lhf5udaps','87c94329-bdb1-4c3d-8075-ac82a7d654b0','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1787,'19e403f3-cd9c-49c6-87ad-76f107c6fcf8','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:47:48',NULL,'CREATE','IN_PROGRESS','55','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-55-ibxeqaq6ex3f','state changed','OS::TripleO::Services::TripleoPackages',NULL,1088),(1788,'4960e4d0-fa1b-4578-b76a-2554786cde3e','b37c4fb1-0763-4fbf-88e7-1cdd91929322','2026-06-10 07:47:48',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-55-ibxeqaq6ex3f','b37c4fb1-0763-4fbf-88e7-1cdd91929322','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1789,'67d8cbf5-3dba-4965-beff-5591587a07f1','b37c4fb1-0763-4fbf-88e7-1cdd91929322','2026-06-10 07:47:48',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-55-ibxeqaq6ex3f-RoleParametersValue-qfpeufgvwcqt','state changed','OS::Heat::Value',NULL,1089),(1790,'d9b20d3a-0417-4650-8bbf-ea628858a970','b37c4fb1-0763-4fbf-88e7-1cdd91929322','2026-06-10 07:47:48',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-55-ibxeqaq6ex3f-RoleParametersValue-qfpeufgvwcqt','state changed','OS::Heat::Value',NULL,1089),(1791,'71dfd5d4-a733-4b18-8a35-b7aa0a930b8e','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:47:48',NULL,'CREATE','COMPLETE','46','12f4deb7-b90f-43eb-af49-237b45c5213b','state changed','OS::TripleO::Services::Rsyslog',NULL,1073),(1792,'439905cf-c686-4aff-99de-098c3f302ad7','ee995dbd-b039-414a-bb95-9d4c0abe29e6','2026-06-10 07:47:48',NULL,'CREATE','IN_PROGRESS','ApacheServiceBase','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-41-e3ru4kpideja-ApacheServiceBase-swk32pxejzvs','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,1093),(1793,'b18e0948-a1ea-4847-8238-b5b270c7ce91','da5ca0fb-adf8-4ce5-adb5-f5d8d39d90e7','2026-06-10 07:47:48',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-41-e3ru4kpideja-ApacheServiceBase-swk32pxejzvs','da5ca0fb-adf8-4ce5-adb5-f5d8d39d90e7','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1794,'510bb2b7-c2c1-4e7d-970d-d780b5da6146','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:47:48',NULL,'CREATE','IN_PROGRESS','50','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-50-mowwoiwa3kd5','state changed','OS::TripleO::Services::SwiftRingBuilder',NULL,1094),(1795,'2a2ce5e1-e79d-4abf-a7fa-0fdf9c65df25','ee995dbd-b039-414a-bb95-9d4c0abe29e6','2026-06-10 07:47:48',NULL,'CREATE','COMPLETE','MySQLClient','97be4f74-ebce-4e6c-9a4e-8b113585868f','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1796,'ed1dbcd4-447a-41ae-813f-ca9362f3695d','da5ca0fb-adf8-4ce5-adb5-f5d8d39d90e7','2026-06-10 07:47:48',NULL,'CREATE','IN_PROGRESS','ApacheNetworks','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-41-e3ru4kpideja-ApacheServiceBase-swk32pxejzvs-ApacheNetworks-hreryqvcdfvl','state changed','OS::Heat::Value',NULL,1095),(1797,'44862380-4473-417d-ad9c-9285d9e6f72d','9fa209b9-33bb-41a0-907a-674a662f6e84','2026-06-10 07:47:48',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-50-mowwoiwa3kd5','9fa209b9-33bb-41a0-907a-674a662f6e84','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1798,'fda61bd5-fd4d-403a-9904-e4e6bb6b0e38','da5ca0fb-adf8-4ce5-adb5-f5d8d39d90e7','2026-06-10 07:47:48',NULL,'CREATE','COMPLETE','ApacheNetworks','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-41-e3ru4kpideja-ApacheServiceBase-swk32pxejzvs-ApacheNetworks-hreryqvcdfvl','state changed','OS::Heat::Value',NULL,1095),(1799,'de2c4f55-d60e-43e5-b229-3ddde8430882','da5ca0fb-adf8-4ce5-adb5-f5d8d39d90e7','2026-06-10 07:47:48',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-41-e3ru4kpideja-ApacheServiceBase-swk32pxejzvs','da5ca0fb-adf8-4ce5-adb5-f5d8d39d90e7','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1800,'00e880bb-3846-4c14-a540-ace3a7a436c8','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:47:48',NULL,'CREATE','COMPLETE','44','87c94329-bdb1-4c3d-8075-ac82a7d654b0','state changed','OS::TripleO::Services::Podman',NULL,1083),(1801,'25894ee2-ede3-4044-b82b-4546476bf6ea','9fa209b9-33bb-41a0-907a-674a662f6e84','2026-06-10 07:47:48',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-50-mowwoiwa3kd5-RoleParametersValue-3obgrgnfdnx6','state changed','OS::Heat::Value',NULL,1096),(1802,'7cc73182-756e-4463-868e-cfade6796604','9fa209b9-33bb-41a0-907a-674a662f6e84','2026-06-10 07:47:49',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-50-mowwoiwa3kd5-RoleParametersValue-3obgrgnfdnx6','state changed','OS::Heat::Value',NULL,1096),(1803,'31e0ba95-0a45-49d5-acbb-bfe7fef43931','9fa209b9-33bb-41a0-907a-674a662f6e84','2026-06-10 07:47:49',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-50-mowwoiwa3kd5','9fa209b9-33bb-41a0-907a-674a662f6e84','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1804,'229d9f57-2bff-4632-8fa3-ad9955bb4dd4','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:47:49',NULL,'CREATE','IN_PROGRESS','48','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-48-uldi33wuytqe','state changed','OS::TripleO::Services::Sshd',NULL,1098),(1805,'ef5a773e-929c-4d63-8292-309b91ea3fa6','1d815963-c951-4097-814c-a1f5346c60c0','2026-06-10 07:47:49',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-48-uldi33wuytqe','1d815963-c951-4097-814c-a1f5346c60c0','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1806,'4d97731d-84cd-4cc0-8778-5487b82dfcff','1d815963-c951-4097-814c-a1f5346c60c0','2026-06-10 07:47:49',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-48-uldi33wuytqe','1d815963-c951-4097-814c-a1f5346c60c0','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1807,'83ec3969-9b38-4d5d-b3d1-e56abb9af6b4','b37c4fb1-0763-4fbf-88e7-1cdd91929322','2026-06-10 07:47:49',NULL,'CREATE','IN_PROGRESS','Podman','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-55-ibxeqaq6ex3f-Podman-7333gjfhv44f','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml',NULL,1099),(1808,'a9358e08-e9bb-4bc0-a2be-de75128536ef','7c1c6881-d8c8-4be5-96e6-70b385090510','2026-06-10 07:47:49',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-55-ibxeqaq6ex3f-Podman-7333gjfhv44f','7c1c6881-d8c8-4be5-96e6-70b385090510','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1809,'fa1067da-b8fa-4e30-aa51-de29a2352c49','7c1c6881-d8c8-4be5-96e6-70b385090510','2026-06-10 07:47:49',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-55-ibxeqaq6ex3f-Podman-7333gjfhv44f','7c1c6881-d8c8-4be5-96e6-70b385090510','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1810,'121f8add-188e-4ea0-9ab0-525eaf7cee93','ee995dbd-b039-414a-bb95-9d4c0abe29e6','2026-06-10 07:47:49',NULL,'CREATE','IN_PROGRESS','PlacementLogging','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-41-e3ru4kpideja-PlacementLogging-2x2qceyndk5z','state changed','OS::TripleO::Services::Logging::PlacementApi',NULL,NULL),(1811,'28cfc2f1-4eb0-4341-a2af-c51733c14e84','6f3c9aa5-c0f7-475e-b590-6c1808aa20de','2026-06-10 07:47:49',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-41-e3ru4kpideja-PlacementLogging-2x2qceyndk5z','6f3c9aa5-c0f7-475e-b590-6c1808aa20de','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1812,'6c4e8445-a078-409a-a416-b7dd23ffa453','ee995dbd-b039-414a-bb95-9d4c0abe29e6','2026-06-10 07:47:49',NULL,'CREATE','COMPLETE','ApacheServiceBase','da5ca0fb-adf8-4ce5-adb5-f5d8d39d90e7','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,1093),(1813,'d150a4bf-2d88-4e02-97bd-f8cb3bb20368','6f3c9aa5-c0f7-475e-b590-6c1808aa20de','2026-06-10 07:47:49',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-41-e3ru4kpideja-PlacementLogging-2x2qceyndk5z-RoleParametersValue-drer7z2awmsu','state changed','OS::Heat::Value',NULL,1100),(1814,'34b8211e-b640-49fb-a8a5-9c9322998b34','6f3c9aa5-c0f7-475e-b590-6c1808aa20de','2026-06-10 07:47:49',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-41-e3ru4kpideja-PlacementLogging-2x2qceyndk5z-RoleParametersValue-drer7z2awmsu','state changed','OS::Heat::Value',NULL,1100),(1815,'ae4d4447-3b21-4de8-9600-0b777025cb57','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:47:49',NULL,'CREATE','COMPLETE','50','9fa209b9-33bb-41a0-907a-674a662f6e84','state changed','OS::TripleO::Services::SwiftRingBuilder',NULL,1094),(1816,'2ed40111-95fc-4193-85ee-975a4481135b','6f3c9aa5-c0f7-475e-b590-6c1808aa20de','2026-06-10 07:47:49',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-41-e3ru4kpideja-PlacementLogging-2x2qceyndk5z','6f3c9aa5-c0f7-475e-b590-6c1808aa20de','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1817,'4e86899d-7781-46fb-9674-50588bbfa150','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:47:50',NULL,'CREATE','IN_PROGRESS','54','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-54-vufnnzqsltwz','state changed','OS::TripleO::Services::TripleoFirewall',NULL,1103),(1818,'13728230-710c-4409-92d7-28b2691c8227','e376d465-ee4b-4b14-ad29-65dcb5025ce1','2026-06-10 07:47:50',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-54-vufnnzqsltwz','e376d465-ee4b-4b14-ad29-65dcb5025ce1','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1819,'ac1c8dcb-6de8-4591-a158-62e557ce3162','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:47:50',NULL,'CREATE','COMPLETE','48','1d815963-c951-4097-814c-a1f5346c60c0','state changed','OS::TripleO::Services::Sshd',NULL,1098),(1820,'5741264c-781f-4d36-84dc-23a2a07f3b00','e376d465-ee4b-4b14-ad29-65dcb5025ce1','2026-06-10 07:47:50',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-54-vufnnzqsltwz-RoleParametersValue-n6ao7wymuix4','state changed','OS::Heat::Value',NULL,1104),(1821,'32935483-29f5-4176-a8b3-540a7718129f','e376d465-ee4b-4b14-ad29-65dcb5025ce1','2026-06-10 07:47:50',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-54-vufnnzqsltwz-RoleParametersValue-n6ao7wymuix4','state changed','OS::Heat::Value',NULL,1104),(1822,'0d5fd06a-dd04-49c8-9f63-56a56fdf0e17','e376d465-ee4b-4b14-ad29-65dcb5025ce1','2026-06-10 07:47:50',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-54-vufnnzqsltwz','e376d465-ee4b-4b14-ad29-65dcb5025ce1','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1823,'53df700d-b7e4-432d-b77e-7223ffdcbf52','b37c4fb1-0763-4fbf-88e7-1cdd91929322','2026-06-10 07:47:50',NULL,'CREATE','COMPLETE','Podman','7c1c6881-d8c8-4be5-96e6-70b385090510','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml',NULL,1099),(1824,'c2f89ef4-7978-4448-85c7-2480001f1f9d','b37c4fb1-0763-4fbf-88e7-1cdd91929322','2026-06-10 07:47:50',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-55-ibxeqaq6ex3f','b37c4fb1-0763-4fbf-88e7-1cdd91929322','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1825,'309bc645-193b-4ae2-ad5c-5a3d9ac1cc20','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:47:50',NULL,'CREATE','IN_PROGRESS','52','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-52-ejhxo2e6vd4q','state changed','OS::TripleO::Services::Timesync',NULL,1106),(1826,'fe6910a9-31fc-47d7-8843-46cb89c554c3','a5e07282-79f3-4777-bb94-954e6fae3771','2026-06-10 07:47:50',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-52-ejhxo2e6vd4q','a5e07282-79f3-4777-bb94-954e6fae3771','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1827,'ce6df5fa-ca69-43e7-a469-f2d0d1419cae','a5e07282-79f3-4777-bb94-954e6fae3771','2026-06-10 07:47:50',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-52-ejhxo2e6vd4q','a5e07282-79f3-4777-bb94-954e6fae3771','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1828,'4acaedb0-fde6-4921-8150-22483db37de5','ee995dbd-b039-414a-bb95-9d4c0abe29e6','2026-06-10 07:47:50',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-41-e3ru4kpideja-ContainersCommon-tnv4ozfi4fp4','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1829,'2b4ddd43-d3b1-448d-beb0-6e4ea90f9149','d390f779-78f9-4047-b6b2-7ea1814db5e9','2026-06-10 07:47:50',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-41-e3ru4kpideja-ContainersCommon-tnv4ozfi4fp4','d390f779-78f9-4047-b6b2-7ea1814db5e9','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1830,'b7f44af5-1811-483e-aafa-c98182d545c4','ee995dbd-b039-414a-bb95-9d4c0abe29e6','2026-06-10 07:47:50',NULL,'CREATE','COMPLETE','PlacementLogging','6f3c9aa5-c0f7-475e-b590-6c1808aa20de','state changed','OS::TripleO::Services::Logging::PlacementApi',NULL,NULL),(1831,'0f9c0554-a6c0-47b1-9e1b-59104272bcaf','d390f779-78f9-4047-b6b2-7ea1814db5e9','2026-06-10 07:47:50',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-41-e3ru4kpideja-ContainersCommon-tnv4ozfi4fp4','d390f779-78f9-4047-b6b2-7ea1814db5e9','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1832,'8c6cc1f8-ffd5-4e97-87e4-7493f3f37591','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:47:51',NULL,'CREATE','COMPLETE','54','e376d465-ee4b-4b14-ad29-65dcb5025ce1','state changed','OS::TripleO::Services::TripleoFirewall',NULL,1103),(1833,'6b928c12-d4e4-4ee6-9c11-98c55c66bde3','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:47:51',NULL,'CREATE','COMPLETE','55','b37c4fb1-0763-4fbf-88e7-1cdd91929322','state changed','OS::TripleO::Services::TripleoPackages',NULL,1088),(1834,'aa333828-d648-49c5-abe1-00bbdbcc445b','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:47:51',NULL,'CREATE','COMPLETE','52','a5e07282-79f3-4777-bb94-954e6fae3771','state changed','OS::TripleO::Services::Timesync',NULL,1106),(1835,'4508c636-b4da-4280-a556-f17d87e7ced7','ee995dbd-b039-414a-bb95-9d4c0abe29e6','2026-06-10 07:47:51',NULL,'CREATE','COMPLETE','ContainersCommon','d390f779-78f9-4047-b6b2-7ea1814db5e9','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1836,'2b12311e-b022-4a2f-b613-64700bda6ac0','ee995dbd-b039-414a-bb95-9d4c0abe29e6','2026-06-10 07:47:51',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-41-e3ru4kpideja','ee995dbd-b039-414a-bb95-9d4c0abe29e6','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1837,'273d70df-84c8-47a9-90a0-3ecceb2355ac','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:47:52',NULL,'CREATE','IN_PROGRESS','56','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-56-wpeqszjoe7a3','state changed','OS::TripleO::Services::Tuned',NULL,1108),(1838,'4665ad56-0bf4-41c4-a7f0-ffea68bd123f','bfa0a32a-38e1-4cda-89c7-a56d97927ade','2026-06-10 07:47:52',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-56-wpeqszjoe7a3','bfa0a32a-38e1-4cda-89c7-a56d97927ade','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1839,'be11464b-8cda-4c3b-b7fb-a8c33b0ffeed','bfa0a32a-38e1-4cda-89c7-a56d97927ade','2026-06-10 07:47:52',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-56-wpeqszjoe7a3-RoleParametersValue-kxowijev2wls','state changed','OS::Heat::Value',NULL,1109),(1840,'b125ed3e-c90c-4963-bb53-1e761820c266','bfa0a32a-38e1-4cda-89c7-a56d97927ade','2026-06-10 07:47:52',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-56-wpeqszjoe7a3-RoleParametersValue-kxowijev2wls','state changed','OS::Heat::Value',NULL,1109),(1841,'4155244b-2a11-49c2-a5f1-be0c25cf0cbc','bfa0a32a-38e1-4cda-89c7-a56d97927ade','2026-06-10 07:47:52',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-56-wpeqszjoe7a3','bfa0a32a-38e1-4cda-89c7-a56d97927ade','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1842,'f8274652-9d30-44b0-b886-920650f93cc3','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:47:52',NULL,'CREATE','COMPLETE','41','ee995dbd-b039-414a-bb95-9d4c0abe29e6','state changed','OS::TripleO::Services::PlacementApi',NULL,1079),(1843,'f80fa8cb-7f41-4a1d-889c-f46ad8347745','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:47:53',NULL,'CREATE','COMPLETE','56','bfa0a32a-38e1-4cda-89c7-a56d97927ade','state changed','OS::TripleO::Services::Tuned',NULL,1108),(1844,'802c1e28-adb8-40f6-8cbe-34c47946be05','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:47:53',NULL,'CREATE','IN_PROGRESS','45','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-45-clffbptsfa5q','state changed','OS::TripleO::Services::Redis',NULL,1118),(1845,'e3698c3e-2d9b-48d1-a611-237d555731d7','b4f61765-41b2-4622-a6aa-7863239d37ea','2026-06-10 07:47:53',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-45-clffbptsfa5q','b4f61765-41b2-4622-a6aa-7863239d37ea','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1846,'b2f0f588-16d3-4a9c-9efc-9995f0694150','b4f61765-41b2-4622-a6aa-7863239d37ea','2026-06-10 07:47:53',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-45-clffbptsfa5q-ContainersCommon-itqo55jvbrsk','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1847,'4848dbe2-17e4-42d2-8b4a-2703bae20fb7','aea227fa-b6e9-4a86-a406-da3ba44d8ae9','2026-06-10 07:47:53',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-45-clffbptsfa5q-ContainersCommon-itqo55jvbrsk','aea227fa-b6e9-4a86-a406-da3ba44d8ae9','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1848,'09ba1a3c-ff4d-494e-9a72-6215844a74a9','aea227fa-b6e9-4a86-a406-da3ba44d8ae9','2026-06-10 07:47:53',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-45-clffbptsfa5q-ContainersCommon-itqo55jvbrsk','aea227fa-b6e9-4a86-a406-da3ba44d8ae9','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1849,'928ef83f-3278-4547-94d2-60460aa648b3','b4f61765-41b2-4622-a6aa-7863239d37ea','2026-06-10 07:47:54',NULL,'CREATE','IN_PROGRESS','RedisBase','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-45-clffbptsfa5q-RedisBase-qsyr76msn2xz','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-container-puppet.yaml',NULL,1119),(1850,'48a19267-b93d-4068-9606-228eb048abe3','b4f61765-41b2-4622-a6aa-7863239d37ea','2026-06-10 07:47:54',NULL,'CREATE','COMPLETE','ContainersCommon','aea227fa-b6e9-4a86-a406-da3ba44d8ae9','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1851,'f4f64e81-b294-4981-8f76-0c2a0a23c87a','8d70f2eb-bc9b-4ee0-86e6-fdf5d34ded82','2026-06-10 07:47:54',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-45-clffbptsfa5q-RedisBase-qsyr76msn2xz','8d70f2eb-bc9b-4ee0-86e6-fdf5d34ded82','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1852,'dba01d4c-fea3-4a1b-bd31-317877abf594','8d70f2eb-bc9b-4ee0-86e6-fdf5d34ded82','2026-06-10 07:47:54',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-45-clffbptsfa5q-RedisBase-qsyr76msn2xz-ContainersCommon-dtspnd4n3awe','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1853,'c20876cd-3158-4400-b1c1-9e091653a232','54acc394-3a2b-4558-b949-096ce525f068','2026-06-10 07:47:54',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-45-clffbptsfa5q-RedisBase-qsyr76msn2xz-ContainersCommon-dtspnd4n3awe','54acc394-3a2b-4558-b949-096ce525f068','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1854,'33de90a8-671a-44f2-a370-6dd7d72f9f91','54acc394-3a2b-4558-b949-096ce525f068','2026-06-10 07:47:54',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-45-clffbptsfa5q-RedisBase-qsyr76msn2xz-ContainersCommon-dtspnd4n3awe','54acc394-3a2b-4558-b949-096ce525f068','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1855,'7d2826be-b190-46b6-a8dc-0cf12b7e4249','b4f61765-41b2-4622-a6aa-7863239d37ea','2026-06-10 07:47:55',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-45-clffbptsfa5q-RoleParametersValue-lt73qsvwkdzk','state changed','OS::Heat::Value',NULL,1120),(1856,'f6ec9cd0-10a0-4828-ab00-78b7acbe5076','b4f61765-41b2-4622-a6aa-7863239d37ea','2026-06-10 07:47:55',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-45-clffbptsfa5q-RoleParametersValue-lt73qsvwkdzk','state changed','OS::Heat::Value',NULL,1120),(1857,'7038c55e-715a-4560-89c2-23a824be22bd','8d70f2eb-bc9b-4ee0-86e6-fdf5d34ded82','2026-06-10 07:47:55',NULL,'CREATE','IN_PROGRESS','RedisBase','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-45-clffbptsfa5q-RedisBase-qsyr76msn2xz-RedisBase-cacfk2kgptyk','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-base-puppet.yaml',NULL,1121),(1858,'e4c2b385-874f-4417-968b-6fe507b08a17','43c8660a-7b9f-468a-aced-c16098a262d4','2026-06-10 07:47:55',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-45-clffbptsfa5q-RedisBase-qsyr76msn2xz-RedisBase-cacfk2kgptyk','43c8660a-7b9f-468a-aced-c16098a262d4','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1859,'de7c56a4-fe1a-4337-9b46-6d47f234a2b6','8d70f2eb-bc9b-4ee0-86e6-fdf5d34ded82','2026-06-10 07:47:55',NULL,'CREATE','COMPLETE','ContainersCommon','54acc394-3a2b-4558-b949-096ce525f068','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1860,'7c2131e0-cf0b-479a-8dc6-4ee43cb280a8','43c8660a-7b9f-468a-aced-c16098a262d4','2026-06-10 07:47:55',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-45-clffbptsfa5q-RedisBase-qsyr76msn2xz-RedisBase-cacfk2kgptyk','43c8660a-7b9f-468a-aced-c16098a262d4','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1861,'c97bd087-065d-48e8-ba4c-7e7139f5c8c3','8d70f2eb-bc9b-4ee0-86e6-fdf5d34ded82','2026-06-10 07:47:56',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-45-clffbptsfa5q-RedisBase-qsyr76msn2xz-RoleParametersValue-d6uiqexwvsxj','state changed','OS::Heat::Value',NULL,1122),(1862,'7ef1cc21-029f-4245-b7aa-5cc6674d28b0','8d70f2eb-bc9b-4ee0-86e6-fdf5d34ded82','2026-06-10 07:47:56',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-45-clffbptsfa5q-RedisBase-qsyr76msn2xz-RoleParametersValue-d6uiqexwvsxj','state changed','OS::Heat::Value',NULL,1122),(1863,'593ab30a-d723-4df0-9999-a0cba217706a','8d70f2eb-bc9b-4ee0-86e6-fdf5d34ded82','2026-06-10 07:47:56',NULL,'CREATE','COMPLETE','RedisBase','43c8660a-7b9f-468a-aced-c16098a262d4','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-base-puppet.yaml',NULL,1121),(1864,'c997714e-a8ee-4237-bc9a-8c5ba2831855','8d70f2eb-bc9b-4ee0-86e6-fdf5d34ded82','2026-06-10 07:47:56',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-45-clffbptsfa5q-RedisBase-qsyr76msn2xz','8d70f2eb-bc9b-4ee0-86e6-fdf5d34ded82','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1865,'c1aefb2c-b3ed-45b8-ba6b-0df00fa6ab68','b4f61765-41b2-4622-a6aa-7863239d37ea','2026-06-10 07:47:57',NULL,'CREATE','COMPLETE','RedisBase','8d70f2eb-bc9b-4ee0-86e6-fdf5d34ded82','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-container-puppet.yaml',NULL,1119),(1866,'dc9181c2-86ed-439a-984c-606269c5bfa7','b4f61765-41b2-4622-a6aa-7863239d37ea','2026-06-10 07:47:57',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-45-clffbptsfa5q','b4f61765-41b2-4622-a6aa-7863239d37ea','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1867,'09175e11-bf52-4bae-952d-b641c87d0ea1','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:47:58',NULL,'CREATE','COMPLETE','45','b4f61765-41b2-4622-a6aa-7863239d37ea','state changed','OS::TripleO::Services::Redis',NULL,1118),(1868,'1755c91b-8b98-4b5a-b26d-96d0d25cd54e','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:47:58',NULL,'CREATE','IN_PROGRESS','49','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-49-4ptpsqu43t3s','state changed','OS::TripleO::Services::SwiftProxy',NULL,1130),(1869,'40e164d5-f2cc-4f26-a922-4dbeb131c79a','895c53a5-5ea7-4d19-95ba-bfd4676ff4d7','2026-06-10 07:47:58',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-49-4ptpsqu43t3s','895c53a5-5ea7-4d19-95ba-bfd4676ff4d7','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1870,'4deb7eae-649e-4608-8482-4efffe746f75','895c53a5-5ea7-4d19-95ba-bfd4676ff4d7','2026-06-10 07:47:59',NULL,'CREATE','IN_PROGRESS','TLSProxyBase','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-49-4ptpsqu43t3s-TLSProxyBase-iysuv7sconh4','state changed','OS::TripleO::Services::TLSProxyBase',NULL,NULL),(1871,'6fcf472f-1a6e-4944-be3b-121332d70936','895c53a5-5ea7-4d19-95ba-bfd4676ff4d7','2026-06-10 07:47:59',NULL,'CREATE','COMPLETE','TLSProxyBase','acf1e0f9-2f01-4fef-904d-6fa0cc98d447','state changed','OS::TripleO::Services::TLSProxyBase',NULL,NULL),(1872,'176686a5-dac9-4a49-8fa5-c76323d1b2be','895c53a5-5ea7-4d19-95ba-bfd4676ff4d7','2026-06-10 07:48:00',NULL,'CREATE','IN_PROGRESS','SwiftBase','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-49-4ptpsqu43t3s-SwiftBase-ql6g5itybk44','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-base.yaml',NULL,1131),(1873,'2337f1f9-e30b-43b1-9488-424a7e250657','da2e01a9-29f7-4dd3-b83c-45de99314dc7','2026-06-10 07:48:00',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-49-4ptpsqu43t3s-SwiftBase-ql6g5itybk44','da2e01a9-29f7-4dd3-b83c-45de99314dc7','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1874,'8e319506-d4d5-4456-a65c-3460b77508da','da2e01a9-29f7-4dd3-b83c-45de99314dc7','2026-06-10 07:48:00',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-49-4ptpsqu43t3s-SwiftBase-ql6g5itybk44','da2e01a9-29f7-4dd3-b83c-45de99314dc7','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1875,'13ce0cfb-2ebc-412b-85cf-2a26c30602b8','895c53a5-5ea7-4d19-95ba-bfd4676ff4d7','2026-06-10 07:48:01',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-49-4ptpsqu43t3s-RoleParametersValue-6s623s3ocr52','state changed','OS::Heat::Value',NULL,1132),(1876,'df9779aa-351d-4340-bca2-8ce0c46c382c','895c53a5-5ea7-4d19-95ba-bfd4676ff4d7','2026-06-10 07:48:01',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-49-4ptpsqu43t3s-RoleParametersValue-6s623s3ocr52','state changed','OS::Heat::Value',NULL,1132),(1877,'2795ca35-3292-4a22-944f-2e33eb4666d4','895c53a5-5ea7-4d19-95ba-bfd4676ff4d7','2026-06-10 07:48:01',NULL,'CREATE','COMPLETE','SwiftBase','da2e01a9-29f7-4dd3-b83c-45de99314dc7','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-base.yaml',NULL,1131),(1878,'cbedabd9-d379-4e6f-8170-a353588e6519','895c53a5-5ea7-4d19-95ba-bfd4676ff4d7','2026-06-10 07:48:02',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-49-4ptpsqu43t3s-ContainersCommon-qqkbtdafduas','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1879,'533136ca-ec61-445f-a081-6bb592f2673b','a372c54d-6c60-47a6-9a83-b100504ac54f','2026-06-10 07:48:02',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-49-4ptpsqu43t3s-ContainersCommon-qqkbtdafduas','a372c54d-6c60-47a6-9a83-b100504ac54f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1880,'815e2663-bc33-4bf9-891f-d31f6e55cc52','a372c54d-6c60-47a6-9a83-b100504ac54f','2026-06-10 07:48:02',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-49-4ptpsqu43t3s-ContainersCommon-qqkbtdafduas','a372c54d-6c60-47a6-9a83-b100504ac54f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1881,'aeb60045-5efc-4ef0-aae6-04ca398266e6','895c53a5-5ea7-4d19-95ba-bfd4676ff4d7','2026-06-10 07:48:03',NULL,'CREATE','COMPLETE','ContainersCommon','a372c54d-6c60-47a6-9a83-b100504ac54f','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1882,'0adbc2bd-abae-404e-bd44-eb830757d7d8','895c53a5-5ea7-4d19-95ba-bfd4676ff4d7','2026-06-10 07:48:03',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-49-4ptpsqu43t3s','895c53a5-5ea7-4d19-95ba-bfd4676ff4d7','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1883,'022bc919-fa37-4bff-bb34-ab2655815d41','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:48:03',NULL,'CREATE','COMPLETE','49','895c53a5-5ea7-4d19-95ba-bfd4676ff4d7','state changed','OS::TripleO::Services::SwiftProxy',NULL,1130),(1884,'47fef5b5-95c7-47cc-b173-fea39aac78a0','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:48:04',NULL,'CREATE','IN_PROGRESS','53','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-53-vscqh5lgwtuj','state changed','OS::TripleO::Services::Timezone',NULL,1138),(1885,'a99a7f8a-9240-42ef-b198-837af72baf4d','2f50087d-c4ee-4115-8741-f68f047cb418','2026-06-10 07:48:04',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-53-vscqh5lgwtuj','2f50087d-c4ee-4115-8741-f68f047cb418','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1886,'b839f3bf-ccdb-40e6-aefd-515e1e80048a','2f50087d-c4ee-4115-8741-f68f047cb418','2026-06-10 07:48:04',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4-53-vscqh5lgwtuj','2f50087d-c4ee-4115-8741-f68f047cb418','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1887,'2bf22e8b-5fe5-4f8a-a9b3-4493dc4a5210','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:48:05',NULL,'CREATE','COMPLETE','53','2f50087d-c4ee-4115-8741-f68f047cb418','state changed','OS::TripleO::Services::Timezone',NULL,1138),(1888,'b82cd7db-d07c-4076-8228-b02ec6f807aa','418cb07f-f8ef-4b77-a27d-29311653bd9d','2026-06-10 07:48:05',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceChain-ch5txals2in4','418cb07f-f8ef-4b77-a27d-29311653bd9d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1889,'672e6619-e9b0-41fd-a5ad-c36c2714fd3e','67454241-df97-4bc4-ba26-4f82633996c2','2026-06-10 07:48:05',NULL,'CREATE','COMPLETE','ServiceChain','418cb07f-f8ef-4b77-a27d-29311653bd9d','state changed','OS::Heat::ResourceChain',NULL,88),(1890,'630ad5e2-fde8-46fa-a8fe-18e48c45982b','67454241-df97-4bc4-ba26-4f82633996c2','2026-06-10 07:48:07',NULL,'CREATE','IN_PROGRESS','ContainerPuppetTasks','overcloud-ControllerServiceChain-ym5qnskzqqum-ContainerPuppetTasks-fpiktt2ixmwy','state changed','OS::Heat::Value',NULL,1147),(1891,'68fde59e-f0fe-46a4-847e-846987bf0dbb','67454241-df97-4bc4-ba26-4f82633996c2','2026-06-10 07:48:07',NULL,'CREATE','COMPLETE','ContainerPuppetTasks','overcloud-ControllerServiceChain-ym5qnskzqqum-ContainerPuppetTasks-fpiktt2ixmwy','state changed','OS::Heat::Value',NULL,1147),(1892,'22c93032-ff67-4fdb-a624-06a568ef2987','67454241-df97-4bc4-ba26-4f82633996c2','2026-06-10 07:48:07',NULL,'CREATE','IN_PROGRESS','UpdateTasks','overcloud-ControllerServiceChain-ym5qnskzqqum-UpdateTasks-s7h3wubqgnrd','state changed','OS::Heat::Value',NULL,1148),(1893,'ab885030-91fb-48b4-bc3e-a18efee9556b','67454241-df97-4bc4-ba26-4f82633996c2','2026-06-10 07:48:07',NULL,'CREATE','COMPLETE','UpdateTasks','overcloud-ControllerServiceChain-ym5qnskzqqum-UpdateTasks-s7h3wubqgnrd','state changed','OS::Heat::Value',NULL,1148),(1894,'22c35b17-0f2c-48c0-a8e7-21bd2ee6ae1d','67454241-df97-4bc4-ba26-4f82633996c2','2026-06-10 07:48:07',NULL,'CREATE','IN_PROGRESS','FirewallFrontendRules','overcloud-ControllerServiceChain-ym5qnskzqqum-FirewallFrontendRules-em7dgbvg2foa','state changed','OS::Heat::Value',NULL,1149),(1895,'a3d0bbca-840f-482e-b694-10273545cf9d','67454241-df97-4bc4-ba26-4f82633996c2','2026-06-10 07:48:08',NULL,'CREATE','IN_PROGRESS','KeystoneResourcesConfigs','overcloud-ControllerServiceChain-ym5qnskzqqum-KeystoneResourcesConfigs-eg4lywwrlcum','state changed','OS::Heat::Value',NULL,1150),(1896,'53742db6-4ff4-46ce-bb7b-90c6bc3614ea','67454241-df97-4bc4-ba26-4f82633996c2','2026-06-10 07:48:08',NULL,'CREATE','COMPLETE','FirewallFrontendRules','overcloud-ControllerServiceChain-ym5qnskzqqum-FirewallFrontendRules-em7dgbvg2foa','state changed','OS::Heat::Value',NULL,1149),(1897,'fedca5ee-06b3-4fc1-bb31-7b7258598e16','67454241-df97-4bc4-ba26-4f82633996c2','2026-06-10 07:48:08',NULL,'CREATE','IN_PROGRESS','UpgradeTasks','overcloud-ControllerServiceChain-ym5qnskzqqum-UpgradeTasks-6ma6yobuopxo','state changed','OS::Heat::Value',NULL,1151),(1898,'10454bf1-8095-45ba-8e4c-8d6a5a9bbd56','67454241-df97-4bc4-ba26-4f82633996c2','2026-06-10 07:48:08',NULL,'CREATE','COMPLETE','KeystoneResourcesConfigs','overcloud-ControllerServiceChain-ym5qnskzqqum-KeystoneResourcesConfigs-eg4lywwrlcum','state changed','OS::Heat::Value',NULL,1150),(1899,'c1e32381-ad58-473d-8498-f3f3e525859e','67454241-df97-4bc4-ba26-4f82633996c2','2026-06-10 07:48:08',NULL,'CREATE','COMPLETE','UpgradeTasks','overcloud-ControllerServiceChain-ym5qnskzqqum-UpgradeTasks-6ma6yobuopxo','state changed','OS::Heat::Value',NULL,1151),(1900,'4eb54b09-6932-42b6-97a0-ebda8840d9b6','67454241-df97-4bc4-ba26-4f82633996c2','2026-06-10 07:48:09',NULL,'CREATE','IN_PROGRESS','ExternalUpgradeTasks','overcloud-ControllerServiceChain-ym5qnskzqqum-ExternalUpgradeTasks-g5ueugm3qkd2','state changed','OS::Heat::Value',NULL,1153),(1901,'36068f1b-66b9-4e9a-8b25-df7858b4be3c','67454241-df97-4bc4-ba26-4f82633996c2','2026-06-10 07:48:09',NULL,'CREATE','IN_PROGRESS','AnsibleGroupVars','overcloud-ControllerServiceChain-ym5qnskzqqum-AnsibleGroupVars-hmiour73k2xj','state changed','OS::Heat::Value',NULL,1152),(1902,'2b30bd70-cbf3-4240-9f66-42927b3f486c','67454241-df97-4bc4-ba26-4f82633996c2','2026-06-10 07:48:09',NULL,'CREATE','COMPLETE','AnsibleGroupVars','overcloud-ControllerServiceChain-ym5qnskzqqum-AnsibleGroupVars-hmiour73k2xj','state changed','OS::Heat::Value',NULL,1152),(1903,'27fb5111-1ef1-48d9-8213-5e901fb6568e','67454241-df97-4bc4-ba26-4f82633996c2','2026-06-10 07:48:09',NULL,'CREATE','COMPLETE','ExternalUpgradeTasks','overcloud-ControllerServiceChain-ym5qnskzqqum-ExternalUpgradeTasks-g5ueugm3qkd2','state changed','OS::Heat::Value',NULL,1153),(1904,'d57b512c-4320-4257-bf4e-7f067fc6e752','67454241-df97-4bc4-ba26-4f82633996c2','2026-06-10 07:48:09',NULL,'CREATE','IN_PROGRESS','ExternalDeployTasks','overcloud-ControllerServiceChain-ym5qnskzqqum-ExternalDeployTasks-w5n4px5hsqg2','state changed','OS::Heat::Value',NULL,1154),(1905,'eafdee82-35c7-44b2-a659-5a19753c3f3c','67454241-df97-4bc4-ba26-4f82633996c2','2026-06-10 07:48:09',NULL,'CREATE','IN_PROGRESS','PuppetConfig','overcloud-ControllerServiceChain-ym5qnskzqqum-PuppetConfig-xyroqdktqpc4','state changed','OS::Heat::Value',NULL,1155),(1906,'c1a562b9-af90-4664-9bd0-d63c8ccf7bbe','67454241-df97-4bc4-ba26-4f82633996c2','2026-06-10 07:48:09',NULL,'CREATE','COMPLETE','PuppetConfig','overcloud-ControllerServiceChain-ym5qnskzqqum-PuppetConfig-xyroqdktqpc4','state changed','OS::Heat::Value',NULL,1155),(1907,'d35a1623-021f-42d3-99aa-284ac5a4af55','67454241-df97-4bc4-ba26-4f82633996c2','2026-06-10 07:48:09',NULL,'CREATE','COMPLETE','ExternalDeployTasks','overcloud-ControllerServiceChain-ym5qnskzqqum-ExternalDeployTasks-w5n4px5hsqg2','state changed','OS::Heat::Value',NULL,1154),(1908,'48043147-f853-4160-9122-6ac9b96a5b5d','67454241-df97-4bc4-ba26-4f82633996c2','2026-06-10 07:48:09',NULL,'CREATE','IN_PROGRESS','DockerConfigScripts','overcloud-ControllerServiceChain-ym5qnskzqqum-DockerConfigScripts-u3oivtjwpklf','state changed','OS::Heat::Value',NULL,1156),(1909,'1b162d8f-7365-4c42-90f1-ff59aa90b8a5','67454241-df97-4bc4-ba26-4f82633996c2','2026-06-10 07:48:09',NULL,'CREATE','COMPLETE','DockerConfigScripts','overcloud-ControllerServiceChain-ym5qnskzqqum-DockerConfigScripts-u3oivtjwpklf','state changed','OS::Heat::Value',NULL,1156),(1910,'92851b9a-96b5-462d-9502-cc43d6715d1d','67454241-df97-4bc4-ba26-4f82633996c2','2026-06-10 07:48:09',NULL,'CREATE','IN_PROGRESS','GlobalConfigSettings','overcloud-ControllerServiceChain-ym5qnskzqqum-GlobalConfigSettings-ioov43mjx2kb','state changed','OS::Heat::Value',NULL,1157),(1911,'69433458-a815-4474-aa6e-e59b832c0518','67454241-df97-4bc4-ba26-4f82633996c2','2026-06-10 07:48:10',NULL,'CREATE','COMPLETE','GlobalConfigSettings','overcloud-ControllerServiceChain-ym5qnskzqqum-GlobalConfigSettings-ioov43mjx2kb','state changed','OS::Heat::Value',NULL,1157),(1912,'963685c9-93d3-4114-a4e4-7c5da22a98b2','67454241-df97-4bc4-ba26-4f82633996c2','2026-06-10 07:48:10',NULL,'CREATE','IN_PROGRESS','DockerPuppetTasks','overcloud-ControllerServiceChain-ym5qnskzqqum-DockerPuppetTasks-b5jtvte3tvxa','state changed','OS::Heat::Value',NULL,1158),(1913,'de2f0922-ad82-4270-a6fe-543b7d895ecf','67454241-df97-4bc4-ba26-4f82633996c2','2026-06-10 07:48:10',NULL,'CREATE','IN_PROGRESS','DockerConfig','overcloud-ControllerServiceChain-ym5qnskzqqum-DockerConfig-ziqjjvlvujya','state changed','OS::Heat::Value',NULL,1159),(1914,'a256a022-8a42-43f0-9ae1-f1ae27dd4c27','67454241-df97-4bc4-ba26-4f82633996c2','2026-06-10 07:48:10',NULL,'CREATE','COMPLETE','DockerConfig','overcloud-ControllerServiceChain-ym5qnskzqqum-DockerConfig-ziqjjvlvujya','state changed','OS::Heat::Value',NULL,1159),(1915,'b05e9c4d-6dc7-41bf-8914-fda03b42d4ed','67454241-df97-4bc4-ba26-4f82633996c2','2026-06-10 07:48:10',NULL,'CREATE','COMPLETE','DockerPuppetTasks','overcloud-ControllerServiceChain-ym5qnskzqqum-DockerPuppetTasks-b5jtvte3tvxa','state changed','OS::Heat::Value',NULL,1158),(1916,'14118507-21e6-4d7c-9e33-2954ce467c10','67454241-df97-4bc4-ba26-4f82633996c2','2026-06-10 07:48:10',NULL,'CREATE','IN_PROGRESS','ServiceNames','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceNames-6ji5krie6sbt','state changed','OS::Heat::Value',NULL,1160),(1917,'3c99e38a-f458-4066-8fef-963ac9f0637c','67454241-df97-4bc4-ba26-4f82633996c2','2026-06-10 07:48:10',NULL,'CREATE','COMPLETE','ServiceNames','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceNames-6ji5krie6sbt','state changed','OS::Heat::Value',NULL,1160),(1918,'15624650-b855-469a-a6ce-9637e0ea84da','67454241-df97-4bc4-ba26-4f82633996c2','2026-06-10 07:48:10',NULL,'CREATE','IN_PROGRESS','PreUpgradeRollingTasks','overcloud-ControllerServiceChain-ym5qnskzqqum-PreUpgradeRollingTasks-nwcejawcfuh4','state changed','OS::Heat::Value',NULL,1161),(1919,'216a4a04-741f-4063-b0d2-5b26355ba606','67454241-df97-4bc4-ba26-4f82633996c2','2026-06-10 07:48:10',NULL,'CREATE','COMPLETE','PreUpgradeRollingTasks','overcloud-ControllerServiceChain-ym5qnskzqqum-PreUpgradeRollingTasks-nwcejawcfuh4','state changed','OS::Heat::Value',NULL,1161),(1920,'7b5ef7c6-c137-45c1-aad1-280190134747','67454241-df97-4bc4-ba26-4f82633996c2','2026-06-10 07:48:11',NULL,'CREATE','IN_PROGRESS','PostUpdateTasks','overcloud-ControllerServiceChain-ym5qnskzqqum-PostUpdateTasks-obis2gkmsk62','state changed','OS::Heat::Value',NULL,1162),(1921,'458ce0e1-3786-43eb-9b14-7a8227520bc2','67454241-df97-4bc4-ba26-4f82633996c2','2026-06-10 07:48:11',NULL,'CREATE','IN_PROGRESS','HostFirewallTasks','overcloud-ControllerServiceChain-ym5qnskzqqum-HostFirewallTasks-7lucdkisdldv','state changed','OS::Heat::Value',NULL,1163),(1922,'148cf026-c484-47e2-b55a-12e5f0f712ca','67454241-df97-4bc4-ba26-4f82633996c2','2026-06-10 07:48:11',NULL,'CREATE','COMPLETE','HostFirewallTasks','overcloud-ControllerServiceChain-ym5qnskzqqum-HostFirewallTasks-7lucdkisdldv','state changed','OS::Heat::Value',NULL,1163),(1923,'309d7c3b-989c-46c2-a357-43a40d34d15d','67454241-df97-4bc4-ba26-4f82633996c2','2026-06-10 07:48:11',NULL,'CREATE','COMPLETE','PostUpdateTasks','overcloud-ControllerServiceChain-ym5qnskzqqum-PostUpdateTasks-obis2gkmsk62','state changed','OS::Heat::Value',NULL,1162),(1924,'d297ee0c-a74e-4bc5-a51a-c4235eab55ec','67454241-df97-4bc4-ba26-4f82633996c2','2026-06-10 07:48:11',NULL,'CREATE','IN_PROGRESS','MonitoringSubscriptionsConfig','overcloud-ControllerServiceChain-ym5qnskzqqum-MonitoringSubscriptionsConfig-v7ywrl5bgonw','state changed','OS::Heat::Value',NULL,1164),(1925,'19b5fe88-8ce3-4e2e-aef6-e915fd08d863','67454241-df97-4bc4-ba26-4f82633996c2','2026-06-10 07:48:11',NULL,'CREATE','COMPLETE','MonitoringSubscriptionsConfig','overcloud-ControllerServiceChain-ym5qnskzqqum-MonitoringSubscriptionsConfig-v7ywrl5bgonw','state changed','OS::Heat::Value',NULL,1164),(1926,'49db7a53-56ca-4ddf-93bf-6074bcc8f96a','67454241-df97-4bc4-ba26-4f82633996c2','2026-06-10 07:48:11',NULL,'CREATE','IN_PROGRESS','ExternalUpdateTasks','overcloud-ControllerServiceChain-ym5qnskzqqum-ExternalUpdateTasks-up3lw3ys7tp4','state changed','OS::Heat::Value',NULL,1165),(1927,'1f5553e3-0541-4744-afd2-14420dec4f6b','67454241-df97-4bc4-ba26-4f82633996c2','2026-06-10 07:48:11',NULL,'CREATE','COMPLETE','ExternalUpdateTasks','overcloud-ControllerServiceChain-ym5qnskzqqum-ExternalUpdateTasks-up3lw3ys7tp4','state changed','OS::Heat::Value',NULL,1165),(1928,'d9054dea-416b-47ec-8e6e-dfd5c58c77e6','67454241-df97-4bc4-ba26-4f82633996c2','2026-06-10 07:48:12',NULL,'CREATE','IN_PROGRESS','KollaConfig','overcloud-ControllerServiceChain-ym5qnskzqqum-KollaConfig-mpfkkcakzf2e','state changed','OS::Heat::Value',NULL,1166),(1929,'c3ad2651-b351-4223-9f24-b4ca10e75ada','67454241-df97-4bc4-ba26-4f82633996c2','2026-06-10 07:48:12',NULL,'CREATE','IN_PROGRESS','ScaleTasks','overcloud-ControllerServiceChain-ym5qnskzqqum-ScaleTasks-7h6hpghrch3l','state changed','OS::Heat::Value',NULL,1167),(1930,'6ed19e05-4400-4f81-b4ce-67c79637cdef','67454241-df97-4bc4-ba26-4f82633996c2','2026-06-10 07:48:12',NULL,'CREATE','COMPLETE','ScaleTasks','overcloud-ControllerServiceChain-ym5qnskzqqum-ScaleTasks-7h6hpghrch3l','state changed','OS::Heat::Value',NULL,1167),(1931,'779e591a-6959-4e68-8b9e-14f8ee293386','67454241-df97-4bc4-ba26-4f82633996c2','2026-06-10 07:48:12',NULL,'CREATE','COMPLETE','KollaConfig','overcloud-ControllerServiceChain-ym5qnskzqqum-KollaConfig-mpfkkcakzf2e','state changed','OS::Heat::Value',NULL,1166),(1932,'5dcd8770-7860-46f0-b6d0-7d3445cd0372','67454241-df97-4bc4-ba26-4f82633996c2','2026-06-10 07:48:12',NULL,'CREATE','IN_PROGRESS','ServiceServerMetadataHook','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceServerMetadataHook-oy5n4edwgrau','state changed','OS::TripleO::ControllerServiceServerMetadataHook',NULL,NULL),(1933,'7fb327a2-3143-4ac6-92ab-7a6fcd9d5573','67454241-df97-4bc4-ba26-4f82633996c2','2026-06-10 07:48:12',NULL,'CREATE','COMPLETE','ServiceServerMetadataHook','fc42de74-f96c-4892-b2b4-1d3a6fff0580','state changed','OS::TripleO::ControllerServiceServerMetadataHook',NULL,NULL),(1934,'d160e79e-ab51-46f9-9f36-25f6f38f3829','67454241-df97-4bc4-ba26-4f82633996c2','2026-06-10 07:48:12',NULL,'CREATE','IN_PROGRESS','PostUpgradeTasks','overcloud-ControllerServiceChain-ym5qnskzqqum-PostUpgradeTasks-wn6i7bxtwucf','state changed','OS::Heat::Value',NULL,1168),(1935,'68f50d52-f465-4687-aa54-41c7662a5825','67454241-df97-4bc4-ba26-4f82633996c2','2026-06-10 07:48:12',NULL,'CREATE','COMPLETE','PostUpgradeTasks','overcloud-ControllerServiceChain-ym5qnskzqqum-PostUpgradeTasks-wn6i7bxtwucf','state changed','OS::Heat::Value',NULL,1168),(1936,'c75edff6-3342-42e0-924d-68b56c23e855','67454241-df97-4bc4-ba26-4f82633996c2','2026-06-10 07:48:12',NULL,'CREATE','IN_PROGRESS','PreDeployStepTasks','overcloud-ControllerServiceChain-ym5qnskzqqum-PreDeployStepTasks-lyoksn5g66x5','state changed','OS::Heat::Value',NULL,1169),(1937,'6b06a622-afe5-446f-b376-eb5296f94b4e','67454241-df97-4bc4-ba26-4f82633996c2','2026-06-10 07:48:12',NULL,'CREATE','IN_PROGRESS','HostPrepTasks','overcloud-ControllerServiceChain-ym5qnskzqqum-HostPrepTasks-q6hoxbkgyyzx','state changed','OS::Heat::Value',NULL,1170),(1938,'c0a9c423-e1f2-4618-b23f-a231e9e935b9','67454241-df97-4bc4-ba26-4f82633996c2','2026-06-10 07:48:12',NULL,'CREATE','COMPLETE','PreDeployStepTasks','overcloud-ControllerServiceChain-ym5qnskzqqum-PreDeployStepTasks-lyoksn5g66x5','state changed','OS::Heat::Value',NULL,1169),(1939,'3c3b8d20-5dde-43cc-9476-9e1fe30b25d0','67454241-df97-4bc4-ba26-4f82633996c2','2026-06-10 07:48:13',NULL,'CREATE','COMPLETE','HostPrepTasks','overcloud-ControllerServiceChain-ym5qnskzqqum-HostPrepTasks-q6hoxbkgyyzx','state changed','OS::Heat::Value',NULL,1170),(1940,'bbef6ec8-f7d1-4569-8f6e-b507b8a3f539','67454241-df97-4bc4-ba26-4f82633996c2','2026-06-10 07:48:13',NULL,'CREATE','IN_PROGRESS','DeployStepsTasks','overcloud-ControllerServiceChain-ym5qnskzqqum-DeployStepsTasks-lxx52upc2rws','state changed','OS::Heat::Value',NULL,1171),(1941,'caaafa83-ecef-417e-a516-14460de1bd60','67454241-df97-4bc4-ba26-4f82633996c2','2026-06-10 07:48:13',NULL,'CREATE','COMPLETE','DeployStepsTasks','overcloud-ControllerServiceChain-ym5qnskzqqum-DeployStepsTasks-lxx52upc2rws','state changed','OS::Heat::Value',NULL,1171),(1942,'66bc4462-2759-4f1e-91dd-2c0f90e63194','67454241-df97-4bc4-ba26-4f82633996c2','2026-06-10 07:48:13',NULL,'CREATE','IN_PROGRESS','FirewallRules','overcloud-ControllerServiceChain-ym5qnskzqqum-FirewallRules-kfqifkwsgjbs','state changed','OS::Heat::Value',NULL,1172),(1943,'47eb606d-f9f4-4ac7-adc7-624c2ddf4f31','67454241-df97-4bc4-ba26-4f82633996c2','2026-06-10 07:48:13',NULL,'CREATE','COMPLETE','FirewallRules','overcloud-ControllerServiceChain-ym5qnskzqqum-FirewallRules-kfqifkwsgjbs','state changed','OS::Heat::Value',NULL,1172),(1944,'1de174dd-8db0-465b-89f4-bfbae5036b09','67454241-df97-4bc4-ba26-4f82633996c2','2026-06-10 07:48:13',NULL,'CREATE','IN_PROGRESS','IpaRegistrationTasks','overcloud-ControllerServiceChain-ym5qnskzqqum-IpaRegistrationTasks-r65e3e4shprm','state changed','OS::Heat::Value',NULL,1173),(1945,'660525c2-b4dc-4d5b-b6ef-abc9cbdea498','67454241-df97-4bc4-ba26-4f82633996c2','2026-06-10 07:48:13',NULL,'CREATE','IN_PROGRESS','PuppetStepConfig','overcloud-ControllerServiceChain-ym5qnskzqqum-PuppetStepConfig-ozn4azjxrvvc','state changed','OS::Heat::Value',NULL,1174),(1946,'fa9daacd-8d82-47b4-b17c-de8f726fb1eb','67454241-df97-4bc4-ba26-4f82633996c2','2026-06-10 07:48:13',NULL,'CREATE','COMPLETE','PuppetStepConfig','overcloud-ControllerServiceChain-ym5qnskzqqum-PuppetStepConfig-ozn4azjxrvvc','state changed','OS::Heat::Value',NULL,1174),(1947,'80170c54-067e-4a3a-848d-86efd2c7e897','67454241-df97-4bc4-ba26-4f82633996c2','2026-06-10 07:48:13',NULL,'CREATE','IN_PROGRESS','UpgradeBatchTasks','overcloud-ControllerServiceChain-ym5qnskzqqum-UpgradeBatchTasks-ahcbf6sm6y76','state changed','OS::Heat::Value',NULL,1175),(1948,'27a96037-ec48-4909-ae27-f8bbef83c2e1','67454241-df97-4bc4-ba26-4f82633996c2','2026-06-10 07:48:13',NULL,'CREATE','COMPLETE','IpaRegistrationTasks','overcloud-ControllerServiceChain-ym5qnskzqqum-IpaRegistrationTasks-r65e3e4shprm','state changed','OS::Heat::Value',NULL,1173),(1949,'c3f6f0f8-0df7-44fe-9032-5f5500039a1c','67454241-df97-4bc4-ba26-4f82633996c2','2026-06-10 07:48:13',NULL,'CREATE','COMPLETE','UpgradeBatchTasks','overcloud-ControllerServiceChain-ym5qnskzqqum-UpgradeBatchTasks-ahcbf6sm6y76','state changed','OS::Heat::Value',NULL,1175),(1950,'e238a966-00c3-49a8-913c-7e57493e6317','67454241-df97-4bc4-ba26-4f82633996c2','2026-06-10 07:48:14',NULL,'CREATE','IN_PROGRESS','ExternalPostDeployTasks','overcloud-ControllerServiceChain-ym5qnskzqqum-ExternalPostDeployTasks-x2axfu23o32m','state changed','OS::Heat::Value',NULL,1176),(1951,'c9c99d2f-4ddb-45df-9ebe-3ffe1c11d597','67454241-df97-4bc4-ba26-4f82633996c2','2026-06-10 07:48:14',NULL,'CREATE','COMPLETE','ExternalPostDeployTasks','overcloud-ControllerServiceChain-ym5qnskzqqum-ExternalPostDeployTasks-x2axfu23o32m','state changed','OS::Heat::Value',NULL,1176),(1952,'f0cdaf92-de26-4866-931b-ab8597ac8880','67454241-df97-4bc4-ba26-4f82633996c2','2026-06-10 07:48:14',NULL,'CREATE','IN_PROGRESS','ServiceConfigSettings','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceConfigSettings-o22hydc5ahwz','state changed','OS::Heat::Value',NULL,1178),(1953,'899c88b3-1ae1-4c29-8835-26002b805134','67454241-df97-4bc4-ba26-4f82633996c2','2026-06-10 07:48:14',NULL,'CREATE','COMPLETE','ServiceConfigSettings','overcloud-ControllerServiceChain-ym5qnskzqqum-ServiceConfigSettings-o22hydc5ahwz','state changed','OS::Heat::Value',NULL,1178),(1954,'47b47a90-6b32-422e-8ec7-d6713a4a705f','67454241-df97-4bc4-ba26-4f82633996c2','2026-06-10 07:48:14',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-ym5qnskzqqum','67454241-df97-4bc4-ba26-4f82633996c2','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1955,'06a18c4a-c50e-4b86-8fec-74e93d5af6e5','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:48:14',NULL,'CREATE','COMPLETE','ControllerServiceChain','67454241-df97-4bc4-ba26-4f82633996c2','state changed','OS::TripleO::ControllerServices',NULL,80),(1956,'255eac5b-6cb1-4e71-bbb0-15b000f285f6','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:48:15',NULL,'CREATE','IN_PROGRESS','ControllerServiceChainRoleData','overcloud-ControllerServiceChainRoleData-og2bncdti3vr','state changed','OS::Heat::Value',NULL,1211),(1957,'30579ebf-280c-4db9-b716-d46ae4dfb047','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:48:15',NULL,'CREATE','COMPLETE','ControllerServiceChainRoleData','overcloud-ControllerServiceChainRoleData-og2bncdti3vr','state changed','OS::Heat::Value',NULL,1211),(1958,'41de07fd-8b24-43bf-be71-5570875b9d81','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:48:16',NULL,'CREATE','IN_PROGRESS','CephStorageServiceConfigSettings','overcloud-CephStorageServiceConfigSettings-dbtjaf5cu5hc','state changed','OS::Heat::Value',NULL,1213),(1959,'ead2bae2-47d0-4b1f-a22d-b56e3defa2f8','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:48:16',NULL,'CREATE','COMPLETE','CephStorageServiceConfigSettings','overcloud-CephStorageServiceConfigSettings-dbtjaf5cu5hc','state changed','OS::Heat::Value',NULL,1213),(1960,'6f5d1552-ed71-4992-8763-66ad9aa1c133','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:48:16',NULL,'CREATE','IN_PROGRESS','ComputeServiceConfigSettings','overcloud-ComputeServiceConfigSettings-2lsnrkep5olj','state changed','OS::Heat::Value',NULL,1214),(1961,'591a9f8d-12a2-4ca8-911b-dcb48b4cdd72','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:48:16',NULL,'CREATE','COMPLETE','ComputeServiceConfigSettings','overcloud-ComputeServiceConfigSettings-2lsnrkep5olj','state changed','OS::Heat::Value',NULL,1214),(1962,'de0c02b5-7db1-4f1a-b61f-d2b2f0935722','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:48:16',NULL,'CREATE','IN_PROGRESS','CellControllerServiceConfigSettings','overcloud-CellControllerServiceConfigSettings-k44uzjbxcefe','state changed','OS::Heat::Value',NULL,1218),(1963,'0dcff943-844b-4e83-90d2-45fbbbd60d1d','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:48:16',NULL,'CREATE','COMPLETE','CellControllerServiceConfigSettings','overcloud-CellControllerServiceConfigSettings-k44uzjbxcefe','state changed','OS::Heat::Value',NULL,1218),(1964,'2c222463-50fa-4cb7-af19-ed2075a4714d','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:48:16',NULL,'CREATE','IN_PROGRESS','ComputeConfigData','overcloud-ComputeConfigData-qtqq24vcph33','state changed','OS::Heat::Value',NULL,1219),(1965,'77035c35-01a4-450f-810c-c3b17df47508','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:48:16',NULL,'CREATE','COMPLETE','ComputeConfigData','overcloud-ComputeConfigData-qtqq24vcph33','state changed','OS::Heat::Value',NULL,1219),(1966,'1d4d45a3-8bae-47a2-bc2a-1e2c9b5c0ea6','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:48:16',NULL,'CREATE','IN_PROGRESS','CephStorageConfigData','overcloud-CephStorageConfigData-42dff53v2fwo','state changed','OS::Heat::Value',NULL,1217),(1967,'a216f8b8-a634-4712-b312-6fac192d5c7f','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:48:16',NULL,'CREATE','COMPLETE','CephStorageConfigData','overcloud-CephStorageConfigData-42dff53v2fwo','state changed','OS::Heat::Value',NULL,1217),(1968,'f827fc91-0d4a-4306-8a51-cc61a2e9d18a','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:48:16',NULL,'CREATE','IN_PROGRESS','CellControllerConfigData','overcloud-CellControllerConfigData-hviuc5gsv5ei','state changed','OS::Heat::Value',NULL,1221),(1969,'6a63457b-d223-402c-9b60-eb2ffa394005','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:48:16',NULL,'CREATE','COMPLETE','CellControllerConfigData','overcloud-CellControllerConfigData-hviuc5gsv5ei','state changed','OS::Heat::Value',NULL,1221),(1970,'df7f7f4e-c95a-4231-98e2-d0264b0d25ca','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:48:16',NULL,'CREATE','IN_PROGRESS','ControllerServiceNames','overcloud-ControllerServiceNames-boxhfmpgicnm','state changed','OS::Heat::Value',NULL,1222),(1971,'480e7342-5604-4f75-92a1-109db1c57384','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:48:16',NULL,'CREATE','COMPLETE','ControllerServiceNames','overcloud-ControllerServiceNames-boxhfmpgicnm','state changed','OS::Heat::Value',NULL,1222),(1972,'f821f84f-0e7c-4b1c-beb6-3b440eb8515b','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:48:16',NULL,'CREATE','IN_PROGRESS','CellControllerComputeServiceConfigSettings','overcloud-CellControllerComputeServiceConfigSettings-buucgj7fwv55','state changed','OS::Heat::Value',NULL,1223),(1973,'d0cd1891-930c-4c24-b8f7-e5201775c242','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:48:16',NULL,'CREATE','COMPLETE','CellControllerComputeServiceConfigSettings','overcloud-CellControllerComputeServiceConfigSettings-buucgj7fwv55','state changed','OS::Heat::Value',NULL,1223),(1974,'561bd1f6-8794-4fb6-a016-72661f86b86b','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:48:16',NULL,'CREATE','IN_PROGRESS','NetworkerServiceConfigSettings','overcloud-NetworkerServiceConfigSettings-mgeghai2dd7d','state changed','OS::Heat::Value',NULL,1226),(1975,'5952b97d-c1da-43bc-b532-a6c79cf6be0f','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:48:16',NULL,'CREATE','IN_PROGRESS','Controller','overcloud-Controller-qduqvimacur2','state changed','OS::Heat::ResourceGroup',NULL,1227),(1976,'35857b08-a070-4c84-97e1-636f19320368','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:48:16',NULL,'CREATE','COMPLETE','NetworkerServiceConfigSettings','overcloud-NetworkerServiceConfigSettings-mgeghai2dd7d','state changed','OS::Heat::Value',NULL,1226),(1977,'b95a3446-5bfa-4594-aa28-08db473c8bf0','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:48:16',NULL,'CREATE','IN_PROGRESS','ObjectStorageServiceConfigSettings','overcloud-ObjectStorageServiceConfigSettings-4lmntwicn6mu','state changed','OS::Heat::Value',NULL,1230),(1978,'759c309b-813b-4a47-8aa8-91438b115e9c','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:48:17',NULL,'CREATE','IN_PROGRESS','CellControllerComputeConfigData','overcloud-CellControllerComputeConfigData-o5uexv7mkgbr','state changed','OS::Heat::Value',NULL,1229),(1979,'01f754b3-316a-4600-9ca3-b1d126313846','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:48:17',NULL,'CREATE','COMPLETE','ObjectStorageServiceConfigSettings','overcloud-ObjectStorageServiceConfigSettings-4lmntwicn6mu','state changed','OS::Heat::Value',NULL,1230),(1980,'70fddc3d-d577-4407-9970-b26e44344626','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:48:17',NULL,'CREATE','COMPLETE','CellControllerComputeConfigData','overcloud-CellControllerComputeConfigData-o5uexv7mkgbr','state changed','OS::Heat::Value',NULL,1229),(1981,'20cdf267-caa4-4d64-8b8f-9af24e12d942','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:48:17',NULL,'CREATE','IN_PROGRESS','NetworkerConfigData','overcloud-NetworkerConfigData-akg2kg3wf4hb','state changed','OS::Heat::Value',NULL,1231),(1982,'ac686013-45e7-4301-bc4c-5baaab7ce397','54f4aa9c-b0ba-4838-9020-f6019f862a2c','2026-06-10 07:48:17',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-qduqvimacur2','54f4aa9c-b0ba-4838-9020-f6019f862a2c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1983,'71421dc3-77ec-48a1-ba28-3d09aedcf23d','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:48:17',NULL,'CREATE','COMPLETE','NetworkerConfigData','overcloud-NetworkerConfigData-akg2kg3wf4hb','state changed','OS::Heat::Value',NULL,1231),(1984,'b197ab28-0586-40c3-a8b0-2b90ef882b41','54f4aa9c-b0ba-4838-9020-f6019f862a2c','2026-06-10 07:48:17',NULL,'CREATE','COMPLETE','overcloud-Controller-qduqvimacur2','54f4aa9c-b0ba-4838-9020-f6019f862a2c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1985,'eae860d8-5091-4cdf-8b2b-69533a6aebe0','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:48:17',NULL,'CREATE','IN_PROGRESS','ObjectStorageConfigData','overcloud-ObjectStorageConfigData-ukes6yalfthd','state changed','OS::Heat::Value',NULL,1233),(1986,'3881f0ce-d1ed-4a6e-a2c2-2cbf283d27b7','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:48:17',NULL,'CREATE','IN_PROGRESS','GlobalConfig','overcloud-GlobalConfig-tmj24ssw7axk','state changed','OS::Heat::Value',NULL,1234),(1987,'c1cb678e-f110-4246-a974-caa0f07274e1','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:48:17',NULL,'CREATE','COMPLETE','ObjectStorageConfigData','overcloud-ObjectStorageConfigData-ukes6yalfthd','state changed','OS::Heat::Value',NULL,1233),(1988,'39dc51cd-2db4-4469-8d27-d975d171764d','54f4aa9c-b0ba-4838-9020-f6019f862a2c','2026-06-10 07:48:17',NULL,'UPDATE','IN_PROGRESS','overcloud-Controller-qduqvimacur2','54f4aa9c-b0ba-4838-9020-f6019f862a2c','Stack UPDATE started','OS::Heat::Stack',NULL,NULL),(1989,'273fb234-cf56-4fae-b341-cbf9092630ab','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:48:17',NULL,'CREATE','COMPLETE','GlobalConfig','overcloud-GlobalConfig-tmj24ssw7axk','state changed','OS::Heat::Value',NULL,1234),(1990,'d94353c3-8c40-42ce-bebc-279e1137429c','54f4aa9c-b0ba-4838-9020-f6019f862a2c','2026-06-10 07:48:17',NULL,'CREATE','IN_PROGRESS','0','overcloud-Controller-qduqvimacur2-0-yjiq75pqzuju','state changed','OS::TripleO::Controller',NULL,1235),(1991,'52d7ab1c-bd28-4228-9e71-a074a8c0ece8','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:48:17',NULL,'CREATE','IN_PROGRESS','BlockStorageServiceConfigSettings','overcloud-BlockStorageServiceConfigSettings-p45w5yc2x22i','state changed','OS::Heat::Value',NULL,1236),(1992,'daabc92d-4570-4a6b-b49a-f931c2f1c720','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:48:17',NULL,'CREATE','COMPLETE','BlockStorageServiceConfigSettings','overcloud-BlockStorageServiceConfigSettings-p45w5yc2x22i','state changed','OS::Heat::Value',NULL,1236),(1993,'313ffa5a-addd-4c8f-b087-5c293b2c76c7','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:48:17',NULL,'CREATE','IN_PROGRESS','ControllerServiceConfigSettings','overcloud-ControllerServiceConfigSettings-34ypbpcgffmq','state changed','OS::Heat::Value',NULL,1238),(1994,'e86a2faa-74d7-4203-ba9b-20d251d91afe','5020d627-388e-47a8-aeeb-9837b6aa1e5a','2026-06-10 07:48:17',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-qduqvimacur2-0-yjiq75pqzuju','5020d627-388e-47a8-aeeb-9837b6aa1e5a','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1995,'96769058-a1c9-4304-9cf3-c19131563681','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:48:17',NULL,'CREATE','COMPLETE','ControllerServiceConfigSettings','overcloud-ControllerServiceConfigSettings-34ypbpcgffmq','state changed','OS::Heat::Value',NULL,1238),(1996,'5af93e1f-014a-480b-b789-b90c375e45a3','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:48:17',NULL,'CREATE','IN_PROGRESS','FirewallFrontendRules','overcloud-FirewallFrontendRules-dp3vsf5phwa2','state changed','OS::Heat::Value',NULL,1240),(1997,'0ee3dd6e-2316-4437-ab1d-7892c3078f21','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:48:17',NULL,'CREATE','COMPLETE','FirewallFrontendRules','overcloud-FirewallFrontendRules-dp3vsf5phwa2','state changed','OS::Heat::Value',NULL,1240),(1998,'70451ef7-e349-4d7a-b2eb-2fd5c90e2aa6','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:48:17',NULL,'CREATE','IN_PROGRESS','BlockStorageConfigData','overcloud-BlockStorageConfigData-6wdkrzsnrpzo','state changed','OS::Heat::Value',NULL,1241),(1999,'ea008c34-b426-46a2-b097-370a873bcb97','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:48:17',NULL,'CREATE','COMPLETE','BlockStorageConfigData','overcloud-BlockStorageConfigData-6wdkrzsnrpzo','state changed','OS::Heat::Value',NULL,1241),(2000,'bb9c7dd2-275e-4cdf-a697-d7e32973b7ca','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:48:17',NULL,'CREATE','IN_PROGRESS','BlockStorageGroupVars','overcloud-BlockStorageGroupVars-pdnqgvf33nst','state changed','OS::Heat::Value',NULL,1243),(2001,'f9a2be87-633b-485a-9b00-f55e454887d7','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:48:17',NULL,'CREATE','IN_PROGRESS','CellControllerComputeGroupVars','overcloud-CellControllerComputeGroupVars-lvhppm5uiz3u','state changed','OS::Heat::Value',NULL,1244),(2002,'23a385a5-c02c-404c-82b3-3691707bc700','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:48:17',NULL,'CREATE','IN_PROGRESS','CephStorageGroupVars','overcloud-CephStorageGroupVars-rmv3mdrecnc6','state changed','OS::Heat::Value',NULL,1246),(2003,'d264acf1-993a-4727-aeea-9029c562c0e3','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:48:17',NULL,'CREATE','IN_PROGRESS','ControllerConfigData','overcloud-ControllerConfigData-baldmukue5ox','state changed','OS::Heat::Value',NULL,1245),(2004,'ca653591-d094-4c1b-bb33-aa18b19cd884','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:48:17',NULL,'CREATE','COMPLETE','CephStorageGroupVars','overcloud-CephStorageGroupVars-rmv3mdrecnc6','state changed','OS::Heat::Value',NULL,1246),(2005,'74017243-046a-44e8-be0c-7561b68400cd','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:48:18',NULL,'CREATE','COMPLETE','ControllerConfigData','overcloud-ControllerConfigData-baldmukue5ox','state changed','OS::Heat::Value',NULL,1245),(2006,'7739f990-ebd5-4b4d-8e41-1db7f1389e9e','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:48:18',NULL,'CREATE','COMPLETE','BlockStorageGroupVars','overcloud-BlockStorageGroupVars-pdnqgvf33nst','state changed','OS::Heat::Value',NULL,1243),(2007,'fd855f31-efff-42d7-b8cd-48202c1d9775','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:48:18',NULL,'CREATE','IN_PROGRESS','CellControllerGroupVars','overcloud-CellControllerGroupVars-4fonym5gewto','state changed','OS::Heat::Value',NULL,1247),(2008,'7384ddfa-91c7-47c4-9fdb-d96be174f386','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:48:18',NULL,'CREATE','COMPLETE','CellControllerComputeGroupVars','overcloud-CellControllerComputeGroupVars-lvhppm5uiz3u','state changed','OS::Heat::Value',NULL,1244),(2009,'a2d68bdd-3fff-447a-81ac-dbb97c932ad2','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:48:18',NULL,'CREATE','IN_PROGRESS','NetworkerGroupVars','overcloud-NetworkerGroupVars-dao7srlqyjan','state changed','OS::Heat::Value',NULL,1248),(2010,'b14211c4-39c9-4ec9-a865-f3e3b6ca0132','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:48:18',NULL,'CREATE','COMPLETE','CellControllerGroupVars','overcloud-CellControllerGroupVars-4fonym5gewto','state changed','OS::Heat::Value',NULL,1247),(2011,'a4468bb5-3825-4f8b-9cb1-dcf779cb96d3','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:48:18',NULL,'CREATE','COMPLETE','NetworkerGroupVars','overcloud-NetworkerGroupVars-dao7srlqyjan','state changed','OS::Heat::Value',NULL,1248),(2012,'4a77b31c-892d-4fa2-a30d-48af6735ba2f','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:48:18',NULL,'CREATE','IN_PROGRESS','ControllerGroupVars','overcloud-ControllerGroupVars-wcneci4bsp45','state changed','OS::Heat::Value',NULL,1249),(2013,'e9a53032-e647-459f-8894-bf0cd1bd20bb','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:48:18',NULL,'CREATE','IN_PROGRESS','ComputeGroupVars','overcloud-ComputeGroupVars-76xashhgaupv','state changed','OS::Heat::Value',NULL,1251),(2014,'18f30830-7dac-46c3-b19d-88d28a9c44bb','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:48:18',NULL,'CREATE','COMPLETE','ControllerGroupVars','overcloud-ControllerGroupVars-wcneci4bsp45','state changed','OS::Heat::Value',NULL,1249),(2015,'8b6067ab-be46-42ec-996f-3a486e935917','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:48:18',NULL,'CREATE','COMPLETE','ComputeGroupVars','overcloud-ComputeGroupVars-76xashhgaupv','state changed','OS::Heat::Value',NULL,1251),(2016,'39e6caab-3455-4c16-9be6-9ea7c7327467','5020d627-388e-47a8-aeeb-9837b6aa1e5a','2026-06-10 07:48:18',NULL,'CREATE','IN_PROGRESS','Controller','overcloud-Controller-qduqvimacur2-0-yjiq75pqzuju-Controller-c3vllopskgsb','state changed','OS::TripleO::ControllerServer',NULL,1252),(2017,'9d64baa4-1003-453d-9ece-a19ecf101cc2','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:48:18',NULL,'CREATE','IN_PROGRESS','ObjectStorageGroupVars','overcloud-ObjectStorageGroupVars-mkpwge4vwv6n','state changed','OS::Heat::Value',NULL,1253),(2018,'2a155524-9bc8-4560-8ff1-eefe46417752','da74ae8d-2ace-4fe8-be8b-35f98b36f3f5','2026-06-10 07:48:18',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-qduqvimacur2-0-yjiq75pqzuju-Controller-c3vllopskgsb','da74ae8d-2ace-4fe8-be8b-35f98b36f3f5','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2019,'e2284b7f-f57c-472e-903b-f3070ca82577','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:48:18',NULL,'CREATE','COMPLETE','ObjectStorageGroupVars','overcloud-ObjectStorageGroupVars-mkpwge4vwv6n','state changed','OS::Heat::Value',NULL,1253),(2020,'b038db73-c5d7-47b4-81e1-3e159d1c66e7','da74ae8d-2ace-4fe8-be8b-35f98b36f3f5','2026-06-10 07:48:18',NULL,'CREATE','IN_PROGRESS','deployed-server','ov-ntroller-c3vllopskgsb-deployed-server-mdmsnyto32t3','state changed','OS::Heat::DeployedServer',NULL,1254),(2021,'ac835dba-758a-4dd8-a766-7b882fafdfcd','da74ae8d-2ace-4fe8-be8b-35f98b36f3f5','2026-06-10 07:48:18',NULL,'CREATE','COMPLETE','deployed-server','26edea7b-926e-460d-a71f-3aaa56a1af9e','state changed','OS::Heat::DeployedServer',NULL,1254),(2022,'77776ad7-c7f8-48a5-bc77-349a71f98c5f','5020d627-388e-47a8-aeeb-9837b6aa1e5a','2026-06-10 07:48:19',NULL,'CREATE','IN_PROGRESS','DeploymentActions','overcloud-Controller-qduqvimacur2-0-yjiq75pqzuju-DeploymentActions-lfxebsolutdw','state changed','OS::Heat::Value',NULL,1255),(2023,'230aee7f-4b0a-4e58-9a08-7471a9f513b1','5020d627-388e-47a8-aeeb-9837b6aa1e5a','2026-06-10 07:48:19',NULL,'CREATE','COMPLETE','DeploymentActions','overcloud-Controller-qduqvimacur2-0-yjiq75pqzuju-DeploymentActions-lfxebsolutdw','state changed','OS::Heat::Value',NULL,1255),(2024,'1e34d0e0-b67c-405c-baea-5c7d011cdd0a','da74ae8d-2ace-4fe8-be8b-35f98b36f3f5','2026-06-10 07:48:19',NULL,'CREATE','IN_PROGRESS','ControlPlanePort','overcloud-Controller-qduqvimacur2-0-yjiq75pqzuju-Controller-c3vllopskgsb-ControlPlanePort-c2pszydtcjne','state changed','OS::TripleO::DeployedServer::ControlPlanePort',NULL,1257),(2025,'ae5016ee-ad6e-4dfa-83e7-ce2236435576','27f31191-f1f4-4459-9249-0e685b22a3a4','2026-06-10 07:48:19',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-qduqvimacur2-0-yjiq75pqzuju-Controller-c3vllopskgsb-ControlPlanePort-c2pszydtcjne','27f31191-f1f4-4459-9249-0e685b22a3a4','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2026,'2cd20419-90d0-460d-9036-c315d5518506','27f31191-f1f4-4459-9249-0e685b22a3a4','2026-06-10 07:48:19',NULL,'CREATE','COMPLETE','overcloud-Controller-qduqvimacur2-0-yjiq75pqzuju-Controller-c3vllopskgsb-ControlPlanePort-c2pszydtcjne','27f31191-f1f4-4459-9249-0e685b22a3a4','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2027,'12b3afe1-5894-4131-946e-790c76b88644','da74ae8d-2ace-4fe8-be8b-35f98b36f3f5','2026-06-10 07:48:20',NULL,'CREATE','COMPLETE','ControlPlanePort','27f31191-f1f4-4459-9249-0e685b22a3a4','state changed','OS::TripleO::DeployedServer::ControlPlanePort',NULL,1257),(2028,'c0afda1e-1aec-4a54-932e-f8b4b0b46261','da74ae8d-2ace-4fe8-be8b-35f98b36f3f5','2026-06-10 07:48:20',NULL,'CREATE','COMPLETE','overcloud-Controller-qduqvimacur2-0-yjiq75pqzuju-Controller-c3vllopskgsb','da74ae8d-2ace-4fe8-be8b-35f98b36f3f5','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2029,'fa58165c-5b1b-41df-8180-e2b42495398f','5020d627-388e-47a8-aeeb-9837b6aa1e5a','2026-06-10 07:48:21',NULL,'CREATE','COMPLETE','Controller','da74ae8d-2ace-4fe8-be8b-35f98b36f3f5','state changed','OS::TripleO::ControllerServer',NULL,1252),(2030,'76005628-a0ec-473f-b4af-64f51d7f403d','5020d627-388e-47a8-aeeb-9837b6aa1e5a','2026-06-10 07:48:21',NULL,'CREATE','IN_PROGRESS','ControllerExtraConfigPre','overcloud-Controller-qduqvimacur2-0-yjiq75pqzuju-ControllerExtraConfigPre-nyweatu2cwn6','state changed','OS::TripleO::ControllerExtraConfigPre',NULL,1259),(2031,'3f66f15c-5571-40b8-856d-34614abb0ef4','5020d627-388e-47a8-aeeb-9837b6aa1e5a','2026-06-10 07:48:21',NULL,'CREATE','IN_PROGRESS','NetHostMap','overcloud-Controller-qduqvimacur2-0-yjiq75pqzuju-NetHostMap-qikssyqvjhql','state changed','OS::Heat::Value',NULL,1260),(2032,'20b3e495-3a28-44b1-bda8-60f46fcdeddc','5020d627-388e-47a8-aeeb-9837b6aa1e5a','2026-06-10 07:48:21',NULL,'CREATE','IN_PROGRESS','NodeTLSCAData','overcloud-Controller-qduqvimacur2-0-yjiq75pqzuju-NodeTLSCAData-juuissl5t5hq','state changed','OS::TripleO::NodeTLSCAData',NULL,NULL),(2033,'6aa914b4-cc34-4fb9-b1cb-d9003fbc2475','5020d627-388e-47a8-aeeb-9837b6aa1e5a','2026-06-10 07:48:21',NULL,'CREATE','COMPLETE','NetHostMap','overcloud-Controller-qduqvimacur2-0-yjiq75pqzuju-NetHostMap-qikssyqvjhql','state changed','OS::Heat::Value',NULL,1260),(2034,'a602fe1a-74e8-4fab-b2d8-24b72c3a985b','5020d627-388e-47a8-aeeb-9837b6aa1e5a','2026-06-10 07:48:21',NULL,'CREATE','IN_PROGRESS','StorageMgmtPort','overcloud-Controller-qduqvimacur2-0-yjiq75pqzuju-StorageMgmtPort-kbjzabfi5wfa','state changed','OS::TripleO::Controller::Ports::StorageMgmtPort',NULL,1261),(2035,'fdaeabfc-030a-4246-9522-6ffe1fc116c8','5020d627-388e-47a8-aeeb-9837b6aa1e5a','2026-06-10 07:48:21',NULL,'CREATE','IN_PROGRESS','TenantPort','overcloud-Controller-qduqvimacur2-0-yjiq75pqzuju-TenantPort-u3rkgxpg5is6','state changed','OS::TripleO::Controller::Ports::TenantPort',NULL,1264),(2036,'b5370066-0769-45e3-b46e-41959c25797c','5020d627-388e-47a8-aeeb-9837b6aa1e5a','2026-06-10 07:48:21',NULL,'CREATE','IN_PROGRESS','PreNetworkConfig','overcloud-Controller-qduqvimacur2-0-yjiq75pqzuju-PreNetworkConfig-b2bbyt6cschc','state changed','OS::TripleO::Controller::PreNetworkConfig',NULL,NULL),(2037,'72ba6ea6-54f4-432b-9898-37119c5f5637','5020d627-388e-47a8-aeeb-9837b6aa1e5a','2026-06-10 07:48:21',NULL,'CREATE','IN_PROGRESS','InternalApiPort','overcloud-Controller-qduqvimacur2-0-yjiq75pqzuju-InternalApiPort-w3gsda65bdvb','state changed','OS::TripleO::Controller::Ports::InternalApiPort',NULL,1262),(2038,'58fa8364-37b3-4b37-b92e-e178d54dad4f','d786331a-034b-4eac-93a0-3ab8d577c3b6','2026-06-10 07:48:21',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-qduqvimacur2-0-yjiq75pqzuju-StorageMgmtPort-kbjzabfi5wfa','d786331a-034b-4eac-93a0-3ab8d577c3b6','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2039,'2d528b41-d40f-4745-a6eb-564dc7576a02','5020d627-388e-47a8-aeeb-9837b6aa1e5a','2026-06-10 07:48:21',NULL,'CREATE','IN_PROGRESS','ControllerAnsibleHostVars','overcloud-Controller-qduqvimacur2-0-yjiq75pqzuju-ControllerAnsibleHostVars-coxg7f65kedi','state changed','OS::Heat::Value',NULL,1267),(2040,'dfcc3872-faca-46fa-b58a-c06bf6a57f13','cbe216e3-0e10-42d7-81c9-b95a99c4bce9','2026-06-10 07:48:21',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-qduqvimacur2-0-yjiq75pqzuju-ControllerExtraConfigPre-nyweatu2cwn6','cbe216e3-0e10-42d7-81c9-b95a99c4bce9','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2041,'152266bb-5506-4641-9329-223458706f6f','5020d627-388e-47a8-aeeb-9837b6aa1e5a','2026-06-10 07:48:21',NULL,'CREATE','IN_PROGRESS','StoragePort','overcloud-Controller-qduqvimacur2-0-yjiq75pqzuju-StoragePort-r23rgdvd45gt','state changed','OS::TripleO::Controller::Ports::StoragePort',NULL,1266),(2042,'a833866b-1afd-4096-a741-3b2b076909e5','5020d627-388e-47a8-aeeb-9837b6aa1e5a','2026-06-10 07:48:21',NULL,'CREATE','COMPLETE','NodeTLSCAData','b0751ced-6f8d-41e3-9a7c-0a639b735369','state changed','OS::TripleO::NodeTLSCAData',NULL,NULL),(2043,'958debbc-2e09-4c02-af68-435d6b5e6403','5020d627-388e-47a8-aeeb-9837b6aa1e5a','2026-06-10 07:48:21',NULL,'CREATE','COMPLETE','ControllerAnsibleHostVars','overcloud-Controller-qduqvimacur2-0-yjiq75pqzuju-ControllerAnsibleHostVars-coxg7f65kedi','state changed','OS::Heat::Value',NULL,1267),(2044,'75da2fdc-adc8-49c6-bb7d-f4dc89ff3308','5020d627-388e-47a8-aeeb-9837b6aa1e5a','2026-06-10 07:48:21',NULL,'CREATE','COMPLETE','PreNetworkConfig','ce2967a9-cb14-4a6c-962b-bd5843f75d80','state changed','OS::TripleO::Controller::PreNetworkConfig',NULL,NULL),(2045,'e43a810f-e8ff-478b-a902-68b0ef851eee','cbe216e3-0e10-42d7-81c9-b95a99c4bce9','2026-06-10 07:48:21',NULL,'CREATE','COMPLETE','overcloud-Controller-qduqvimacur2-0-yjiq75pqzuju-ControllerExtraConfigPre-nyweatu2cwn6','cbe216e3-0e10-42d7-81c9-b95a99c4bce9','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2046,'682e3cfe-f0a6-4e37-9a50-b4828c08c74e','4716eec1-20f8-492b-a237-784a6ad0c58f','2026-06-10 07:48:21',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-qduqvimacur2-0-yjiq75pqzuju-TenantPort-u3rkgxpg5is6','4716eec1-20f8-492b-a237-784a6ad0c58f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2047,'e53924da-ea39-435a-914f-c72da0d6945f','cc4467ba-ec7b-456f-a3cf-15815b707b22','2026-06-10 07:48:21',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-qduqvimacur2-0-yjiq75pqzuju-StoragePort-r23rgdvd45gt','cc4467ba-ec7b-456f-a3cf-15815b707b22','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2048,'2a8effb2-3b12-4687-a491-b1e4e221ca5c','3bb0cac2-f9de-4677-9bf9-ed9f41a003be','2026-06-10 07:48:21',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-qduqvimacur2-0-yjiq75pqzuju-InternalApiPort-w3gsda65bdvb','3bb0cac2-f9de-4677-9bf9-ed9f41a003be','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2049,'8079a03f-bbb0-43bc-8a87-1ecad646754a','d786331a-034b-4eac-93a0-3ab8d577c3b6','2026-06-10 07:48:21',NULL,'CREATE','IN_PROGRESS','StorageMgmtDeployedPort','overcloud-Controller-qduqvimacur2-0-yjiq75pqzuju-StorageMgmtPort-kbjzabfi5wfa-StorageMgmtDeployedPort-6rvg5na4nc6r','state changed','OS::Heat::Value',NULL,1268),(2050,'49383840-a1c0-4827-9046-f54c7e34f632','d786331a-034b-4eac-93a0-3ab8d577c3b6','2026-06-10 07:48:21',NULL,'CREATE','COMPLETE','StorageMgmtDeployedPort','overcloud-Controller-qduqvimacur2-0-yjiq75pqzuju-StorageMgmtPort-kbjzabfi5wfa-StorageMgmtDeployedPort-6rvg5na4nc6r','state changed','OS::Heat::Value',NULL,1268),(2051,'726427cb-4b84-423f-8b74-ccaee43cfef9','d786331a-034b-4eac-93a0-3ab8d577c3b6','2026-06-10 07:48:21',NULL,'CREATE','COMPLETE','overcloud-Controller-qduqvimacur2-0-yjiq75pqzuju-StorageMgmtPort-kbjzabfi5wfa','d786331a-034b-4eac-93a0-3ab8d577c3b6','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2052,'751013f1-c81a-4d54-8e02-867ac7a6b531','cc4467ba-ec7b-456f-a3cf-15815b707b22','2026-06-10 07:48:21',NULL,'CREATE','IN_PROGRESS','StorageDeployedPort','overcloud-Controller-qduqvimacur2-0-yjiq75pqzuju-StoragePort-r23rgdvd45gt-StorageDeployedPort-7xzhnvmwqb32','state changed','OS::Heat::Value',NULL,1269),(2053,'a4339f1b-07e1-4eb4-bb8c-2960ce4c43bc','cc4467ba-ec7b-456f-a3cf-15815b707b22','2026-06-10 07:48:21',NULL,'CREATE','COMPLETE','StorageDeployedPort','overcloud-Controller-qduqvimacur2-0-yjiq75pqzuju-StoragePort-r23rgdvd45gt-StorageDeployedPort-7xzhnvmwqb32','state changed','OS::Heat::Value',NULL,1269),(2054,'b40e09a1-a480-4704-919d-1750d438b85c','3bb0cac2-f9de-4677-9bf9-ed9f41a003be','2026-06-10 07:48:21',NULL,'CREATE','IN_PROGRESS','InternalApiDeployedPort','overcloud-Controller-qduqvimacur2-0-yjiq75pqzuju-InternalApiPort-w3gsda65bdvb-InternalApiDeployedPort-gsejycy4xwwk','state changed','OS::Heat::Value',NULL,1270),(2055,'43677348-d15c-4084-8887-a07bc2886645','cc4467ba-ec7b-456f-a3cf-15815b707b22','2026-06-10 07:48:21',NULL,'CREATE','COMPLETE','overcloud-Controller-qduqvimacur2-0-yjiq75pqzuju-StoragePort-r23rgdvd45gt','cc4467ba-ec7b-456f-a3cf-15815b707b22','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2056,'95e26d8c-6079-4690-99c6-053aed628d50','3bb0cac2-f9de-4677-9bf9-ed9f41a003be','2026-06-10 07:48:21',NULL,'CREATE','COMPLETE','InternalApiDeployedPort','overcloud-Controller-qduqvimacur2-0-yjiq75pqzuju-InternalApiPort-w3gsda65bdvb-InternalApiDeployedPort-gsejycy4xwwk','state changed','OS::Heat::Value',NULL,1270),(2057,'9ac30c33-f7c0-4c03-9808-d68a93edf9fe','4716eec1-20f8-492b-a237-784a6ad0c58f','2026-06-10 07:48:21',NULL,'CREATE','IN_PROGRESS','TenantDeployedPort','overcloud-Controller-qduqvimacur2-0-yjiq75pqzuju-TenantPort-u3rkgxpg5is6-TenantDeployedPort-fmquzolmb5zd','state changed','OS::Heat::Value',NULL,1271),(2058,'666408e1-6dfb-40a6-a98f-4e1886c16faa','3bb0cac2-f9de-4677-9bf9-ed9f41a003be','2026-06-10 07:48:21',NULL,'CREATE','COMPLETE','overcloud-Controller-qduqvimacur2-0-yjiq75pqzuju-InternalApiPort-w3gsda65bdvb','3bb0cac2-f9de-4677-9bf9-ed9f41a003be','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2059,'7ab036f7-582c-42b4-8ab9-a0495859ea73','4716eec1-20f8-492b-a237-784a6ad0c58f','2026-06-10 07:48:21',NULL,'CREATE','COMPLETE','TenantDeployedPort','overcloud-Controller-qduqvimacur2-0-yjiq75pqzuju-TenantPort-u3rkgxpg5is6-TenantDeployedPort-fmquzolmb5zd','state changed','OS::Heat::Value',NULL,1271),(2060,'620dd5a8-d577-4f3e-b650-db3b08b373b3','4716eec1-20f8-492b-a237-784a6ad0c58f','2026-06-10 07:48:21',NULL,'CREATE','COMPLETE','overcloud-Controller-qduqvimacur2-0-yjiq75pqzuju-TenantPort-u3rkgxpg5is6','4716eec1-20f8-492b-a237-784a6ad0c58f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2061,'3619e9bc-0840-4a5d-9566-620a7a38e9b0','5020d627-388e-47a8-aeeb-9837b6aa1e5a','2026-06-10 07:48:22',NULL,'CREATE','COMPLETE','StorageMgmtPort','d786331a-034b-4eac-93a0-3ab8d577c3b6','state changed','OS::TripleO::Controller::Ports::StorageMgmtPort',NULL,1261),(2062,'87e2d357-81d7-429d-8e7c-98109648dc64','5020d627-388e-47a8-aeeb-9837b6aa1e5a','2026-06-10 07:48:22',NULL,'CREATE','COMPLETE','ControllerExtraConfigPre','cbe216e3-0e10-42d7-81c9-b95a99c4bce9','state changed','OS::TripleO::ControllerExtraConfigPre',NULL,1259),(2063,'99f94769-5a84-4cbe-aabf-f88fd762f7ad','5020d627-388e-47a8-aeeb-9837b6aa1e5a','2026-06-10 07:48:22',NULL,'CREATE','COMPLETE','InternalApiPort','3bb0cac2-f9de-4677-9bf9-ed9f41a003be','state changed','OS::TripleO::Controller::Ports::InternalApiPort',NULL,1262),(2064,'34a71e1b-9604-4cb3-89c8-9795065c8a0b','5020d627-388e-47a8-aeeb-9837b6aa1e5a','2026-06-10 07:48:22',NULL,'CREATE','COMPLETE','StoragePort','cc4467ba-ec7b-456f-a3cf-15815b707b22','state changed','OS::TripleO::Controller::Ports::StoragePort',NULL,1266),(2065,'a8dcc572-89c2-4a89-858c-7a4be2b1280e','5020d627-388e-47a8-aeeb-9837b6aa1e5a','2026-06-10 07:48:22',NULL,'CREATE','COMPLETE','TenantPort','4716eec1-20f8-492b-a237-784a6ad0c58f','state changed','OS::TripleO::Controller::Ports::TenantPort',NULL,1264),(2066,'0c271144-c9e5-4e29-af63-849c8d3c488d','5020d627-388e-47a8-aeeb-9837b6aa1e5a','2026-06-10 07:48:22',NULL,'CREATE','IN_PROGRESS','NodeExtraConfig','overcloud-Controller-qduqvimacur2-0-yjiq75pqzuju-NodeExtraConfig-c573megxig25','state changed','OS::TripleO::NodeExtraConfig',NULL,1277),(2067,'0ef34f0d-1485-4297-b110-4d2f045c1781','e1e1daff-20b5-4f5b-a2c3-e0a12598e367','2026-06-10 07:48:23',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-qduqvimacur2-0-yjiq75pqzuju-NodeExtraConfig-c573megxig25','e1e1daff-20b5-4f5b-a2c3-e0a12598e367','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2068,'018305d3-ded7-4fbf-a3a8-0424a9901b19','e1e1daff-20b5-4f5b-a2c3-e0a12598e367','2026-06-10 07:48:23',NULL,'CREATE','COMPLETE','overcloud-Controller-qduqvimacur2-0-yjiq75pqzuju-NodeExtraConfig-c573megxig25','e1e1daff-20b5-4f5b-a2c3-e0a12598e367','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2069,'57012254-1a3a-45a1-a77c-47feed2d1eca','5020d627-388e-47a8-aeeb-9837b6aa1e5a','2026-06-10 07:48:23',NULL,'CREATE','IN_PROGRESS','NetIpMap','overcloud-Controller-qduqvimacur2-0-yjiq75pqzuju-NetIpMap-mpcv3cnwoxzo','state changed','OS::TripleO::Network::Ports::NetIpMap',NULL,1282),(2070,'7756f0bb-8a65-42fe-9c88-a470edcca22f','0fc046af-a256-4576-b87b-ba682a30df27','2026-06-10 07:48:23',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-qduqvimacur2-0-yjiq75pqzuju-NetIpMap-mpcv3cnwoxzo','0fc046af-a256-4576-b87b-ba682a30df27','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2071,'e38357e1-9252-47f9-af17-760e93c9fdff','0fc046af-a256-4576-b87b-ba682a30df27','2026-06-10 07:48:23',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','overcloud-Controller-qduqvimacur2-0-yjiq75pqzuju-NetIpMap-mpcv3cnwoxzo-NetIpMapValue-deu6s4kpcmrl','state changed','OS::Heat::Value',NULL,1283),(2072,'eed70fbf-73f9-4ce2-897a-2dd26969326e','0fc046af-a256-4576-b87b-ba682a30df27','2026-06-10 07:48:23',NULL,'CREATE','COMPLETE','NetIpMapValue','overcloud-Controller-qduqvimacur2-0-yjiq75pqzuju-NetIpMap-mpcv3cnwoxzo-NetIpMapValue-deu6s4kpcmrl','state changed','OS::Heat::Value',NULL,1283),(2073,'9f4f9ce1-1d24-41d4-aaaa-08e41f6264d2','0fc046af-a256-4576-b87b-ba682a30df27','2026-06-10 07:48:23',NULL,'CREATE','COMPLETE','overcloud-Controller-qduqvimacur2-0-yjiq75pqzuju-NetIpMap-mpcv3cnwoxzo','0fc046af-a256-4576-b87b-ba682a30df27','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2074,'f0d993eb-5927-4b65-80c7-06baed7cb03a','5020d627-388e-47a8-aeeb-9837b6aa1e5a','2026-06-10 07:48:24',NULL,'CREATE','COMPLETE','NodeExtraConfig','e1e1daff-20b5-4f5b-a2c3-e0a12598e367','state changed','OS::TripleO::NodeExtraConfig',NULL,1277),(2075,'03da8f48-6540-4382-96fa-aaeec45bbd98','5020d627-388e-47a8-aeeb-9837b6aa1e5a','2026-06-10 07:48:24',NULL,'CREATE','COMPLETE','NetIpMap','0fc046af-a256-4576-b87b-ba682a30df27','state changed','OS::TripleO::Network::Ports::NetIpMap',NULL,1282),(2076,'6608c915-bcb7-434d-a111-a5eb0fb8fb73','5020d627-388e-47a8-aeeb-9837b6aa1e5a','2026-06-10 07:48:24',NULL,'CREATE','COMPLETE','overcloud-Controller-qduqvimacur2-0-yjiq75pqzuju','5020d627-388e-47a8-aeeb-9837b6aa1e5a','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2077,'c39ef950-91be-4af1-a14a-5284720cb541','54f4aa9c-b0ba-4838-9020-f6019f862a2c','2026-06-10 07:48:24',NULL,'CREATE','COMPLETE','0','5020d627-388e-47a8-aeeb-9837b6aa1e5a','state changed','OS::TripleO::Controller',NULL,1235),(2078,'6d042be2-34d7-40a1-92c2-a0fa426d9c1f','54f4aa9c-b0ba-4838-9020-f6019f862a2c','2026-06-10 07:48:24',NULL,'UPDATE','COMPLETE','overcloud-Controller-qduqvimacur2','54f4aa9c-b0ba-4838-9020-f6019f862a2c','Stack UPDATE completed successfully','OS::Heat::Stack',NULL,NULL),(2079,'ec1893ef-71ab-4529-b3bb-4266666088a4','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:48:25',NULL,'CREATE','COMPLETE','Controller','54f4aa9c-b0ba-4838-9020-f6019f862a2c','state changed','OS::Heat::ResourceGroup',NULL,1227),(2080,'173110eb-e3a2-48ad-8019-95d05aa66db8','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:48:25',NULL,'CREATE','IN_PROGRESS','ControllerNetworkHostnameMap','overcloud-ControllerNetworkHostnameMap-xswyy3kn246x','state changed','OS::Heat::Value',NULL,1289),(2081,'c0b8af1f-3eb4-4fe6-8784-6e606cdab2b7','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:48:25',NULL,'CREATE','COMPLETE','ControllerNetworkHostnameMap','overcloud-ControllerNetworkHostnameMap-xswyy3kn246x','state changed','OS::Heat::Value',NULL,1289),(2082,'b2f2d814-d8c1-4a5f-bfcb-4913752b0d72','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:48:26',NULL,'CREATE','IN_PROGRESS','ControllerIpListMap','overcloud-ControllerIpListMap-f2fmf4oa5u6h','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,1292),(2083,'a5dcf7c3-58bb-4947-9693-32ac306c3537','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:48:26',NULL,'CREATE','IN_PROGRESS','ControllerServers','overcloud-ControllerServers-kpkjfuiapjla','state changed','OS::Heat::Value',NULL,1293),(2084,'9b6387ec-e499-4368-a425-9954e298f617','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:48:26',NULL,'CREATE','IN_PROGRESS','BlacklistedHostnames','overcloud-BlacklistedHostnames-qfvxozrabwj4','state changed','OS::Heat::Value',NULL,1294),(2085,'b0c39c4a-ae1b-446e-aa6e-692b1eec1b74','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:48:26',NULL,'CREATE','IN_PROGRESS','HostsEntryValue','overcloud-HostsEntryValue-r2dhpqdzjxk2','state changed','OS::Heat::Value',NULL,1291),(2086,'e0a009f9-cf83-46e8-8187-eec72d0e028d','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:48:26',NULL,'CREATE','IN_PROGRESS','ServerIdMap','overcloud-ServerIdMap-4neynpfkdz5j','state changed','OS::Heat::Value',NULL,1296),(2087,'055cf57b-dd5a-4976-b38c-fc94ba0b76bc','1aeea248-4895-49d8-b38f-cb77265a054a','2026-06-10 07:48:26',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerIpListMap-f2fmf4oa5u6h','1aeea248-4895-49d8-b38f-cb77265a054a','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2088,'ab1ed3db-a5e1-41a9-87d3-a846afa180f0','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:48:26',NULL,'CREATE','COMPLETE','HostsEntryValue','overcloud-HostsEntryValue-r2dhpqdzjxk2','state changed','OS::Heat::Value',NULL,1291),(2089,'69e995dd-0ee8-49ea-bed2-0ddd3aaf6be2','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:48:26',NULL,'CREATE','IN_PROGRESS','AnsibleHostVars','overcloud-AnsibleHostVars-u57bq4n4nvwf','state changed','OS::Heat::Value',NULL,1297),(2090,'b47ce86a-0805-4ff8-ab68-339805f31451','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:48:26',NULL,'CREATE','IN_PROGRESS','BlacklistedIpAddresses','overcloud-BlacklistedIpAddresses-wwbdopeubphv','state changed','OS::Heat::Value',NULL,1298),(2091,'9a0b87a7-6ff8-4223-9b0b-f141e4fb7a19','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:48:26',NULL,'CREATE','COMPLETE','BlacklistedHostnames','overcloud-BlacklistedHostnames-qfvxozrabwj4','state changed','OS::Heat::Value',NULL,1294),(2092,'9f5b70be-2af2-41d0-9c36-0fbe7f7c715a','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:48:26',NULL,'CREATE','COMPLETE','ControllerServers','overcloud-ControllerServers-kpkjfuiapjla','state changed','OS::Heat::Value',NULL,1293),(2093,'fcbc3a8c-8c1c-4f13-a242-b5785de6e9c6','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:48:26',NULL,'CREATE','COMPLETE','BlacklistedIpAddresses','overcloud-BlacklistedIpAddresses-wwbdopeubphv','state changed','OS::Heat::Value',NULL,1298),(2094,'4f5103a8-b82b-4412-a8ff-a9edde283c40','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:48:26',NULL,'CREATE','COMPLETE','ServerIdMap','overcloud-ServerIdMap-4neynpfkdz5j','state changed','OS::Heat::Value',NULL,1296),(2095,'6fbf9129-c2e9-411d-acb2-d4e9eea1e8eb','1aeea248-4895-49d8-b38f-cb77265a054a','2026-06-10 07:48:26',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','overcloud-ControllerIpListMap-f2fmf4oa5u6h-NetIpMapValue-bcmxouw6bxzh','state changed','OS::Heat::Value',NULL,1299),(2096,'9ccfe9d5-3e79-4a34-9d51-6f594151aedf','1aeea248-4895-49d8-b38f-cb77265a054a','2026-06-10 07:48:26',NULL,'CREATE','COMPLETE','NetIpMapValue','overcloud-ControllerIpListMap-f2fmf4oa5u6h-NetIpMapValue-bcmxouw6bxzh','state changed','OS::Heat::Value',NULL,1299),(2097,'840884c7-b5d9-4b81-b3a5-d473980188e1','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:48:26',NULL,'CREATE','COMPLETE','AnsibleHostVars','overcloud-AnsibleHostVars-u57bq4n4nvwf','state changed','OS::Heat::Value',NULL,1297),(2098,'333d5103-6f08-400e-bd65-bfbecb011da1','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:48:26',NULL,'CREATE','IN_PROGRESS','AllNodesExtraConfig','overcloud-AllNodesExtraConfig-o6zev7nrwc6q','state changed','OS::TripleO::AllNodesExtraConfig',NULL,NULL),(2099,'73cdd976-2177-4db7-8e6a-69391d391b81','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:48:26',NULL,'CREATE','COMPLETE','AllNodesExtraConfig','146261f0-f3e4-42ef-9498-d955928d3242','state changed','OS::TripleO::AllNodesExtraConfig',NULL,NULL),(2100,'5eb3a2dc-b9a6-4f12-a2a5-6a44c58a3eaf','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:48:26',NULL,'CREATE','IN_PROGRESS','AllNodesDeploySteps','overcloud-AllNodesDeploySteps-5fw7lnwmw6k6','state changed','OS::TripleO::PostDeploySteps',NULL,1302),(2101,'013ab49c-93e2-48ef-aba9-5084ec97152e','1aeea248-4895-49d8-b38f-cb77265a054a','2026-06-10 07:48:27',NULL,'CREATE','IN_PROGRESS','EnabledServicesValue','overcloud-ControllerIpListMap-f2fmf4oa5u6h-EnabledServicesValue-3bycsrebsk43','state changed','OS::Heat::Value',NULL,1303),(2102,'fd8fedc2-22c0-4a97-a0f9-88e05b12c144','5dccf5dc-1746-4ec0-810d-9d405723d785','2026-06-10 07:48:27',NULL,'CREATE','IN_PROGRESS','overcloud-AllNodesDeploySteps-5fw7lnwmw6k6','5dccf5dc-1746-4ec0-810d-9d405723d785','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2103,'0e3e23f1-cbd1-466d-8e67-1ab053e17d7a','1aeea248-4895-49d8-b38f-cb77265a054a','2026-06-10 07:48:27',NULL,'CREATE','COMPLETE','EnabledServicesValue','overcloud-ControllerIpListMap-f2fmf4oa5u6h-EnabledServicesValue-3bycsrebsk43','state changed','OS::Heat::Value',NULL,1303),(2104,'38223923-93ec-448b-9f7c-85beed92eeb6','1aeea248-4895-49d8-b38f-cb77265a054a','2026-06-10 07:48:27',NULL,'CREATE','COMPLETE','overcloud-ControllerIpListMap-f2fmf4oa5u6h','1aeea248-4895-49d8-b38f-cb77265a054a','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2105,'afb20d39-67c1-4ebc-a075-5c81c87fc9f1','5dccf5dc-1746-4ec0-810d-9d405723d785','2026-06-10 07:48:27',NULL,'CREATE','IN_PROGRESS','ExternalUpgradeTasks','overcloud-AllNodesDeploySteps-5fw7lnwmw6k6-ExternalUpgradeTasks-scq767cflhvq','state changed','OS::Heat::Value',NULL,1304),(2106,'99f72975-c4ae-4912-a19e-5fa16942cbea','5dccf5dc-1746-4ec0-810d-9d405723d785','2026-06-10 07:48:27',NULL,'CREATE','COMPLETE','ExternalUpgradeTasks','overcloud-AllNodesDeploySteps-5fw7lnwmw6k6-ExternalUpgradeTasks-scq767cflhvq','state changed','OS::Heat::Value',NULL,1304),(2107,'ead2624b-1899-4ce1-9c74-12af9ae70179','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:48:28',NULL,'CREATE','COMPLETE','ControllerIpListMap','1aeea248-4895-49d8-b38f-cb77265a054a','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,1292),(2108,'bba9ff23-58c1-409f-b9e3-cfe521499e35','5dccf5dc-1746-4ec0-810d-9d405723d785','2026-06-10 07:48:28',NULL,'CREATE','IN_PROGRESS','ExternalDeployTasks','overcloud-AllNodesDeploySteps-5fw7lnwmw6k6-ExternalDeployTasks-q3ski7p4i3ej','state changed','OS::Heat::Value',NULL,1305),(2109,'be7417d8-a0aa-4a3e-bf87-bfb23589408f','5dccf5dc-1746-4ec0-810d-9d405723d785','2026-06-10 07:48:28',NULL,'CREATE','COMPLETE','ExternalDeployTasks','overcloud-AllNodesDeploySteps-5fw7lnwmw6k6-ExternalDeployTasks-q3ski7p4i3ej','state changed','OS::Heat::Value',NULL,1305),(2110,'0a38c7f4-473d-4385-9cb8-a407febf99cb','5dccf5dc-1746-4ec0-810d-9d405723d785','2026-06-10 07:48:29',NULL,'CREATE','IN_PROGRESS','ScaleTasks','overcloud-AllNodesDeploySteps-5fw7lnwmw6k6-ScaleTasks-zcyuxbqgbh4p','state changed','OS::Heat::Value',NULL,1306),(2111,'ca401cc6-ab52-45fb-88a2-1b8cd9cccb18','5dccf5dc-1746-4ec0-810d-9d405723d785','2026-06-10 07:48:29',NULL,'CREATE','COMPLETE','ScaleTasks','overcloud-AllNodesDeploySteps-5fw7lnwmw6k6-ScaleTasks-zcyuxbqgbh4p','state changed','OS::Heat::Value',NULL,1306),(2112,'73d4c3d8-8edb-48b3-86b9-0bb643e62fe2','5dccf5dc-1746-4ec0-810d-9d405723d785','2026-06-10 07:48:30',NULL,'CREATE','IN_PROGRESS','BootstrapServerId','overcloud-AllNodesDeploySteps-5fw7lnwmw6k6-BootstrapServerId-cwxmmz5ehdkt','state changed','OS::Heat::Value',NULL,1307),(2113,'54227ffc-d072-49e5-b8ce-63f7872e30c1','5dccf5dc-1746-4ec0-810d-9d405723d785','2026-06-10 07:48:30',NULL,'CREATE','COMPLETE','BootstrapServerId','overcloud-AllNodesDeploySteps-5fw7lnwmw6k6-BootstrapServerId-cwxmmz5ehdkt','state changed','OS::Heat::Value',NULL,1307),(2114,'9992d513-fbb9-44e7-92bd-1773a7cfc235','5dccf5dc-1746-4ec0-810d-9d405723d785','2026-06-10 07:48:31',NULL,'CREATE','IN_PROGRESS','ExternalUpdateTasks','overcloud-AllNodesDeploySteps-5fw7lnwmw6k6-ExternalUpdateTasks-7tfgg6rmacxa','state changed','OS::Heat::Value',NULL,1308),(2115,'efc41640-660f-427c-9545-77fe5f9a9b64','5dccf5dc-1746-4ec0-810d-9d405723d785','2026-06-10 07:48:31',NULL,'CREATE','COMPLETE','ExternalUpdateTasks','overcloud-AllNodesDeploySteps-5fw7lnwmw6k6-ExternalUpdateTasks-7tfgg6rmacxa','state changed','OS::Heat::Value',NULL,1308),(2116,'38e56ca9-1f00-4027-bde9-6d7e6f52f25f','5dccf5dc-1746-4ec0-810d-9d405723d785','2026-06-10 07:48:32',NULL,'CREATE','IN_PROGRESS','PreDeployStepTasks','overcloud-AllNodesDeploySteps-5fw7lnwmw6k6-PreDeployStepTasks-d44kdzzxxkz5','state changed','OS::Heat::Value',NULL,1309),(2117,'66aab9fb-e2a9-40e9-bd53-abfbcbc859cd','5dccf5dc-1746-4ec0-810d-9d405723d785','2026-06-10 07:48:32',NULL,'CREATE','COMPLETE','PreDeployStepTasks','overcloud-AllNodesDeploySteps-5fw7lnwmw6k6-PreDeployStepTasks-d44kdzzxxkz5','state changed','OS::Heat::Value',NULL,1309),(2118,'ca49d398-15d9-4d00-a2a5-d93706ea95ce','5dccf5dc-1746-4ec0-810d-9d405723d785','2026-06-10 07:48:33',NULL,'CREATE','IN_PROGRESS','ExternalPostDeployTasks','overcloud-AllNodesDeploySteps-5fw7lnwmw6k6-ExternalPostDeployTasks-hrd63spe2wmn','state changed','OS::Heat::Value',NULL,1310),(2119,'62041797-d0ea-42e3-9dc3-588184162a6e','5dccf5dc-1746-4ec0-810d-9d405723d785','2026-06-10 07:48:33',NULL,'CREATE','COMPLETE','ExternalPostDeployTasks','overcloud-AllNodesDeploySteps-5fw7lnwmw6k6-ExternalPostDeployTasks-hrd63spe2wmn','state changed','OS::Heat::Value',NULL,1310),(2120,'0cdde908-f306-44b6-a69b-2b6093fa8ad1','5dccf5dc-1746-4ec0-810d-9d405723d785','2026-06-10 07:48:34',NULL,'CREATE','IN_PROGRESS','ControllerExtraConfigPost','overcloud-AllNodesDeploySteps-5fw7lnwmw6k6-ControllerExtraConfigPost-ii2hqofmfpxy','state changed','OS::TripleO::NodeExtraConfigPost',NULL,1311),(2121,'8c2229cd-ee0d-4ca5-9a12-cb11e19faf18','44a42bad-3250-4a45-96c6-45bf82d29165','2026-06-10 07:48:34',NULL,'CREATE','IN_PROGRESS','overcloud-AllNodesDeploySteps-5fw7lnwmw6k6-ControllerExtraConfigPost-ii2hqofmfpxy','44a42bad-3250-4a45-96c6-45bf82d29165','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2122,'0e4ecc70-3c38-4bc1-8cb8-8c64c403d65d','44a42bad-3250-4a45-96c6-45bf82d29165','2026-06-10 07:48:34',NULL,'CREATE','COMPLETE','overcloud-AllNodesDeploySteps-5fw7lnwmw6k6-ControllerExtraConfigPost-ii2hqofmfpxy','44a42bad-3250-4a45-96c6-45bf82d29165','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2123,'79d04659-72eb-4ffa-a7c8-9e50a9fd2e6f','5dccf5dc-1746-4ec0-810d-9d405723d785','2026-06-10 07:48:35',NULL,'CREATE','COMPLETE','ControllerExtraConfigPost','44a42bad-3250-4a45-96c6-45bf82d29165','state changed','OS::TripleO::NodeExtraConfigPost',NULL,1311),(2124,'2918cc69-e683-49d4-9826-fab5090fa57f','5dccf5dc-1746-4ec0-810d-9d405723d785','2026-06-10 07:48:35',NULL,'CREATE','IN_PROGRESS','ControllerPostConfig','overcloud-AllNodesDeploySteps-5fw7lnwmw6k6-ControllerPostConfig-k6qwqb3c5eim','state changed','OS::TripleO::Tasks::ControllerPostConfig',NULL,NULL),(2125,'cb98403c-d998-4a03-8df8-a761af4e2eea','5dccf5dc-1746-4ec0-810d-9d405723d785','2026-06-10 07:48:35',NULL,'CREATE','COMPLETE','ControllerPostConfig','5c6efcc8-1755-43ca-a8d3-4676773d7c17','state changed','OS::TripleO::Tasks::ControllerPostConfig',NULL,NULL),(2126,'e6a4d897-0599-4a5e-9ab7-e4fcfd76b218','5dccf5dc-1746-4ec0-810d-9d405723d785','2026-06-10 07:48:35',NULL,'CREATE','COMPLETE','overcloud-AllNodesDeploySteps-5fw7lnwmw6k6','5dccf5dc-1746-4ec0-810d-9d405723d785','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2127,'ca47fbed-bfe4-40b3-9532-58966f9b3b0a','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:48:36',NULL,'CREATE','COMPLETE','AllNodesDeploySteps','5dccf5dc-1746-4ec0-810d-9d405723d785','state changed','OS::TripleO::PostDeploySteps',NULL,1302),(2128,'d88b0b73-337d-419b-9b6b-e9ddf86e3635','e859a2ee-38d3-411a-99f8-e1215b7d5532','2026-06-10 07:48:36',NULL,'CREATE','COMPLETE','overcloud','e859a2ee-38d3-411a-99f8-e1215b7d5532','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL);
/*!40000 ALTER TABLE `event` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `migrate_version`
--

DROP TABLE IF EXISTS `migrate_version`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `migrate_version` (
  `repository_id` varchar(250) NOT NULL,
  `repository_path` text DEFAULT NULL,
  `version` int(11) DEFAULT NULL,
  PRIMARY KEY (`repository_id`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1 COLLATE=latin1_swedish_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `migrate_version`
--

LOCK TABLES `migrate_version` WRITE;
/*!40000 ALTER TABLE `migrate_version` DISABLE KEYS */;
INSERT INTO `migrate_version` VALUES ('heat','/usr/lib/python3.9/site-packages/heat/db/sqlalchemy/migrate_repo',86);
/*!40000 ALTER TABLE `migrate_version` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `raw_template`
--

DROP TABLE IF EXISTS `raw_template`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `raw_template` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `created_at` datetime DEFAULT NULL,
  `updated_at` datetime DEFAULT NULL,
  `template` longtext DEFAULT NULL,
  `files` longtext DEFAULT NULL,
  `environment` longtext DEFAULT NULL,
  `files_id` int(11) DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `raw_tmpl_files_fkey_ref` (`files_id`),
  CONSTRAINT `raw_tmpl_files_fkey_ref` FOREIGN KEY (`files_id`) REFERENCES `raw_template_files` (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=287 DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `raw_template`
--

LOCK TABLES `raw_template` WRITE;
/*!40000 ALTER TABLE `raw_template` DISABLE KEYS */;
INSERT INTO `raw_template` VALUES (1,'2026-06-10 07:46:20',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Deploy an OpenStack environment, consisting of several node types (roles), Controller, Compute, BlockStorage, SwiftStorage and CephStorage. The Storage roles enable independent scaling of the storage components, but the minimal deployment is one Controller and one Compute node.\\n\", \"parameters\": {\"CloudNameStorage\": {\"default\": \"overcloud.storage.localdomain\", \"description\": \"The DNS name of this cloud\'s storage endpoint. E.g. \'ci-overcloud.storage.tripleo.org\'.\\n\", \"type\": \"string\"}, \"StorageVirtualFixedIPs\": {\"default\": [], \"description\": \"Control the IP allocation for the StorageVirtualInterface port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"type\": \"json\"}, \"CloudNameStorageManagement\": {\"default\": \"overcloud.storagemgmt.localdomain\", \"description\": \"The DNS name of this cloud\'s storage_mgmt endpoint. E.g. \'ci-overcloud.storagemgmt.tripleo.org\'.\\n\", \"type\": \"string\"}, \"StorageMgmtVirtualFixedIPs\": {\"default\": [], \"description\": \"Control the IP allocation for the StorageMgmtVirtualInterface port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"type\": \"json\"}, \"CloudNameInternal\": {\"default\": \"overcloud.internalapi.localdomain\", \"description\": \"The DNS name of this cloud\'s internal_api endpoint. E.g. \'ci-overcloud.internalapi.tripleo.org\'.\\n\", \"type\": \"string\"}, \"InternalApiVirtualFixedIPs\": {\"default\": [], \"description\": \"Control the IP allocation for the InternalApiVirtualInterface port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"type\": \"json\"}, \"CloudName\": {\"default\": \"overcloud.localdomain\", \"description\": \"The DNS name of this cloud. E.g. ci-overcloud.tripleo.org\", \"type\": \"string\"}, \"PublicVirtualFixedIPs\": {\"default\": [], \"description\": \"Control the IP allocation for the PublicVirtualInterface port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"type\": \"json\"}, \"ExternalVirtualFixedIPs\": {\"default\": [], \"description\": \"Control the IP allocation for the ExternalVirtualInterface port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"type\": \"json\"}, \"CloudNameCtlplane\": {\"default\": \"overcloud.ctlplane.localdomain\", \"description\": \"The DNS name of this cloud\'s provisioning network endpoint. E.g. \'ci-overcloud.ctlplane.tripleo.org\'.\\n\", \"type\": \"string\"}, \"ExtraHostFileEntries\": {\"default\": [], \"description\": \"List of extra hosts entries to be appended to /etc/hosts\", \"type\": \"comma_delimited_list\"}, \"UndercloudHostsEntries\": {\"default\": [], \"description\": \"List of undercloud hosts entries to be appended to /etc/hosts. The value is populated with the HEAT_HOSTS entries on the undercloud by tripleoclient when running deploy.\\n\", \"type\": \"comma_delimited_list\"}, \"EndpointMapOverride\": {\"default\": {}, \"description\": \"Can be used to override the calcluated EndpointMap\", \"type\": \"json\"}, \"ExtraConfig\": {\"default\": {}, \"description\": \"Additional hiera configuration to inject into the cluster.\\n\", \"type\": \"json\"}, \"DeployedServerPortMap\": {\"default\": {}, \"type\": \"json\"}, \"NeutronControlPlaneID\": {\"default\": \"ctlplane\", \"type\": \"string\", \"description\": \"Neutron ID or name for ctlplane network.\"}, \"NeutronPhysicalBridge\": {\"default\": \"br-ex\", \"description\": \"An OVS bridge to create for accessing external networks.\", \"type\": \"string\"}, \"NeutronPublicInterface\": {\"default\": \"nic1\", \"description\": \"Which interface to add to the NeutronPhysicalBridge.\", \"type\": \"string\"}, \"ControlPlaneSubnet\": {\"description\": \"The name of the undercloud Neutron control plane subnet\", \"default\": \"ctlplane-subnet\", \"type\": \"string\"}, \"ControlPlaneSubnetCidr\": {\"default\": \"\", \"description\": \"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\n\", \"type\": \"string\"}, \"DnsSearchDomains\": {\"default\": [], \"description\": \"A list of DNS search domains to be added (in order) to resolv.conf.\", \"type\": \"comma_delimited_list\"}, \"ControlFixedIPs\": {\"default\": [], \"description\": \"Control the IP allocation for the ControlVirtualIP port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"type\": \"json\"}, \"RabbitCookieSalt\": {\"type\": \"string\", \"default\": \"unset\", \"description\": \"Salt for the rabbit cookie, change this to force the randomly generated rabbit cookie to change.\"}, \"CloudDomain\": {\"default\": \"localdomain\", \"type\": \"string\", \"description\": \"The DNS domain used for the hosts. This must match the overcloud_domain_name configured on the undercloud.\\n\"}, \"ServerMetadata\": {\"default\": {}, \"description\": \"Extra properties or metadata passed to Nova for the created nodes in the overcloud. It\'s accessible via the Nova metadata API.\\n\", \"type\": \"json\"}, \"HypervisorNeutronPhysicalBridge\": {\"default\": \"br-ex\", \"description\": \"An OVS bridge to create on each hypervisor. This defaults to br-ex the same as the control plane nodes, as we have a uniform configuration of the openvswitch agent. Typically should not need to be changed.\\n\", \"type\": \"string\"}, \"HypervisorNeutronPublicInterface\": {\"default\": \"nic1\", \"description\": \"What interface to add to the HypervisorNeutronPhysicalBridge.\", \"type\": \"string\"}, \"NodeCreateBatchSize\": {\"default\": 30, \"description\": \"Maxiumum batch size for creating nodes\", \"type\": \"number\"}, \"NovaAdditionalCell\": {\"default\": false, \"description\": \"Whether this is an cell additional to the default cell.\", \"type\": \"boolean\"}, \"NovaLocalMetadataPerCell\": {\"default\": false, \"description\": \"Indicates that the nova-metadata API service has been deployed per-cell, so that we can have better performance and data isolation in a multi-cell deployment. Users should consider the use of this configuration depending on how neutron is setup. If networks span cells, you might need to run nova-metadata API service globally. If your networks are segmented along cell boundaries, then you can run nova-metadata API service per cell. When running nova-metadata API service per cell, you should also configure each Neutron metadata-agent to point to the corresponding nova-metadata API service.\\n\", \"type\": \"boolean\"}, \"BondInterfaceOvsOptions\": {\"default\": \"\", \"description\": \"The ovs_options or bonding_options string for the bond interface. Set things like lacp=active and/or bond_mode=balance-slb for OVS bonds or like mode=4 for Linux bonds using this option.\", \"type\": \"string\", \"constraints\": [{\"allowed_pattern\": \"^((?!balance.tcp).)*$\", \"description\": \"The balance-tcp bond mode is known to cause packet loss and should not be used in BondInterfaceOvsOptions.\"}]}, \"NetworkConfigWithAnsible\": {\"description\": \"NetworkConfig with ansible flag\", \"type\": \"boolean\", \"default\": true}, \"ControllerLocalMtu\": {\"default\": 1500, \"description\": \"MTU to use for the Undercloud local_interface.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1000, \"max\": 65536}}]}, \"ControllerNetworkConfigTemplate\": {\"description\": \"Controller NetworkConfig Template\", \"type\": \"string\", \"default\": \"\"}, \"ControllerExtraConfig\": {\"default\": {}, \"description\": \"Role specific additional hiera configuration to inject into the cluster.\\n\", \"type\": \"json\"}, \"controllerExtraConfig\": {\"default\": {}, \"description\": \"DEPRECATED use CellControllerComputeExtraConfig instead\\n\", \"type\": \"json\"}, \"ControllerServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the Controller role.\", \"type\": \"comma_delimited_list\"}, \"ControllerNetworkConfigUpdate\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", existing networks will be updated on the overcloud. This parameter replaces the functionality previously provided by NetworkDeploymentActions. Defaults to \\\"False\\\" so that only new nodes will have their networks configured. This is a role based parameter.\\n\", \"default\": false}, \"ControllerUseNMState\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", NMState provider is used in os-net-config command to apply the network configuration. This is a role based parameter.\\n\", \"default\": false}, \"ControllerIfcfgPurge\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", os-net-config will remove the ifcfg-* provider based configurations and apply the same network_configuration using nmstate provider. This flag is intended to be used along with \\\"ControllerUseNMState: True\\\" ONLY for provider migration use-case. This is a role based parameter.\\n\", \"default\": false}, \"ControllerAnyErrorsFatal\": {\"default\": true, \"type\": \"string\"}, \"ControllerMaxFailPercentage\": {\"default\": 0, \"type\": \"number\"}, \"ControllerCount\": {\"description\": \"Number of Controller nodes to deploy\", \"type\": \"number\", \"default\": 1}, \"ControllerHostnameFormat\": {\"type\": \"string\", \"description\": \"Format for Controller node hostnames Note %index% is translated into the index of the node, e.g 0/1/2 etc and %stackname% is replaced with the stack name e.g overcloud\\n\", \"default\": \"%stackname%-controller-%index%\"}, \"ControllerRemovalPolicies\": {\"default\": [], \"type\": \"json\", \"description\": \"List of resources to be removed from Controller ResourceGroup when doing an update which requires removal of specific resources. Example format ComputeRemovalPolicies: [{\'resource_list\': [\'0\']}]\\n\"}, \"ControllerRemovalPoliciesMode\": {\"default\": \"append\", \"type\": \"string\", \"description\": \"How to handle change to RemovalPolicies for Controller ResourceGroup when doing an update. Default mode \'append\' will append to the existing blacklist and \'update\' would replace the blacklist.\\n\"}, \"ControllerSchedulerHints\": {\"type\": \"json\", \"description\": \"Optional scheduler hints to pass to nova\", \"default\": {}}, \"ControllerParameters\": {\"type\": \"json\", \"description\": \"Optional Role Specific parameters to be provided to service\", \"default\": {}}, \"ControllerExtraGroupVars\": {\"type\": \"json\", \"description\": \"Optional extra Ansible group vars\", \"default\": {}}, \"ControllerControlPlaneSubnet\": {\"default\": \"ctlplane-subnet\", \"description\": \"Name of the subnet on ctlplane network for this role.\\n\", \"type\": \"string\"}, \"ControllerServiceNetMap\": {\"default\": {}, \"description\": \"Role specific ServiceNetMap overrides, the map provided will be merged\\nwith the global ServiceNetMap when passing the ServiceNetMap to the\\nControllerServiceChain resource and the Controller resource group.\\nFor example:\\nControllerServiceNetMap:\\n  NovaLibvirtNetwork: internal_api_leaf2\\n\", \"type\": \"json\"}, \"ControllerNetConfigOverride\": {\"default\": {}, \"description\": \"Custom JSON data to be used to override the os-net-config config.\\nThis is meant to be used by net_config_override parameter in tripleoclient\\nto provide an easy means to pass in custom net configs for the Undercloud.\\n\", \"type\": \"json\"}, \"CellControllerLocalMtu\": {\"default\": 1500, \"description\": \"MTU to use for the Undercloud local_interface.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1000, \"max\": 65536}}]}, \"CellControllerNetworkConfigTemplate\": {\"description\": \"CellController NetworkConfig Template\", \"type\": \"string\", \"default\": \"\"}, \"CellControllerExtraConfig\": {\"default\": {}, \"description\": \"Role specific additional hiera configuration to inject into the cluster.\\n\", \"type\": \"json\"}, \"CellControllerServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the CellController role.\", \"type\": \"comma_delimited_list\"}, \"CellControllerNetworkConfigUpdate\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", existing networks will be updated on the overcloud. This parameter replaces the functionality previously provided by NetworkDeploymentActions. Defaults to \\\"False\\\" so that only new nodes will have their networks configured. This is a role based parameter.\\n\", \"default\": false}, \"CellControllerUseNMState\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", NMState provider is used in os-net-config command to apply the network configuration. This is a role based parameter.\\n\", \"default\": false}, \"CellControllerIfcfgPurge\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", os-net-config will remove the ifcfg-* provider based configurations and apply the same network_configuration using nmstate provider. This flag is intended to be used along with \\\"CellControllerUseNMState: True\\\" ONLY for provider migration use-case. This is a role based parameter.\\n\", \"default\": false}, \"CellControllerAnyErrorsFatal\": {\"default\": true, \"type\": \"string\"}, \"CellControllerMaxFailPercentage\": {\"default\": 0, \"type\": \"number\"}, \"CellControllerCount\": {\"description\": \"Number of CellController nodes to deploy\", \"type\": \"number\", \"default\": 1}, \"CellControllerHostnameFormat\": {\"type\": \"string\", \"description\": \"Format for CellController node hostnames Note %index% is translated into the index of the node, e.g 0/1/2 etc and %stackname% is replaced with the stack name e.g overcloud\\n\", \"default\": \"%stackname%-controller-%index%\"}, \"CellControllerRemovalPolicies\": {\"default\": [], \"type\": \"json\", \"description\": \"List of resources to be removed from CellController ResourceGroup when doing an update which requires removal of specific resources. Example format ComputeRemovalPolicies: [{\'resource_list\': [\'0\']}]\\n\"}, \"CellControllerRemovalPoliciesMode\": {\"default\": \"append\", \"type\": \"string\", \"description\": \"How to handle change to RemovalPolicies for CellController ResourceGroup when doing an update. Default mode \'append\' will append to the existing blacklist and \'update\' would replace the blacklist.\\n\"}, \"CellControllerSchedulerHints\": {\"type\": \"json\", \"description\": \"Optional scheduler hints to pass to nova\", \"default\": {}}, \"CellControllerParameters\": {\"type\": \"json\", \"description\": \"Optional Role Specific parameters to be provided to service\", \"default\": {}}, \"CellControllerExtraGroupVars\": {\"type\": \"json\", \"description\": \"Optional extra Ansible group vars\", \"default\": {}}, \"CellControllerControlPlaneSubnet\": {\"default\": \"ctlplane-subnet\", \"description\": \"Name of the subnet on ctlplane network for this role.\\n\", \"type\": \"string\"}, \"CellControllerServiceNetMap\": {\"default\": {}, \"description\": \"Role specific ServiceNetMap overrides, the map provided will be merged\\nwith the global ServiceNetMap when passing the ServiceNetMap to the\\nCellControllerServiceChain resource and the CellController resource group.\\nFor example:\\nCellControllerServiceNetMap:\\n  NovaLibvirtNetwork: internal_api_leaf2\\n\", \"type\": \"json\"}, \"CellControllerNetConfigOverride\": {\"default\": {}, \"description\": \"Custom JSON data to be used to override the os-net-config config.\\nThis is meant to be used by net_config_override parameter in tripleoclient\\nto provide an easy means to pass in custom net configs for the Undercloud.\\n\", \"type\": \"json\"}, \"CellControllerComputeLocalMtu\": {\"default\": 1500, \"description\": \"MTU to use for the Undercloud local_interface.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1000, \"max\": 65536}}]}, \"CellControllerComputeNetworkConfigTemplate\": {\"description\": \"CellControllerCompute NetworkConfig Template\", \"type\": \"string\", \"default\": \"\"}, \"CellControllerComputeExtraConfig\": {\"default\": {}, \"description\": \"Role specific additional hiera configuration to inject into the cluster.\\n\", \"type\": \"json\"}, \"CellControllerComputeServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the CellControllerCompute role.\", \"type\": \"comma_delimited_list\"}, \"CellControllerComputeNetworkConfigUpdate\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", existing networks will be updated on the overcloud. This parameter replaces the functionality previously provided by NetworkDeploymentActions. Defaults to \\\"False\\\" so that only new nodes will have their networks configured. This is a role based parameter.\\n\", \"default\": false}, \"CellControllerComputeUseNMState\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", NMState provider is used in os-net-config command to apply the network configuration. This is a role based parameter.\\n\", \"default\": false}, \"CellControllerComputeIfcfgPurge\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", os-net-config will remove the ifcfg-* provider based configurations and apply the same network_configuration using nmstate provider. This flag is intended to be used along with \\\"CellControllerComputeUseNMState: True\\\" ONLY for provider migration use-case. This is a role based parameter.\\n\", \"default\": false}, \"CellControllerComputeAnyErrorsFatal\": {\"default\": true, \"type\": \"string\"}, \"CellControllerComputeMaxFailPercentage\": {\"default\": 0, \"type\": \"number\"}, \"CellControllerComputeCount\": {\"description\": \"Number of CellControllerCompute nodes to deploy\", \"type\": \"number\", \"default\": 1}, \"CellControllerComputeHostnameFormat\": {\"type\": \"string\", \"description\": \"Format for CellControllerCompute node hostnames Note %index% is translated into the index of the node, e.g 0/1/2 etc and %stackname% is replaced with the stack name e.g overcloud\\n\", \"default\": \"%stackname%-controller-compute-%index%\"}, \"CellControllerComputeRemovalPolicies\": {\"default\": [], \"type\": \"json\", \"description\": \"List of resources to be removed from CellControllerCompute ResourceGroup when doing an update which requires removal of specific resources. Example format ComputeRemovalPolicies: [{\'resource_list\': [\'0\']}]\\n\"}, \"CellControllerComputeRemovalPoliciesMode\": {\"default\": \"append\", \"type\": \"string\", \"description\": \"How to handle change to RemovalPolicies for CellControllerCompute ResourceGroup when doing an update. Default mode \'append\' will append to the existing blacklist and \'update\' would replace the blacklist.\\n\"}, \"CellControllerComputeSchedulerHints\": {\"type\": \"json\", \"description\": \"Optional scheduler hints to pass to nova\", \"default\": {}}, \"CellControllerComputeParameters\": {\"type\": \"json\", \"description\": \"Optional Role Specific parameters to be provided to service\", \"default\": {}}, \"CellControllerComputeExtraGroupVars\": {\"type\": \"json\", \"description\": \"Optional extra Ansible group vars\", \"default\": {}}, \"CellControllerComputeControlPlaneSubnet\": {\"default\": \"ctlplane-subnet\", \"description\": \"Name of the subnet on ctlplane network for this role.\\n\", \"type\": \"string\"}, \"CellControllerComputeServiceNetMap\": {\"default\": {}, \"description\": \"Role specific ServiceNetMap overrides, the map provided will be merged\\nwith the global ServiceNetMap when passing the ServiceNetMap to the\\nCellControllerComputeServiceChain resource and the CellControllerCompute resource group.\\nFor example:\\nCellControllerComputeServiceNetMap:\\n  NovaLibvirtNetwork: internal_api_leaf2\\n\", \"type\": \"json\"}, \"CellControllerComputeNetConfigOverride\": {\"default\": {}, \"description\": \"Custom JSON data to be used to override the os-net-config config.\\nThis is meant to be used by net_config_override parameter in tripleoclient\\nto provide an easy means to pass in custom net configs for the Undercloud.\\n\", \"type\": \"json\"}, \"ComputeLocalMtu\": {\"default\": 1500, \"description\": \"MTU to use for the Undercloud local_interface.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1000, \"max\": 65536}}]}, \"ComputeNetworkConfigTemplate\": {\"description\": \"Compute NetworkConfig Template\", \"type\": \"string\", \"default\": \"\"}, \"ComputeExtraConfig\": {\"default\": {}, \"description\": \"Role specific additional hiera configuration to inject into the cluster.\\n\", \"type\": \"json\"}, \"NovaComputeExtraConfig\": {\"default\": {}, \"description\": \"DEPRECATED use ComputeExtraConfig instead\\n\", \"type\": \"json\"}, \"ComputeServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the Compute role.\", \"type\": \"comma_delimited_list\"}, \"ComputeNetworkConfigUpdate\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", existing networks will be updated on the overcloud. This parameter replaces the functionality previously provided by NetworkDeploymentActions. Defaults to \\\"False\\\" so that only new nodes will have their networks configured. This is a role based parameter.\\n\", \"default\": false}, \"ComputeUseNMState\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", NMState provider is used in os-net-config command to apply the network configuration. This is a role based parameter.\\n\", \"default\": false}, \"ComputeIfcfgPurge\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", os-net-config will remove the ifcfg-* provider based configurations and apply the same network_configuration using nmstate provider. This flag is intended to be used along with \\\"ComputeUseNMState: True\\\" ONLY for provider migration use-case. This is a role based parameter.\\n\", \"default\": false}, \"ComputeAnyErrorsFatal\": {\"default\": true, \"type\": \"string\"}, \"ComputeMaxFailPercentage\": {\"default\": 0, \"type\": \"number\"}, \"ComputeCount\": {\"description\": \"Number of Compute nodes to deploy\", \"type\": \"number\", \"default\": 1}, \"ComputeHostnameFormat\": {\"type\": \"string\", \"description\": \"Format for Compute node hostnames Note %index% is translated into the index of the node, e.g 0/1/2 etc and %stackname% is replaced with the stack name e.g overcloud\\n\", \"default\": \"%stackname%-novacompute-%index%\"}, \"ComputeRemovalPolicies\": {\"default\": [], \"type\": \"json\", \"description\": \"List of resources to be removed from Compute ResourceGroup when doing an update which requires removal of specific resources. Example format ComputeRemovalPolicies: [{\'resource_list\': [\'0\']}]\\n\"}, \"ComputeRemovalPoliciesMode\": {\"default\": \"append\", \"type\": \"string\", \"description\": \"How to handle change to RemovalPolicies for Compute ResourceGroup when doing an update. Default mode \'append\' will append to the existing blacklist and \'update\' would replace the blacklist.\\n\"}, \"ComputeSchedulerHints\": {\"type\": \"json\", \"description\": \"Optional scheduler hints to pass to nova\", \"default\": {}}, \"NovaComputeSchedulerHints\": {\"type\": \"json\", \"description\": \"DEPRECATED - use ComputeSchedulerHints instead\", \"default\": {}}, \"ComputeParameters\": {\"type\": \"json\", \"description\": \"Optional Role Specific parameters to be provided to service\", \"default\": {}}, \"ComputeExtraGroupVars\": {\"type\": \"json\", \"description\": \"Optional extra Ansible group vars\", \"default\": {}}, \"ComputeControlPlaneSubnet\": {\"default\": \"ctlplane-subnet\", \"description\": \"Name of the subnet on ctlplane network for this role.\\n\", \"type\": \"string\"}, \"ComputeServiceNetMap\": {\"default\": {}, \"description\": \"Role specific ServiceNetMap overrides, the map provided will be merged\\nwith the global ServiceNetMap when passing the ServiceNetMap to the\\nComputeServiceChain resource and the Compute resource group.\\nFor example:\\nComputeServiceNetMap:\\n  NovaLibvirtNetwork: internal_api_leaf2\\n\", \"type\": \"json\"}, \"ComputeNetConfigOverride\": {\"default\": {}, \"description\": \"Custom JSON data to be used to override the os-net-config config.\\nThis is meant to be used by net_config_override parameter in tripleoclient\\nto provide an easy means to pass in custom net configs for the Undercloud.\\n\", \"type\": \"json\"}, \"BlockStorageLocalMtu\": {\"default\": 1500, \"description\": \"MTU to use for the Undercloud local_interface.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1000, \"max\": 65536}}]}, \"BlockStorageNetworkConfigTemplate\": {\"description\": \"BlockStorage NetworkConfig Template\", \"type\": \"string\", \"default\": \"\"}, \"BlockStorageExtraConfig\": {\"default\": {}, \"description\": \"Role specific additional hiera configuration to inject into the cluster.\\n\", \"type\": \"json\"}, \"BlockStorageServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the BlockStorage role.\", \"type\": \"comma_delimited_list\"}, \"BlockStorageNetworkConfigUpdate\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", existing networks will be updated on the overcloud. This parameter replaces the functionality previously provided by NetworkDeploymentActions. Defaults to \\\"False\\\" so that only new nodes will have their networks configured. This is a role based parameter.\\n\", \"default\": false}, \"BlockStorageUseNMState\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", NMState provider is used in os-net-config command to apply the network configuration. This is a role based parameter.\\n\", \"default\": false}, \"BlockStorageIfcfgPurge\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", os-net-config will remove the ifcfg-* provider based configurations and apply the same network_configuration using nmstate provider. This flag is intended to be used along with \\\"BlockStorageUseNMState: True\\\" ONLY for provider migration use-case. This is a role based parameter.\\n\", \"default\": false}, \"BlockStorageAnyErrorsFatal\": {\"default\": true, \"type\": \"string\"}, \"BlockStorageMaxFailPercentage\": {\"default\": 0, \"type\": \"number\"}, \"BlockStorageCount\": {\"description\": \"Number of BlockStorage nodes to deploy\", \"type\": \"number\", \"default\": 0}, \"BlockStorageHostnameFormat\": {\"type\": \"string\", \"description\": \"Format for BlockStorage node hostnames Note %index% is translated into the index of the node, e.g 0/1/2 etc and %stackname% is replaced with the stack name e.g overcloud\\n\", \"default\": \"%stackname%-blockstorage-%index%\"}, \"BlockStorageRemovalPolicies\": {\"default\": [], \"type\": \"json\", \"description\": \"List of resources to be removed from BlockStorage ResourceGroup when doing an update which requires removal of specific resources. Example format ComputeRemovalPolicies: [{\'resource_list\': [\'0\']}]\\n\"}, \"BlockStorageRemovalPoliciesMode\": {\"default\": \"append\", \"type\": \"string\", \"description\": \"How to handle change to RemovalPolicies for BlockStorage ResourceGroup when doing an update. Default mode \'append\' will append to the existing blacklist and \'update\' would replace the blacklist.\\n\"}, \"BlockStorageSchedulerHints\": {\"type\": \"json\", \"description\": \"Optional scheduler hints to pass to nova\", \"default\": {}}, \"BlockStorageParameters\": {\"type\": \"json\", \"description\": \"Optional Role Specific parameters to be provided to service\", \"default\": {}}, \"BlockStorageExtraGroupVars\": {\"type\": \"json\", \"description\": \"Optional extra Ansible group vars\", \"default\": {}}, \"BlockStorageControlPlaneSubnet\": {\"default\": \"ctlplane-subnet\", \"description\": \"Name of the subnet on ctlplane network for this role.\\n\", \"type\": \"string\"}, \"BlockStorageServiceNetMap\": {\"default\": {}, \"description\": \"Role specific ServiceNetMap overrides, the map provided will be merged\\nwith the global ServiceNetMap when passing the ServiceNetMap to the\\nBlockStorageServiceChain resource and the BlockStorage resource group.\\nFor example:\\nBlockStorageServiceNetMap:\\n  NovaLibvirtNetwork: internal_api_leaf2\\n\", \"type\": \"json\"}, \"BlockStorageNetConfigOverride\": {\"default\": {}, \"description\": \"Custom JSON data to be used to override the os-net-config config.\\nThis is meant to be used by net_config_override parameter in tripleoclient\\nto provide an easy means to pass in custom net configs for the Undercloud.\\n\", \"type\": \"json\"}, \"ObjectStorageLocalMtu\": {\"default\": 1500, \"description\": \"MTU to use for the Undercloud local_interface.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1000, \"max\": 65536}}]}, \"ObjectStorageNetworkConfigTemplate\": {\"description\": \"ObjectStorage NetworkConfig Template\", \"type\": \"string\", \"default\": \"\"}, \"ObjectStorageExtraConfig\": {\"default\": {}, \"description\": \"Role specific additional hiera configuration to inject into the cluster.\\n\", \"type\": \"json\"}, \"ObjectStorageServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the ObjectStorage role.\", \"type\": \"comma_delimited_list\"}, \"ObjectStorageNetworkConfigUpdate\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", existing networks will be updated on the overcloud. This parameter replaces the functionality previously provided by NetworkDeploymentActions. Defaults to \\\"False\\\" so that only new nodes will have their networks configured. This is a role based parameter.\\n\", \"default\": false}, \"ObjectStorageUseNMState\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", NMState provider is used in os-net-config command to apply the network configuration. This is a role based parameter.\\n\", \"default\": false}, \"ObjectStorageIfcfgPurge\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", os-net-config will remove the ifcfg-* provider based configurations and apply the same network_configuration using nmstate provider. This flag is intended to be used along with \\\"ObjectStorageUseNMState: True\\\" ONLY for provider migration use-case. This is a role based parameter.\\n\", \"default\": false}, \"ObjectStorageAnyErrorsFatal\": {\"default\": true, \"type\": \"string\"}, \"ObjectStorageMaxFailPercentage\": {\"default\": 0, \"type\": \"number\"}, \"ObjectStorageCount\": {\"description\": \"Number of ObjectStorage nodes to deploy\", \"type\": \"number\", \"default\": 0}, \"ObjectStorageHostnameFormat\": {\"type\": \"string\", \"description\": \"Format for ObjectStorage node hostnames Note %index% is translated into the index of the node, e.g 0/1/2 etc and %stackname% is replaced with the stack name e.g overcloud\\n\", \"default\": \"%stackname%-objectstorage-%index%\"}, \"ObjectStorageRemovalPolicies\": {\"default\": [], \"type\": \"json\", \"description\": \"List of resources to be removed from ObjectStorage ResourceGroup when doing an update which requires removal of specific resources. Example format ComputeRemovalPolicies: [{\'resource_list\': [\'0\']}]\\n\"}, \"ObjectStorageRemovalPoliciesMode\": {\"default\": \"append\", \"type\": \"string\", \"description\": \"How to handle change to RemovalPolicies for ObjectStorage ResourceGroup when doing an update. Default mode \'append\' will append to the existing blacklist and \'update\' would replace the blacklist.\\n\"}, \"ObjectStorageSchedulerHints\": {\"type\": \"json\", \"description\": \"Optional scheduler hints to pass to nova\", \"default\": {}}, \"ObjectStorageParameters\": {\"type\": \"json\", \"description\": \"Optional Role Specific parameters to be provided to service\", \"default\": {}}, \"ObjectStorageExtraGroupVars\": {\"type\": \"json\", \"description\": \"Optional extra Ansible group vars\", \"default\": {}}, \"ObjectStorageControlPlaneSubnet\": {\"default\": \"ctlplane-subnet\", \"description\": \"Name of the subnet on ctlplane network for this role.\\n\", \"type\": \"string\"}, \"ObjectStorageServiceNetMap\": {\"default\": {}, \"description\": \"Role specific ServiceNetMap overrides, the map provided will be merged\\nwith the global ServiceNetMap when passing the ServiceNetMap to the\\nObjectStorageServiceChain resource and the ObjectStorage resource group.\\nFor example:\\nObjectStorageServiceNetMap:\\n  NovaLibvirtNetwork: internal_api_leaf2\\n\", \"type\": \"json\"}, \"ObjectStorageNetConfigOverride\": {\"default\": {}, \"description\": \"Custom JSON data to be used to override the os-net-config config.\\nThis is meant to be used by net_config_override parameter in tripleoclient\\nto provide an easy means to pass in custom net configs for the Undercloud.\\n\", \"type\": \"json\"}, \"CephStorageLocalMtu\": {\"default\": 1500, \"description\": \"MTU to use for the Undercloud local_interface.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1000, \"max\": 65536}}]}, \"CephStorageNetworkConfigTemplate\": {\"description\": \"CephStorage NetworkConfig Template\", \"type\": \"string\", \"default\": \"\"}, \"CephStorageExtraConfig\": {\"default\": {}, \"description\": \"Role specific additional hiera configuration to inject into the cluster.\\n\", \"type\": \"json\"}, \"CephStorageServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the CephStorage role.\", \"type\": \"comma_delimited_list\"}, \"CephStorageNetworkConfigUpdate\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", existing networks will be updated on the overcloud. This parameter replaces the functionality previously provided by NetworkDeploymentActions. Defaults to \\\"False\\\" so that only new nodes will have their networks configured. This is a role based parameter.\\n\", \"default\": false}, \"CephStorageUseNMState\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", NMState provider is used in os-net-config command to apply the network configuration. This is a role based parameter.\\n\", \"default\": false}, \"CephStorageIfcfgPurge\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", os-net-config will remove the ifcfg-* provider based configurations and apply the same network_configuration using nmstate provider. This flag is intended to be used along with \\\"CephStorageUseNMState: True\\\" ONLY for provider migration use-case. This is a role based parameter.\\n\", \"default\": false}, \"CephStorageAnyErrorsFatal\": {\"default\": true, \"type\": \"string\"}, \"CephStorageMaxFailPercentage\": {\"default\": 0, \"type\": \"number\"}, \"CephStorageCount\": {\"description\": \"Number of CephStorage nodes to deploy\", \"type\": \"number\", \"default\": 0}, \"CephStorageHostnameFormat\": {\"type\": \"string\", \"description\": \"Format for CephStorage node hostnames Note %index% is translated into the index of the node, e.g 0/1/2 etc and %stackname% is replaced with the stack name e.g overcloud\\n\", \"default\": \"%stackname%-cephstorage-%index%\"}, \"CephStorageRemovalPolicies\": {\"default\": [], \"type\": \"json\", \"description\": \"List of resources to be removed from CephStorage ResourceGroup when doing an update which requires removal of specific resources. Example format ComputeRemovalPolicies: [{\'resource_list\': [\'0\']}]\\n\"}, \"CephStorageRemovalPoliciesMode\": {\"default\": \"append\", \"type\": \"string\", \"description\": \"How to handle change to RemovalPolicies for CephStorage ResourceGroup when doing an update. Default mode \'append\' will append to the existing blacklist and \'update\' would replace the blacklist.\\n\"}, \"CephStorageSchedulerHints\": {\"type\": \"json\", \"description\": \"Optional scheduler hints to pass to nova\", \"default\": {}}, \"CephStorageParameters\": {\"type\": \"json\", \"description\": \"Optional Role Specific parameters to be provided to service\", \"default\": {}}, \"CephStorageExtraGroupVars\": {\"type\": \"json\", \"description\": \"Optional extra Ansible group vars\", \"default\": {}}, \"CephStorageControlPlaneSubnet\": {\"default\": \"ctlplane-subnet\", \"description\": \"Name of the subnet on ctlplane network for this role.\\n\", \"type\": \"string\"}, \"CephStorageServiceNetMap\": {\"default\": {}, \"description\": \"Role specific ServiceNetMap overrides, the map provided will be merged\\nwith the global ServiceNetMap when passing the ServiceNetMap to the\\nCephStorageServiceChain resource and the CephStorage resource group.\\nFor example:\\nCephStorageServiceNetMap:\\n  NovaLibvirtNetwork: internal_api_leaf2\\n\", \"type\": \"json\"}, \"CephStorageNetConfigOverride\": {\"default\": {}, \"description\": \"Custom JSON data to be used to override the os-net-config config.\\nThis is meant to be used by net_config_override parameter in tripleoclient\\nto provide an easy means to pass in custom net configs for the Undercloud.\\n\", \"type\": \"json\"}, \"NetworkerLocalMtu\": {\"default\": 1500, \"description\": \"MTU to use for the Undercloud local_interface.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1000, \"max\": 65536}}]}, \"NetworkerNetworkConfigTemplate\": {\"description\": \"Networker NetworkConfig Template\", \"type\": \"string\", \"default\": \"\"}, \"NetworkerExtraConfig\": {\"default\": {}, \"description\": \"Role specific additional hiera configuration to inject into the cluster.\\n\", \"type\": \"json\"}, \"NetworkerServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the Networker role.\", \"type\": \"comma_delimited_list\"}, \"NetworkerNetworkConfigUpdate\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", existing networks will be updated on the overcloud. This parameter replaces the functionality previously provided by NetworkDeploymentActions. Defaults to \\\"False\\\" so that only new nodes will have their networks configured. This is a role based parameter.\\n\", \"default\": false}, \"NetworkerUseNMState\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", NMState provider is used in os-net-config command to apply the network configuration. This is a role based parameter.\\n\", \"default\": false}, \"NetworkerIfcfgPurge\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", os-net-config will remove the ifcfg-* provider based configurations and apply the same network_configuration using nmstate provider. This flag is intended to be used along with \\\"NetworkerUseNMState: True\\\" ONLY for provider migration use-case. This is a role based parameter.\\n\", \"default\": false}, \"NetworkerAnyErrorsFatal\": {\"default\": true, \"type\": \"string\"}, \"NetworkerMaxFailPercentage\": {\"default\": 0, \"type\": \"number\"}, \"NetworkerCount\": {\"description\": \"Number of Networker nodes to deploy\", \"type\": \"number\", \"default\": 0}, \"NetworkerHostnameFormat\": {\"type\": \"string\", \"description\": \"Format for Networker node hostnames Note %index% is translated into the index of the node, e.g 0/1/2 etc and %stackname% is replaced with the stack name e.g overcloud\\n\", \"default\": \"%stackname%-networker-%index%\"}, \"NetworkerRemovalPolicies\": {\"default\": [], \"type\": \"json\", \"description\": \"List of resources to be removed from Networker ResourceGroup when doing an update which requires removal of specific resources. Example format ComputeRemovalPolicies: [{\'resource_list\': [\'0\']}]\\n\"}, \"NetworkerRemovalPoliciesMode\": {\"default\": \"append\", \"type\": \"string\", \"description\": \"How to handle change to RemovalPolicies for Networker ResourceGroup when doing an update. Default mode \'append\' will append to the existing blacklist and \'update\' would replace the blacklist.\\n\"}, \"NetworkerSchedulerHints\": {\"type\": \"json\", \"description\": \"Optional scheduler hints to pass to nova\", \"default\": {}}, \"NetworkerParameters\": {\"type\": \"json\", \"description\": \"Optional Role Specific parameters to be provided to service\", \"default\": {}}, \"NetworkerExtraGroupVars\": {\"type\": \"json\", \"description\": \"Optional extra Ansible group vars\", \"default\": {}}, \"NetworkerControlPlaneSubnet\": {\"default\": \"ctlplane-subnet\", \"description\": \"Name of the subnet on ctlplane network for this role.\\n\", \"type\": \"string\"}, \"NetworkerServiceNetMap\": {\"default\": {}, \"description\": \"Role specific ServiceNetMap overrides, the map provided will be merged\\nwith the global ServiceNetMap when passing the ServiceNetMap to the\\nNetworkerServiceChain resource and the Networker resource group.\\nFor example:\\nNetworkerServiceNetMap:\\n  NovaLibvirtNetwork: internal_api_leaf2\\n\", \"type\": \"json\"}, \"NetworkerNetConfigOverride\": {\"default\": {}, \"description\": \"Custom JSON data to be used to override the os-net-config config.\\nThis is meant to be used by net_config_override parameter in tripleoclient\\nto provide an easy means to pass in custom net configs for the Undercloud.\\n\", \"type\": \"json\"}, \"UpdateIdentifier\": {\"default\": \"\", \"type\": \"string\", \"description\": \"Setting to a previously unused value during stack-update will trigger package update on all nodes\\n\"}, \"DeployIdentifier\": {\"default\": \"\", \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}, \"AddVipsToEtcHosts\": {\"default\": true, \"type\": \"boolean\", \"description\": \"Set to true to append per network Vips to /etc/hosts on each node.\\n\"}, \"DeploymentServerBlacklist\": {\"default\": [], \"type\": \"comma_delimited_list\", \"description\": \"List of server hostnames to blacklist from any triggered deployments.\\n\"}, \"GlobalConfigExtraMapData\": {\"type\": \"json\", \"default\": {}, \"description\": \"Map of extra global_config_settings data to set on each node.\"}, \"NetConfigDataLookup\": {\"type\": \"json\", \"default\": {}, \"description\": \"Configure os-net-config mappings for specific nodes Your environment file needs to look like:\\n  parameter_defaults:\\n    NetConfigDataLookup:\\n      node1:\\n        nic1: \\\"00:c8:7c:e6:f0:2e\\\"\\n      node2:\\n        nic1: \\\"00:18:7d:99:0c:b6\\\"\\n      node3:\\n        dmiString: \'system-uuid\'\\n        id: \'A8C85861-1B16-4803-8689-AFC62984F8F6\'\\n        nic1: em3\\n      # Dell PowerEdge\\n      nodegroup1:\\n        dmiString: \\\"system-product-name\\\"\\n        id: \\\"PowerEdge R630\\\"\\n        nic1: em3\\n        nic2: em1\\n        nic3: em2\\n      # Cisco UCS B200-M4\\\"\\n      nodegroup2:\\n        dmiString: \\\"system-product-name\\\"\\n        id: \\\"UCSB-B200-M4\\\"\\n        nic1: enp7s0\\n        nic2: enp6s0\\n\\nThis will result in the first node* entry where either a mac matches a local device or a DMI String matches the specified id being written as a mapping file for os-net-config. (/etc/os-net-config/mapping.yaml)\\n\"}, \"DnsServers\": {\"default\": [], \"description\": \"DNS servers to use for the Overcloud (2 max for some implementations). If not set the nameservers configured in the ctlplane subnet\'s dns_nameservers attribute will be used.\\n\", \"type\": \"comma_delimited_list\"}, \"RootStackName\": {\"description\": \"The name of the stack/plan.\", \"type\": \"string\"}, \"AdminPassword\": {\"description\": \"The password for the keystone admin account, used for monitoring, querying neutron etc.\", \"type\": \"string\", \"hidden\": true}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"Do not use deprecated params, they will be removed.\", \"parameters\": [\"DnsServers\", \"NovaComputeSchedulerHints\", \"NovaComputeExtraConfig\"]}], \"conditions\": {\"add_vips_to_etc_hosts\": {\"equals\": [{\"get_param\": \"AddVipsToEtcHosts\"}, true]}, \"control_fixed_ip_not_set\": {\"equals\": [{\"get_param\": \"ControlFixedIPs\"}, []]}, \"storage_virtual_fixed_ip_set\": {\"not\": {\"equals\": [{\"get_param\": \"StorageVirtualFixedIPs\"}, []]}}, \"storage_mgmt_virtual_fixed_ip_set\": {\"not\": {\"equals\": [{\"get_param\": \"StorageMgmtVirtualFixedIPs\"}, []]}}, \"internal_api_virtual_fixed_ip_set\": {\"not\": {\"equals\": [{\"get_param\": \"InternalApiVirtualFixedIPs\"}, []]}}, \"tenant_virtual_fixed_ip_set\": {\"not\": {\"equals\": [{\"get_param\": \"TenantVirtualFixedIPs\"}, []]}}, \"public_virtual_fixed_ip_set\": {\"not\": {\"equals\": [{\"get_param\": \"PublicVirtualFixedIPs\"}, []]}}, \"set_default_mysql_cell_internal\": {\"or\": [{\"equals\": [{\"get_param\": \"NovaAdditionalCell\"}, true]}, {\"and\": [{\"equals\": [{\"get_param\": \"NovaAdditionalCell\"}, false]}, {\"equals\": [{\"get_param\": [\"EndpointMapOverride\", \"MysqlCellInternal\"]}, \"\"]}]}]}, \"set_default_nova_vnc_proxy_cell_public\": {\"or\": [{\"equals\": [{\"get_param\": \"NovaAdditionalCell\"}, true]}, {\"and\": [{\"equals\": [{\"get_param\": \"NovaAdditionalCell\"}, false]}, {\"equals\": [{\"get_param\": [\"EndpointMapOverride\", \"NovaVNCProxyCellPublic\"]}, \"\"]}]}]}, \"set_default_nova_metadata_cell_internal\": {\"or\": [{\"equals\": [{\"get_param\": \"NovaLocalMetadataPerCell\"}, true]}, {\"and\": [{\"equals\": [{\"get_param\": \"NovaLocalMetadataPerCell\"}, false]}, {\"equals\": [{\"get_param\": [\"EndpointMapOverride\", \"NovaMetadataCellInternal\"]}, \"\"]}]}]}, \"dnsservers_set\": {\"not\": {\"equals\": [{\"get_param\": \"DnsServers\"}, []]}}}, \"resources\": {\"VipHosts\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": [{\"str_replace\": {\"template\": \"IP  HOST\", \"params\": {\"IP\": {\"get_attr\": [\"VipMap\", \"net_ip_map\", \"ctlplane\"]}, \"HOST\": {\"get_param\": \"CloudNameCtlplane\"}}}}, {\"str_replace\": {\"template\": \"IP  HOST\", \"params\": {\"IP\": {\"get_attr\": [\"VipMap\", \"net_ip_map\", \"storage\"]}, \"HOST\": {\"get_param\": \"CloudNameStorage\"}}}}, {\"str_replace\": {\"template\": \"IP  HOST\", \"params\": {\"IP\": {\"get_attr\": [\"VipMap\", \"net_ip_map\", \"storage_mgmt\"]}, \"HOST\": {\"get_param\": \"CloudNameStorageManagement\"}}}}, {\"str_replace\": {\"template\": \"IP  HOST\", \"params\": {\"IP\": {\"get_attr\": [\"VipMap\", \"net_ip_map\", \"internal_api\"]}, \"HOST\": {\"get_param\": \"CloudNameInternal\"}}}}, {\"str_replace\": {\"template\": \"IP  HOST\", \"params\": {\"IP\": {\"get_attr\": [\"VipMap\", \"net_ip_map\", \"external\"]}, \"HOST\": {\"get_param\": \"CloudName\"}}}}]}}, \"NetCidrMapValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_merge\": [{\"get_attr\": [\"Networks\", \"net_cidr_map\"]}, {\"ctlplane\": {\"get_attr\": [\"ControlVirtualIP\", \"network\", \"tags\"]}}]}, {\"keys\": {\"ctlplane\": {\"get_param\": \"NeutronControlPlaneID\"}}}]}}}, \"NetIpVersionMapValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_merge\": [{\"get_attr\": [\"Networks\", \"net_ip_version_map\"]}, {\"ctlplane\": {\"get_attr\": [\"ControlVirtualIP\", \"subnets\", 0, \"ip_version\"]}}]}, {\"keys\": {\"ctlplane\": {\"get_param\": \"NeutronControlPlaneID\"}}}]}}}, \"ServiceNetMap\": {\"type\": \"OS::TripleO::ServiceNetMap\"}, \"EndpointMap\": {\"type\": \"OS::TripleO::EndpointMap\", \"properties\": {\"CloudEndpoints\": {\"ctlplane\": {\"get_param\": \"CloudNameCtlplane\"}, \"storage\": {\"get_param\": \"CloudNameStorage\"}, \"storage_mgmt\": {\"get_param\": \"CloudNameStorageManagement\"}, \"internal_api\": {\"get_param\": \"CloudNameInternal\"}, \"external\": {\"get_param\": \"CloudName\"}}, \"NetIpMap\": {\"get_attr\": [\"VipMap\", \"net_ip_map\"]}, \"ServiceNetMap\": {\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}}}, \"EndpointMapData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": [{\"get_attr\": [\"EndpointMap\", \"endpoint_map\"]}, {\"get_param\": \"EndpointMapOverride\"}, {\"if\": [\"set_default_mysql_cell_internal\", {\"MysqlCellInternal\": {\"get_attr\": [\"EndpointMap\", \"endpoint_map\", \"MysqlInternal\"]}}, {}]}, {\"if\": [\"set_default_nova_vnc_proxy_cell_public\", {\"NovaVNCProxyCellPublic\": {\"get_attr\": [\"EndpointMap\", \"endpoint_map\", \"NovaVNCProxyPublic\"]}}, {}]}, {\"if\": [\"set_default_nova_metadata_cell_internal\", {\"NovaMetadataCellInternal\": {\"get_attr\": [\"EndpointMap\", \"endpoint_map\", \"NovaMetadataInternal\"]}}, {}]}]}}}, \"NodeAdminUserData\": {\"type\": \"OS::TripleO::NodeAdminUserData\"}, \"NodeTimesyncUserData\": {\"type\": \"OS::TripleO::NodeTimesyncUserData\"}, \"NodeUserData\": {\"type\": \"OS::TripleO::NodeUserData\"}, \"ControllerServiceChain\": {\"type\": \"OS::TripleO::ControllerServices\", \"properties\": {\"Services\": {\"get_param\": \"ControllerServices\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"ControllerServiceNetMap\"}]}, \"ServiceData\": {\"net_cidr_map\": {\"get_attr\": [\"NetCidrMapValue\", \"value\"]}, \"net_vip_map\": {\"get_attr\": [\"VipMap\", \"net_ip_map\"]}, \"net_ip_version_map\": {\"get_attr\": [\"NetIpVersionMapValue\", \"value\"]}, \"vip_subnet_map\": {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\"]}}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"map_merge\": [{\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, {\"get_param\": \"ControllerParameters\"}]}}}, \"ControllerServiceChainRoleData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"get_attr\": [\"ControllerServiceChain\", \"role_data\"]}}}, \"ControllerConfigData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"service_configs\": {\"get_attr\": [\"ControllerServiceConfigSettings\", \"value\"]}, \"service_names\": {\"get_attr\": [\"ControllerServiceNames\", \"value\"]}, \"role_extraconfig\": {\"map_merge\": [{\"tripleo::profile::base::metrics::collectd::sensubility::subscriptions\": {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"tripleo_collectd_sensubility_subscriptions\": {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"get_param\": \"controllerExtraConfig\"}, {\"get_param\": \"ControllerExtraConfig\"}]}, \"extraconfig\": {\"get_param\": \"ExtraConfig\"}, \"hieradata_files\": [\"%{::uuid}\", \"fqdn\", \"docker_puppet\", \"ansible_managed\", \"heat_config_%{::deploy_config_name}\", \"config_step\", \"role_extraconfig\", \"extraconfig\", \"pci_passthrough_whitelist\", \"service_names\", \"service_configs\", \"cloud_domain\", \"bootstrap_node\", \"all_nodes\", \"vip_data\", \"net_ip_map\", \"ovn_chassis_mac_map\", \"%{::osfamily}\", \"neutron_bigswitch_data\", \"upgrade\"]}}}, \"ControllerServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": [{\"get_param\": \"GlobalConfigExtraMapData\"}, {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"config_settings\"]}, {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"yaql\": {\"expression\": \"let(root => $) -> $.data.map.items().where($[0] in coalesce($root.data.services, [])).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"map\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"service_config_settings\"]}]}}, \"services\": {\"get_attr\": [\"ControllerServiceNames\", \"value\"]}}}}]}}}, \"ControllerServiceNames\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"ControllerServiceChain\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> distinct($.data.extra_services.items().where($[0] in coalesce($root.data.enabled_services, [])).select($[1]).flatten() + coalesce($root.data.enabled_services, []))\", \"data\": {\"enabled_services\": {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"service_names\"]}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"ControllerServiceNetMapLower\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map_lower\"]}, {\"yaql\": {\"expression\": \"dict($.data.map.items().select([ regex(`([a-z0-9])([A-Z])`).replace($[0], \'\\\\\\\\1_\\\\\\\\2\').toLower(), $[1]]))\", \"data\": {\"map\": {\"get_param\": \"ControllerServiceNetMap\"}}}}]}}}, \"ControllerIpListMap\": {\"type\": \"OS::TripleO::Network::Ports::NetIpListMap\", \"properties\": {\"ControlPlaneIpList\": {\"get_attr\": [\"Controller\", \"ip_address\"]}, \"StorageIpList\": {\"get_attr\": [\"Controller\", \"storage_ip_address\"]}, \"StorageMgmtIpList\": {\"get_attr\": [\"Controller\", \"storage_mgmt_ip_address\"]}, \"InternalApiIpList\": {\"get_attr\": [\"Controller\", \"internal_api_ip_address\"]}, \"TenantIpList\": {\"get_attr\": [\"Controller\", \"tenant_ip_address\"]}, \"RoleNetworks\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"tenant\"], \"EnabledServices\": {\"get_attr\": [\"ControllerServiceNames\", \"value\"]}, \"ServiceNetMap\": {\"get_attr\": [\"ControllerServiceNetMapLower\", \"value\"]}, \"ServiceHostnameList\": {\"get_attr\": [\"Controller\", \"hostname\"]}, \"NetworkHostnameMap\": {\"get_attr\": [\"ControllerNetworkHostnameMap\", \"value\"]}}}, \"ControllerNetworkHostnameMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict($.data.where($ != null).flatten().selectMany($.items()).groupBy($[0], $[1]).select([$[0], $[1].flatten()]))\", \"data\": [{\"get_attr\": [\"Controller\", \"hostname_map\"]}]}}}}, \"ControllerUserData\": {\"type\": \"OS::Heat::MultipartMime\", \"properties\": {\"parts\": [{\"config\": {\"get_resource\": \"NodeAdminUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeTimesyncUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"ControllerRoleUserData\"}, \"type\": \"multipart\"}]}}, \"ControllerRoleUserData\": {\"type\": \"OS::TripleO::Controller::NodeUserData\"}, \"Controller\": {\"type\": \"OS::Heat::ResourceGroup\", \"depends_on\": \"Networks\", \"update_policy\": {\"batch_create\": {\"max_batch_size\": {\"get_param\": \"NodeCreateBatchSize\"}}}, \"properties\": {\"count\": {\"get_param\": \"ControllerCount\"}, \"removal_policies\": {\"get_param\": \"ControllerRemovalPolicies\"}, \"removal_policies_mode\": {\"get_param\": \"ControllerRemovalPoliciesMode\"}, \"resource_def\": {\"type\": \"OS::TripleO::Controller\", \"properties\": {\"CloudDomain\": {\"get_param\": \"CloudDomain\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"ControllerServiceNetMap\"}]}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"Hostname\": {\"str_replace\": {\"template\": {\"get_param\": \"ControllerHostnameFormat\"}, \"params\": {\"%stackname%\": {\"get_param\": \"OS::stack_name\"}}}}, \"NodeIndex\": \"%index%\", \"ControllerSchedulerHints\": {\"map_merge\": [{\"get_param\": \"ControllerSchedulerHints\"}]}, \"ServiceNames\": {\"get_attr\": [\"ControllerServiceNames\", \"value\"]}, \"ServiceMetadataSettings\": {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"OVNBridgeMappings\": {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"config_settings\", \"ovn::controller::ovn_bridge_mappings\"]}, \"DeploymentServerBlacklistDict\": {\"get_attr\": [\"DeploymentServerBlacklistDict\", \"value\"]}, \"RoleParameters\": {\"map_merge\": [{\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, {\"get_param\": \"ControllerParameters\"}]}, \"UserData\": {\"get_resource\": \"ControllerUserData\"}}}}}, \"CellControllerServiceChain\": {\"type\": \"OS::TripleO::CellControllerServices\", \"properties\": {\"Services\": {\"get_param\": \"CellControllerServices\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"CellControllerServiceNetMap\"}]}, \"ServiceData\": {\"net_cidr_map\": {\"get_attr\": [\"NetCidrMapValue\", \"value\"]}, \"net_vip_map\": {\"get_attr\": [\"VipMap\", \"net_ip_map\"]}, \"net_ip_version_map\": {\"get_attr\": [\"NetIpVersionMapValue\", \"value\"]}, \"vip_subnet_map\": {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\"]}}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"RoleName\": \"CellController\", \"RoleParameters\": {\"map_merge\": [{\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, {\"get_param\": \"CellControllerParameters\"}]}}}, \"CellControllerServiceChainRoleData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"get_attr\": [\"CellControllerServiceChain\", \"role_data\"]}}}, \"CellControllerConfigData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"service_configs\": {\"get_attr\": [\"CellControllerServiceConfigSettings\", \"value\"]}, \"service_names\": {\"get_attr\": [\"CellControllerServiceNames\", \"value\"]}, \"role_extraconfig\": {\"map_merge\": [{\"tripleo::profile::base::metrics::collectd::sensubility::subscriptions\": {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"tripleo_collectd_sensubility_subscriptions\": {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"get_param\": \"controllerExtraConfig\"}, {\"get_param\": \"CellControllerExtraConfig\"}]}, \"extraconfig\": {\"get_param\": \"ExtraConfig\"}, \"hieradata_files\": [\"%{::uuid}\", \"fqdn\", \"docker_puppet\", \"ansible_managed\", \"heat_config_%{::deploy_config_name}\", \"config_step\", \"role_extraconfig\", \"extraconfig\", \"pci_passthrough_whitelist\", \"service_names\", \"service_configs\", \"cloud_domain\", \"bootstrap_node\", \"all_nodes\", \"vip_data\", \"net_ip_map\", \"ovn_chassis_mac_map\", \"%{::osfamily}\", \"neutron_bigswitch_data\", \"upgrade\"]}}}, \"CellControllerServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": [{\"get_param\": \"GlobalConfigExtraMapData\"}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"config_settings\"]}, {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"yaql\": {\"expression\": \"let(root => $) -> $.data.map.items().where($[0] in coalesce($root.data.services, [])).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"map\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"service_config_settings\"]}]}}, \"services\": {\"get_attr\": [\"CellControllerServiceNames\", \"value\"]}}}}]}}}, \"CellControllerServiceNames\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"CellControllerServiceChain\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> distinct($.data.extra_services.items().where($[0] in coalesce($root.data.enabled_services, [])).select($[1]).flatten() + coalesce($root.data.enabled_services, []))\", \"data\": {\"enabled_services\": {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"service_names\"]}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"CellControllerServiceNetMapLower\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map_lower\"]}, {\"yaql\": {\"expression\": \"dict($.data.map.items().select([ regex(`([a-z0-9])([A-Z])`).replace($[0], \'\\\\\\\\1_\\\\\\\\2\').toLower(), $[1]]))\", \"data\": {\"map\": {\"get_param\": \"CellControllerServiceNetMap\"}}}}]}}}, \"CellControllerIpListMap\": {\"type\": \"OS::TripleO::Network::Ports::NetIpListMap\", \"properties\": {\"ControlPlaneIpList\": {\"get_attr\": [\"CellController\", \"ip_address\"]}, \"StorageIpList\": {\"get_attr\": [\"CellController\", \"storage_ip_address\"]}, \"StorageMgmtIpList\": {\"get_attr\": [\"CellController\", \"storage_mgmt_ip_address\"]}, \"InternalApiIpList\": {\"get_attr\": [\"CellController\", \"internal_api_ip_address\"]}, \"TenantIpList\": {\"get_attr\": [\"CellController\", \"tenant_ip_address\"]}, \"RoleNetworks\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"tenant\"], \"EnabledServices\": {\"get_attr\": [\"CellControllerServiceNames\", \"value\"]}, \"ServiceNetMap\": {\"get_attr\": [\"CellControllerServiceNetMapLower\", \"value\"]}, \"ServiceHostnameList\": {\"get_attr\": [\"CellController\", \"hostname\"]}, \"NetworkHostnameMap\": {\"get_attr\": [\"CellControllerNetworkHostnameMap\", \"value\"]}}}, \"CellControllerNetworkHostnameMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict($.data.where($ != null).flatten().selectMany($.items()).groupBy($[0], $[1]).select([$[0], $[1].flatten()]))\", \"data\": [{\"get_attr\": [\"CellController\", \"hostname_map\"]}]}}}}, \"CellControllerUserData\": {\"type\": \"OS::Heat::MultipartMime\", \"properties\": {\"parts\": [{\"config\": {\"get_resource\": \"NodeAdminUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeTimesyncUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"CellControllerRoleUserData\"}, \"type\": \"multipart\"}]}}, \"CellControllerRoleUserData\": {\"type\": \"OS::TripleO::CellController::NodeUserData\"}, \"CellController\": {\"type\": \"OS::Heat::ResourceGroup\", \"depends_on\": \"Networks\", \"update_policy\": {\"batch_create\": {\"max_batch_size\": {\"get_param\": \"NodeCreateBatchSize\"}}}, \"properties\": {\"count\": {\"get_param\": \"CellControllerCount\"}, \"removal_policies\": {\"get_param\": \"CellControllerRemovalPolicies\"}, \"removal_policies_mode\": {\"get_param\": \"CellControllerRemovalPoliciesMode\"}, \"resource_def\": {\"type\": \"OS::TripleO::CellController\", \"properties\": {\"CloudDomain\": {\"get_param\": \"CloudDomain\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"CellControllerServiceNetMap\"}]}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"Hostname\": {\"str_replace\": {\"template\": {\"get_param\": \"CellControllerHostnameFormat\"}, \"params\": {\"%stackname%\": {\"get_param\": \"OS::stack_name\"}}}}, \"NodeIndex\": \"%index%\", \"CellControllerSchedulerHints\": {\"map_merge\": [{\"get_param\": \"CellControllerSchedulerHints\"}]}, \"ServiceNames\": {\"get_attr\": [\"CellControllerServiceNames\", \"value\"]}, \"ServiceMetadataSettings\": {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"OVNBridgeMappings\": {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"config_settings\", \"ovn::controller::ovn_bridge_mappings\"]}, \"DeploymentServerBlacklistDict\": {\"get_attr\": [\"DeploymentServerBlacklistDict\", \"value\"]}, \"RoleParameters\": {\"map_merge\": [{\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, {\"get_param\": \"CellControllerParameters\"}]}, \"UserData\": {\"get_resource\": \"CellControllerUserData\"}}}}}, \"CellControllerComputeServiceChain\": {\"type\": \"OS::TripleO::CellControllerComputeServices\", \"properties\": {\"Services\": {\"get_param\": \"CellControllerComputeServices\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"CellControllerComputeServiceNetMap\"}]}, \"ServiceData\": {\"net_cidr_map\": {\"get_attr\": [\"NetCidrMapValue\", \"value\"]}, \"net_vip_map\": {\"get_attr\": [\"VipMap\", \"net_ip_map\"]}, \"net_ip_version_map\": {\"get_attr\": [\"NetIpVersionMapValue\", \"value\"]}, \"vip_subnet_map\": {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\"]}}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"RoleName\": \"CellControllerCompute\", \"RoleParameters\": {\"map_merge\": [{\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, {\"get_param\": \"CellControllerComputeParameters\"}]}}}, \"CellControllerComputeServiceChainRoleData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"get_attr\": [\"CellControllerComputeServiceChain\", \"role_data\"]}}}, \"CellControllerComputeConfigData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"service_configs\": {\"get_attr\": [\"CellControllerComputeServiceConfigSettings\", \"value\"]}, \"service_names\": {\"get_attr\": [\"CellControllerComputeServiceNames\", \"value\"]}, \"role_extraconfig\": {\"map_merge\": [{\"tripleo::profile::base::metrics::collectd::sensubility::subscriptions\": {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"tripleo_collectd_sensubility_subscriptions\": {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"get_param\": \"controllerExtraConfig\"}, {\"get_param\": \"CellControllerComputeExtraConfig\"}]}, \"extraconfig\": {\"get_param\": \"ExtraConfig\"}, \"hieradata_files\": [\"%{::uuid}\", \"fqdn\", \"docker_puppet\", \"ansible_managed\", \"heat_config_%{::deploy_config_name}\", \"config_step\", \"role_extraconfig\", \"extraconfig\", \"pci_passthrough_whitelist\", \"service_names\", \"service_configs\", \"cloud_domain\", \"bootstrap_node\", \"all_nodes\", \"vip_data\", \"net_ip_map\", \"ovn_chassis_mac_map\", \"%{::osfamily}\", \"neutron_bigswitch_data\", \"upgrade\"]}}}, \"CellControllerComputeServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": [{\"get_param\": \"GlobalConfigExtraMapData\"}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"config_settings\"]}, {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"yaql\": {\"expression\": \"let(root => $) -> $.data.map.items().where($[0] in coalesce($root.data.services, [])).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"map\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"service_config_settings\"]}]}}, \"services\": {\"get_attr\": [\"CellControllerComputeServiceNames\", \"value\"]}}}}]}}}, \"CellControllerComputeServiceNames\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"CellControllerComputeServiceChain\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> distinct($.data.extra_services.items().where($[0] in coalesce($root.data.enabled_services, [])).select($[1]).flatten() + coalesce($root.data.enabled_services, []))\", \"data\": {\"enabled_services\": {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"service_names\"]}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"CellControllerComputeServiceNetMapLower\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map_lower\"]}, {\"yaql\": {\"expression\": \"dict($.data.map.items().select([ regex(`([a-z0-9])([A-Z])`).replace($[0], \'\\\\\\\\1_\\\\\\\\2\').toLower(), $[1]]))\", \"data\": {\"map\": {\"get_param\": \"CellControllerComputeServiceNetMap\"}}}}]}}}, \"CellControllerComputeIpListMap\": {\"type\": \"OS::TripleO::Network::Ports::NetIpListMap\", \"properties\": {\"ControlPlaneIpList\": {\"get_attr\": [\"CellControllerCompute\", \"ip_address\"]}, \"StorageIpList\": {\"get_attr\": [\"CellControllerCompute\", \"storage_ip_address\"]}, \"StorageMgmtIpList\": {\"get_attr\": [\"CellControllerCompute\", \"storage_mgmt_ip_address\"]}, \"InternalApiIpList\": {\"get_attr\": [\"CellControllerCompute\", \"internal_api_ip_address\"]}, \"TenantIpList\": {\"get_attr\": [\"CellControllerCompute\", \"tenant_ip_address\"]}, \"RoleNetworks\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"tenant\"], \"EnabledServices\": {\"get_attr\": [\"CellControllerComputeServiceNames\", \"value\"]}, \"ServiceNetMap\": {\"get_attr\": [\"CellControllerComputeServiceNetMapLower\", \"value\"]}, \"ServiceHostnameList\": {\"get_attr\": [\"CellControllerCompute\", \"hostname\"]}, \"NetworkHostnameMap\": {\"get_attr\": [\"CellControllerComputeNetworkHostnameMap\", \"value\"]}}}, \"CellControllerComputeNetworkHostnameMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict($.data.where($ != null).flatten().selectMany($.items()).groupBy($[0], $[1]).select([$[0], $[1].flatten()]))\", \"data\": [{\"get_attr\": [\"CellControllerCompute\", \"hostname_map\"]}]}}}}, \"CellControllerComputeUserData\": {\"type\": \"OS::Heat::MultipartMime\", \"properties\": {\"parts\": [{\"config\": {\"get_resource\": \"NodeAdminUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeTimesyncUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"CellControllerComputeRoleUserData\"}, \"type\": \"multipart\"}]}}, \"CellControllerComputeRoleUserData\": {\"type\": \"OS::TripleO::CellControllerCompute::NodeUserData\"}, \"CellControllerCompute\": {\"type\": \"OS::Heat::ResourceGroup\", \"depends_on\": \"Networks\", \"update_policy\": {\"batch_create\": {\"max_batch_size\": {\"get_param\": \"NodeCreateBatchSize\"}}}, \"properties\": {\"count\": {\"get_param\": \"CellControllerComputeCount\"}, \"removal_policies\": {\"get_param\": \"CellControllerComputeRemovalPolicies\"}, \"removal_policies_mode\": {\"get_param\": \"CellControllerComputeRemovalPoliciesMode\"}, \"resource_def\": {\"type\": \"OS::TripleO::CellControllerCompute\", \"properties\": {\"CloudDomain\": {\"get_param\": \"CloudDomain\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"CellControllerComputeServiceNetMap\"}]}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"Hostname\": {\"str_replace\": {\"template\": {\"get_param\": \"CellControllerComputeHostnameFormat\"}, \"params\": {\"%stackname%\": {\"get_param\": \"OS::stack_name\"}}}}, \"NodeIndex\": \"%index%\", \"CellControllerComputeSchedulerHints\": {\"map_merge\": [{\"get_param\": \"CellControllerComputeSchedulerHints\"}]}, \"ServiceNames\": {\"get_attr\": [\"CellControllerComputeServiceNames\", \"value\"]}, \"ServiceMetadataSettings\": {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"OVNBridgeMappings\": {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"config_settings\", \"ovn::controller::ovn_bridge_mappings\"]}, \"DeploymentServerBlacklistDict\": {\"get_attr\": [\"DeploymentServerBlacklistDict\", \"value\"]}, \"RoleParameters\": {\"map_merge\": [{\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, {\"get_param\": \"CellControllerComputeParameters\"}]}, \"UserData\": {\"get_resource\": \"CellControllerComputeUserData\"}}}}}, \"ComputeServiceChain\": {\"type\": \"OS::TripleO::ComputeServices\", \"properties\": {\"Services\": {\"get_param\": \"ComputeServices\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"ComputeServiceNetMap\"}]}, \"ServiceData\": {\"net_cidr_map\": {\"get_attr\": [\"NetCidrMapValue\", \"value\"]}, \"net_vip_map\": {\"get_attr\": [\"VipMap\", \"net_ip_map\"]}, \"net_ip_version_map\": {\"get_attr\": [\"NetIpVersionMapValue\", \"value\"]}, \"vip_subnet_map\": {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\"]}}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"map_merge\": [{\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, {\"get_param\": \"ComputeParameters\"}]}}}, \"ComputeServiceChainRoleData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"get_attr\": [\"ComputeServiceChain\", \"role_data\"]}}}, \"ComputeConfigData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"service_configs\": {\"get_attr\": [\"ComputeServiceConfigSettings\", \"value\"]}, \"service_names\": {\"get_attr\": [\"ComputeServiceNames\", \"value\"]}, \"role_extraconfig\": {\"map_merge\": [{\"tripleo::profile::base::metrics::collectd::sensubility::subscriptions\": {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"tripleo_collectd_sensubility_subscriptions\": {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"get_param\": \"NovaComputeExtraConfig\"}, {\"get_param\": \"ComputeExtraConfig\"}]}, \"extraconfig\": {\"get_param\": \"ExtraConfig\"}, \"hieradata_files\": [\"%{::uuid}\", \"fqdn\", \"docker_puppet\", \"ansible_managed\", \"heat_config_%{::deploy_config_name}\", \"config_step\", \"role_extraconfig\", \"extraconfig\", \"pci_passthrough_whitelist\", \"service_names\", \"service_configs\", \"cloud_domain\", \"bootstrap_node\", \"all_nodes\", \"vip_data\", \"net_ip_map\", \"ovn_chassis_mac_map\", \"%{::osfamily}\", \"neutron_bigswitch_data\", \"upgrade\"]}}}, \"ComputeServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": [{\"get_param\": \"GlobalConfigExtraMapData\"}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"config_settings\"]}, {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"yaql\": {\"expression\": \"let(root => $) -> $.data.map.items().where($[0] in coalesce($root.data.services, [])).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"map\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"service_config_settings\"]}]}}, \"services\": {\"get_attr\": [\"ComputeServiceNames\", \"value\"]}}}}]}}}, \"ComputeServiceNames\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"ComputeServiceChain\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> distinct($.data.extra_services.items().where($[0] in coalesce($root.data.enabled_services, [])).select($[1]).flatten() + coalesce($root.data.enabled_services, []))\", \"data\": {\"enabled_services\": {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"service_names\"]}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"ComputeServiceNetMapLower\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map_lower\"]}, {\"yaql\": {\"expression\": \"dict($.data.map.items().select([ regex(`([a-z0-9])([A-Z])`).replace($[0], \'\\\\\\\\1_\\\\\\\\2\').toLower(), $[1]]))\", \"data\": {\"map\": {\"get_param\": \"ComputeServiceNetMap\"}}}}]}}}, \"ComputeIpListMap\": {\"type\": \"OS::TripleO::Network::Ports::NetIpListMap\", \"properties\": {\"ControlPlaneIpList\": {\"get_attr\": [\"Compute\", \"ip_address\"]}, \"StorageIpList\": {\"get_attr\": [\"Compute\", \"storage_ip_address\"]}, \"InternalApiIpList\": {\"get_attr\": [\"Compute\", \"internal_api_ip_address\"]}, \"TenantIpList\": {\"get_attr\": [\"Compute\", \"tenant_ip_address\"]}, \"RoleNetworks\": [\"ctlplane\", \"storage\", \"internal_api\", \"tenant\"], \"EnabledServices\": {\"get_attr\": [\"ComputeServiceNames\", \"value\"]}, \"ServiceNetMap\": {\"get_attr\": [\"ComputeServiceNetMapLower\", \"value\"]}, \"ServiceHostnameList\": {\"get_attr\": [\"Compute\", \"hostname\"]}, \"NetworkHostnameMap\": {\"get_attr\": [\"ComputeNetworkHostnameMap\", \"value\"]}}}, \"ComputeNetworkHostnameMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict($.data.where($ != null).flatten().selectMany($.items()).groupBy($[0], $[1]).select([$[0], $[1].flatten()]))\", \"data\": [{\"get_attr\": [\"Compute\", \"hostname_map\"]}]}}}}, \"ComputeUserData\": {\"type\": \"OS::Heat::MultipartMime\", \"properties\": {\"parts\": [{\"config\": {\"get_resource\": \"NodeAdminUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeTimesyncUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"ComputeRoleUserData\"}, \"type\": \"multipart\"}]}}, \"ComputeRoleUserData\": {\"type\": \"OS::TripleO::Compute::NodeUserData\"}, \"Compute\": {\"type\": \"OS::Heat::ResourceGroup\", \"depends_on\": \"Networks\", \"update_policy\": {\"batch_create\": {\"max_batch_size\": {\"get_param\": \"NodeCreateBatchSize\"}}}, \"properties\": {\"count\": {\"get_param\": \"ComputeCount\"}, \"removal_policies\": {\"get_param\": \"ComputeRemovalPolicies\"}, \"removal_policies_mode\": {\"get_param\": \"ComputeRemovalPoliciesMode\"}, \"resource_def\": {\"type\": \"OS::TripleO::Compute\", \"properties\": {\"CloudDomain\": {\"get_param\": \"CloudDomain\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"ComputeServiceNetMap\"}]}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"Hostname\": {\"str_replace\": {\"template\": {\"get_param\": \"ComputeHostnameFormat\"}, \"params\": {\"%stackname%\": {\"get_param\": \"OS::stack_name\"}}}}, \"NodeIndex\": \"%index%\", \"ComputeSchedulerHints\": {\"map_merge\": [{\"get_param\": \"NovaComputeSchedulerHints\"}, {\"get_param\": \"ComputeSchedulerHints\"}]}, \"ServiceNames\": {\"get_attr\": [\"ComputeServiceNames\", \"value\"]}, \"ServiceMetadataSettings\": {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"OVNBridgeMappings\": {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"config_settings\", \"ovn::controller::ovn_bridge_mappings\"]}, \"DeploymentServerBlacklistDict\": {\"get_attr\": [\"DeploymentServerBlacklistDict\", \"value\"]}, \"RoleParameters\": {\"map_merge\": [{\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, {\"get_param\": \"ComputeParameters\"}]}, \"UserData\": {\"get_resource\": \"ComputeUserData\"}}}}}, \"BlockStorageServiceChain\": {\"type\": \"OS::TripleO::BlockStorageServices\", \"properties\": {\"Services\": {\"get_param\": \"BlockStorageServices\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"BlockStorageServiceNetMap\"}]}, \"ServiceData\": {\"net_cidr_map\": {\"get_attr\": [\"NetCidrMapValue\", \"value\"]}, \"net_vip_map\": {\"get_attr\": [\"VipMap\", \"net_ip_map\"]}, \"net_ip_version_map\": {\"get_attr\": [\"NetIpVersionMapValue\", \"value\"]}, \"vip_subnet_map\": {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\"]}}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"RoleName\": \"BlockStorage\", \"RoleParameters\": {\"map_merge\": [{}, {\"get_param\": \"BlockStorageParameters\"}]}}}, \"BlockStorageServiceChainRoleData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"get_attr\": [\"BlockStorageServiceChain\", \"role_data\"]}}}, \"BlockStorageConfigData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"service_configs\": {\"get_attr\": [\"BlockStorageServiceConfigSettings\", \"value\"]}, \"service_names\": {\"get_attr\": [\"BlockStorageServiceNames\", \"value\"]}, \"role_extraconfig\": {\"map_merge\": [{\"tripleo::profile::base::metrics::collectd::sensubility::subscriptions\": {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"tripleo_collectd_sensubility_subscriptions\": {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"get_param\": \"BlockStorageExtraConfig\"}]}, \"extraconfig\": {\"get_param\": \"ExtraConfig\"}, \"hieradata_files\": [\"%{::uuid}\", \"fqdn\", \"docker_puppet\", \"ansible_managed\", \"heat_config_%{::deploy_config_name}\", \"config_step\", \"role_extraconfig\", \"extraconfig\", \"pci_passthrough_whitelist\", \"service_names\", \"service_configs\", \"cloud_domain\", \"bootstrap_node\", \"all_nodes\", \"vip_data\", \"net_ip_map\", \"ovn_chassis_mac_map\", \"%{::osfamily}\", \"neutron_bigswitch_data\", \"upgrade\"]}}}, \"BlockStorageServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": [{\"get_param\": \"GlobalConfigExtraMapData\"}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"config_settings\"]}, {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"yaql\": {\"expression\": \"let(root => $) -> $.data.map.items().where($[0] in coalesce($root.data.services, [])).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"map\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"service_config_settings\"]}]}}, \"services\": {\"get_attr\": [\"BlockStorageServiceNames\", \"value\"]}}}}]}}}, \"BlockStorageServiceNames\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"BlockStorageServiceChain\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> distinct($.data.extra_services.items().where($[0] in coalesce($root.data.enabled_services, [])).select($[1]).flatten() + coalesce($root.data.enabled_services, []))\", \"data\": {\"enabled_services\": {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"service_names\"]}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"BlockStorageServiceNetMapLower\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map_lower\"]}, {\"yaql\": {\"expression\": \"dict($.data.map.items().select([ regex(`([a-z0-9])([A-Z])`).replace($[0], \'\\\\\\\\1_\\\\\\\\2\').toLower(), $[1]]))\", \"data\": {\"map\": {\"get_param\": \"BlockStorageServiceNetMap\"}}}}]}}}, \"BlockStorageIpListMap\": {\"type\": \"OS::TripleO::Network::Ports::NetIpListMap\", \"properties\": {\"ControlPlaneIpList\": {\"get_attr\": [\"BlockStorage\", \"ip_address\"]}, \"StorageIpList\": {\"get_attr\": [\"BlockStorage\", \"storage_ip_address\"]}, \"StorageMgmtIpList\": {\"get_attr\": [\"BlockStorage\", \"storage_mgmt_ip_address\"]}, \"InternalApiIpList\": {\"get_attr\": [\"BlockStorage\", \"internal_api_ip_address\"]}, \"RoleNetworks\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"EnabledServices\": {\"get_attr\": [\"BlockStorageServiceNames\", \"value\"]}, \"ServiceNetMap\": {\"get_attr\": [\"BlockStorageServiceNetMapLower\", \"value\"]}, \"ServiceHostnameList\": {\"get_attr\": [\"BlockStorage\", \"hostname\"]}, \"NetworkHostnameMap\": {\"get_attr\": [\"BlockStorageNetworkHostnameMap\", \"value\"]}}}, \"BlockStorageNetworkHostnameMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict($.data.where($ != null).flatten().selectMany($.items()).groupBy($[0], $[1]).select([$[0], $[1].flatten()]))\", \"data\": [{\"get_attr\": [\"BlockStorage\", \"hostname_map\"]}]}}}}, \"BlockStorageUserData\": {\"type\": \"OS::Heat::MultipartMime\", \"properties\": {\"parts\": [{\"config\": {\"get_resource\": \"NodeAdminUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeTimesyncUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"BlockStorageRoleUserData\"}, \"type\": \"multipart\"}]}}, \"BlockStorageRoleUserData\": {\"type\": \"OS::TripleO::BlockStorage::NodeUserData\"}, \"BlockStorage\": {\"type\": \"OS::Heat::ResourceGroup\", \"depends_on\": \"Networks\", \"update_policy\": {\"batch_create\": {\"max_batch_size\": {\"get_param\": \"NodeCreateBatchSize\"}}}, \"properties\": {\"count\": {\"get_param\": \"BlockStorageCount\"}, \"removal_policies\": {\"get_param\": \"BlockStorageRemovalPolicies\"}, \"removal_policies_mode\": {\"get_param\": \"BlockStorageRemovalPoliciesMode\"}, \"resource_def\": {\"type\": \"OS::TripleO::BlockStorage\", \"properties\": {\"CloudDomain\": {\"get_param\": \"CloudDomain\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"BlockStorageServiceNetMap\"}]}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"Hostname\": {\"str_replace\": {\"template\": {\"get_param\": \"BlockStorageHostnameFormat\"}, \"params\": {\"%stackname%\": {\"get_param\": \"OS::stack_name\"}}}}, \"NodeIndex\": \"%index%\", \"BlockStorageSchedulerHints\": {\"map_merge\": [{\"get_param\": \"BlockStorageSchedulerHints\"}]}, \"ServiceNames\": {\"get_attr\": [\"BlockStorageServiceNames\", \"value\"]}, \"ServiceMetadataSettings\": {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"OVNBridgeMappings\": {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"config_settings\", \"ovn::controller::ovn_bridge_mappings\"]}, \"DeploymentServerBlacklistDict\": {\"get_attr\": [\"DeploymentServerBlacklistDict\", \"value\"]}, \"RoleParameters\": {\"map_merge\": [{}, {\"get_param\": \"BlockStorageParameters\"}]}, \"UserData\": {\"get_resource\": \"BlockStorageUserData\"}}}}}, \"ObjectStorageServiceChain\": {\"type\": \"OS::TripleO::ObjectStorageServices\", \"properties\": {\"Services\": {\"get_param\": \"ObjectStorageServices\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"ObjectStorageServiceNetMap\"}]}, \"ServiceData\": {\"net_cidr_map\": {\"get_attr\": [\"NetCidrMapValue\", \"value\"]}, \"net_vip_map\": {\"get_attr\": [\"VipMap\", \"net_ip_map\"]}, \"net_ip_version_map\": {\"get_attr\": [\"NetIpVersionMapValue\", \"value\"]}, \"vip_subnet_map\": {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\"]}}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"RoleName\": \"ObjectStorage\", \"RoleParameters\": {\"map_merge\": [{}, {\"get_param\": \"ObjectStorageParameters\"}]}}}, \"ObjectStorageServiceChainRoleData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"get_attr\": [\"ObjectStorageServiceChain\", \"role_data\"]}}}, \"ObjectStorageConfigData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"service_configs\": {\"get_attr\": [\"ObjectStorageServiceConfigSettings\", \"value\"]}, \"service_names\": {\"get_attr\": [\"ObjectStorageServiceNames\", \"value\"]}, \"role_extraconfig\": {\"map_merge\": [{\"tripleo::profile::base::metrics::collectd::sensubility::subscriptions\": {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"tripleo_collectd_sensubility_subscriptions\": {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"get_param\": \"ObjectStorageExtraConfig\"}]}, \"extraconfig\": {\"get_param\": \"ExtraConfig\"}, \"hieradata_files\": [\"%{::uuid}\", \"fqdn\", \"docker_puppet\", \"ansible_managed\", \"heat_config_%{::deploy_config_name}\", \"config_step\", \"role_extraconfig\", \"extraconfig\", \"pci_passthrough_whitelist\", \"service_names\", \"service_configs\", \"cloud_domain\", \"bootstrap_node\", \"all_nodes\", \"vip_data\", \"net_ip_map\", \"ovn_chassis_mac_map\", \"%{::osfamily}\", \"neutron_bigswitch_data\", \"upgrade\"]}}}, \"ObjectStorageServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": [{\"get_param\": \"GlobalConfigExtraMapData\"}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"config_settings\"]}, {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"yaql\": {\"expression\": \"let(root => $) -> $.data.map.items().where($[0] in coalesce($root.data.services, [])).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"map\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"service_config_settings\"]}]}}, \"services\": {\"get_attr\": [\"ObjectStorageServiceNames\", \"value\"]}}}}]}}}, \"ObjectStorageServiceNames\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"ObjectStorageServiceChain\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> distinct($.data.extra_services.items().where($[0] in coalesce($root.data.enabled_services, [])).select($[1]).flatten() + coalesce($root.data.enabled_services, []))\", \"data\": {\"enabled_services\": {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"service_names\"]}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"ObjectStorageServiceNetMapLower\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map_lower\"]}, {\"yaql\": {\"expression\": \"dict($.data.map.items().select([ regex(`([a-z0-9])([A-Z])`).replace($[0], \'\\\\\\\\1_\\\\\\\\2\').toLower(), $[1]]))\", \"data\": {\"map\": {\"get_param\": \"ObjectStorageServiceNetMap\"}}}}]}}}, \"ObjectStorageIpListMap\": {\"type\": \"OS::TripleO::Network::Ports::NetIpListMap\", \"properties\": {\"ControlPlaneIpList\": {\"get_attr\": [\"ObjectStorage\", \"ip_address\"]}, \"StorageIpList\": {\"get_attr\": [\"ObjectStorage\", \"storage_ip_address\"]}, \"StorageMgmtIpList\": {\"get_attr\": [\"ObjectStorage\", \"storage_mgmt_ip_address\"]}, \"InternalApiIpList\": {\"get_attr\": [\"ObjectStorage\", \"internal_api_ip_address\"]}, \"RoleNetworks\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"EnabledServices\": {\"get_attr\": [\"ObjectStorageServiceNames\", \"value\"]}, \"ServiceNetMap\": {\"get_attr\": [\"ObjectStorageServiceNetMapLower\", \"value\"]}, \"ServiceHostnameList\": {\"get_attr\": [\"ObjectStorage\", \"hostname\"]}, \"NetworkHostnameMap\": {\"get_attr\": [\"ObjectStorageNetworkHostnameMap\", \"value\"]}}}, \"ObjectStorageNetworkHostnameMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict($.data.where($ != null).flatten().selectMany($.items()).groupBy($[0], $[1]).select([$[0], $[1].flatten()]))\", \"data\": [{\"get_attr\": [\"ObjectStorage\", \"hostname_map\"]}]}}}}, \"ObjectStorageUserData\": {\"type\": \"OS::Heat::MultipartMime\", \"properties\": {\"parts\": [{\"config\": {\"get_resource\": \"NodeAdminUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeTimesyncUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"ObjectStorageRoleUserData\"}, \"type\": \"multipart\"}]}}, \"ObjectStorageRoleUserData\": {\"type\": \"OS::TripleO::ObjectStorage::NodeUserData\"}, \"ObjectStorage\": {\"type\": \"OS::Heat::ResourceGroup\", \"depends_on\": \"Networks\", \"update_policy\": {\"batch_create\": {\"max_batch_size\": {\"get_param\": \"NodeCreateBatchSize\"}}}, \"properties\": {\"count\": {\"get_param\": \"ObjectStorageCount\"}, \"removal_policies\": {\"get_param\": \"ObjectStorageRemovalPolicies\"}, \"removal_policies_mode\": {\"get_param\": \"ObjectStorageRemovalPoliciesMode\"}, \"resource_def\": {\"type\": \"OS::TripleO::ObjectStorage\", \"properties\": {\"CloudDomain\": {\"get_param\": \"CloudDomain\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"ObjectStorageServiceNetMap\"}]}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"Hostname\": {\"str_replace\": {\"template\": {\"get_param\": \"ObjectStorageHostnameFormat\"}, \"params\": {\"%stackname%\": {\"get_param\": \"OS::stack_name\"}}}}, \"NodeIndex\": \"%index%\", \"ObjectStorageSchedulerHints\": {\"map_merge\": [{\"get_param\": \"ObjectStorageSchedulerHints\"}]}, \"ServiceNames\": {\"get_attr\": [\"ObjectStorageServiceNames\", \"value\"]}, \"ServiceMetadataSettings\": {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"OVNBridgeMappings\": {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"config_settings\", \"ovn::controller::ovn_bridge_mappings\"]}, \"DeploymentServerBlacklistDict\": {\"get_attr\": [\"DeploymentServerBlacklistDict\", \"value\"]}, \"RoleParameters\": {\"map_merge\": [{}, {\"get_param\": \"ObjectStorageParameters\"}]}, \"UserData\": {\"get_resource\": \"ObjectStorageUserData\"}}}}}, \"CephStorageServiceChain\": {\"type\": \"OS::TripleO::CephStorageServices\", \"properties\": {\"Services\": {\"get_param\": \"CephStorageServices\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"CephStorageServiceNetMap\"}]}, \"ServiceData\": {\"net_cidr_map\": {\"get_attr\": [\"NetCidrMapValue\", \"value\"]}, \"net_vip_map\": {\"get_attr\": [\"VipMap\", \"net_ip_map\"]}, \"net_ip_version_map\": {\"get_attr\": [\"NetIpVersionMapValue\", \"value\"]}, \"vip_subnet_map\": {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\"]}}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"RoleName\": \"CephStorage\", \"RoleParameters\": {\"map_merge\": [{}, {\"get_param\": \"CephStorageParameters\"}]}}}, \"CephStorageServiceChainRoleData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"get_attr\": [\"CephStorageServiceChain\", \"role_data\"]}}}, \"CephStorageConfigData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"service_configs\": {\"get_attr\": [\"CephStorageServiceConfigSettings\", \"value\"]}, \"service_names\": {\"get_attr\": [\"CephStorageServiceNames\", \"value\"]}, \"role_extraconfig\": {\"map_merge\": [{\"tripleo::profile::base::metrics::collectd::sensubility::subscriptions\": {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"tripleo_collectd_sensubility_subscriptions\": {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"get_param\": \"CephStorageExtraConfig\"}]}, \"extraconfig\": {\"get_param\": \"ExtraConfig\"}, \"hieradata_files\": [\"%{::uuid}\", \"fqdn\", \"docker_puppet\", \"ansible_managed\", \"heat_config_%{::deploy_config_name}\", \"config_step\", \"role_extraconfig\", \"extraconfig\", \"pci_passthrough_whitelist\", \"service_names\", \"service_configs\", \"cloud_domain\", \"bootstrap_node\", \"all_nodes\", \"vip_data\", \"net_ip_map\", \"ovn_chassis_mac_map\", \"%{::osfamily}\", \"neutron_bigswitch_data\", \"upgrade\"]}}}, \"CephStorageServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": [{\"get_param\": \"GlobalConfigExtraMapData\"}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"config_settings\"]}, {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"yaql\": {\"expression\": \"let(root => $) -> $.data.map.items().where($[0] in coalesce($root.data.services, [])).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"map\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"service_config_settings\"]}]}}, \"services\": {\"get_attr\": [\"CephStorageServiceNames\", \"value\"]}}}}]}}}, \"CephStorageServiceNames\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"CephStorageServiceChain\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> distinct($.data.extra_services.items().where($[0] in coalesce($root.data.enabled_services, [])).select($[1]).flatten() + coalesce($root.data.enabled_services, []))\", \"data\": {\"enabled_services\": {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"service_names\"]}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"CephStorageServiceNetMapLower\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map_lower\"]}, {\"yaql\": {\"expression\": \"dict($.data.map.items().select([ regex(`([a-z0-9])([A-Z])`).replace($[0], \'\\\\\\\\1_\\\\\\\\2\').toLower(), $[1]]))\", \"data\": {\"map\": {\"get_param\": \"CephStorageServiceNetMap\"}}}}]}}}, \"CephStorageIpListMap\": {\"type\": \"OS::TripleO::Network::Ports::NetIpListMap\", \"properties\": {\"ControlPlaneIpList\": {\"get_attr\": [\"CephStorage\", \"ip_address\"]}, \"StorageIpList\": {\"get_attr\": [\"CephStorage\", \"storage_ip_address\"]}, \"StorageMgmtIpList\": {\"get_attr\": [\"CephStorage\", \"storage_mgmt_ip_address\"]}, \"RoleNetworks\": [\"ctlplane\", \"storage\", \"storage_mgmt\"], \"EnabledServices\": {\"get_attr\": [\"CephStorageServiceNames\", \"value\"]}, \"ServiceNetMap\": {\"get_attr\": [\"CephStorageServiceNetMapLower\", \"value\"]}, \"ServiceHostnameList\": {\"get_attr\": [\"CephStorage\", \"hostname\"]}, \"NetworkHostnameMap\": {\"get_attr\": [\"CephStorageNetworkHostnameMap\", \"value\"]}}}, \"CephStorageNetworkHostnameMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict($.data.where($ != null).flatten().selectMany($.items()).groupBy($[0], $[1]).select([$[0], $[1].flatten()]))\", \"data\": [{\"get_attr\": [\"CephStorage\", \"hostname_map\"]}]}}}}, \"CephStorageUserData\": {\"type\": \"OS::Heat::MultipartMime\", \"properties\": {\"parts\": [{\"config\": {\"get_resource\": \"NodeAdminUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeTimesyncUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"CephStorageRoleUserData\"}, \"type\": \"multipart\"}]}}, \"CephStorageRoleUserData\": {\"type\": \"OS::TripleO::CephStorage::NodeUserData\"}, \"CephStorage\": {\"type\": \"OS::Heat::ResourceGroup\", \"depends_on\": \"Networks\", \"update_policy\": {\"batch_create\": {\"max_batch_size\": {\"get_param\": \"NodeCreateBatchSize\"}}}, \"properties\": {\"count\": {\"get_param\": \"CephStorageCount\"}, \"removal_policies\": {\"get_param\": \"CephStorageRemovalPolicies\"}, \"removal_policies_mode\": {\"get_param\": \"CephStorageRemovalPoliciesMode\"}, \"resource_def\": {\"type\": \"OS::TripleO::CephStorage\", \"properties\": {\"CloudDomain\": {\"get_param\": \"CloudDomain\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"CephStorageServiceNetMap\"}]}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"Hostname\": {\"str_replace\": {\"template\": {\"get_param\": \"CephStorageHostnameFormat\"}, \"params\": {\"%stackname%\": {\"get_param\": \"OS::stack_name\"}}}}, \"NodeIndex\": \"%index%\", \"CephStorageSchedulerHints\": {\"map_merge\": [{\"get_param\": \"CephStorageSchedulerHints\"}]}, \"ServiceNames\": {\"get_attr\": [\"CephStorageServiceNames\", \"value\"]}, \"ServiceMetadataSettings\": {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"OVNBridgeMappings\": {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"config_settings\", \"ovn::controller::ovn_bridge_mappings\"]}, \"DeploymentServerBlacklistDict\": {\"get_attr\": [\"DeploymentServerBlacklistDict\", \"value\"]}, \"RoleParameters\": {\"map_merge\": [{}, {\"get_param\": \"CephStorageParameters\"}]}, \"UserData\": {\"get_resource\": \"CephStorageUserData\"}}}}}, \"NetworkerServiceChain\": {\"type\": \"OS::TripleO::NetworkerServices\", \"properties\": {\"Services\": {\"get_param\": \"NetworkerServices\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"NetworkerServiceNetMap\"}]}, \"ServiceData\": {\"net_cidr_map\": {\"get_attr\": [\"NetCidrMapValue\", \"value\"]}, \"net_vip_map\": {\"get_attr\": [\"VipMap\", \"net_ip_map\"]}, \"net_ip_version_map\": {\"get_attr\": [\"NetIpVersionMapValue\", \"value\"]}, \"vip_subnet_map\": {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\"]}}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"RoleName\": \"Networker\", \"RoleParameters\": {\"map_merge\": [{\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, {\"get_param\": \"NetworkerParameters\"}]}}}, \"NetworkerServiceChainRoleData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"get_attr\": [\"NetworkerServiceChain\", \"role_data\"]}}}, \"NetworkerConfigData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"service_configs\": {\"get_attr\": [\"NetworkerServiceConfigSettings\", \"value\"]}, \"service_names\": {\"get_attr\": [\"NetworkerServiceNames\", \"value\"]}, \"role_extraconfig\": {\"map_merge\": [{\"tripleo::profile::base::metrics::collectd::sensubility::subscriptions\": {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"tripleo_collectd_sensubility_subscriptions\": {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"get_param\": \"NetworkerExtraConfig\"}]}, \"extraconfig\": {\"get_param\": \"ExtraConfig\"}, \"hieradata_files\": [\"%{::uuid}\", \"fqdn\", \"docker_puppet\", \"ansible_managed\", \"heat_config_%{::deploy_config_name}\", \"config_step\", \"role_extraconfig\", \"extraconfig\", \"pci_passthrough_whitelist\", \"service_names\", \"service_configs\", \"cloud_domain\", \"bootstrap_node\", \"all_nodes\", \"vip_data\", \"net_ip_map\", \"ovn_chassis_mac_map\", \"%{::osfamily}\", \"neutron_bigswitch_data\", \"upgrade\"]}}}, \"NetworkerServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": [{\"get_param\": \"GlobalConfigExtraMapData\"}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"config_settings\"]}, {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"yaql\": {\"expression\": \"let(root => $) -> $.data.map.items().where($[0] in coalesce($root.data.services, [])).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"map\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"service_config_settings\"]}]}}, \"services\": {\"get_attr\": [\"NetworkerServiceNames\", \"value\"]}}}}]}}}, \"NetworkerServiceNames\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"NetworkerServiceChain\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> distinct($.data.extra_services.items().where($[0] in coalesce($root.data.enabled_services, [])).select($[1]).flatten() + coalesce($root.data.enabled_services, []))\", \"data\": {\"enabled_services\": {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"service_names\"]}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"NetworkerServiceNetMapLower\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map_lower\"]}, {\"yaql\": {\"expression\": \"dict($.data.map.items().select([ regex(`([a-z0-9])([A-Z])`).replace($[0], \'\\\\\\\\1_\\\\\\\\2\').toLower(), $[1]]))\", \"data\": {\"map\": {\"get_param\": \"NetworkerServiceNetMap\"}}}}]}}}, \"NetworkerIpListMap\": {\"type\": \"OS::TripleO::Network::Ports::NetIpListMap\", \"properties\": {\"ControlPlaneIpList\": {\"get_attr\": [\"Networker\", \"ip_address\"]}, \"InternalApiIpList\": {\"get_attr\": [\"Networker\", \"internal_api_ip_address\"]}, \"TenantIpList\": {\"get_attr\": [\"Networker\", \"tenant_ip_address\"]}, \"RoleNetworks\": [\"ctlplane\", \"internal_api\", \"tenant\"], \"EnabledServices\": {\"get_attr\": [\"NetworkerServiceNames\", \"value\"]}, \"ServiceNetMap\": {\"get_attr\": [\"NetworkerServiceNetMapLower\", \"value\"]}, \"ServiceHostnameList\": {\"get_attr\": [\"Networker\", \"hostname\"]}, \"NetworkHostnameMap\": {\"get_attr\": [\"NetworkerNetworkHostnameMap\", \"value\"]}}}, \"NetworkerNetworkHostnameMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict($.data.where($ != null).flatten().selectMany($.items()).groupBy($[0], $[1]).select([$[0], $[1].flatten()]))\", \"data\": [{\"get_attr\": [\"Networker\", \"hostname_map\"]}]}}}}, \"NetworkerUserData\": {\"type\": \"OS::Heat::MultipartMime\", \"properties\": {\"parts\": [{\"config\": {\"get_resource\": \"NodeAdminUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeTimesyncUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NetworkerRoleUserData\"}, \"type\": \"multipart\"}]}}, \"NetworkerRoleUserData\": {\"type\": \"OS::TripleO::Networker::NodeUserData\"}, \"Networker\": {\"type\": \"OS::Heat::ResourceGroup\", \"depends_on\": \"Networks\", \"update_policy\": {\"batch_create\": {\"max_batch_size\": {\"get_param\": \"NodeCreateBatchSize\"}}}, \"properties\": {\"count\": {\"get_param\": \"NetworkerCount\"}, \"removal_policies\": {\"get_param\": \"NetworkerRemovalPolicies\"}, \"removal_policies_mode\": {\"get_param\": \"NetworkerRemovalPoliciesMode\"}, \"resource_def\": {\"type\": \"OS::TripleO::Networker\", \"properties\": {\"CloudDomain\": {\"get_param\": \"CloudDomain\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"NetworkerServiceNetMap\"}]}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"Hostname\": {\"str_replace\": {\"template\": {\"get_param\": \"NetworkerHostnameFormat\"}, \"params\": {\"%stackname%\": {\"get_param\": \"OS::stack_name\"}}}}, \"NodeIndex\": \"%index%\", \"NetworkerSchedulerHints\": {\"map_merge\": [{\"get_param\": \"NetworkerSchedulerHints\"}]}, \"ServiceNames\": {\"get_attr\": [\"NetworkerServiceNames\", \"value\"]}, \"ServiceMetadataSettings\": {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"OVNBridgeMappings\": {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"config_settings\", \"ovn::controller::ovn_bridge_mappings\"]}, \"DeploymentServerBlacklistDict\": {\"get_attr\": [\"DeploymentServerBlacklistDict\", \"value\"]}, \"RoleParameters\": {\"map_merge\": [{\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, {\"get_param\": \"NetworkerParameters\"}]}, \"UserData\": {\"get_resource\": \"NetworkerUserData\"}}}}}, \"ControllerServers\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"Controller\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"let(servers=>switch(isDict($.data.servers) => $.data.servers, true => {})) -> $servers.deleteAll($servers.keys().where($servers[$] = null))\", \"data\": {\"servers\": {\"get_attr\": [\"Controller\", \"attributes\", \"nova_server_resource\"]}}}}}}, \"CellControllerServers\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"CellController\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"let(servers=>switch(isDict($.data.servers) => $.data.servers, true => {})) -> $servers.deleteAll($servers.keys().where($servers[$] = null))\", \"data\": {\"servers\": {\"get_attr\": [\"CellController\", \"attributes\", \"nova_server_resource\"]}}}}}}, \"CellControllerComputeServers\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"CellControllerCompute\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"let(servers=>switch(isDict($.data.servers) => $.data.servers, true => {})) -> $servers.deleteAll($servers.keys().where($servers[$] = null))\", \"data\": {\"servers\": {\"get_attr\": [\"CellControllerCompute\", \"attributes\", \"nova_server_resource\"]}}}}}}, \"ComputeServers\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"Compute\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"let(servers=>switch(isDict($.data.servers) => $.data.servers, true => {})) -> $servers.deleteAll($servers.keys().where($servers[$] = null))\", \"data\": {\"servers\": {\"get_attr\": [\"Compute\", \"attributes\", \"nova_server_resource\"]}}}}}}, \"BlockStorageServers\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"BlockStorage\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"let(servers=>switch(isDict($.data.servers) => $.data.servers, true => {})) -> $servers.deleteAll($servers.keys().where($servers[$] = null))\", \"data\": {\"servers\": {\"get_attr\": [\"BlockStorage\", \"attributes\", \"nova_server_resource\"]}}}}}}, \"ObjectStorageServers\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"ObjectStorage\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"let(servers=>switch(isDict($.data.servers) => $.data.servers, true => {})) -> $servers.deleteAll($servers.keys().where($servers[$] = null))\", \"data\": {\"servers\": {\"get_attr\": [\"ObjectStorage\", \"attributes\", \"nova_server_resource\"]}}}}}}, \"CephStorageServers\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"CephStorage\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"let(servers=>switch(isDict($.data.servers) => $.data.servers, true => {})) -> $servers.deleteAll($servers.keys().where($servers[$] = null))\", \"data\": {\"servers\": {\"get_attr\": [\"CephStorage\", \"attributes\", \"nova_server_resource\"]}}}}}}, \"NetworkerServers\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"Networker\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"let(servers=>switch(isDict($.data.servers) => $.data.servers, true => {})) -> $servers.deleteAll($servers.keys().where($servers[$] = null))\", \"data\": {\"servers\": {\"get_attr\": [\"Networker\", \"attributes\", \"nova_server_resource\"]}}}}}}, \"ServerIdMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"server_ids\": {\"Controller\": {\"get_attr\": [\"Controller\", \"nova_server_resource\"]}, \"CellController\": {\"get_attr\": [\"CellController\", \"nova_server_resource\"]}, \"CellControllerCompute\": {\"get_attr\": [\"CellControllerCompute\", \"nova_server_resource\"]}, \"Compute\": {\"get_attr\": [\"Compute\", \"nova_server_resource\"]}, \"BlockStorage\": {\"get_attr\": [\"BlockStorage\", \"nova_server_resource\"]}, \"ObjectStorage\": {\"get_attr\": [\"ObjectStorage\", \"nova_server_resource\"]}, \"CephStorage\": {\"get_attr\": [\"CephStorage\", \"nova_server_resource\"]}, \"Networker\": {\"get_attr\": [\"Networker\", \"nova_server_resource\"]}}, \"bootstrap_server_id\": {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CellControllerCompute\", \"nova_server_resource\"]}}}}}}, \"DeploymentServerBlacklistDict\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"repeat\": {\"template\": {\"hostname\": 1}, \"for_each\": {\"hostname\": {\"get_param\": \"DeploymentServerBlacklist\"}}}}}}}, \"HostsEntryValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"list_concat_unique\": {\"list_concat\": [[{\"get_param\": \"UndercloudHostsEntries\"}], [{\"if\": [\"add_vips_to_etc_hosts\", {\"get_attr\": [\"VipHosts\", \"value\"]}, []]}], {\"get_attr\": [\"Controller\", \"hosts_entry\"]}, {\"get_attr\": [\"CellController\", \"hosts_entry\"]}, {\"get_attr\": [\"CellControllerCompute\", \"hosts_entry\"]}, {\"get_attr\": [\"Compute\", \"hosts_entry\"]}, {\"get_attr\": [\"BlockStorage\", \"hosts_entry\"]}, {\"get_attr\": [\"ObjectStorage\", \"hosts_entry\"]}, {\"get_attr\": [\"CephStorage\", \"hosts_entry\"]}, {\"get_attr\": [\"Networker\", \"hosts_entry\"]}, [{\"get_param\": \"ExtraHostFileEntries\"}]]}}}}, \"CloudNames\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"cloud_name_storage\": {\"get_param\": \"CloudNameStorage\"}, \"cloud_name_storage_mgmt\": {\"get_param\": \"CloudNameStorageManagement\"}, \"cloud_name_internal_api\": {\"get_param\": \"CloudNameInternal\"}, \"cloud_name_external\": {\"get_param\": \"CloudName\"}, \"cloud_name_ctlplane\": {\"get_param\": \"CloudNameCtlplane\"}}}}, \"GlobalConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"global_config_settings\"]}]}}}, \"Networks\": {\"type\": \"OS::TripleO::Network\", \"depends_on\": \"ServiceNetMap\", \"properties\": {\"CtlplaneNetworkCidrs\": {\"get_attr\": [\"ControlVirtualIP\", \"network\", \"tags\"]}}}, \"FirewallFrontendRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"frontend\": {\"map_merge\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"firewall_frontend_rules\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"firewall_frontend_rules\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"firewall_frontend_rules\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"firewall_frontend_rules\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"firewall_frontend_rules\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"firewall_frontend_rules\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"firewall_frontend_rules\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"firewall_frontend_rules\"]}]}, \"ssl_frontend\": {\"map_merge\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"firewall_ssl_frontend_rules\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"firewall_ssl_frontend_rules\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"firewall_ssl_frontend_rules\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"firewall_ssl_frontend_rules\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"firewall_ssl_frontend_rules\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"firewall_ssl_frontend_rules\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"firewall_ssl_frontend_rules\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"firewall_ssl_frontend_rules\"]}]}, \"edge_frontend\": {\"map_merge\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"firewall_edge_frontend_rules\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"firewall_edge_frontend_rules\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"firewall_edge_frontend_rules\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"firewall_edge_frontend_rules\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"firewall_edge_frontend_rules\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"firewall_edge_frontend_rules\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"firewall_edge_frontend_rules\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"firewall_edge_frontend_rules\"]}]}, \"edge_ssl_frontend\": {\"map_merge\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"firewall_edge_ssl_frontend_rules\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"firewall_edge_ssl_frontend_rules\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"firewall_edge_ssl_frontend_rules\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"firewall_edge_ssl_frontend_rules\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"firewall_edge_ssl_frontend_rules\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"firewall_edge_ssl_frontend_rules\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"firewall_edge_ssl_frontend_rules\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"firewall_edge_ssl_frontend_rules\"]}]}}}}, \"ControllerGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"ctlplane_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"ctlplane_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ControllerControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ctlplane_dns_nameservers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ControllerControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"ctlplane_subnet_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ControllerControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ctlplane_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ControllerControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ControllerControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"storage_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"storage_mgmt_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"internal_api_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"tenant_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"network\", \"mtu\"]}, \"external_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"network\", \"mtu\"]}, \"storage_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, \"storage_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"storage_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"storage_mgmt_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"gateway_ip\"]}, \"storage_mgmt_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"host_routes\"]}]}, \"storage_mgmt_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"cidr\"]}, 1]}, \"storage_mgmt_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"tags\"]}}}, \"internal_api_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}, \"internal_api_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"internal_api_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}, \"internal_api_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}, \"tenant_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"gateway_ip\"]}, \"tenant_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"host_routes\"]}]}, \"tenant_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"cidr\"]}, 1]}, \"tenant_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"tags\"]}}}, \"network_cidrs\": {\"Storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"StorageMgmt_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"cidr\"]}, 1]}, \"InternalApi_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}, \"Tenant_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"cidr\"]}, 1]}}, \"dns_search_domains\": {\"get_param\": \"DnsSearchDomains\"}, \"bond_interface_ovs_options\": {\"get_param\": \"BondInterfaceOvsOptions\"}, \"local_mtu\": {\"get_param\": \"ControllerLocalMtu\"}, \"role_networks\": [\"Storage\", \"StorageMgmt\", \"InternalApi\", \"Tenant\"], \"networks_lower\": {\"Storage\": \"storage\", \"StorageMgmt\": \"storage_mgmt\", \"InternalApi\": \"internal_api\", \"Tenant\": \"tenant\", \"External\": \"external\"}, \"networks_all\": [\"Storage\", \"StorageMgmt\", \"InternalApi\", \"Tenant\", \"External\"], \"service_metadata_settings\": {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"tripleo_network_config_template\": {\"get_param\": \"ControllerNetworkConfigTemplate\"}, \"tripleo_network_config_with_ansible\": {\"get_param\": \"NetworkConfigWithAnsible\"}, \"default_route_networks\": [\"ControlPlane\"], \"networks_skip_config\": [], \"tripleo_firewall_rules\": {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"firewall_rules\"]}, \"tripleo_firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"tripleo_firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"tripleo_firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"tripleo_firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"role_tags\": [\"primary\", \"controller\", \"external_bridge\"], \"service_net_map\": {\"get_attr\": [\"ControllerServiceNetMapLower\", \"value\"]}}}}, \"ControllerNetworkConfig\": {\"type\": \"OS::TripleO::Controller::Net::SoftwareConfig\", \"properties\": {\"ControlPlaneIp\": \"{{ ctlplane_ip }}\", \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ControllerControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ControlPlaneDefaultRoute\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ControllerControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ControlPlaneStaticRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ControllerControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ControllerControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"ControlPlaneMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"DnsServers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ControllerControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"StorageIpSubnet\": \"{{ storage_ip ~ \'/\' ~ storage_cidr }}\", \"StorageInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"StorageMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"StorageNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"StorageMgmtIpSubnet\": \"{{ storage_mgmt_ip ~ \'/\' ~ storage_mgmt_cidr }}\", \"StorageMgmtInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"host_routes\"]}]}, \"StorageMgmtMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"StorageMgmtNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"tags\"]}}}, \"InternalApiIpSubnet\": \"{{ internal_api_ip ~ \'/\' ~ internal_api_cidr }}\", \"InternalApiInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"InternalApiMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"InternalApiNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}, \"TenantIpSubnet\": \"{{ tenant_ip ~ \'/\' ~ tenant_cidr }}\", \"TenantInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"host_routes\"]}]}, \"TenantMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"network\", \"mtu\"]}, \"TenantNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"tags\"]}}}}}, \"CellControllerGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"ctlplane_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"ctlplane_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ctlplane_dns_nameservers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"ctlplane_subnet_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ctlplane_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"storage_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"storage_mgmt_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"internal_api_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"tenant_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"network\", \"mtu\"]}, \"external_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"network\", \"mtu\"]}, \"storage_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, \"storage_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"storage_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"storage_mgmt_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"gateway_ip\"]}, \"storage_mgmt_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"host_routes\"]}]}, \"storage_mgmt_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"cidr\"]}, 1]}, \"storage_mgmt_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"tags\"]}}}, \"internal_api_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}, \"internal_api_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"internal_api_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}, \"internal_api_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}, \"tenant_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"gateway_ip\"]}, \"tenant_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"host_routes\"]}]}, \"tenant_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"cidr\"]}, 1]}, \"tenant_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"tags\"]}}}, \"network_cidrs\": {\"Storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"StorageMgmt_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"cidr\"]}, 1]}, \"InternalApi_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}, \"Tenant_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"cidr\"]}, 1]}}, \"dns_search_domains\": {\"get_param\": \"DnsSearchDomains\"}, \"bond_interface_ovs_options\": {\"get_param\": \"BondInterfaceOvsOptions\"}, \"local_mtu\": {\"get_param\": \"CellControllerLocalMtu\"}, \"role_networks\": [\"Storage\", \"StorageMgmt\", \"InternalApi\", \"Tenant\"], \"networks_lower\": {\"Storage\": \"storage\", \"StorageMgmt\": \"storage_mgmt\", \"InternalApi\": \"internal_api\", \"Tenant\": \"tenant\", \"External\": \"external\"}, \"networks_all\": [\"Storage\", \"StorageMgmt\", \"InternalApi\", \"Tenant\", \"External\"], \"service_metadata_settings\": {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"tripleo_network_config_template\": {\"get_param\": \"CellControllerNetworkConfigTemplate\"}, \"tripleo_network_config_with_ansible\": {\"get_param\": \"NetworkConfigWithAnsible\"}, \"default_route_networks\": [\"ControlPlane\"], \"networks_skip_config\": [], \"tripleo_firewall_rules\": {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"firewall_rules\"]}, \"tripleo_firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"tripleo_firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"tripleo_firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"tripleo_firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"role_tags\": [\"primary\", \"controller\"], \"service_net_map\": {\"get_attr\": [\"CellControllerServiceNetMapLower\", \"value\"]}}}}, \"CellControllerNetworkConfig\": {\"type\": \"OS::TripleO::CellController::Net::SoftwareConfig\", \"properties\": {\"ControlPlaneIp\": \"{{ ctlplane_ip }}\", \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ControlPlaneDefaultRoute\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ControlPlaneStaticRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"ControlPlaneMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"DnsServers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"StorageIpSubnet\": \"{{ storage_ip ~ \'/\' ~ storage_cidr }}\", \"StorageInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"StorageMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"StorageNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"StorageMgmtIpSubnet\": \"{{ storage_mgmt_ip ~ \'/\' ~ storage_mgmt_cidr }}\", \"StorageMgmtInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"host_routes\"]}]}, \"StorageMgmtMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"StorageMgmtNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"tags\"]}}}, \"InternalApiIpSubnet\": \"{{ internal_api_ip ~ \'/\' ~ internal_api_cidr }}\", \"InternalApiInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"InternalApiMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"InternalApiNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}, \"TenantIpSubnet\": \"{{ tenant_ip ~ \'/\' ~ tenant_cidr }}\", \"TenantInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"host_routes\"]}]}, \"TenantMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"network\", \"mtu\"]}, \"TenantNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"tags\"]}}}}}, \"CellControllerComputeGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"ctlplane_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"ctlplane_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerComputeControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ctlplane_dns_nameservers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerComputeControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"ctlplane_subnet_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerComputeControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ctlplane_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerComputeControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerComputeControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"storage_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"storage_mgmt_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"internal_api_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"tenant_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"network\", \"mtu\"]}, \"external_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"network\", \"mtu\"]}, \"storage_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, \"storage_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"storage_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"storage_mgmt_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"gateway_ip\"]}, \"storage_mgmt_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"host_routes\"]}]}, \"storage_mgmt_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"cidr\"]}, 1]}, \"storage_mgmt_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"tags\"]}}}, \"internal_api_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}, \"internal_api_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"internal_api_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}, \"internal_api_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}, \"tenant_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"gateway_ip\"]}, \"tenant_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"host_routes\"]}]}, \"tenant_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"cidr\"]}, 1]}, \"tenant_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"tags\"]}}}, \"network_cidrs\": {\"Storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"StorageMgmt_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"cidr\"]}, 1]}, \"InternalApi_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}, \"Tenant_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"cidr\"]}, 1]}}, \"dns_search_domains\": {\"get_param\": \"DnsSearchDomains\"}, \"bond_interface_ovs_options\": {\"get_param\": \"BondInterfaceOvsOptions\"}, \"local_mtu\": {\"get_param\": \"CellControllerComputeLocalMtu\"}, \"role_networks\": [\"Storage\", \"StorageMgmt\", \"InternalApi\", \"Tenant\"], \"networks_lower\": {\"Storage\": \"storage\", \"StorageMgmt\": \"storage_mgmt\", \"InternalApi\": \"internal_api\", \"Tenant\": \"tenant\", \"External\": \"external\"}, \"networks_all\": [\"Storage\", \"StorageMgmt\", \"InternalApi\", \"Tenant\", \"External\"], \"service_metadata_settings\": {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"tripleo_network_config_template\": {\"get_param\": \"CellControllerComputeNetworkConfigTemplate\"}, \"tripleo_network_config_with_ansible\": {\"get_param\": \"NetworkConfigWithAnsible\"}, \"default_route_networks\": [\"ControlPlane\"], \"networks_skip_config\": [], \"tripleo_firewall_rules\": {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"firewall_rules\"]}, \"tripleo_firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"tripleo_firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"tripleo_firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"tripleo_firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"role_tags\": [\"primary\", \"controller\", \"external_bridge\"], \"service_net_map\": {\"get_attr\": [\"CellControllerComputeServiceNetMapLower\", \"value\"]}}}}, \"CellControllerComputeNetworkConfig\": {\"type\": \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\", \"properties\": {\"ControlPlaneIp\": \"{{ ctlplane_ip }}\", \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerComputeControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ControlPlaneDefaultRoute\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerComputeControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ControlPlaneStaticRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerComputeControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerComputeControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"ControlPlaneMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"DnsServers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerComputeControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"StorageIpSubnet\": \"{{ storage_ip ~ \'/\' ~ storage_cidr }}\", \"StorageInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"StorageMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"StorageNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"StorageMgmtIpSubnet\": \"{{ storage_mgmt_ip ~ \'/\' ~ storage_mgmt_cidr }}\", \"StorageMgmtInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"host_routes\"]}]}, \"StorageMgmtMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"StorageMgmtNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"tags\"]}}}, \"InternalApiIpSubnet\": \"{{ internal_api_ip ~ \'/\' ~ internal_api_cidr }}\", \"InternalApiInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"InternalApiMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"InternalApiNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}, \"TenantIpSubnet\": \"{{ tenant_ip ~ \'/\' ~ tenant_cidr }}\", \"TenantInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"host_routes\"]}]}, \"TenantMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"network\", \"mtu\"]}, \"TenantNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"tags\"]}}}}}, \"ComputeGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"ctlplane_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"ctlplane_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ComputeControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ctlplane_dns_nameservers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ComputeControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"ctlplane_subnet_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ComputeControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ctlplane_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ComputeControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ComputeControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"storage_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"storage_mgmt_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"internal_api_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"tenant_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"network\", \"mtu\"]}, \"external_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"network\", \"mtu\"]}, \"storage_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, \"storage_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"storage_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"internal_api_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}, \"internal_api_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"internal_api_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}, \"internal_api_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}, \"tenant_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"gateway_ip\"]}, \"tenant_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"host_routes\"]}]}, \"tenant_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"cidr\"]}, 1]}, \"tenant_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"tags\"]}}}, \"network_cidrs\": {\"Storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"InternalApi_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}, \"Tenant_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"cidr\"]}, 1]}}, \"dns_search_domains\": {\"get_param\": \"DnsSearchDomains\"}, \"bond_interface_ovs_options\": {\"get_param\": \"BondInterfaceOvsOptions\"}, \"local_mtu\": {\"get_param\": \"ComputeLocalMtu\"}, \"role_networks\": [\"Storage\", \"InternalApi\", \"Tenant\"], \"networks_lower\": {\"Storage\": \"storage\", \"StorageMgmt\": \"storage_mgmt\", \"InternalApi\": \"internal_api\", \"Tenant\": \"tenant\", \"External\": \"external\"}, \"networks_all\": [\"Storage\", \"StorageMgmt\", \"InternalApi\", \"Tenant\", \"External\"], \"service_metadata_settings\": {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"tripleo_network_config_template\": {\"get_param\": \"ComputeNetworkConfigTemplate\"}, \"tripleo_network_config_with_ansible\": {\"get_param\": \"NetworkConfigWithAnsible\"}, \"default_route_networks\": [\"ControlPlane\"], \"networks_skip_config\": [], \"tripleo_firewall_rules\": {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"firewall_rules\"]}, \"tripleo_firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"tripleo_firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"tripleo_firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"tripleo_firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"role_tags\": [\"compute\", \"external_bridge\"], \"service_net_map\": {\"get_attr\": [\"ComputeServiceNetMapLower\", \"value\"]}}}}, \"ComputeNetworkConfig\": {\"type\": \"OS::TripleO::Compute::Net::SoftwareConfig\", \"properties\": {\"ControlPlaneIp\": \"{{ ctlplane_ip }}\", \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ComputeControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ControlPlaneDefaultRoute\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ComputeControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ControlPlaneStaticRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ComputeControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ComputeControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"ControlPlaneMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"DnsServers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ComputeControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"StorageIpSubnet\": \"{{ storage_ip ~ \'/\' ~ storage_cidr }}\", \"StorageInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"StorageMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"StorageNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"InternalApiIpSubnet\": \"{{ internal_api_ip ~ \'/\' ~ internal_api_cidr }}\", \"InternalApiInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"InternalApiMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"InternalApiNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}, \"TenantIpSubnet\": \"{{ tenant_ip ~ \'/\' ~ tenant_cidr }}\", \"TenantInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"host_routes\"]}]}, \"TenantMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"network\", \"mtu\"]}, \"TenantNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"tags\"]}}}}}, \"BlockStorageGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"ctlplane_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"ctlplane_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"BlockStorageControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ctlplane_dns_nameservers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"BlockStorageControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"ctlplane_subnet_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"BlockStorageControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ctlplane_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"BlockStorageControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"BlockStorageControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"storage_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"storage_mgmt_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"internal_api_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"tenant_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"network\", \"mtu\"]}, \"external_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"network\", \"mtu\"]}, \"storage_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, \"storage_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"storage_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"storage_mgmt_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"gateway_ip\"]}, \"storage_mgmt_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"host_routes\"]}]}, \"storage_mgmt_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"cidr\"]}, 1]}, \"storage_mgmt_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"tags\"]}}}, \"internal_api_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}, \"internal_api_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"internal_api_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}, \"internal_api_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}, \"network_cidrs\": {\"Storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"StorageMgmt_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"cidr\"]}, 1]}, \"InternalApi_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}}, \"dns_search_domains\": {\"get_param\": \"DnsSearchDomains\"}, \"bond_interface_ovs_options\": {\"get_param\": \"BondInterfaceOvsOptions\"}, \"local_mtu\": {\"get_param\": \"BlockStorageLocalMtu\"}, \"role_networks\": [\"Storage\", \"StorageMgmt\", \"InternalApi\"], \"networks_lower\": {\"Storage\": \"storage\", \"StorageMgmt\": \"storage_mgmt\", \"InternalApi\": \"internal_api\", \"Tenant\": \"tenant\", \"External\": \"external\"}, \"networks_all\": [\"Storage\", \"StorageMgmt\", \"InternalApi\", \"Tenant\", \"External\"], \"service_metadata_settings\": {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"tripleo_network_config_template\": {\"get_param\": \"BlockStorageNetworkConfigTemplate\"}, \"tripleo_network_config_with_ansible\": {\"get_param\": \"NetworkConfigWithAnsible\"}, \"default_route_networks\": [\"ControlPlane\"], \"networks_skip_config\": [], \"tripleo_firewall_rules\": {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"firewall_rules\"]}, \"tripleo_firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"tripleo_firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"tripleo_firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"tripleo_firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"role_tags\": [\"storage\"], \"service_net_map\": {\"get_attr\": [\"BlockStorageServiceNetMapLower\", \"value\"]}}}}, \"BlockStorageNetworkConfig\": {\"type\": \"OS::TripleO::BlockStorage::Net::SoftwareConfig\", \"properties\": {\"ControlPlaneIp\": \"{{ ctlplane_ip }}\", \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"BlockStorageControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ControlPlaneDefaultRoute\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"BlockStorageControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ControlPlaneStaticRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"BlockStorageControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"BlockStorageControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"ControlPlaneMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"DnsServers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"BlockStorageControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"StorageIpSubnet\": \"{{ storage_ip ~ \'/\' ~ storage_cidr }}\", \"StorageInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"StorageMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"StorageNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"StorageMgmtIpSubnet\": \"{{ storage_mgmt_ip ~ \'/\' ~ storage_mgmt_cidr }}\", \"StorageMgmtInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"host_routes\"]}]}, \"StorageMgmtMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"StorageMgmtNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"tags\"]}}}, \"InternalApiIpSubnet\": \"{{ internal_api_ip ~ \'/\' ~ internal_api_cidr }}\", \"InternalApiInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"InternalApiMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"InternalApiNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}}}, \"ObjectStorageGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"ctlplane_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"ctlplane_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ObjectStorageControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ctlplane_dns_nameservers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ObjectStorageControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"ctlplane_subnet_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ObjectStorageControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ctlplane_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ObjectStorageControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ObjectStorageControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"storage_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"storage_mgmt_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"internal_api_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"tenant_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"network\", \"mtu\"]}, \"external_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"network\", \"mtu\"]}, \"storage_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, \"storage_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"storage_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"storage_mgmt_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"gateway_ip\"]}, \"storage_mgmt_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"host_routes\"]}]}, \"storage_mgmt_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"cidr\"]}, 1]}, \"storage_mgmt_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"tags\"]}}}, \"internal_api_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}, \"internal_api_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"internal_api_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}, \"internal_api_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}, \"network_cidrs\": {\"Storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"StorageMgmt_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"cidr\"]}, 1]}, \"InternalApi_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}}, \"dns_search_domains\": {\"get_param\": \"DnsSearchDomains\"}, \"bond_interface_ovs_options\": {\"get_param\": \"BondInterfaceOvsOptions\"}, \"local_mtu\": {\"get_param\": \"ObjectStorageLocalMtu\"}, \"role_networks\": [\"Storage\", \"StorageMgmt\", \"InternalApi\"], \"networks_lower\": {\"Storage\": \"storage\", \"StorageMgmt\": \"storage_mgmt\", \"InternalApi\": \"internal_api\", \"Tenant\": \"tenant\", \"External\": \"external\"}, \"networks_all\": [\"Storage\", \"StorageMgmt\", \"InternalApi\", \"Tenant\", \"External\"], \"service_metadata_settings\": {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"tripleo_network_config_template\": {\"get_param\": \"ObjectStorageNetworkConfigTemplate\"}, \"tripleo_network_config_with_ansible\": {\"get_param\": \"NetworkConfigWithAnsible\"}, \"default_route_networks\": [\"ControlPlane\"], \"networks_skip_config\": [], \"tripleo_firewall_rules\": {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"firewall_rules\"]}, \"tripleo_firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"tripleo_firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"tripleo_firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"tripleo_firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"role_tags\": [\"storage\"], \"service_net_map\": {\"get_attr\": [\"ObjectStorageServiceNetMapLower\", \"value\"]}}}}, \"ObjectStorageNetworkConfig\": {\"type\": \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\", \"properties\": {\"ControlPlaneIp\": \"{{ ctlplane_ip }}\", \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ObjectStorageControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ControlPlaneDefaultRoute\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ObjectStorageControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ControlPlaneStaticRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ObjectStorageControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ObjectStorageControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"ControlPlaneMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"DnsServers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ObjectStorageControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"StorageIpSubnet\": \"{{ storage_ip ~ \'/\' ~ storage_cidr }}\", \"StorageInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"StorageMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"StorageNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"StorageMgmtIpSubnet\": \"{{ storage_mgmt_ip ~ \'/\' ~ storage_mgmt_cidr }}\", \"StorageMgmtInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"host_routes\"]}]}, \"StorageMgmtMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"StorageMgmtNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"tags\"]}}}, \"InternalApiIpSubnet\": \"{{ internal_api_ip ~ \'/\' ~ internal_api_cidr }}\", \"InternalApiInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"InternalApiMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"InternalApiNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}}}, \"CephStorageGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"ctlplane_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"ctlplane_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CephStorageControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ctlplane_dns_nameservers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CephStorageControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"ctlplane_subnet_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CephStorageControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ctlplane_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CephStorageControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CephStorageControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"storage_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"storage_mgmt_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"internal_api_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"tenant_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"network\", \"mtu\"]}, \"external_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"network\", \"mtu\"]}, \"storage_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, \"storage_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"storage_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"storage_mgmt_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"gateway_ip\"]}, \"storage_mgmt_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"host_routes\"]}]}, \"storage_mgmt_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"cidr\"]}, 1]}, \"storage_mgmt_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"tags\"]}}}, \"network_cidrs\": {\"Storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"StorageMgmt_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"cidr\"]}, 1]}}, \"dns_search_domains\": {\"get_param\": \"DnsSearchDomains\"}, \"bond_interface_ovs_options\": {\"get_param\": \"BondInterfaceOvsOptions\"}, \"local_mtu\": {\"get_param\": \"CephStorageLocalMtu\"}, \"role_networks\": [\"Storage\", \"StorageMgmt\"], \"networks_lower\": {\"Storage\": \"storage\", \"StorageMgmt\": \"storage_mgmt\", \"InternalApi\": \"internal_api\", \"Tenant\": \"tenant\", \"External\": \"external\"}, \"networks_all\": [\"Storage\", \"StorageMgmt\", \"InternalApi\", \"Tenant\", \"External\"], \"service_metadata_settings\": {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"tripleo_network_config_template\": {\"get_param\": \"CephStorageNetworkConfigTemplate\"}, \"tripleo_network_config_with_ansible\": {\"get_param\": \"NetworkConfigWithAnsible\"}, \"default_route_networks\": [\"ControlPlane\"], \"networks_skip_config\": [], \"tripleo_firewall_rules\": {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"firewall_rules\"]}, \"tripleo_firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"tripleo_firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"tripleo_firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"tripleo_firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"role_tags\": [\"ceph\", \"storage\"], \"service_net_map\": {\"get_attr\": [\"CephStorageServiceNetMapLower\", \"value\"]}}}}, \"CephStorageNetworkConfig\": {\"type\": \"OS::TripleO::CephStorage::Net::SoftwareConfig\", \"properties\": {\"ControlPlaneIp\": \"{{ ctlplane_ip }}\", \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CephStorageControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ControlPlaneDefaultRoute\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CephStorageControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ControlPlaneStaticRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CephStorageControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CephStorageControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"ControlPlaneMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"DnsServers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CephStorageControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"StorageIpSubnet\": \"{{ storage_ip ~ \'/\' ~ storage_cidr }}\", \"StorageInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"StorageMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"StorageNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"StorageMgmtIpSubnet\": \"{{ storage_mgmt_ip ~ \'/\' ~ storage_mgmt_cidr }}\", \"StorageMgmtInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"host_routes\"]}]}, \"StorageMgmtMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"StorageMgmtNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"tags\"]}}}}}, \"NetworkerGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"ctlplane_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"ctlplane_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"NetworkerControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ctlplane_dns_nameservers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"NetworkerControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"ctlplane_subnet_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"NetworkerControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ctlplane_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"NetworkerControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"NetworkerControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"storage_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"storage_mgmt_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"internal_api_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"tenant_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"network\", \"mtu\"]}, \"external_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"network\", \"mtu\"]}, \"internal_api_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}, \"internal_api_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"internal_api_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}, \"internal_api_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}, \"tenant_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"gateway_ip\"]}, \"tenant_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"host_routes\"]}]}, \"tenant_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"cidr\"]}, 1]}, \"tenant_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"tags\"]}}}, \"network_cidrs\": {\"InternalApi_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}, \"Tenant_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"cidr\"]}, 1]}}, \"dns_search_domains\": {\"get_param\": \"DnsSearchDomains\"}, \"bond_interface_ovs_options\": {\"get_param\": \"BondInterfaceOvsOptions\"}, \"local_mtu\": {\"get_param\": \"NetworkerLocalMtu\"}, \"role_networks\": [\"InternalApi\", \"Tenant\"], \"networks_lower\": {\"Storage\": \"storage\", \"StorageMgmt\": \"storage_mgmt\", \"InternalApi\": \"internal_api\", \"Tenant\": \"tenant\", \"External\": \"external\"}, \"networks_all\": [\"Storage\", \"StorageMgmt\", \"InternalApi\", \"Tenant\", \"External\"], \"service_metadata_settings\": {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"tripleo_network_config_template\": {\"get_param\": \"NetworkerNetworkConfigTemplate\"}, \"tripleo_network_config_with_ansible\": {\"get_param\": \"NetworkConfigWithAnsible\"}, \"default_route_networks\": [\"ControlPlane\"], \"networks_skip_config\": [], \"tripleo_firewall_rules\": {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"firewall_rules\"]}, \"tripleo_firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"tripleo_firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"tripleo_firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"tripleo_firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"role_tags\": [\"external_bridge\"], \"service_net_map\": {\"get_attr\": [\"NetworkerServiceNetMapLower\", \"value\"]}}}}, \"NetworkerNetworkConfig\": {\"type\": \"OS::TripleO::Networker::Net::SoftwareConfig\", \"properties\": {\"ControlPlaneIp\": \"{{ ctlplane_ip }}\", \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"NetworkerControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ControlPlaneDefaultRoute\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"NetworkerControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ControlPlaneStaticRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"NetworkerControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"NetworkerControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"ControlPlaneMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"DnsServers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"NetworkerControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"InternalApiIpSubnet\": \"{{ internal_api_ip ~ \'/\' ~ internal_api_cidr }}\", \"InternalApiInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"InternalApiMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"InternalApiNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}, \"TenantIpSubnet\": \"{{ tenant_ip ~ \'/\' ~ tenant_cidr }}\", \"TenantInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"host_routes\"]}]}, \"TenantMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"network\", \"mtu\"]}, \"TenantNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"tags\"]}}}}}, \"ControlVirtualIP\": {\"depends_on\": \"ServiceNetMap\", \"type\": \"OS::TripleO::Network::Ports::ControlPlaneVipPort\", \"properties\": {\"name\": \"control_virtual_ip\", \"dns_name\": {\"str_split\": [\".\", {\"get_param\": \"CloudNameCtlplane\"}, 0]}, \"network\": {\"get_param\": \"NeutronControlPlaneID\"}, \"fixed_ips\": {\"if\": [\"control_fixed_ip_not_set\", [{\"subnet\": {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\", \"ctlplane\"]}}], {\"get_param\": \"ControlFixedIPs\"}]}, \"replacement_policy\": \"AUTO\", \"tags\": [\"tripleo_vip_net=ctlplane\", {\"str_replace\": {\"template\": \"tripleo_stack_name=$STACK_NAME\", \"params\": {\"$STACK_NAME\": {\"get_param\": \"OS::stack_name\"}}}}]}}, \"StorageVirtualIP\": {\"depends_on\": [\"Networks\", \"ServiceNetMap\"], \"type\": \"OS::TripleO::Network::Ports::StorageVipPort\", \"properties\": {\"ControlPlaneIP\": {\"get_attr\": [\"ControlVirtualIP\", \"fixed_ips\", 0, \"ip_address\"]}, \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\", \"ctlplane\"]}, \"cidr\"]}, 1]}, \"PortName\": \"storage_virtual_ip\", \"DnsName\": {\"str_split\": [\".\", {\"get_param\": \"CloudNameStorage\"}, 0]}, \"FixedIPs\": {\"if\": [\"storage_virtual_fixed_ip_set\", {\"get_param\": \"StorageVirtualFixedIPs\"}, [{\"subnet\": {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\", \"Storage\"]}}]]}, \"IsVirtualIP\": true}}, \"StorageMgmtVirtualIP\": {\"depends_on\": [\"Networks\", \"ServiceNetMap\"], \"type\": \"OS::TripleO::Network::Ports::StorageMgmtVipPort\", \"properties\": {\"ControlPlaneIP\": {\"get_attr\": [\"ControlVirtualIP\", \"fixed_ips\", 0, \"ip_address\"]}, \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\", \"ctlplane\"]}, \"cidr\"]}, 1]}, \"PortName\": \"storage_mgmt_virtual_ip\", \"DnsName\": {\"str_split\": [\".\", {\"get_param\": \"CloudNameStorageManagement\"}, 0]}, \"FixedIPs\": {\"if\": [\"storage_mgmt_virtual_fixed_ip_set\", {\"get_param\": \"StorageMgmtVirtualFixedIPs\"}, [{\"subnet\": {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\", \"StorageMgmt\"]}}]]}, \"IsVirtualIP\": true}}, \"InternalApiVirtualIP\": {\"depends_on\": [\"Networks\", \"ServiceNetMap\"], \"type\": \"OS::TripleO::Network::Ports::InternalApiVipPort\", \"properties\": {\"ControlPlaneIP\": {\"get_attr\": [\"ControlVirtualIP\", \"fixed_ips\", 0, \"ip_address\"]}, \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\", \"ctlplane\"]}, \"cidr\"]}, 1]}, \"PortName\": \"internal_api_virtual_ip\", \"DnsName\": {\"str_split\": [\".\", {\"get_param\": \"CloudNameInternal\"}, 0]}, \"FixedIPs\": {\"if\": [\"internal_api_virtual_fixed_ip_set\", {\"get_param\": \"InternalApiVirtualFixedIPs\"}, [{\"subnet\": {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\", \"InternalApi\"]}}]]}, \"IsVirtualIP\": true}}, \"PublicVirtualIP\": {\"depends_on\": [\"Networks\", \"ServiceNetMap\"], \"type\": \"OS::TripleO::Network::Ports::ExternalVipPort\", \"properties\": {\"ControlPlaneIP\": {\"get_attr\": [\"ControlVirtualIP\", \"fixed_ips\", 0, \"ip_address\"]}, \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\", \"ctlplane\"]}, \"cidr\"]}, 1]}, \"PortName\": \"external_virtual_ip\", \"DnsName\": {\"str_split\": [\".\", {\"get_param\": \"CloudName\"}, 0]}, \"FixedIPs\": {\"if\": [\"public_virtual_fixed_ip_set\", {\"get_param\": \"PublicVirtualFixedIPs\"}, [{\"subnet\": {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\", \"External\"]}}]]}, \"IsVirtualIP\": true}}, \"VipMap\": {\"type\": \"OS::TripleO::Network::Ports::NetVipMap\", \"properties\": {\"ControlPlaneIp\": {\"get_attr\": [\"ControlVirtualIP\", \"fixed_ips\", 0, \"ip_address\"]}, \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\", \"ctlplane\"]}, \"cidr\"]}, 1]}, \"StorageIp\": {\"get_attr\": [\"StorageVirtualIP\", \"ip_address\"]}, \"StorageIpUri\": {\"get_attr\": [\"StorageVirtualIP\", \"ip_address_uri\"]}, \"StorageMgmtIp\": {\"get_attr\": [\"StorageMgmtVirtualIP\", \"ip_address\"]}, \"StorageMgmtIpUri\": {\"get_attr\": [\"StorageMgmtVirtualIP\", \"ip_address_uri\"]}, \"InternalApiIp\": {\"get_attr\": [\"InternalApiVirtualIP\", \"ip_address\"]}, \"InternalApiIpUri\": {\"get_attr\": [\"InternalApiVirtualIP\", \"ip_address_uri\"]}, \"ExternalIp\": {\"get_attr\": [\"PublicVirtualIP\", \"ip_address\"]}, \"ExternalIpUri\": {\"get_attr\": [\"PublicVirtualIP\", \"ip_address_uri\"]}}, \"depends_on\": \"ServiceNetMap\"}, \"AllNodesExtraConfig\": {\"type\": \"OS::TripleO::AllNodesExtraConfig\", \"properties\": {\"servers\": {\"Controller\": {\"get_attr\": [\"ControllerServers\", \"value\"]}, \"CellController\": {\"get_attr\": [\"CellControllerServers\", \"value\"]}, \"CellControllerCompute\": {\"get_attr\": [\"CellControllerComputeServers\", \"value\"]}, \"Compute\": {\"get_attr\": [\"ComputeServers\", \"value\"]}, \"BlockStorage\": {\"get_attr\": [\"BlockStorageServers\", \"value\"]}, \"ObjectStorage\": {\"get_attr\": [\"ObjectStorageServers\", \"value\"]}, \"CephStorage\": {\"get_attr\": [\"CephStorageServers\", \"value\"]}, \"Networker\": {\"get_attr\": [\"NetworkerServers\", \"value\"]}}}}, \"BlacklistedIpAddresses\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"list_concat\": [{\"get_attr\": [\"Controller\", \"blacklist_ip_address\"]}, {\"get_attr\": [\"CellController\", \"blacklist_ip_address\"]}, {\"get_attr\": [\"CellControllerCompute\", \"blacklist_ip_address\"]}, {\"get_attr\": [\"Compute\", \"blacklist_ip_address\"]}, {\"get_attr\": [\"BlockStorage\", \"blacklist_ip_address\"]}, {\"get_attr\": [\"ObjectStorage\", \"blacklist_ip_address\"]}, {\"get_attr\": [\"CephStorage\", \"blacklist_ip_address\"]}, {\"get_attr\": [\"Networker\", \"blacklist_ip_address\"]}]}}}, \"AnsibleHostVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"Controller\": {\"map_merge\": {\"list_concat\": [{\"get_attr\": [\"Controller\", \"ansible_host_vars_map\"]}]}}, \"CellController\": {\"map_merge\": {\"list_concat\": [{\"get_attr\": [\"CellController\", \"ansible_host_vars_map\"]}]}}, \"CellControllerCompute\": {\"map_merge\": {\"list_concat\": [{\"get_attr\": [\"CellControllerCompute\", \"ansible_host_vars_map\"]}]}}, \"Compute\": {\"map_merge\": {\"list_concat\": [{\"get_attr\": [\"Compute\", \"ansible_host_vars_map\"]}]}}, \"BlockStorage\": {\"map_merge\": {\"list_concat\": [{\"get_attr\": [\"BlockStorage\", \"ansible_host_vars_map\"]}]}}, \"ObjectStorage\": {\"map_merge\": {\"list_concat\": [{\"get_attr\": [\"ObjectStorage\", \"ansible_host_vars_map\"]}]}}, \"CephStorage\": {\"map_merge\": {\"list_concat\": [{\"get_attr\": [\"CephStorage\", \"ansible_host_vars_map\"]}]}}, \"Networker\": {\"map_merge\": {\"list_concat\": [{\"get_attr\": [\"Networker\", \"ansible_host_vars_map\"]}]}}}}}, \"BlacklistedHostnames\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"list_concat\": [{\"get_attr\": [\"Controller\", \"blacklist_hostname\"]}, {\"get_attr\": [\"CellController\", \"blacklist_hostname\"]}, {\"get_attr\": [\"CellControllerCompute\", \"blacklist_hostname\"]}, {\"get_attr\": [\"Compute\", \"blacklist_hostname\"]}, {\"get_attr\": [\"BlockStorage\", \"blacklist_hostname\"]}, {\"get_attr\": [\"ObjectStorage\", \"blacklist_hostname\"]}, {\"get_attr\": [\"CephStorage\", \"blacklist_hostname\"]}, {\"get_attr\": [\"Networker\", \"blacklist_hostname\"]}]}}}, \"AllNodesDeploySteps\": {\"type\": \"OS::TripleO::PostDeploySteps\", \"depends_on\": [\"AllNodesExtraConfig\"], \"properties\": {\"servers\": {\"Controller\": {\"get_attr\": [\"ControllerServers\", \"value\"]}, \"CellController\": {\"get_attr\": [\"CellControllerServers\", \"value\"]}, \"CellControllerCompute\": {\"get_attr\": [\"CellControllerComputeServers\", \"value\"]}, \"Compute\": {\"get_attr\": [\"ComputeServers\", \"value\"]}, \"BlockStorage\": {\"get_attr\": [\"BlockStorageServers\", \"value\"]}, \"ObjectStorage\": {\"get_attr\": [\"ObjectStorageServers\", \"value\"]}, \"CephStorage\": {\"get_attr\": [\"CephStorageServers\", \"value\"]}, \"Networker\": {\"get_attr\": [\"NetworkerServers\", \"value\"]}}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"role_data\": {\"Controller\": {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\"]}, \"CellController\": {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\"]}, \"CellControllerCompute\": {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\"]}, \"Compute\": {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\"]}, \"BlockStorage\": {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\"]}, \"ObjectStorage\": {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\"]}, \"CephStorage\": {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\"]}, \"Networker\": {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\"]}}, \"ControllerCount\": {\"get_param\": \"ControllerCount\"}, \"CellControllerCount\": {\"get_param\": \"CellControllerCount\"}, \"CellControllerComputeCount\": {\"get_param\": \"CellControllerComputeCount\"}, \"ComputeCount\": {\"get_param\": \"ComputeCount\"}, \"BlockStorageCount\": {\"get_param\": \"BlockStorageCount\"}, \"ObjectStorageCount\": {\"get_param\": \"ObjectStorageCount\"}, \"CephStorageCount\": {\"get_param\": \"CephStorageCount\"}, \"NetworkerCount\": {\"get_param\": \"NetworkerCount\"}, \"ServiceNetMapLower\": {\"get_attr\": [\"ServiceNetMap\", \"service_net_map_lower\"]}, \"PingTestGatewayIPsMap\": {\"Controller\": {\"yaql\": {\"expression\": \"list($.data.where($ != null and len($) > 0)).flatten()\", \"data\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ControllerControlPlaneSubnet\"}, \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"gateway_ip\"]}]}}, \"CellController\": {\"yaql\": {\"expression\": \"list($.data.where($ != null and len($) > 0)).flatten()\", \"data\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerControlPlaneSubnet\"}, \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"gateway_ip\"]}]}}, \"CellControllerCompute\": {\"yaql\": {\"expression\": \"list($.data.where($ != null and len($) > 0)).flatten()\", \"data\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerComputeControlPlaneSubnet\"}, \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"gateway_ip\"]}]}}, \"Compute\": {\"yaql\": {\"expression\": \"list($.data.where($ != null and len($) > 0)).flatten()\", \"data\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ComputeControlPlaneSubnet\"}, \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"gateway_ip\"]}]}}, \"BlockStorage\": {\"yaql\": {\"expression\": \"list($.data.where($ != null and len($) > 0)).flatten()\", \"data\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"BlockStorageControlPlaneSubnet\"}, \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}]}}, \"ObjectStorage\": {\"yaql\": {\"expression\": \"list($.data.where($ != null and len($) > 0)).flatten()\", \"data\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ObjectStorageControlPlaneSubnet\"}, \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}]}}, \"CephStorage\": {\"yaql\": {\"expression\": \"list($.data.where($ != null and len($) > 0)).flatten()\", \"data\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CephStorageControlPlaneSubnet\"}, \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"gateway_ip\"]}]}}, \"Networker\": {\"yaql\": {\"expression\": \"list($.data.where($ != null and len($) > 0)).flatten()\", \"data\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"NetworkerControlPlaneSubnet\"}, \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"gateway_ip\"]}]}}}, \"PingTestIpsMap\": {\"Controller\": {\"list_join\": [\" \", [{\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"Controller\", \"ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"Controller\", \"storage_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"Controller\", \"storage_mgmt_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"Controller\", \"internal_api_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"Controller\", \"tenant_ip_address\"]}}}]]}, \"CellController\": {\"list_join\": [\" \", [{\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CellController\", \"ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CellController\", \"storage_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CellController\", \"storage_mgmt_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CellController\", \"internal_api_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CellController\", \"tenant_ip_address\"]}}}]]}, \"CellControllerCompute\": {\"list_join\": [\" \", [{\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CellControllerCompute\", \"ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CellControllerCompute\", \"storage_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CellControllerCompute\", \"storage_mgmt_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CellControllerCompute\", \"internal_api_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CellControllerCompute\", \"tenant_ip_address\"]}}}]]}, \"Compute\": {\"list_join\": [\" \", [{\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"Compute\", \"ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"Compute\", \"storage_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"Compute\", \"internal_api_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"Compute\", \"tenant_ip_address\"]}}}]]}, \"BlockStorage\": {\"list_join\": [\" \", [{\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"BlockStorage\", \"ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"BlockStorage\", \"storage_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"BlockStorage\", \"storage_mgmt_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"BlockStorage\", \"internal_api_ip_address\"]}}}]]}, \"ObjectStorage\": {\"list_join\": [\" \", [{\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"ObjectStorage\", \"ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"ObjectStorage\", \"storage_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"ObjectStorage\", \"storage_mgmt_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"ObjectStorage\", \"internal_api_ip_address\"]}}}]]}, \"CephStorage\": {\"list_join\": [\" \", [{\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CephStorage\", \"ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CephStorage\", \"storage_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CephStorage\", \"storage_mgmt_ip_address\"]}}}]]}, \"Networker\": {\"list_join\": [\" \", [{\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"Networker\", \"ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"Networker\", \"internal_api_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"Networker\", \"tenant_ip_address\"]}}}]]}}, \"HostsEntry\": {\"get_attr\": [\"HostsEntryValue\", \"value\"]}, \"EnabledServices\": {\"list_concat\": [{\"get_attr\": [\"ControllerServiceNames\", \"value\"]}, {\"get_attr\": [\"CellControllerServiceNames\", \"value\"]}, {\"get_attr\": [\"CellControllerComputeServiceNames\", \"value\"]}, {\"get_attr\": [\"ComputeServiceNames\", \"value\"]}, {\"get_attr\": [\"BlockStorageServiceNames\", \"value\"]}, {\"get_attr\": [\"ObjectStorageServiceNames\", \"value\"]}, {\"get_attr\": [\"CephStorageServiceNames\", \"value\"]}, {\"get_attr\": [\"NetworkerServiceNames\", \"value\"]}]}, \"ControlVirtualIP\": {\"get_attr\": [\"ControlVirtualIP\", \"fixed_ips\", 0, \"ip_address\"]}, \"EnabledNetworks\": [\"Storage\", \"StorageMgmt\", \"InternalApi\", \"Tenant\", \"External\"], \"NetVipMap\": {\"get_attr\": [\"VipMap\", \"net_ip_map\"]}, \"CloudNames\": {\"get_attr\": [\"CloudNames\", \"value\"]}, \"UndercloudHostsEntries\": {\"get_param\": \"UndercloudHostsEntries\"}, \"ExtraHostsEntries\": {\"get_param\": \"ExtraHostFileEntries\"}, \"VipHostsEntries\": {\"if\": [\"add_vips_to_etc_hosts\", {\"get_attr\": [\"VipHosts\", \"value\"]}, []]}, \"KeystoneResourcesConfigs\": {\"map_merge\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"keystone_resources\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"keystone_resources\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"keystone_resources\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"keystone_resources\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"keystone_resources\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"keystone_resources\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"keystone_resources\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"keystone_resources\"]}]}, \"NetCidrMap\": {\"get_attr\": [\"NetCidrMapValue\", \"value\"]}}}}, \"outputs\": {\"ManagedEndpoints\": {\"description\": \"Asserts that the keystone endpoints have been provisioned.\", \"value\": true}, \"KeystoneURL\": {\"description\": \"URL for the Overcloud Keystone service\", \"value\": {\"get_attr\": [\"EndpointMapData\", \"value\", \"KeystonePublic\", \"uri_no_suffix\"]}}, \"KeystoneAdminVip\": {\"description\": \"Keystone Admin VIP endpoint\", \"value\": {\"get_attr\": [\"VipMap\", \"net_ip_map\", {\"get_attr\": [\"ServiceNetMap\", \"service_net_map\", \"KeystoneAdminApiNetwork\"]}]}}, \"EndpointMap\": {\"description\": \"Mapping of the resources with the needed info for their endpoints.\\nThis includes the protocol used, the IP, port and also a full\\nrepresentation of the URI.\\n\", \"value\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}}, \"HostsEntry\": {\"description\": \"The content that should be appended to your /etc/hosts if you want to get\\nhostname-based access to the deployed nodes (useful for testing without\\nsetting up a DNS).\\n\", \"value\": {\"list_concat_unique\": [{\"get_attr\": [\"HostsEntryValue\", \"value\"]}, {\"get_attr\": [\"VipHosts\", \"value\"]}]}}, \"EnabledServices\": {\"description\": \"The services enabled on each role\", \"value\": {\"Controller\": {\"get_attr\": [\"ControllerServiceNames\", \"value\"]}, \"CellController\": {\"get_attr\": [\"CellControllerServiceNames\", \"value\"]}, \"CellControllerCompute\": {\"get_attr\": [\"CellControllerComputeServiceNames\", \"value\"]}, \"Compute\": {\"get_attr\": [\"ComputeServiceNames\", \"value\"]}, \"BlockStorage\": {\"get_attr\": [\"BlockStorageServiceNames\", \"value\"]}, \"ObjectStorage\": {\"get_attr\": [\"ObjectStorageServiceNames\", \"value\"]}, \"CephStorage\": {\"get_attr\": [\"CephStorageServiceNames\", \"value\"]}, \"Networker\": {\"get_attr\": [\"NetworkerServiceNames\", \"value\"]}}}, \"RoleData\": {\"description\": \"The configuration data associated with each role\", \"value\": {\"Controller\": {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\"]}, \"CellController\": {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\"]}, \"CellControllerCompute\": {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\"]}, \"Compute\": {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\"]}, \"BlockStorage\": {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\"]}, \"ObjectStorage\": {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\"]}, \"CephStorage\": {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\"]}, \"Networker\": {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\"]}}}, \"RoleConfig\": {\"description\": \"The configuration workflows associated with each role\", \"value\": {\"get_attr\": [\"AllNodesDeploySteps\", \"RoleConfig\"]}}, \"RoleNetIpMap\": {\"description\": \"Mapping of each network to a list of IPs for each role\", \"value\": {\"Controller\": {\"get_attr\": [\"ControllerIpListMap\", \"net_ip_map\"]}, \"CellController\": {\"get_attr\": [\"CellControllerIpListMap\", \"net_ip_map\"]}, \"CellControllerCompute\": {\"get_attr\": [\"CellControllerComputeIpListMap\", \"net_ip_map\"]}, \"Compute\": {\"get_attr\": [\"ComputeIpListMap\", \"net_ip_map\"]}, \"BlockStorage\": {\"get_attr\": [\"BlockStorageIpListMap\", \"net_ip_map\"]}, \"ObjectStorage\": {\"get_attr\": [\"ObjectStorageIpListMap\", \"net_ip_map\"]}, \"CephStorage\": {\"get_attr\": [\"CephStorageIpListMap\", \"net_ip_map\"]}, \"Networker\": {\"get_attr\": [\"NetworkerIpListMap\", \"net_ip_map\"]}}}, \"RoleGroupVars\": {\"description\": \"Mapping of roles to ansible group_vars to be applied config in those roles\", \"value\": {\"Controller\": {\"map_merge\": [{\"get_attr\": [\"ControllerGroupVars\", \"value\"]}, {\"get_attr\": [\"ControllerConfigData\", \"value\"]}, {\"any_errors_fatal\": {\"get_param\": \"ControllerAnyErrorsFatal\"}, \"max_fail_percentage\": {\"get_param\": \"ControllerMaxFailPercentage\"}, \"neutron_physical_bridge_name\": {\"get_param\": \"NeutronPhysicalBridge\"}, \"neutron_public_interface_name\": {\"get_param\": \"NeutronPublicInterface\"}, \"network_config_update\": {\"get_param\": \"ControllerNetworkConfigUpdate\"}, \"use_nmstate\": {\"get_param\": \"ControllerUseNMState\"}, \"ifcfg_purge\": {\"get_param\": \"ControllerIfcfgPurge\"}, \"tripleo_network_config_os_net_config_mappings\": {\"get_param\": \"NetConfigDataLookup\"}, \"deployed_server_port_map\": {\"get_param\": \"DeployedServerPortMap\"}, \"tripleo_network_config_override\": {\"get_param\": \"ControllerNetConfigOverride\"}, \"tripleo_stack_name\": {\"get_param\": \"RootStackName\"}}, {\"get_param\": \"ControllerExtraGroupVars\"}]}, \"CellController\": {\"map_merge\": [{\"get_attr\": [\"CellControllerGroupVars\", \"value\"]}, {\"get_attr\": [\"CellControllerConfigData\", \"value\"]}, {\"any_errors_fatal\": {\"get_param\": \"CellControllerAnyErrorsFatal\"}, \"max_fail_percentage\": {\"get_param\": \"CellControllerMaxFailPercentage\"}, \"neutron_physical_bridge_name\": {\"get_param\": \"NeutronPhysicalBridge\"}, \"neutron_public_interface_name\": {\"get_param\": \"NeutronPublicInterface\"}, \"network_config_update\": {\"get_param\": \"CellControllerNetworkConfigUpdate\"}, \"use_nmstate\": {\"get_param\": \"CellControllerUseNMState\"}, \"ifcfg_purge\": {\"get_param\": \"CellControllerIfcfgPurge\"}, \"tripleo_network_config_os_net_config_mappings\": {\"get_param\": \"NetConfigDataLookup\"}, \"deployed_server_port_map\": {\"get_param\": \"DeployedServerPortMap\"}, \"tripleo_network_config_override\": {\"get_param\": \"CellControllerNetConfigOverride\"}, \"tripleo_stack_name\": {\"get_param\": \"RootStackName\"}}, {\"get_param\": \"CellControllerExtraGroupVars\"}]}, \"CellControllerCompute\": {\"map_merge\": [{\"get_attr\": [\"CellControllerComputeGroupVars\", \"value\"]}, {\"get_attr\": [\"CellControllerComputeConfigData\", \"value\"]}, {\"any_errors_fatal\": {\"get_param\": \"CellControllerComputeAnyErrorsFatal\"}, \"max_fail_percentage\": {\"get_param\": \"CellControllerComputeMaxFailPercentage\"}, \"neutron_physical_bridge_name\": {\"get_param\": \"NeutronPhysicalBridge\"}, \"neutron_public_interface_name\": {\"get_param\": \"NeutronPublicInterface\"}, \"network_config_update\": {\"get_param\": \"CellControllerComputeNetworkConfigUpdate\"}, \"use_nmstate\": {\"get_param\": \"CellControllerComputeUseNMState\"}, \"ifcfg_purge\": {\"get_param\": \"CellControllerComputeIfcfgPurge\"}, \"tripleo_network_config_os_net_config_mappings\": {\"get_param\": \"NetConfigDataLookup\"}, \"deployed_server_port_map\": {\"get_param\": \"DeployedServerPortMap\"}, \"tripleo_network_config_override\": {\"get_param\": \"CellControllerComputeNetConfigOverride\"}, \"tripleo_stack_name\": {\"get_param\": \"RootStackName\"}}, {\"get_param\": \"CellControllerComputeExtraGroupVars\"}]}, \"Compute\": {\"map_merge\": [{\"get_attr\": [\"ComputeGroupVars\", \"value\"]}, {\"get_attr\": [\"ComputeConfigData\", \"value\"]}, {\"any_errors_fatal\": {\"get_param\": \"ComputeAnyErrorsFatal\"}, \"max_fail_percentage\": {\"get_param\": \"ComputeMaxFailPercentage\"}, \"neutron_physical_bridge_name\": {\"get_param\": \"NeutronPhysicalBridge\"}, \"neutron_public_interface_name\": {\"get_param\": \"NeutronPublicInterface\"}, \"network_config_update\": {\"get_param\": \"ComputeNetworkConfigUpdate\"}, \"use_nmstate\": {\"get_param\": \"ComputeUseNMState\"}, \"ifcfg_purge\": {\"get_param\": \"ComputeIfcfgPurge\"}, \"tripleo_network_config_os_net_config_mappings\": {\"get_param\": \"NetConfigDataLookup\"}, \"deployed_server_port_map\": {\"get_param\": \"DeployedServerPortMap\"}, \"tripleo_network_config_override\": {\"get_param\": \"ComputeNetConfigOverride\"}, \"tripleo_stack_name\": {\"get_param\": \"RootStackName\"}}, {\"get_param\": \"ComputeExtraGroupVars\"}]}, \"BlockStorage\": {\"map_merge\": [{\"get_attr\": [\"BlockStorageGroupVars\", \"value\"]}, {\"get_attr\": [\"BlockStorageConfigData\", \"value\"]}, {\"any_errors_fatal\": {\"get_param\": \"BlockStorageAnyErrorsFatal\"}, \"max_fail_percentage\": {\"get_param\": \"BlockStorageMaxFailPercentage\"}, \"neutron_physical_bridge_name\": {\"get_param\": \"NeutronPhysicalBridge\"}, \"neutron_public_interface_name\": {\"get_param\": \"NeutronPublicInterface\"}, \"network_config_update\": {\"get_param\": \"BlockStorageNetworkConfigUpdate\"}, \"use_nmstate\": {\"get_param\": \"BlockStorageUseNMState\"}, \"ifcfg_purge\": {\"get_param\": \"BlockStorageIfcfgPurge\"}, \"tripleo_network_config_os_net_config_mappings\": {\"get_param\": \"NetConfigDataLookup\"}, \"deployed_server_port_map\": {\"get_param\": \"DeployedServerPortMap\"}, \"tripleo_network_config_override\": {\"get_param\": \"BlockStorageNetConfigOverride\"}, \"tripleo_stack_name\": {\"get_param\": \"RootStackName\"}}, {\"get_param\": \"BlockStorageExtraGroupVars\"}]}, \"ObjectStorage\": {\"map_merge\": [{\"get_attr\": [\"ObjectStorageGroupVars\", \"value\"]}, {\"get_attr\": [\"ObjectStorageConfigData\", \"value\"]}, {\"any_errors_fatal\": {\"get_param\": \"ObjectStorageAnyErrorsFatal\"}, \"max_fail_percentage\": {\"get_param\": \"ObjectStorageMaxFailPercentage\"}, \"neutron_physical_bridge_name\": {\"get_param\": \"NeutronPhysicalBridge\"}, \"neutron_public_interface_name\": {\"get_param\": \"NeutronPublicInterface\"}, \"network_config_update\": {\"get_param\": \"ObjectStorageNetworkConfigUpdate\"}, \"use_nmstate\": {\"get_param\": \"ObjectStorageUseNMState\"}, \"ifcfg_purge\": {\"get_param\": \"ObjectStorageIfcfgPurge\"}, \"tripleo_network_config_os_net_config_mappings\": {\"get_param\": \"NetConfigDataLookup\"}, \"deployed_server_port_map\": {\"get_param\": \"DeployedServerPortMap\"}, \"tripleo_network_config_override\": {\"get_param\": \"ObjectStorageNetConfigOverride\"}, \"tripleo_stack_name\": {\"get_param\": \"RootStackName\"}}, {\"get_param\": \"ObjectStorageExtraGroupVars\"}]}, \"CephStorage\": {\"map_merge\": [{\"get_attr\": [\"CephStorageGroupVars\", \"value\"]}, {\"get_attr\": [\"CephStorageConfigData\", \"value\"]}, {\"any_errors_fatal\": {\"get_param\": \"CephStorageAnyErrorsFatal\"}, \"max_fail_percentage\": {\"get_param\": \"CephStorageMaxFailPercentage\"}, \"neutron_physical_bridge_name\": {\"get_param\": \"NeutronPhysicalBridge\"}, \"neutron_public_interface_name\": {\"get_param\": \"NeutronPublicInterface\"}, \"network_config_update\": {\"get_param\": \"CephStorageNetworkConfigUpdate\"}, \"use_nmstate\": {\"get_param\": \"CephStorageUseNMState\"}, \"ifcfg_purge\": {\"get_param\": \"CephStorageIfcfgPurge\"}, \"tripleo_network_config_os_net_config_mappings\": {\"get_param\": \"NetConfigDataLookup\"}, \"deployed_server_port_map\": {\"get_param\": \"DeployedServerPortMap\"}, \"tripleo_network_config_override\": {\"get_param\": \"CephStorageNetConfigOverride\"}, \"tripleo_stack_name\": {\"get_param\": \"RootStackName\"}}, {\"get_param\": \"CephStorageExtraGroupVars\"}]}, \"Networker\": {\"map_merge\": [{\"get_attr\": [\"NetworkerGroupVars\", \"value\"]}, {\"get_attr\": [\"NetworkerConfigData\", \"value\"]}, {\"any_errors_fatal\": {\"get_param\": \"NetworkerAnyErrorsFatal\"}, \"max_fail_percentage\": {\"get_param\": \"NetworkerMaxFailPercentage\"}, \"neutron_physical_bridge_name\": {\"get_param\": \"NeutronPhysicalBridge\"}, \"neutron_public_interface_name\": {\"get_param\": \"NeutronPublicInterface\"}, \"network_config_update\": {\"get_param\": \"NetworkerNetworkConfigUpdate\"}, \"use_nmstate\": {\"get_param\": \"NetworkerUseNMState\"}, \"ifcfg_purge\": {\"get_param\": \"NetworkerIfcfgPurge\"}, \"tripleo_network_config_os_net_config_mappings\": {\"get_param\": \"NetConfigDataLookup\"}, \"deployed_server_port_map\": {\"get_param\": \"DeployedServerPortMap\"}, \"tripleo_network_config_override\": {\"get_param\": \"NetworkerNetConfigOverride\"}, \"tripleo_stack_name\": {\"get_param\": \"RootStackName\"}}, {\"get_param\": \"NetworkerExtraGroupVars\"}]}}}, \"RoleNetHostnameMap\": {\"description\": \"Mapping of each network to a list of hostnames for each role\", \"value\": {\"Controller\": {\"get_attr\": [\"ControllerNetworkHostnameMap\", \"value\"]}, \"CellController\": {\"get_attr\": [\"CellControllerNetworkHostnameMap\", \"value\"]}, \"CellControllerCompute\": {\"get_attr\": [\"CellControllerComputeNetworkHostnameMap\", \"value\"]}, \"Compute\": {\"get_attr\": [\"ComputeNetworkHostnameMap\", \"value\"]}, \"BlockStorage\": {\"get_attr\": [\"BlockStorageNetworkHostnameMap\", \"value\"]}, \"ObjectStorage\": {\"get_attr\": [\"ObjectStorageNetworkHostnameMap\", \"value\"]}, \"CephStorage\": {\"get_attr\": [\"CephStorageNetworkHostnameMap\", \"value\"]}, \"Networker\": {\"get_attr\": [\"NetworkerNetworkHostnameMap\", \"value\"]}}}, \"RoleTags\": {\"description\": \"Tags for each role, as defined in roles_data.yaml\", \"value\": {\"Controller\": [\"primary\", \"controller\", \"external_bridge\"], \"CellController\": [\"primary\", \"controller\"], \"CellControllerCompute\": [\"primary\", \"controller\", \"external_bridge\"], \"Compute\": [\"compute\", \"external_bridge\"], \"BlockStorage\": [\"storage\"], \"ObjectStorage\": [\"storage\"], \"CephStorage\": [\"ceph\", \"storage\"], \"Networker\": [\"external_bridge\"]}}, \"VipMap\": {\"description\": \"Mapping of each network to VIP addresses. Also includes the Redis and OVN DBs VIPs.\", \"value\": {\"get_attr\": [\"VipMap\", \"net_ip_map\"]}}, \"ServerIdData\": {\"description\": \"Mapping of each role to a list of nova server IDs and the bootstrap ID\", \"value\": {\"get_attr\": [\"ServerIdMap\", \"value\"]}}, \"BlacklistedHostnames\": {\"description\": \"List of blacklisted hostnames\", \"value\": {\"get_attr\": [\"BlacklistedHostnames\", \"value\"]}}, \"BlacklistedIpAddresses\": {\"description\": \"List of blacklisted ctlplane IP addresses\", \"value\": {\"get_attr\": [\"BlacklistedIpAddresses\", \"value\"]}}, \"GlobalConfig\": {\"description\": \"The global_config (hieradata).\", \"value\": {\"get_attr\": [\"GlobalConfig\", \"value\"]}}, \"RoleNetworkConfigMap\": {\"description\": \"Mapping of roles to network config\", \"value\": {\"Controller\": {\"get_attr\": [\"ControllerNetworkConfig\", \"config\"]}, \"CellController\": {\"get_attr\": [\"CellControllerNetworkConfig\", \"config\"]}, \"CellControllerCompute\": {\"get_attr\": [\"CellControllerComputeNetworkConfig\", \"config\"]}, \"Compute\": {\"get_attr\": [\"ComputeNetworkConfig\", \"config\"]}, \"BlockStorage\": {\"get_attr\": [\"BlockStorageNetworkConfig\", \"config\"]}, \"ObjectStorage\": {\"get_attr\": [\"ObjectStorageNetworkConfig\", \"config\"]}, \"CephStorage\": {\"get_attr\": [\"CephStorageNetworkConfig\", \"config\"]}, \"Networker\": {\"get_attr\": [\"NetworkerNetworkConfig\", \"config\"]}}}, \"AnsibleHostVarsMap\": {\"description\": \"Map of Ansible Host variables per role\", \"value\": {\"get_attr\": [\"AnsibleHostVars\", \"value\"]}}, \"TripleoHeatTemplatesJinja2RenderingDataSources\": {\"description\": \"The role_data and the network_data used when rendering the THT Jinja2 templates\", \"value\": {\"roles_data\": [{\"name\": \"Controller\", \"description\": \"Controller role that has all the controler services loaded and handles\\\\nDatabase, Messaging and Network functions.\\\\n\", \"CountDefault\": 1, \"tags\": [\"primary\", \"controller\", \"external_bridge\"], \"networks\": {\"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Storage\": {\"subnet\": \"storage_subnet\"}, \"StorageMgmt\": {\"subnet\": \"storage_mgmt_subnet\"}, \"Tenant\": {\"subnet\": \"tenant_subnet\"}}, \"default_route_networks\": [\"ControlPlane\"], \"HostnameFormatDefault\": \"%stackname%-controller-%index%\", \"RoleParametersDefault\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"uses_deprecated_params\": true, \"deprecated_param_extraconfig\": \"controllerExtraConfig\", \"deprecated_param_flavor\": \"OvercloudControlFlavor\", \"deprecated_param_image\": \"controllerImage\", \"deprecated_nic_config_name\": \"controller.yaml\", \"update_serial\": 1, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BarbicanApi\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\", \"OS::TripleO::Services::BarbicanBackendDogtag\", \"OS::TripleO::Services::BarbicanBackendKmip\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephExternal\", \"OS::TripleO::Services::CephGrafana\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CephNfs\", \"OS::TripleO::Services::CephRbdMirror\", \"OS::TripleO::Services::CephRgw\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackendDellSc\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\", \"OS::TripleO::Services::CinderBackendDellEMCSc\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\", \"OS::TripleO::Services::CinderBackendNetApp\", \"OS::TripleO::Services::CinderBackendPure\", \"OS::TripleO::Services::CinderBackendScaleIO\", \"OS::TripleO::Services::CinderBackendNVMeOF\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::DesignateApi\", \"OS::TripleO::Services::DesignateCentral\", \"OS::TripleO::Services::DesignateProducer\", \"OS::TripleO::Services::DesignateWorker\", \"OS::TripleO::Services::DesignateMDNS\", \"OS::TripleO::Services::DesignateSink\", \"OS::TripleO::Services::DesignateBind\", \"OS::TripleO::Services::Etcd\", \"OS::TripleO::Services::ExternalSwiftProxy\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::IronicApi\", \"OS::TripleO::Services::IronicConductor\", \"OS::TripleO::Services::IronicInspector\", \"OS::TripleO::Services::IronicPxe\", \"OS::TripleO::Services::IronicNeutronAgent\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaBackendFlashBlade\", \"OS::TripleO::Services::ManilaBackendIsilon\", \"OS::TripleO::Services::ManilaBackendNetapp\", \"OS::TripleO::Services::ManilaBackendPowerMax\", \"OS::TripleO::Services::ManilaBackendUnity\", \"OS::TripleO::Services::ManilaBackendVNX\", \"OS::TripleO::Services::ManilaBackendVMAX\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::Multipathd\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronBgpVpnApi\", \"OS::TripleO::Services::NeutronSfcApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NeutronDhcpAgent\", \"OS::TripleO::Services::NeutronL2gwAgent\", \"OS::TripleO::Services::NeutronL2gwApi\", \"OS::TripleO::Services::NeutronL3Agent\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\", \"OS::TripleO::Services::NeutronMetadataAgent\", \"OS::TripleO::Services::NeutronOvsAgent\", \"OS::TripleO::Services::NeutronVppAgent\", \"OS::TripleO::Services::NeutronAgentsIBConfig\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaIronic\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OctaviaApi\", \"OS::TripleO::Services::OctaviaDeploymentConfig\", \"OS::TripleO::Services::OctaviaHealthManager\", \"OS::TripleO::Services::OctaviaHousekeeping\", \"OS::TripleO::Services::OctaviaWorker\", \"OS::TripleO::Services::OpenStackClients\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftDispersion\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::Unbound\", \"OS::TripleO::Services::Vpp\"]}, {\"name\": \"CellController\", \"description\": \"Controller role that has the cell controler specific\\\\nservices and handles Database, Messaging and Network functions.\\\\n\", \"CountDefault\": 1, \"tags\": [\"primary\", \"controller\"], \"networks\": {\"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Storage\": {\"subnet\": \"storage_subnet\"}, \"StorageMgmt\": {\"subnet\": \"storage_mgmt_subnet\"}, \"Tenant\": {\"subnet\": \"tenant_subnet\"}}, \"default_route_networks\": [\"ControlPlane\"], \"HostnameFormatDefault\": \"%stackname%-controller-%index%\", \"RoleParametersDefault\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"uses_deprecated_params\": true, \"deprecated_param_extraconfig\": \"controllerExtraConfig\", \"deprecated_param_flavor\": \"OvercloudControlFlavor\", \"deprecated_param_image\": \"controllerImage\", \"deprecated_nic_config_name\": \"controller.yaml\", \"update_serial\": 1, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronMetadataAgent\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Ptp\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::Vpp\"]}, {\"name\": \"CellControllerCompute\", \"description\": \"Controller and Compute AIO role that has compute and cell controler specific\\\\nservices loaded and handles Database, Messaging and Network functions.\\\\n\", \"CountDefault\": 1, \"tags\": [\"primary\", \"controller\", \"external_bridge\"], \"networks\": {\"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Storage\": {\"subnet\": \"storage_subnet\"}, \"StorageMgmt\": {\"subnet\": \"storage_mgmt_subnet\"}, \"Tenant\": {\"subnet\": \"tenant_subnet\"}}, \"default_route_networks\": [\"ControlPlane\"], \"HostnameFormatDefault\": \"%stackname%-controller-compute-%index%\", \"RoleParametersDefault\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"uses_deprecated_params\": true, \"deprecated_param_extraconfig\": \"controllerExtraConfig\", \"deprecated_param_flavor\": \"OvercloudControlFlavor\", \"deprecated_param_image\": \"controllerImage\", \"deprecated_nic_config_name\": \"controller.yaml\", \"update_serial\": 1, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephExternal\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\", \"OS::TripleO::Services::ComputeNeutronL3Agent\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::Multipathd\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\", \"OS::TripleO::Services::NeutronVppAgent\", \"OS::TripleO::Services::NovaAZConfig\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::NeutronMetadataAgent\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Ptp\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::Vpp\"]}, {\"name\": \"Compute\", \"description\": \"Basic Compute Node role\\\\n\", \"CountDefault\": 1, \"tags\": [\"compute\", \"external_bridge\"], \"networks\": {\"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Tenant\": {\"subnet\": \"tenant_subnet\"}, \"Storage\": {\"subnet\": \"storage_subnet\"}}, \"default_route_networks\": [\"ControlPlane\"], \"HostnameFormatDefault\": \"%stackname%-novacompute-%index%\", \"RoleParametersDefault\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"uses_deprecated_params\": true, \"deprecated_param_image\": \"NovaImage\", \"deprecated_param_extraconfig\": \"NovaComputeExtraConfig\", \"deprecated_param_metadata\": \"NovaComputeServerMetadata\", \"deprecated_param_scheduler_hints\": \"NovaComputeSchedulerHints\", \"deprecated_param_ips\": \"NovaComputeIPs\", \"deprecated_server_resource_name\": \"NovaCompute\", \"deprecated_nic_config_name\": \"compute.yaml\", \"update_serial\": 25, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephExternal\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\", \"OS::TripleO::Services::ComputeNeutronL3Agent\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::Multipathd\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\", \"OS::TripleO::Services::NeutronVppAgent\", \"OS::TripleO::Services::NovaAZConfig\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::Vpp\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"]}, {\"name\": \"BlockStorage\", \"description\": \"Cinder Block Storage node role\\\\n\", \"tags\": [\"storage\"], \"networks\": {\"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Storage\": {\"subnet\": \"storage_subnet\"}, \"StorageMgmt\": {\"subnet\": \"storage_mgmt_subnet\"}}, \"uses_deprecated_params\": false, \"deprecated_nic_config_name\": \"cinder-storage.yaml\", \"update_serial\": 25, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BlockStorageCinderVolume\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::Multipathd\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"]}, {\"name\": \"ObjectStorage\", \"description\": \"Swift Object Storage node role\\\\n\", \"tags\": [\"storage\"], \"networks\": {\"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Storage\": {\"subnet\": \"storage_subnet\"}, \"StorageMgmt\": {\"subnet\": \"storage_mgmt_subnet\"}}, \"uses_deprecated_params\": true, \"deprecated_param_metadata\": \"SwiftStorageServerMetadata\", \"deprecated_param_ips\": \"SwiftStorageIPs\", \"deprecated_param_image\": \"SwiftStorageImage\", \"deprecated_param_flavor\": \"OvercloudSwiftStorageFlavor\", \"deprecated_nic_config_name\": \"swift-storage.yaml\", \"deprecated_server_resource_name\": \"SwiftStorage\", \"update_serial\": 1, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::Ptp\"]}, {\"name\": \"CephStorage\", \"description\": \"Ceph OSD Storage node role\\\\n\", \"tags\": [\"ceph\", \"storage\"], \"networks\": {\"Storage\": {\"subnet\": \"storage_subnet\"}, \"StorageMgmt\": {\"subnet\": \"storage_mgmt_subnet\"}}, \"uses_deprecated_params\": false, \"HostnameFormatDefault\": \"%stackname%-cephstorage-%index%\", \"deprecated_nic_config_name\": \"ceph-storage.yaml\", \"update_serial\": 1, \"rhsm_enforce\": false, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"]}, {\"name\": \"Networker\", \"description\": \"Standalone networking role to run Neutron agents on their own.\\\\n\", \"networks\": {\"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Tenant\": {\"subnet\": \"tenant_subnet\"}}, \"tags\": [\"external_bridge\"], \"HostnameFormatDefault\": \"%stackname%-networker-%index%\", \"RoleParametersDefault\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"update_serial\": 1, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::IronicNeutronAgent\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronDhcpAgent\", \"OS::TripleO::Services::NeutronL2gwAgent\", \"OS::TripleO::Services::NeutronL3Agent\", \"OS::TripleO::Services::NeutronMetadataAgent\", \"OS::TripleO::Services::NeutronOvsAgent\", \"OS::TripleO::Services::NeutronVppAgent\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OctaviaDeploymentConfig\", \"OS::TripleO::Services::OctaviaHealthManager\", \"OS::TripleO::Services::OctaviaHousekeeping\", \"OS::TripleO::Services::OctaviaWorker\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"]}], \"networks_data\": [{\"name\": \"Storage\", \"mtu\": 1500, \"vip\": true, \"name_lower\": \"storage\", \"dns_domain\": \"storage.ooo.test.\", \"service_net_map_replace\": \"storage\", \"subnets\": {\"storage_subnet\": {\"vlan\": 21, \"ip_subnet\": \"172.18.0.0/24\", \"allocation_pools\": [{\"start\": \"172.18.0.160\", \"end\": \"172.18.0.250\"}]}}, \"idx\": 0}, {\"name\": \"StorageMgmt\", \"mtu\": 1500, \"vip\": true, \"name_lower\": \"storage_mgmt\", \"dns_domain\": \"storagemgmt.ooo.test.\", \"service_net_map_replace\": \"storage_mgmt\", \"subnets\": {\"storage_mgmt_subnet\": {\"vlan\": 23, \"ip_subnet\": \"172.20.0.0/24\", \"allocation_pools\": [{\"start\": \"172.20.0.160\", \"end\": \"172.20.0.250\"}]}}, \"idx\": 1}, {\"name\": \"InternalApi\", \"mtu\": 1500, \"vip\": true, \"name_lower\": \"internal_api\", \"dns_domain\": \"internal-api.ooo.test.\", \"service_net_map_replace\": \"internal_api\", \"subnets\": {\"internal_api_subnet\": {\"vlan\": 20, \"ip_subnet\": \"172.17.0.0/24\", \"allocation_pools\": [{\"start\": \"172.17.0.160\", \"end\": \"172.17.0.250\"}]}}, \"idx\": 2}, {\"name\": \"Tenant\", \"mtu\": 1500, \"vip\": false, \"name_lower\": \"tenant\", \"dns_domain\": \"tenant.ooo.test.\", \"service_net_map_replace\": \"tenant\", \"subnets\": {\"tenant_subnet\": {\"vlan\": 22, \"ip_subnet\": \"172.19.0.0/24\", \"allocation_pools\": [{\"start\": \"172.19.0.160\", \"end\": \"172.19.0.250\"}]}}, \"idx\": 3}, {\"name\": \"External\", \"mtu\": 1500, \"vip\": true, \"name_lower\": \"external\", \"dns_domain\": \"external.ooo.test.\", \"service_net_map_replace\": \"external\", \"subnets\": {\"external_subnet\": {\"gateway_ip\": \"172.21.0.1\", \"vlan\": 44, \"ip_subnet\": \"172.21.0.0/24\", \"allocation_pools\": [{\"start\": \"172.21.0.160\", \"end\": \"172.21.0.250\"}]}}, \"idx\": 4}]}}, \"AdminPassword\": {\"description\": \"The password for the keystone admin account, used for monitoring, querying neutron etc.\", \"value\": {\"get_param\": \"AdminPassword\"}}, \"KeystoneRegion\": {\"description\": \"Keystone region for endpoint\", \"value\": {\"get_param\": \"KeystoneRegion\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(2,'2026-06-10 07:46:24',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"This is a default no-op template which provides empty user-data which can be passed to the OS::Nova::Server resources. This template can be replaced with a different implementation via the resource registry, such that deployers may customize their first-boot configuration.\\n\", \"resources\": {\"userdata\": {\"type\": \"OS::Heat::MultipartMime\"}}, \"outputs\": {\"OS::stack_id\": {\"value\": {\"get_resource\": \"userdata\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(3,'2026-06-10 07:46:25',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mapping of service_name_network -> network name\\n\", \"parameters\": {\"ServiceNetMap\": {\"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults. Note that the key in this map must match the service_name in the service template, e.g if the service_name is heat_api the key must be either heat_api_network, or optionally HeatApiNetwork (which will be internally converted to transform captalization to underscores).\", \"type\": \"json\", \"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}}, \"ControlPlaneSubnet\": {\"description\": \"The name of the undercloud Neutron control plane subnet\", \"default\": \"ctlplane-subnet\", \"type\": \"string\"}, \"VipSubnetMap\": {\"description\": \"Map of (network_name or service_name) -> subnet_name that defines which subnet to host the VIP. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\", \"default\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMapDeprecatedMapping\": {\"default\": {\"RabbitMqNetwork\": \"RabbitmqNetwork\", \"CephPublicNetwork\": \"CephMonNetwork\", \"SwiftMgmtNetwork\": \"SwiftStorageNetwork\"}, \"description\": \"Mapping older deprecated service names, intended for internal use only, this will be removed in future.\", \"type\": \"json\"}, \"StorageNetName\": {\"default\": \"storage\", \"description\": \"The name of the storage network.\", \"type\": \"string\"}, \"StorageMgmtNetName\": {\"default\": \"storage_mgmt\", \"description\": \"The name of the storage_mgmt network.\", \"type\": \"string\"}, \"InternalApiNetName\": {\"default\": \"internal_api\", \"description\": \"The name of the internal_api network.\", \"type\": \"string\"}, \"TenantNetName\": {\"default\": \"tenant\", \"description\": \"The name of the tenant network.\", \"type\": \"string\"}, \"ExternalNetName\": {\"default\": \"external\", \"description\": \"The name of the external network.\", \"type\": \"string\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"Do not use deprecated params, they will be removed.\", \"parameters\": [\"ServiceNetMapDeprecatedMapping\"]}], \"resources\": {\"ServiceNetMapValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": [{\"map_replace\": [{\"get_param\": \"ServiceNetMap\"}, {\"values\": {\"storage\": {\"get_param\": \"StorageNetName\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtNetName\"}, \"internal_api\": {\"get_param\": \"InternalApiNetName\"}, \"tenant\": {\"get_param\": \"TenantNetName\"}, \"external\": {\"get_param\": \"ExternalNetName\"}}, \"keys\": {\"get_param\": \"ServiceNetMapDeprecatedMapping\"}}]}, {\"NovaVncProxyNetwork\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}}]}}}}, \"outputs\": {\"service_net_map\": {\"value\": {\"get_attr\": [\"ServiceNetMapValue\", \"value\"]}}, \"service_net_map_lower\": {\"value\": {\"yaql\": {\"expression\": \"dict($.data.map.items().select([ regex(`([a-z0-9])([A-Z])`).replace($[0], \'\\\\\\\\1_\\\\\\\\2\').toLower(), $[1]]))\", \"data\": {\"map\": {\"get_attr\": [\"ServiceNetMapValue\", \"value\"]}}}}}, \"vip_subnet_map\": {\"value\": {\"map_replace\": [{\"get_param\": \"VipSubnetMap\"}, {\"values\": {\"ctlplane-subnet\": {\"get_param\": \"ControlPlaneSubnet\"}}}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(4,'2026-06-10 07:46:26',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"This is a default no-op template which provides empty user-data which can be passed to the OS::Nova::Server resources. This template can be replaced with a different implementation via the resource registry, such that deployers may customize their first-boot configuration.\\n\", \"resources\": {\"userdata\": {\"type\": \"OS::Heat::MultipartMime\"}}, \"outputs\": {\"OS::stack_id\": {\"value\": {\"get_resource\": \"userdata\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(5,'2026-06-10 07:46:27',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Deployed VIP port on the Control Plane network.\\n\", \"parameters\": {\"name\": {\"default\": \"\", \"type\": \"string\"}, \"dns_name\": {\"default\": \"\", \"type\": \"string\"}, \"network\": {\"default\": \"\", \"type\": \"string\"}, \"fixed_ips\": {\"default\": \"\", \"type\": \"comma_delimited_list\"}, \"replacement_policy\": {\"default\": \"\", \"type\": \"string\"}, \"tags\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ControlPlaneVipData\": {\"description\": \"Control Plane Virtual IP data\\n\", \"default\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"type\": \"json\"}}, \"outputs\": {\"name\": {\"value\": {\"get_param\": [\"ControlPlaneVipData\", \"name\"]}}, \"fixed_ips\": {\"value\": {\"get_param\": [\"ControlPlaneVipData\", \"fixed_ips\"]}}, \"network\": {\"value\": {\"get_param\": [\"ControlPlaneVipData\", \"network\"]}}, \"subnets\": {\"value\": {\"get_param\": [\"ControlPlaneVipData\", \"subnets\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"name\": \"control_virtual_ip\", \"dns_name\": \"multicell\", \"network\": \"ctlplane\", \"fixed_ips\": \".member.0.subnet=ctlplane-subnet\", \"replacement_policy\": \"AUTO\", \"tags\": \"tripleo_vip_net=ctlplane,tripleo_stack_name=overcloud\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(6,'2026-06-10 07:46:27',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"This is a default no-op template which provides empty user-data which can be passed to the OS::Nova::Server resources. This template can be replaced with a different implementation via the resource registry, such that deployers may customize their first-boot configuration.\\n\", \"resources\": {\"userdata\": {\"type\": \"OS::Heat::MultipartMime\"}}, \"outputs\": {\"OS::stack_id\": {\"value\": {\"get_resource\": \"userdata\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(7,'2026-06-10 07:46:28',NULL,'{\"heat_template_version\": \"wallaby\", \"parameters\": {\"node_admin_username\": {\"type\": \"string\", \"default\": \"heat-admin\"}, \"node_admin_extra_ssh_keys\": {\"type\": \"comma_delimited_list\", \"default\": []}}, \"description\": \"Uses cloud-init to create an additional user with a known name, in addition to the distro-default user created by the cloud-init default.\\n\", \"resources\": {\"userdata\": {\"type\": \"OS::Heat::MultipartMime\", \"properties\": {\"parts\": [{\"config\": {\"get_resource\": \"user_config\"}}]}}, \"user_config\": {\"type\": \"OS::Heat::CloudConfig\", \"properties\": {\"cloud_config\": {\"user\": {\"get_param\": \"node_admin_username\"}, \"ssh_authorized_keys\": {\"get_param\": \"node_admin_extra_ssh_keys\"}}}}}, \"outputs\": {\"OS::stack_id\": {\"value\": {\"get_resource\": \"userdata\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(8,'2026-06-10 07:46:28',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Create networks to split out Overcloud traffic\", \"parameters\": {\"DeployedNetworkEnvironment\": {\"type\": \"json\", \"description\": \"Deployed network environment\", \"default\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}}, \"CtlplaneNetworkCidrs\": {\"type\": \"json\", \"description\": \"Cidrs for the ctlplane network.\"}, \"CtlplaneNetworkAttributes\": {\"type\": \"json\", \"default\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"description\": \"A map containing attributes of the undercloud ctlplane network and subnets. NOTE: The value for this parameter is automatically populated in the plan environment by tripleoclient.\\n\"}}, \"resources\": {\"NetworkExtraConfig\": {\"type\": \"OS::TripleO::Network::ExtraConfig\"}, \"NetworkAttributesMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"map_merge\": [{\"ctlplane\": {\"get_param\": \"CtlplaneNetworkAttributes\"}}, {\"get_param\": [\"DeployedNetworkEnvironment\", \"net_attributes_map\"]}]}}}, \"NetworkCidrMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"map_merge\": [{\"ctlplane\": {\"get_param\": \"CtlplaneNetworkCidrs\"}}, {\"get_param\": [\"DeployedNetworkEnvironment\", \"net_cidr_map\"]}]}}}, \"NetworkIpVersionMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"map_merge\": [{\"ctlplane\": {\"yaql\": {\"expression\": \"$.data.items().first().last().ip_version\", \"data\": {\"get_param\": [\"CtlplaneNetworkAttributes\", \"subnets\"]}}}}, {\"get_param\": [\"DeployedNetworkEnvironment\", \"net_ip_version_map\"]}]}}}}, \"outputs\": {\"net_cidr_map\": {\"value\": {\"get_attr\": [\"NetworkCidrMap\", \"value\"]}}, \"net_ip_version_map\": {\"value\": {\"get_attr\": [\"NetworkIpVersionMap\", \"value\"]}}, \"net_attributes_map\": {\"value\": {\"get_attr\": [\"NetworkAttributesMap\", \"value\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"CtlplaneNetworkCidrs\": \"[\\\"192.168.122.0/24\\\"]\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(9,'2026-06-10 07:46:29',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"This is a default no-op template which provides empty user-data which can be passed to the OS::Nova::Server resources. This template can be replaced with a different implementation via the resource registry, such that deployers may customize their first-boot configuration.\\n\", \"resources\": {\"userdata\": {\"type\": \"OS::Heat::MultipartMime\"}}, \"outputs\": {\"OS::stack_id\": {\"value\": {\"get_resource\": \"userdata\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (10,'2026-06-10 07:46:31',NULL,'{\"heat_template_version\": \"wallaby\", \"parameters\": {\"NtpServer\": {\"default\": \"pool.ntp.org\", \"description\": \"NTP servers list. Defaulted to a set of pool.ntp.org servers in order to have a sane default for Pacemaker deployments when not configuring this parameter by default.\", \"type\": \"comma_delimited_list\"}, \"NtpPool\": {\"default\": [], \"description\": \"NTP pool list.  Defaults to [], so only NtpServer is used by default.\", \"type\": \"comma_delimited_list\"}, \"NtpService\": {\"default\": \"chrony\", \"description\": \"NTP Service to use for the timesync bootstrap.\", \"type\": \"string\"}}, \"description\": \"Uses cloud-init to bootstrap timesync configuration to ensure it is done as soon as possible. We do additional and more complex configurations as part of the deployment itself.\\n\", \"conditions\": {\"use_chrony\": {\"equals\": [{\"get_param\": \"NtpService\"}, \"chrony\"]}}, \"resources\": {\"userdata\": {\"type\": \"OS::Heat::MultipartMime\", \"properties\": {\"parts\": [{\"config\": {\"get_resource\": \"timesync_chrony\"}}, {\"config\": {\"get_resource\": \"timesync_sync\"}}]}}, \"timesync_chrony\": {\"type\": \"OS::Heat::SoftwareConfig\", \"properties\": {\"config\": {\"str_replace\": {\"template\": \"#!/bin/bash\\nif [ \\\"$service\\\" != \\\"chrony\\\" ]; then\\n  exit 0\\nfi\\nset -x\\nSERVERS=\\\"$ntp_servers\\\"\\nPOOLS=\\\"$ntp_pools\\\"\\nsystemctl is-active --quiet chronyd || systemctl start chronyd\\nfor server in $SERVERS; do\\n  chronyc add server \\\"${server}\\\" iburst\\ndone\\nfor pool in $POOLS; do\\n  chronyc add server \\\"${pool}\\\" iburst\\ndone\\nchronyc sources\\n\", \"params\": {\"$ntp_servers\": {\"list_join\": [\" \", {\"get_param\": \"NtpServer\"}]}, \"$ntp_pools\": {\"list_join\": [\" \", {\"get_param\": \"NtpPool\"}]}, \"$service\": {\"get_param\": \"NtpService\"}}}}}}, \"timesync_sync\": {\"type\": \"OS::Heat::SoftwareConfig\", \"properties\": {\"config\": {\"str_replace\": {\"template\": \"#!/bin/bash\\nset -x\\nif [ \\\"$service\\\" = \\\"chrony\\\" ]; then\\n    if command -v chronyc >/dev/null; then\\n        chronyc makestep\\n        chronyc waitsync 30\\n    else\\n        echo \\\"No chronyc available, skipping sync\\\"\\n    fi\\nelif [ \\\"$service\\\" = \\\"ntp\\\" ]; then\\n    if command -v ntpdate >/dev/null; then\\n        ntpdate -u $ntp_servers\\n    else\\n        echo \\\"No ntpdate available, skipping sync\\\"\\n    fi\\nfi\\nhwclock --systohc --utc\\n\", \"params\": {\"$service\": {\"get_param\": \"NtpService\"}, \"$ntp_servers\": {\"list_join\": [\" \", {\"get_param\": \"NtpServer\"}]}}}}}}}, \"outputs\": {\"OS::stack_id\": {\"value\": {\"get_resource\": \"userdata\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(11,'2026-06-10 07:46:32',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"This is a default no-op template which provides empty user-data which can be passed to the OS::Nova::Server resources. This template can be replaced with a different implementation via the resource registry, such that deployers may customize their first-boot configuration.\\n\", \"resources\": {\"userdata\": {\"type\": \"OS::Heat::MultipartMime\"}}, \"outputs\": {\"OS::stack_id\": {\"value\": {\"get_resource\": \"userdata\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(12,'2026-06-10 07:46:33',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Deployed VIP port on the StorageMgmt network.\\n\", \"parameters\": {\"StackName\": {\"description\": \"Name of the overcloud heat stack\", \"default\": \"overcloud\", \"type\": \"string\"}, \"PortName\": {\"description\": \"Name of the port\", \"default\": \"\", \"type\": \"string\"}, \"DnsName\": {\"description\": \"DNS name of the port\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneIP\": {\"description\": \"IP address on the control plane\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneSubnetCidr\": {\"default\": \"\", \"description\": \"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\n\", \"type\": \"string\"}, \"ControlPlaneNetwork\": {\"description\": \"The name of the undercloud Neutron control plane\", \"default\": \"ctlplane\", \"type\": \"string\"}, \"ControlPlaneSubnet\": {\"description\": \"The name of the undercloud Neutron control plane subnet\", \"default\": \"ctlplane-subnet\", \"type\": \"string\"}, \"FixedIPs\": {\"description\": \"Control the IP allocation for the VIP port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"default\": [], \"type\": \"json\"}, \"IPPool\": {\"default\": {}, \"type\": \"json\"}, \"NodeIndex\": {\"default\": 0, \"type\": \"number\"}, \"IsVirtualIP\": {\"type\": \"boolean\", \"default\": false}, \"VipPortMap\": {\"description\": \"A map of deployed port data\\n\", \"default\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"type\": \"json\"}}, \"outputs\": {\"ip_address\": {\"description\": \"StorageMgmt network VIP\", \"value\": {\"get_param\": [\"VipPortMap\", \"storage_mgmt\", \"ip_address\"]}}, \"ip_address_uri\": {\"description\": \"StorageMgmt network VIP (with brackets for IPv6 URLs)\", \"value\": {\"get_param\": [\"VipPortMap\", \"storage_mgmt\", \"ip_address_uri\"]}}, \"ip_subnet\": {\"description\": \"IP/Subnet CIDR for the StorageMgmt network VIP\", \"value\": {\"get_param\": [\"VipPortMap\", \"storage_mgmt\", \"ip_subnet\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"PortName\": \"storage_mgmt_virtual_ip\", \"DnsName\": \"multicell\", \"ControlPlaneIP\": \"192.168.122.90\", \"ControlPlaneSubnetCidr\": \"24\", \"FixedIPs\": \"[{\\\"subnet\\\": \\\"storage_mgmt_subnet\\\"}]\", \"IsVirtualIP\": true}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(13,'2026-06-10 07:46:33',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Deployed VIP port on the InternalApi network.\\n\", \"parameters\": {\"StackName\": {\"description\": \"Name of the overcloud heat stack\", \"default\": \"overcloud\", \"type\": \"string\"}, \"PortName\": {\"description\": \"Name of the port\", \"default\": \"\", \"type\": \"string\"}, \"DnsName\": {\"description\": \"DNS name of the port\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneIP\": {\"description\": \"IP address on the control plane\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneSubnetCidr\": {\"default\": \"\", \"description\": \"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\n\", \"type\": \"string\"}, \"ControlPlaneNetwork\": {\"description\": \"The name of the undercloud Neutron control plane\", \"default\": \"ctlplane\", \"type\": \"string\"}, \"ControlPlaneSubnet\": {\"description\": \"The name of the undercloud Neutron control plane subnet\", \"default\": \"ctlplane-subnet\", \"type\": \"string\"}, \"FixedIPs\": {\"description\": \"Control the IP allocation for the VIP port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"default\": [], \"type\": \"json\"}, \"IPPool\": {\"default\": {}, \"type\": \"json\"}, \"NodeIndex\": {\"default\": 0, \"type\": \"number\"}, \"IsVirtualIP\": {\"type\": \"boolean\", \"default\": false}, \"VipPortMap\": {\"description\": \"A map of deployed port data\\n\", \"default\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"type\": \"json\"}}, \"outputs\": {\"ip_address\": {\"description\": \"InternalApi network VIP\", \"value\": {\"get_param\": [\"VipPortMap\", \"internal_api\", \"ip_address\"]}}, \"ip_address_uri\": {\"description\": \"InternalApi network VIP (with brackets for IPv6 URLs)\", \"value\": {\"get_param\": [\"VipPortMap\", \"internal_api\", \"ip_address_uri\"]}}, \"ip_subnet\": {\"description\": \"IP/Subnet CIDR for the InternalApi network VIP\", \"value\": {\"get_param\": [\"VipPortMap\", \"internal_api\", \"ip_subnet\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"PortName\": \"internal_api_virtual_ip\", \"DnsName\": \"multicell\", \"ControlPlaneIP\": \"192.168.122.90\", \"ControlPlaneSubnetCidr\": \"24\", \"FixedIPs\": \"[{\\\"subnet\\\": \\\"internal_api_subnet\\\"}]\", \"IsVirtualIP\": true}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(14,'2026-06-10 07:46:33',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"This is a default no-op template which provides empty user-data which can be passed to the OS::Nova::Server resources. This template can be replaced with a different implementation via the resource registry, such that deployers may customize their first-boot configuration.\\n\", \"resources\": {\"userdata\": {\"type\": \"OS::Heat::MultipartMime\"}}, \"outputs\": {\"OS::stack_id\": {\"value\": {\"get_resource\": \"userdata\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(15,'2026-06-10 07:46:33',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Deployed VIP port on the Storage network.\\n\", \"parameters\": {\"StackName\": {\"description\": \"Name of the overcloud heat stack\", \"default\": \"overcloud\", \"type\": \"string\"}, \"PortName\": {\"description\": \"Name of the port\", \"default\": \"\", \"type\": \"string\"}, \"DnsName\": {\"description\": \"DNS name of the port\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneIP\": {\"description\": \"IP address on the control plane\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneSubnetCidr\": {\"default\": \"\", \"description\": \"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\n\", \"type\": \"string\"}, \"ControlPlaneNetwork\": {\"description\": \"The name of the undercloud Neutron control plane\", \"default\": \"ctlplane\", \"type\": \"string\"}, \"ControlPlaneSubnet\": {\"description\": \"The name of the undercloud Neutron control plane subnet\", \"default\": \"ctlplane-subnet\", \"type\": \"string\"}, \"FixedIPs\": {\"description\": \"Control the IP allocation for the VIP port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"default\": [], \"type\": \"json\"}, \"IPPool\": {\"default\": {}, \"type\": \"json\"}, \"NodeIndex\": {\"default\": 0, \"type\": \"number\"}, \"IsVirtualIP\": {\"type\": \"boolean\", \"default\": false}, \"VipPortMap\": {\"description\": \"A map of deployed port data\\n\", \"default\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"type\": \"json\"}}, \"outputs\": {\"ip_address\": {\"description\": \"Storage network VIP\", \"value\": {\"get_param\": [\"VipPortMap\", \"storage\", \"ip_address\"]}}, \"ip_address_uri\": {\"description\": \"Storage network VIP (with brackets for IPv6 URLs)\", \"value\": {\"get_param\": [\"VipPortMap\", \"storage\", \"ip_address_uri\"]}}, \"ip_subnet\": {\"description\": \"IP/Subnet CIDR for the Storage network VIP\", \"value\": {\"get_param\": [\"VipPortMap\", \"storage\", \"ip_subnet\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"PortName\": \"storage_virtual_ip\", \"DnsName\": \"multicell\", \"ControlPlaneIP\": \"192.168.122.90\", \"ControlPlaneSubnetCidr\": \"24\", \"FixedIPs\": \"[{\\\"subnet\\\": \\\"storage_subnet\\\"}]\", \"IsVirtualIP\": true}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(16,'2026-06-10 07:46:33',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Deployed VIP port on the External network.\\n\", \"parameters\": {\"StackName\": {\"description\": \"Name of the overcloud heat stack\", \"default\": \"overcloud\", \"type\": \"string\"}, \"PortName\": {\"description\": \"Name of the port\", \"default\": \"\", \"type\": \"string\"}, \"DnsName\": {\"description\": \"DNS name of the port\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneIP\": {\"description\": \"IP address on the control plane\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneSubnetCidr\": {\"default\": \"\", \"description\": \"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\n\", \"type\": \"string\"}, \"ControlPlaneNetwork\": {\"description\": \"The name of the undercloud Neutron control plane\", \"default\": \"ctlplane\", \"type\": \"string\"}, \"ControlPlaneSubnet\": {\"description\": \"The name of the undercloud Neutron control plane subnet\", \"default\": \"ctlplane-subnet\", \"type\": \"string\"}, \"FixedIPs\": {\"description\": \"Control the IP allocation for the VIP port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"default\": [], \"type\": \"json\"}, \"IPPool\": {\"default\": {}, \"type\": \"json\"}, \"NodeIndex\": {\"default\": 0, \"type\": \"number\"}, \"IsVirtualIP\": {\"type\": \"boolean\", \"default\": false}, \"VipPortMap\": {\"description\": \"A map of deployed port data\\n\", \"default\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"type\": \"json\"}}, \"outputs\": {\"ip_address\": {\"description\": \"External network VIP\", \"value\": {\"get_param\": [\"VipPortMap\", \"external\", \"ip_address\"]}}, \"ip_address_uri\": {\"description\": \"External network VIP (with brackets for IPv6 URLs)\", \"value\": {\"get_param\": [\"VipPortMap\", \"external\", \"ip_address_uri\"]}}, \"ip_subnet\": {\"description\": \"IP/Subnet CIDR for the External network VIP\", \"value\": {\"get_param\": [\"VipPortMap\", \"external\", \"ip_subnet\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"PortName\": \"external_virtual_ip\", \"DnsName\": \"multicell\", \"ControlPlaneIP\": \"192.168.122.90\", \"ControlPlaneSubnetCidr\": \"24\", \"FixedIPs\": \"[{\\\"subnet\\\": \\\"external_subnet\\\"}]\", \"IsVirtualIP\": true}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(17,'2026-06-10 07:46:34',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"This is a default no-op template which provides empty user-data which can be passed to the OS::Nova::Server resources. This template can be replaced with a different implementation via the resource registry, such that deployers may customize their first-boot configuration.\\n\", \"resources\": {\"userdata\": {\"type\": \"OS::Heat::MultipartMime\"}}, \"outputs\": {\"OS::stack_id\": {\"value\": {\"get_resource\": \"userdata\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(18,'2026-06-10 07:46:35',NULL,'{\"heat_template_version\": \"wallaby\", \"parameters\": {\"ControlPlaneIp\": {\"default\": \"\", \"type\": \"string\"}, \"ControlPlaneSubnetCidr\": {\"default\": \"\", \"description\": \"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\n\", \"type\": \"string\"}, \"StorageIp\": {\"default\": \"\", \"type\": \"string\"}, \"StorageIpSubnet\": {\"description\": \"IP address/subnet on the storage network\", \"default\": \"\", \"type\": \"string\"}, \"StorageIpUri\": {\"default\": \"\", \"type\": \"string\", \"description\": \"IP address with brackets in case of IPv6\"}, \"StorageNetName\": {\"default\": \"storage\", \"description\": \"The name of the storage network.\", \"type\": \"string\"}, \"StorageMgmtIp\": {\"default\": \"\", \"type\": \"string\"}, \"StorageMgmtIpSubnet\": {\"description\": \"IP address/subnet on the storage_mgmt network\", \"default\": \"\", \"type\": \"string\"}, \"StorageMgmtIpUri\": {\"default\": \"\", \"type\": \"string\", \"description\": \"IP address with brackets in case of IPv6\"}, \"StorageMgmtNetName\": {\"default\": \"storage_mgmt\", \"description\": \"The name of the storage_mgmt network.\", \"type\": \"string\"}, \"InternalApiIp\": {\"default\": \"\", \"type\": \"string\"}, \"InternalApiIpSubnet\": {\"description\": \"IP address/subnet on the internal_api network\", \"default\": \"\", \"type\": \"string\"}, \"InternalApiIpUri\": {\"default\": \"\", \"type\": \"string\", \"description\": \"IP address with brackets in case of IPv6\"}, \"InternalApiNetName\": {\"default\": \"internal_api\", \"description\": \"The name of the internal_api network.\", \"type\": \"string\"}, \"TenantIp\": {\"default\": \"\", \"type\": \"string\"}, \"TenantIpSubnet\": {\"description\": \"IP address/subnet on the tenant network\", \"default\": \"\", \"type\": \"string\"}, \"TenantIpUri\": {\"default\": \"\", \"type\": \"string\", \"description\": \"IP address with brackets in case of IPv6\"}, \"TenantNetName\": {\"default\": \"tenant\", \"description\": \"The name of the tenant network.\", \"type\": \"string\"}, \"ExternalIp\": {\"default\": \"\", \"type\": \"string\"}, \"ExternalIpSubnet\": {\"description\": \"IP address/subnet on the external network\", \"default\": \"\", \"type\": \"string\"}, \"ExternalIpUri\": {\"default\": \"\", \"type\": \"string\", \"description\": \"IP address with brackets in case of IPv6\"}, \"ExternalNetName\": {\"default\": \"external\", \"description\": \"The name of the external network.\", \"type\": \"string\"}}, \"resources\": {\"NetIpMapValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"ctlplane\": {\"get_param\": \"ControlPlaneIp\"}, \"ctlplane_subnet\": {\"list_join\": [\"\", [{\"get_param\": \"ControlPlaneIp\"}, \"/\", {\"get_param\": \"ControlPlaneSubnetCidr\"}]]}, \"ctlplane_uri\": {\"str_replace\": {\"template\": {\"make_url\": {\"host\": {\"get_param\": \"ControlPlaneIp\"}}}, \"params\": {\"//\": \"\"}}}, \"storage\": {\"get_param\": \"StorageIp\"}, \"storage_subnet\": {\"get_param\": \"StorageIpSubnet\"}, \"storage_uri\": {\"get_param\": \"StorageIpUri\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtIp\"}, \"storage_mgmt_subnet\": {\"get_param\": \"StorageMgmtIpSubnet\"}, \"storage_mgmt_uri\": {\"get_param\": \"StorageMgmtIpUri\"}, \"internal_api\": {\"get_param\": \"InternalApiIp\"}, \"internal_api_subnet\": {\"get_param\": \"InternalApiIpSubnet\"}, \"internal_api_uri\": {\"get_param\": \"InternalApiIpUri\"}, \"tenant\": {\"get_param\": \"TenantIp\"}, \"tenant_subnet\": {\"get_param\": \"TenantIpSubnet\"}, \"tenant_uri\": {\"get_param\": \"TenantIpUri\"}, \"external\": {\"get_param\": \"ExternalIp\"}, \"external_subnet\": {\"get_param\": \"ExternalIpSubnet\"}, \"external_uri\": {\"get_param\": \"ExternalIpUri\"}}, {\"keys\": {\"ctlplane\": \"ctlplane\", \"storage\": {\"get_param\": \"StorageNetName\"}, \"storage_subnet\": {\"str_replace\": {\"template\": \"NAME_subnet\", \"params\": {\"NAME\": {\"get_param\": \"StorageNetName\"}}}}, \"storage_uri\": {\"str_replace\": {\"template\": \"NAME_uri\", \"params\": {\"NAME\": {\"get_param\": \"StorageNetName\"}}}}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtNetName\"}, \"storage_mgmt_subnet\": {\"str_replace\": {\"template\": \"NAME_subnet\", \"params\": {\"NAME\": {\"get_param\": \"StorageMgmtNetName\"}}}}, \"storage_mgmt_uri\": {\"str_replace\": {\"template\": \"NAME_uri\", \"params\": {\"NAME\": {\"get_param\": \"StorageMgmtNetName\"}}}}, \"internal_api\": {\"get_param\": \"InternalApiNetName\"}, \"internal_api_subnet\": {\"str_replace\": {\"template\": \"NAME_subnet\", \"params\": {\"NAME\": {\"get_param\": \"InternalApiNetName\"}}}}, \"internal_api_uri\": {\"str_replace\": {\"template\": \"NAME_uri\", \"params\": {\"NAME\": {\"get_param\": \"InternalApiNetName\"}}}}, \"tenant\": {\"get_param\": \"TenantNetName\"}, \"tenant_subnet\": {\"str_replace\": {\"template\": \"NAME_subnet\", \"params\": {\"NAME\": {\"get_param\": \"TenantNetName\"}}}}, \"tenant_uri\": {\"str_replace\": {\"template\": \"NAME_uri\", \"params\": {\"NAME\": {\"get_param\": \"TenantNetName\"}}}}, \"external\": {\"get_param\": \"ExternalNetName\"}, \"external_subnet\": {\"str_replace\": {\"template\": \"NAME_subnet\", \"params\": {\"NAME\": {\"get_param\": \"ExternalNetName\"}}}}, \"external_uri\": {\"str_replace\": {\"template\": \"NAME_uri\", \"params\": {\"NAME\": {\"get_param\": \"ExternalNetName\"}}}}}}]}}}}, \"outputs\": {\"net_ip_map\": {\"description\": \"A Hash containing a mapping of network names to assigned IPs for a specific machine.\\n\", \"value\": {\"get_attr\": [\"NetIpMapValue\", \"value\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ControlPlaneIp\": \"192.168.122.90\", \"ControlPlaneSubnetCidr\": \"24\", \"StorageIp\": \"172.18.0.140\", \"StorageIpUri\": \"172.18.0.140\", \"StorageMgmtIp\": \"172.20.0.150\", \"StorageMgmtIpUri\": \"172.20.0.150\", \"InternalApiIp\": \"172.17.0.130\", \"InternalApiIpUri\": \"172.17.0.130\", \"ExternalIp\": \"172.21.0.80\", \"ExternalIpUri\": \"172.21.0.80\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(19,'2026-06-10 07:46:35',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"This is a default no-op template which provides empty user-data which can be passed to the OS::Nova::Server resources. This template can be replaced with a different implementation via the resource registry, such that deployers may customize their first-boot configuration.\\n\", \"resources\": {\"userdata\": {\"type\": \"OS::Heat::MultipartMime\"}}, \"outputs\": {\"OS::stack_id\": {\"value\": {\"get_resource\": \"userdata\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(20,'2026-06-10 07:46:36',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"This is a default no-op template which provides empty user-data which can be passed to the OS::Nova::Server resources. This template can be replaced with a different implementation via the resource registry, such that deployers may customize their first-boot configuration.\\n\", \"resources\": {\"userdata\": {\"type\": \"OS::Heat::MultipartMime\"}}, \"outputs\": {\"OS::stack_id\": {\"value\": {\"get_resource\": \"userdata\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (21,'2026-06-10 07:46:36',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"A map of OpenStack endpoints. Since the endpoints are URLs, we need to have brackets around IPv6 IP addresses. The inputs to these parameters come from net_ip_uri_map, which will include these brackets in IPv6 addresses.\", \"parameters\": {\"NetIpMap\": {\"type\": \"json\", \"default\": {}, \"description\": \"The Net IP map\"}, \"ServiceNetMap\": {\"type\": \"json\", \"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"The Service Net map\"}, \"EndpointMap\": {\"type\": \"json\", \"default\": {\"AodhAdmin\": {\"protocol\": \"http\", \"port\": \"8042\", \"host\": \"IP_ADDRESS\"}, \"AodhInternal\": {\"protocol\": \"http\", \"port\": \"8042\", \"host\": \"IP_ADDRESS\"}, \"AodhPublic\": {\"protocol\": \"http\", \"port\": \"8042\", \"host\": \"IP_ADDRESS\"}, \"BarbicanAdmin\": {\"protocol\": \"http\", \"port\": \"9311\", \"host\": \"IP_ADDRESS\"}, \"BarbicanInternal\": {\"protocol\": \"http\", \"port\": \"9311\", \"host\": \"IP_ADDRESS\"}, \"BarbicanPublic\": {\"protocol\": \"http\", \"port\": \"9311\", \"host\": \"IP_ADDRESS\"}, \"CephDashboardInternal\": {\"protocol\": \"http\", \"port\": \"8444\", \"host\": \"IP_ADDRESS\"}, \"CephGrafanaInternal\": {\"protocol\": \"http\", \"port\": \"3100\", \"host\": \"IP_ADDRESS\"}, \"CephRgwAdmin\": {\"protocol\": \"http\", \"port\": \"8080\", \"host\": \"IP_ADDRESS\"}, \"CephRgwInternal\": {\"protocol\": \"http\", \"port\": \"8080\", \"host\": \"IP_ADDRESS\"}, \"CephRgwPublic\": {\"protocol\": \"http\", \"port\": \"8080\", \"host\": \"IP_ADDRESS\"}, \"CinderAdmin\": {\"protocol\": \"http\", \"port\": \"8776\", \"host\": \"IP_ADDRESS\"}, \"CinderInternal\": {\"protocol\": \"http\", \"port\": \"8776\", \"host\": \"IP_ADDRESS\"}, \"CinderPublic\": {\"protocol\": \"http\", \"port\": \"8776\", \"host\": \"IP_ADDRESS\"}, \"DesignateAdmin\": {\"protocol\": \"http\", \"port\": \"9001\", \"host\": \"IP_ADDRESS\"}, \"DesignateInternal\": {\"protocol\": \"http\", \"port\": \"9001\", \"host\": \"IP_ADDRESS\"}, \"DesignatePublic\": {\"protocol\": \"http\", \"port\": \"9001\", \"host\": \"IP_ADDRESS\"}, \"DockerRegistryInternal\": {\"protocol\": \"http\", \"port\": \"8787\", \"host\": \"IP_ADDRESS\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"http\", \"port\": \"9293\", \"host\": \"IP_ADDRESS\"}, \"GlanceInternal\": {\"protocol\": \"http\", \"port\": \"9293\", \"host\": \"IP_ADDRESS\"}, \"GlancePublic\": {\"protocol\": \"http\", \"port\": \"9292\", \"host\": \"IP_ADDRESS\"}, \"GnocchiAdmin\": {\"protocol\": \"http\", \"port\": \"8041\", \"host\": \"IP_ADDRESS\"}, \"GnocchiInternal\": {\"protocol\": \"http\", \"port\": \"8041\", \"host\": \"IP_ADDRESS\"}, \"GnocchiPublic\": {\"protocol\": \"http\", \"port\": \"8041\", \"host\": \"IP_ADDRESS\"}, \"HeatAdmin\": {\"protocol\": \"http\", \"port\": \"8004\", \"host\": \"IP_ADDRESS\"}, \"HeatInternal\": {\"protocol\": \"http\", \"port\": \"8004\", \"host\": \"IP_ADDRESS\"}, \"HeatPublic\": {\"protocol\": \"http\", \"port\": \"8004\", \"host\": \"IP_ADDRESS\"}, \"HeatCfnAdmin\": {\"protocol\": \"http\", \"port\": \"8000\", \"host\": \"IP_ADDRESS\"}, \"HeatCfnInternal\": {\"protocol\": \"http\", \"port\": \"8000\", \"host\": \"IP_ADDRESS\"}, \"HeatCfnPublic\": {\"protocol\": \"http\", \"port\": \"8000\", \"host\": \"IP_ADDRESS\"}, \"HorizonPublic\": {\"protocol\": \"http\", \"port\": \"80\", \"host\": \"IP_ADDRESS\"}, \"IronicAdmin\": {\"protocol\": \"http\", \"port\": \"6385\", \"host\": \"IP_ADDRESS\"}, \"IronicInternal\": {\"protocol\": \"http\", \"port\": \"6385\", \"host\": \"IP_ADDRESS\"}, \"IronicPublic\": {\"protocol\": \"http\", \"port\": \"6385\", \"host\": \"IP_ADDRESS\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"IP_ADDRESS\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"IP_ADDRESS\"}, \"IronicInspectorPublic\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"IP_ADDRESS\"}, \"KeystoneAdmin\": {\"protocol\": \"http\", \"port\": \"35357\", \"host\": \"IP_ADDRESS\"}, \"KeystoneInternal\": {\"protocol\": \"http\", \"port\": \"5000\", \"host\": \"IP_ADDRESS\"}, \"KeystonePublic\": {\"protocol\": \"http\", \"port\": \"5000\", \"host\": \"IP_ADDRESS\"}, \"ManilaAdmin\": {\"protocol\": \"http\", \"port\": \"8786\", \"host\": \"IP_ADDRESS\"}, \"ManilaInternal\": {\"protocol\": \"http\", \"port\": \"8786\", \"host\": \"IP_ADDRESS\"}, \"ManilaPublic\": {\"protocol\": \"http\", \"port\": \"8786\", \"host\": \"IP_ADDRESS\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"IP_ADDRESS\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"IP_ADDRESS\"}, \"NeutronAdmin\": {\"protocol\": \"http\", \"port\": \"9696\", \"host\": \"IP_ADDRESS\"}, \"NeutronInternal\": {\"protocol\": \"http\", \"port\": \"9696\", \"host\": \"IP_ADDRESS\"}, \"NeutronPublic\": {\"protocol\": \"http\", \"port\": \"9696\", \"host\": \"IP_ADDRESS\"}, \"NovaAdmin\": {\"protocol\": \"http\", \"port\": \"8774\", \"host\": \"IP_ADDRESS\"}, \"NovaInternal\": {\"protocol\": \"http\", \"port\": \"8774\", \"host\": \"IP_ADDRESS\"}, \"NovaPublic\": {\"protocol\": \"http\", \"port\": \"8774\", \"host\": \"IP_ADDRESS\"}, \"NovaMetadataInternal\": {\"protocol\": \"http\", \"port\": \"8775\", \"host\": \"IP_ADDRESS\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"http\", \"port\": \"6080\", \"host\": \"IP_ADDRESS\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"http\", \"port\": \"6080\", \"host\": \"IP_ADDRESS\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"http\", \"port\": \"6080\", \"host\": \"IP_ADDRESS\"}, \"NovajoinAdmin\": {\"protocol\": \"http\", \"port\": \"9090\", \"host\": \"IP_ADDRESS\"}, \"NovajoinInternal\": {\"protocol\": \"http\", \"port\": \"9090\", \"host\": \"IP_ADDRESS\"}, \"NovajoinPublic\": {\"protocol\": \"http\", \"port\": \"9090\", \"host\": \"IP_ADDRESS\"}, \"OctaviaAdmin\": {\"protocol\": \"http\", \"port\": \"9876\", \"host\": \"IP_ADDRESS\"}, \"OctaviaInternal\": {\"protocol\": \"http\", \"port\": \"9876\", \"host\": \"IP_ADDRESS\"}, \"OctaviaPublic\": {\"protocol\": \"http\", \"port\": \"9876\", \"host\": \"IP_ADDRESS\"}, \"PlacementAdmin\": {\"protocol\": \"http\", \"port\": \"8778\", \"host\": \"IP_ADDRESS\"}, \"PlacementInternal\": {\"protocol\": \"http\", \"port\": \"8778\", \"host\": \"IP_ADDRESS\"}, \"PlacementPublic\": {\"protocol\": \"http\", \"port\": \"8778\", \"host\": \"IP_ADDRESS\"}, \"SwiftAdmin\": {\"protocol\": \"http\", \"port\": \"8080\", \"host\": \"IP_ADDRESS\"}, \"SwiftInternal\": {\"protocol\": \"http\", \"port\": \"8080\", \"host\": \"IP_ADDRESS\"}, \"SwiftPublic\": {\"protocol\": \"http\", \"port\": \"8080\", \"host\": \"IP_ADDRESS\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\"}, \"CloudEndpoints\": {\"type\": \"json\", \"default\": {}, \"description\": \"A map containing the DNS names for the different endpoints (external, internal_api, etc.)\"}}, \"outputs\": {\"endpoint_map\": {\"value\": {\"AodhAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"AodhAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"AodhAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"AodhAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"AodhAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"AodhAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"AodhAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"AodhAdmin\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"AodhAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"AodhAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"AodhAdmin\", \"port\"]}}}}, \"AodhInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"AodhInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"AodhInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"AodhInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"AodhInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"AodhInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"AodhInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"AodhInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"AodhInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"AodhInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"AodhInternal\", \"port\"]}}}}, \"AodhPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"AodhPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"AodhPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"AodhPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"AodhPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"AodhPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"AodhPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"AodhPublic\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"AodhPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"AodhPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"AodhPublic\", \"port\"]}}}}, \"BarbicanAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"BarbicanAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"BarbicanAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"BarbicanAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"BarbicanAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"BarbicanAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"BarbicanAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"BarbicanAdmin\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"BarbicanAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"BarbicanAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"BarbicanAdmin\", \"port\"]}}}}, \"BarbicanInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"BarbicanInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"BarbicanInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"BarbicanInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"BarbicanInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"BarbicanInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"BarbicanInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"BarbicanInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"BarbicanInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"BarbicanInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"BarbicanInternal\", \"port\"]}}}}, \"BarbicanPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"BarbicanPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"BarbicanPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"BarbicanPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"BarbicanPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"BarbicanPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"BarbicanPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"BarbicanPublic\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"BarbicanPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"BarbicanPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"BarbicanPublic\", \"port\"]}}}}, \"CephDashboardInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephDashboardInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephDashboardNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CephDashboardNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephDashboardInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephDashboardNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"CephDashboardNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephDashboardInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CephDashboardInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CephDashboardInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephDashboardInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephDashboardNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CephDashboardNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephDashboardInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CephDashboardInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephDashboardInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephDashboardNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CephDashboardNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephDashboardInternal\", \"port\"]}}}}, \"CephGrafanaInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephGrafanaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephGrafanaNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CephGrafanaNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephGrafanaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephGrafanaNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"CephGrafanaNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephGrafanaInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CephGrafanaInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CephGrafanaInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephGrafanaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephGrafanaNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CephGrafanaNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephGrafanaInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CephGrafanaInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephGrafanaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephGrafanaNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CephGrafanaNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephGrafanaInternal\", \"port\"]}}}}, \"CephRgwAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephRgwAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephRgwAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephRgwAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CephRgwAdmin\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CephRgwAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephRgwAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephRgwAdmin\", \"port\"]}, \"path\": \"/swift/v1/AUTH_\"}}, \"%(project_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CephRgwAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephRgwAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephRgwAdmin\", \"port\"]}}}}, \"CephRgwInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephRgwInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephRgwInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephRgwInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CephRgwInternal\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CephRgwInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephRgwInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephRgwInternal\", \"port\"]}, \"path\": \"/swift/v1/AUTH_\"}}, \"%(project_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CephRgwInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephRgwInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephRgwInternal\", \"port\"]}}}}, \"CephRgwPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephRgwPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephRgwPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephRgwPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CephRgwPublic\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CephRgwPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephRgwPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephRgwPublic\", \"port\"]}, \"path\": \"/swift/v1/AUTH_\"}}, \"%(project_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CephRgwPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephRgwPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephRgwPublic\", \"port\"]}}}}, \"CinderAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"port\"]}, \"path\": \"/v1/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"port\"]}}}}, \"CinderInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"port\"]}, \"path\": \"/v1/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"port\"]}}}}, \"CinderPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"port\"]}, \"path\": \"/v1/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"port\"]}}}}, \"CinderV2Admin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"port\"]}, \"path\": \"/v2/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"port\"]}}}}, \"CinderV2Internal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"port\"]}, \"path\": \"/v2/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"port\"]}}}}, \"CinderV2Public\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"port\"]}, \"path\": \"/v2/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"port\"]}}}}, \"CinderV3Admin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"port\"]}, \"path\": \"/v3/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"port\"]}}}}, \"CinderV3Internal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"port\"]}, \"path\": \"/v3/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"port\"]}}}}, \"CinderV3Public\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"port\"]}, \"path\": \"/v3/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"port\"]}}}}, \"DesignateAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DesignateAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DesignateAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"DesignateAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"DesignateAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"DesignateAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DesignateAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"DesignateAdmin\", \"port\"]}, \"path\": \"/v2\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"DesignateAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DesignateAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"DesignateAdmin\", \"port\"]}}}}, \"DesignateInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DesignateInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DesignateInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"DesignateInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"DesignateInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"DesignateInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DesignateInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"DesignateInternal\", \"port\"]}, \"path\": \"/v2\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"DesignateInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DesignateInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"DesignateInternal\", \"port\"]}}}}, \"DesignatePublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DesignatePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DesignatePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"DesignatePublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"DesignatePublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"DesignatePublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DesignatePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"DesignatePublic\", \"port\"]}, \"path\": \"/v2\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"DesignatePublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DesignatePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"DesignatePublic\", \"port\"]}}}}, \"DockerRegistryInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DockerRegistryInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"DockerRegistryNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"DockerRegistryNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DockerRegistryInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"DockerRegistryNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"DockerRegistryNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"DockerRegistryInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"DockerRegistryInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"DockerRegistryInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DockerRegistryInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"DockerRegistryNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"DockerRegistryNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"DockerRegistryInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"DockerRegistryInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DockerRegistryInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"DockerRegistryNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"DockerRegistryNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"DockerRegistryInternal\", \"port\"]}}}}, \"GaneshaInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GaneshaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GaneshaNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GaneshaNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GaneshaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GaneshaNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"GaneshaNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GaneshaInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"GaneshaInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GaneshaInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GaneshaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GaneshaNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GaneshaNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GaneshaInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GaneshaInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GaneshaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GaneshaNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GaneshaNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GaneshaInternal\", \"port\"]}}}}, \"GlanceAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GlanceAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GlanceAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GlanceAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"GlanceAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GlanceAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GlanceAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GlanceAdmin\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GlanceAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GlanceAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GlanceAdmin\", \"port\"]}}}}, \"GlanceInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"port\"]}}}}, \"GlancePublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GlancePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GlancePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GlancePublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"GlancePublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GlancePublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GlancePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GlancePublic\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GlancePublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GlancePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GlancePublic\", \"port\"]}}}}, \"GnocchiAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GnocchiAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GnocchiAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GnocchiAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"GnocchiAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GnocchiAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GnocchiAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GnocchiAdmin\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GnocchiAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GnocchiAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GnocchiAdmin\", \"port\"]}}}}, \"GnocchiInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GnocchiInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GnocchiInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GnocchiInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"GnocchiInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GnocchiInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GnocchiInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GnocchiInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GnocchiInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GnocchiInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GnocchiInternal\", \"port\"]}}}}, \"GnocchiPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GnocchiPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GnocchiPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GnocchiPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"GnocchiPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GnocchiPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GnocchiPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GnocchiPublic\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GnocchiPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GnocchiPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GnocchiPublic\", \"port\"]}}}}, \"HeatAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"HeatAdmin\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HeatAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatAdmin\", \"port\"]}, \"path\": \"/v1/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HeatAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatAdmin\", \"port\"]}}}}, \"HeatInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"HeatInternal\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HeatInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatInternal\", \"port\"]}, \"path\": \"/v1/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HeatInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatInternal\", \"port\"]}}}}, \"HeatPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"HeatPublic\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HeatPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatPublic\", \"port\"]}, \"path\": \"/v1/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HeatPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatPublic\", \"port\"]}}}}, \"HeatCfnAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatCfnAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatCfnAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatCfnAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"HeatCfnAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HeatCfnAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatCfnAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatCfnAdmin\", \"port\"]}, \"path\": \"/v1\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HeatCfnAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatCfnAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatCfnAdmin\", \"port\"]}}}}, \"HeatCfnInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatCfnInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatCfnInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatCfnInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"HeatCfnInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HeatCfnInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatCfnInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatCfnInternal\", \"port\"]}, \"path\": \"/v1\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HeatCfnInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatCfnInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatCfnInternal\", \"port\"]}}}}, \"HeatCfnPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"port\"]}, \"path\": \"/v1\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"port\"]}}}}, \"HorizonPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HorizonPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HorizonPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HorizonPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"HorizonPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HorizonPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HorizonPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HorizonPublic\", \"port\"]}, \"path\": \"/dashboard\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HorizonPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HorizonPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HorizonPublic\", \"port\"]}}}}, \"IronicAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"IronicAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"IronicAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicAdmin\", \"port\"]}, \"path\": \"/v1\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"IronicAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicAdmin\", \"port\"]}}}}, \"IronicInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"IronicInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"IronicInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicInternal\", \"port\"]}, \"path\": \"/v1\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"IronicInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicInternal\", \"port\"]}}}}, \"IronicPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"IronicPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"IronicPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicPublic\", \"port\"]}, \"path\": \"/v1\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"IronicPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicPublic\", \"port\"]}}}}, \"IronicInspectorAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorAdmin\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorAdmin\", \"port\"]}}}}, \"IronicInspectorInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorInternal\", \"port\"]}}}}, \"IronicInspectorPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorPublic\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorPublic\", \"port\"]}}}}, \"KeystoneAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"port\"]}, \"path\": \"/\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"port\"]}}}}, \"KeystoneInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"port\"]}, \"path\": \"/\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"port\"]}}}}, \"KeystonePublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"port\"]}, \"path\": \"/\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"port\"]}}}}, \"KeystoneV3Admin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"port\"]}, \"path\": \"/v3\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"port\"]}}}}, \"KeystoneV3Internal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"port\"]}, \"path\": \"/v3\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"port\"]}}}}, \"KeystoneV3Public\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"port\"]}, \"path\": \"/v3\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"port\"]}}}}, \"ManilaAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"port\"]}, \"path\": \"/v2\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"port\"]}}}}, \"ManilaInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"port\"]}, \"path\": \"/v2\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"port\"]}}}}, \"ManilaPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"port\"]}, \"path\": \"/v2\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"port\"]}}}}, \"ManilaV1Admin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"port\"]}, \"path\": \"/v1/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"port\"]}}}}, \"ManilaV1Internal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"port\"]}, \"path\": \"/v1/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"port\"]}}}}, \"ManilaV1Public\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"port\"]}, \"path\": \"/v1/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"port\"]}}}}, \"MetricsQdrPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"MetricsQdrPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"MetricsQdrPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"MetricsQdrPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"MetricsQdrPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MetricsQdrPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"MetricsQdrPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"MetricsQdrPublic\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MetricsQdrPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"MetricsQdrPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"MetricsQdrPublic\", \"port\"]}}}}, \"MysqlInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"port\"]}}}}, \"NeutronAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NeutronAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NeutronAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NeutronAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"NeutronAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NeutronAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NeutronAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NeutronAdmin\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NeutronAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NeutronAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NeutronAdmin\", \"port\"]}}}}, \"NeutronInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NeutronInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NeutronInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NeutronInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"NeutronInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NeutronInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NeutronInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NeutronInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NeutronInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NeutronInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NeutronInternal\", \"port\"]}}}}, \"NeutronPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NeutronPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NeutronPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NeutronPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"NeutronPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NeutronPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NeutronPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NeutronPublic\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NeutronPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NeutronPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NeutronPublic\", \"port\"]}}}}, \"NovaAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"NovaAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaAdmin\", \"port\"]}, \"path\": \"/v2.1\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaAdmin\", \"port\"]}}}}, \"NovaInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"NovaInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaInternal\", \"port\"]}, \"path\": \"/v2.1\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaInternal\", \"port\"]}}}}, \"NovaPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"NovaPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaPublic\", \"port\"]}, \"path\": \"/v2.1\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaPublic\", \"port\"]}}}}, \"NovaMetadataInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaMetadataInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaMetadataNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaMetadataNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaMetadataInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaMetadataNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"NovaMetadataNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaMetadataInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"NovaMetadataInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaMetadataInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaMetadataInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaMetadataNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaMetadataNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaMetadataInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaMetadataInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaMetadataInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaMetadataNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaMetadataNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaMetadataInternal\", \"port\"]}}}}, \"NovaVNCProxyAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyAdmin\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyAdmin\", \"port\"]}}}}, \"NovaVNCProxyInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyInternal\", \"port\"]}}}}, \"NovaVNCProxyPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyPublic\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyPublic\", \"port\"]}}}}, \"NovajoinAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovajoinAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovajoinAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovajoinAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"NovajoinAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovajoinAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovajoinAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovajoinAdmin\", \"port\"]}, \"path\": \"/v1\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovajoinAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovajoinAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovajoinAdmin\", \"port\"]}}}}, \"NovajoinInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovajoinInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovajoinInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovajoinInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"NovajoinInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovajoinInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovajoinInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovajoinInternal\", \"port\"]}, \"path\": \"/v1\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovajoinInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovajoinInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovajoinInternal\", \"port\"]}}}}, \"NovajoinPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovajoinPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovajoinPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovajoinPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"NovajoinPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovajoinPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovajoinPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovajoinPublic\", \"port\"]}, \"path\": \"/v1\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovajoinPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovajoinPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovajoinPublic\", \"port\"]}}}}, \"OctaviaAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"OctaviaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"OctaviaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"OctaviaAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"OctaviaAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"OctaviaAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"OctaviaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"OctaviaAdmin\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"OctaviaAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"OctaviaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"OctaviaAdmin\", \"port\"]}}}}, \"OctaviaInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"OctaviaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"OctaviaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"OctaviaInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"OctaviaInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"OctaviaInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"OctaviaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"OctaviaInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"OctaviaInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"OctaviaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"OctaviaInternal\", \"port\"]}}}}, \"OctaviaPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"OctaviaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"OctaviaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"OctaviaPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"OctaviaPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"OctaviaPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"OctaviaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"OctaviaPublic\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"OctaviaPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"OctaviaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"OctaviaPublic\", \"port\"]}}}}, \"PlacementAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"PlacementAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"PlacementAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"PlacementAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"PlacementAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"PlacementAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"PlacementAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"PlacementAdmin\", \"port\"]}, \"path\": \"/placement\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"PlacementAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"PlacementAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"PlacementAdmin\", \"port\"]}}}}, \"PlacementInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"PlacementInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"PlacementInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"PlacementInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"PlacementInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"PlacementInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"PlacementInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"PlacementInternal\", \"port\"]}, \"path\": \"/placement\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"PlacementInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"PlacementInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"PlacementInternal\", \"port\"]}}}}, \"PlacementPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"PlacementPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"PlacementPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"PlacementPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"PlacementPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"PlacementPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"PlacementPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"PlacementPublic\", \"port\"]}, \"path\": \"/placement\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"PlacementPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"PlacementPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"PlacementPublic\", \"port\"]}}}}, \"SwiftAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"port\"]}}}}, \"SwiftInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"port\"]}, \"path\": \"/v1/AUTH_\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"port\"]}}}}, \"SwiftPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"port\"]}, \"path\": \"/v1/AUTH_\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"port\"]}}}}, \"SwiftS3Admin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"port\"]}}}}, \"SwiftS3Internal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"port\"]}}}}, \"SwiftS3Public\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"port\"]}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"NetIpMap\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"CloudEndpoints\": {\"ctlplane\": \"multicell.ctlplane.localdomain\", \"storage\": \"multicell.storage.localdomain\", \"storage_mgmt\": \"multicell.storagemgmt.localdomain\", \"internal_api\": \"multicell.internalapi.localdomain\", \"external\": \"multicell.ooo.test\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(22,'2026-06-10 07:46:38',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Utility stack to convert an array of services into a set of combined role configs.\\n\", \"parameters\": {\"Services\": {\"default\": [], \"description\": \"List nested stack service templates.\\n\", \"type\": \"comma_delimited_list\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"description\": \"Parameters specific to the role\", \"default\": {}, \"type\": \"json\"}}, \"resources\": {\"ServiceChain\": {\"type\": \"OS::Heat::ResourceChain\", \"properties\": {\"resources\": {\"get_param\": \"Services\"}, \"concurrent\": true, \"resource_properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}}, \"ServiceServerMetadataHook\": {\"type\": \"OS::TripleO::ObjectStorageServiceServerMetadataHook\", \"properties\": {\"RoleData\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}, \"PuppetStepConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"string\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.step_config, []), coalesce($.data.docker_config, [])).where($[2] = null).where($[1] != null).select($[1]).join(\\\"\\\\n\\\")\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}, \"step_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"step_config\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.docker_config, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfigScripts\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.container_config_scripts, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"container_config_scripts\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"container_config_scripts\"]}}}}}}, \"MonitoringSubscriptionsConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'monitoring_subscription\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"ServiceNames\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"filter\": [[null], {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}]}}}, \"GlobalConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'global_config_settings\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"KeystoneResourcesConfigs\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'keystone_resources\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"ServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'service_config_settings\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DeployStepsTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'deploy_steps_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalPostDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_post_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ScaleTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'scale_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreUpgradeRollingTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_upgrade_rolling_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeBatchTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_batch_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PuppetConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'puppet_config\')).where($ != null).distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"KollaConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'kolla_config\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DockerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'docker_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ContainerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'container_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostFirewallTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_firewall_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostPrepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_prep_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreDeployStepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_deploy_step_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"IpaRegistrationTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'ipa_registration_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"AnsibleGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'ansible_group_vars\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallFrontendRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ssl_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_sslfrontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}}}, \"outputs\": {\"role_data\": {\"description\": \"Combined Role data for this set of services.\", \"value\": {\"service_names\": {\"get_attr\": [\"ServiceNames\", \"value\"]}, \"monitoring_subscriptions\": {\"get_attr\": [\"MonitoringSubscriptionsConfig\", \"value\"]}, \"config_settings\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"config_settings\"]}}}, \"global_config_settings\": {\"get_attr\": [\"GlobalConfigSettings\", \"value\"]}, \"service_config_settings\": {\"get_attr\": [\"ServiceConfigSettings\", \"value\"]}, \"step_config\": {\"get_attr\": [\"PuppetStepConfig\", \"value\"]}, \"deploy_steps_tasks\": {\"get_attr\": [\"DeployStepsTasks\", \"value\"]}, \"external_deploy_tasks\": {\"get_attr\": [\"ExternalDeployTasks\", \"value\"]}, \"external_post_deploy_tasks\": {\"get_attr\": [\"ExternalPostDeployTasks\", \"value\"]}, \"external_update_tasks\": {\"get_attr\": [\"ExternalUpdateTasks\", \"value\"]}, \"external_upgrade_tasks\": {\"get_attr\": [\"ExternalUpgradeTasks\", \"value\"]}, \"scale_tasks\": {\"get_attr\": [\"ScaleTasks\", \"value\"]}, \"pre_upgrade_rolling_tasks\": {\"get_attr\": [\"PreUpgradeRollingTasks\", \"value\"]}, \"upgrade_tasks\": {\"get_attr\": [\"UpgradeTasks\", \"value\"]}, \"post_upgrade_tasks\": {\"get_attr\": [\"PostUpgradeTasks\", \"value\"]}, \"update_tasks\": {\"get_attr\": [\"UpdateTasks\", \"value\"]}, \"post_update_tasks\": {\"get_attr\": [\"PostUpdateTasks\", \"value\"]}, \"upgrade_batch_tasks\": {\"get_attr\": [\"UpgradeBatchTasks\", \"value\"]}, \"service_metadata_settings\": {\"get_attr\": [\"ServiceServerMetadataHook\", \"metadata\"]}, \"ansible_group_vars\": {\"map_merge\": [{\"ansible_async_dir\": \"/tmp/.ansible_async\"}, {\"get_attr\": [\"AnsibleGroupVars\", \"value\"]}]}, \"keystone_resources\": {\"get_attr\": [\"KeystoneResourcesConfigs\", \"value\"]}, \"firewall_rules\": {\"get_attr\": [\"FirewallRules\", \"value\"]}, \"firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"puppet_config\": {\"get_attr\": [\"PuppetConfig\", \"value\"]}, \"kolla_config\": {\"get_attr\": [\"KollaConfig\", \"value\"]}, \"docker_config\": {\"get_attr\": [\"DockerConfig\", \"value\"]}, \"container_config_scripts\": {\"get_attr\": [\"DockerConfigScripts\", \"value\"]}, \"container_puppet_tasks\": {\"map_merge\": [{\"get_attr\": [\"ContainerPuppetTasks\", \"value\"]}, {\"get_attr\": [\"DockerPuppetTasks\", \"value\"]}]}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"HostFirewallTasks\", \"value\"]}, {\"get_attr\": [\"HostPrepTasks\", \"value\"]}]}, \"pre_deploy_step_tasks\": {\"list_concat\": [{\"get_attr\": [\"PreDeployStepTasks\", \"value\"]}, {\"get_attr\": [\"IpaRegistrationTasks\", \"value\"]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"Services\": \"\", \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"RoleName\": \"ObjectStorage\", \"RoleParameters\": {}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(23,'2026-06-10 07:46:38',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Utility stack to convert an array of services into a set of combined role configs.\\n\", \"parameters\": {\"Services\": {\"default\": [], \"description\": \"List nested stack service templates.\\n\", \"type\": \"comma_delimited_list\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"description\": \"Parameters specific to the role\", \"default\": {}, \"type\": \"json\"}}, \"resources\": {\"ServiceChain\": {\"type\": \"OS::Heat::ResourceChain\", \"properties\": {\"resources\": {\"get_param\": \"Services\"}, \"concurrent\": true, \"resource_properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}}, \"ServiceServerMetadataHook\": {\"type\": \"OS::TripleO::ControllerServiceServerMetadataHook\", \"properties\": {\"RoleData\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}, \"PuppetStepConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"string\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.step_config, []), coalesce($.data.docker_config, [])).where($[2] = null).where($[1] != null).select($[1]).join(\\\"\\\\n\\\")\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}, \"step_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"step_config\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.docker_config, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfigScripts\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.container_config_scripts, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"container_config_scripts\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"container_config_scripts\"]}}}}}}, \"MonitoringSubscriptionsConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'monitoring_subscription\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"ServiceNames\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"filter\": [[null], {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}]}}}, \"GlobalConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'global_config_settings\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"KeystoneResourcesConfigs\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'keystone_resources\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"ServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'service_config_settings\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DeployStepsTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'deploy_steps_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalPostDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_post_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ScaleTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'scale_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreUpgradeRollingTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_upgrade_rolling_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeBatchTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_batch_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PuppetConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'puppet_config\')).where($ != null).distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"KollaConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'kolla_config\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DockerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'docker_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ContainerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'container_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostFirewallTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_firewall_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostPrepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_prep_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreDeployStepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_deploy_step_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"IpaRegistrationTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'ipa_registration_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"AnsibleGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'ansible_group_vars\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallFrontendRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ssl_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_sslfrontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}}}, \"outputs\": {\"role_data\": {\"description\": \"Combined Role data for this set of services.\", \"value\": {\"service_names\": {\"get_attr\": [\"ServiceNames\", \"value\"]}, \"monitoring_subscriptions\": {\"get_attr\": [\"MonitoringSubscriptionsConfig\", \"value\"]}, \"config_settings\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"config_settings\"]}}}, \"global_config_settings\": {\"get_attr\": [\"GlobalConfigSettings\", \"value\"]}, \"service_config_settings\": {\"get_attr\": [\"ServiceConfigSettings\", \"value\"]}, \"step_config\": {\"get_attr\": [\"PuppetStepConfig\", \"value\"]}, \"deploy_steps_tasks\": {\"get_attr\": [\"DeployStepsTasks\", \"value\"]}, \"external_deploy_tasks\": {\"get_attr\": [\"ExternalDeployTasks\", \"value\"]}, \"external_post_deploy_tasks\": {\"get_attr\": [\"ExternalPostDeployTasks\", \"value\"]}, \"external_update_tasks\": {\"get_attr\": [\"ExternalUpdateTasks\", \"value\"]}, \"external_upgrade_tasks\": {\"get_attr\": [\"ExternalUpgradeTasks\", \"value\"]}, \"scale_tasks\": {\"get_attr\": [\"ScaleTasks\", \"value\"]}, \"pre_upgrade_rolling_tasks\": {\"get_attr\": [\"PreUpgradeRollingTasks\", \"value\"]}, \"upgrade_tasks\": {\"get_attr\": [\"UpgradeTasks\", \"value\"]}, \"post_upgrade_tasks\": {\"get_attr\": [\"PostUpgradeTasks\", \"value\"]}, \"update_tasks\": {\"get_attr\": [\"UpdateTasks\", \"value\"]}, \"post_update_tasks\": {\"get_attr\": [\"PostUpdateTasks\", \"value\"]}, \"upgrade_batch_tasks\": {\"get_attr\": [\"UpgradeBatchTasks\", \"value\"]}, \"service_metadata_settings\": {\"get_attr\": [\"ServiceServerMetadataHook\", \"metadata\"]}, \"ansible_group_vars\": {\"map_merge\": [{\"ansible_async_dir\": \"/tmp/.ansible_async\"}, {\"get_attr\": [\"AnsibleGroupVars\", \"value\"]}]}, \"keystone_resources\": {\"get_attr\": [\"KeystoneResourcesConfigs\", \"value\"]}, \"firewall_rules\": {\"get_attr\": [\"FirewallRules\", \"value\"]}, \"firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"puppet_config\": {\"get_attr\": [\"PuppetConfig\", \"value\"]}, \"kolla_config\": {\"get_attr\": [\"KollaConfig\", \"value\"]}, \"docker_config\": {\"get_attr\": [\"DockerConfig\", \"value\"]}, \"container_config_scripts\": {\"get_attr\": [\"DockerConfigScripts\", \"value\"]}, \"container_puppet_tasks\": {\"map_merge\": [{\"get_attr\": [\"ContainerPuppetTasks\", \"value\"]}, {\"get_attr\": [\"DockerPuppetTasks\", \"value\"]}]}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"HostFirewallTasks\", \"value\"]}, {\"get_attr\": [\"HostPrepTasks\", \"value\"]}]}, \"pre_deploy_step_tasks\": {\"list_concat\": [{\"get_attr\": [\"PreDeployStepTasks\", \"value\"]}, {\"get_attr\": [\"IpaRegistrationTasks\", \"value\"]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"Services\": \"OS::TripleO::Services::BootParams,OS::TripleO::Services::CACerts,OS::TripleO::Services::CeilometerAgentCentral,OS::TripleO::Services::CeilometerAgentNotification,OS::TripleO::Services::CinderApi,OS::TripleO::Services::CinderBackup,OS::TripleO::Services::CinderScheduler,OS::TripleO::Services::CinderVolume,OS::TripleO::Services::Clustercheck,OS::TripleO::Services::Collectd,OS::TripleO::Services::ContainerImagePrepare,OS::TripleO::Services::GlanceApi,OS::TripleO::Services::GlanceApiInternal,OS::TripleO::Services::HAproxy,OS::TripleO::Services::HeatApi,OS::TripleO::Services::HeatApiCloudwatch,OS::TripleO::Services::HeatApiCfn,OS::TripleO::Services::HeatEngine,OS::TripleO::Services::Horizon,OS::TripleO::Services::Iscsid,OS::TripleO::Services::Kernel,OS::TripleO::Services::Keystone,OS::TripleO::Services::ManilaApi,OS::TripleO::Services::ManilaBackendCephFs,OS::TripleO::Services::ManilaScheduler,OS::TripleO::Services::ManilaShare,OS::TripleO::Services::Memcached,OS::TripleO::Services::MetricsQdr,OS::TripleO::Services::MySQL,OS::TripleO::Services::MySQLClient,OS::TripleO::Services::NeutronApi,OS::TripleO::Services::NeutronCorePlugin,OS::TripleO::Services::NovaApi,OS::TripleO::Services::NovaConductor,OS::TripleO::Services::NovaMetadata,OS::TripleO::Services::NovaScheduler,OS::TripleO::Services::NovaVncProxy,OS::TripleO::Services::ContainersLogrotateCrond,OS::TripleO::Services::OVNDBs,OS::TripleO::Services::OVNController,OS::TripleO::Services::Pacemaker,OS::TripleO::Services::PlacementApi,OS::TripleO::Services::OsloMessagingRpc,OS::TripleO::Services::OsloMessagingNotify,OS::TripleO::Services::Podman,OS::TripleO::Services::Redis,OS::TripleO::Services::Rsyslog,OS::TripleO::Services::Snmp,OS::TripleO::Services::Sshd,OS::TripleO::Services::SwiftProxy,OS::TripleO::Services::SwiftRingBuilder,OS::TripleO::Services::SwiftStorage,OS::TripleO::Services::Timesync,OS::TripleO::Services::Timezone,OS::TripleO::Services::TripleoFirewall,OS::TripleO::Services::TripleoPackages,OS::TripleO::Services::Tuned\", \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(24,'2026-06-10 07:46:38',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Utility stack to convert an array of services into a set of combined role configs.\\n\", \"parameters\": {\"Services\": {\"default\": [], \"description\": \"List nested stack service templates.\\n\", \"type\": \"comma_delimited_list\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"description\": \"Parameters specific to the role\", \"default\": {}, \"type\": \"json\"}}, \"resources\": {\"ServiceChain\": {\"type\": \"OS::Heat::ResourceChain\", \"properties\": {\"resources\": {\"get_param\": \"Services\"}, \"concurrent\": true, \"resource_properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}}, \"ServiceServerMetadataHook\": {\"type\": \"OS::TripleO::ComputeServiceServerMetadataHook\", \"properties\": {\"RoleData\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}, \"PuppetStepConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"string\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.step_config, []), coalesce($.data.docker_config, [])).where($[2] = null).where($[1] != null).select($[1]).join(\\\"\\\\n\\\")\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}, \"step_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"step_config\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.docker_config, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfigScripts\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.container_config_scripts, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"container_config_scripts\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"container_config_scripts\"]}}}}}}, \"MonitoringSubscriptionsConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'monitoring_subscription\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"ServiceNames\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"filter\": [[null], {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}]}}}, \"GlobalConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'global_config_settings\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"KeystoneResourcesConfigs\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'keystone_resources\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"ServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'service_config_settings\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DeployStepsTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'deploy_steps_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalPostDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_post_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ScaleTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'scale_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreUpgradeRollingTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_upgrade_rolling_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeBatchTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_batch_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PuppetConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'puppet_config\')).where($ != null).distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"KollaConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'kolla_config\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DockerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'docker_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ContainerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'container_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostFirewallTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_firewall_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostPrepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_prep_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreDeployStepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_deploy_step_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"IpaRegistrationTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'ipa_registration_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"AnsibleGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'ansible_group_vars\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallFrontendRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ssl_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_sslfrontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}}}, \"outputs\": {\"role_data\": {\"description\": \"Combined Role data for this set of services.\", \"value\": {\"service_names\": {\"get_attr\": [\"ServiceNames\", \"value\"]}, \"monitoring_subscriptions\": {\"get_attr\": [\"MonitoringSubscriptionsConfig\", \"value\"]}, \"config_settings\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"config_settings\"]}}}, \"global_config_settings\": {\"get_attr\": [\"GlobalConfigSettings\", \"value\"]}, \"service_config_settings\": {\"get_attr\": [\"ServiceConfigSettings\", \"value\"]}, \"step_config\": {\"get_attr\": [\"PuppetStepConfig\", \"value\"]}, \"deploy_steps_tasks\": {\"get_attr\": [\"DeployStepsTasks\", \"value\"]}, \"external_deploy_tasks\": {\"get_attr\": [\"ExternalDeployTasks\", \"value\"]}, \"external_post_deploy_tasks\": {\"get_attr\": [\"ExternalPostDeployTasks\", \"value\"]}, \"external_update_tasks\": {\"get_attr\": [\"ExternalUpdateTasks\", \"value\"]}, \"external_upgrade_tasks\": {\"get_attr\": [\"ExternalUpgradeTasks\", \"value\"]}, \"scale_tasks\": {\"get_attr\": [\"ScaleTasks\", \"value\"]}, \"pre_upgrade_rolling_tasks\": {\"get_attr\": [\"PreUpgradeRollingTasks\", \"value\"]}, \"upgrade_tasks\": {\"get_attr\": [\"UpgradeTasks\", \"value\"]}, \"post_upgrade_tasks\": {\"get_attr\": [\"PostUpgradeTasks\", \"value\"]}, \"update_tasks\": {\"get_attr\": [\"UpdateTasks\", \"value\"]}, \"post_update_tasks\": {\"get_attr\": [\"PostUpdateTasks\", \"value\"]}, \"upgrade_batch_tasks\": {\"get_attr\": [\"UpgradeBatchTasks\", \"value\"]}, \"service_metadata_settings\": {\"get_attr\": [\"ServiceServerMetadataHook\", \"metadata\"]}, \"ansible_group_vars\": {\"map_merge\": [{\"ansible_async_dir\": \"/tmp/.ansible_async\"}, {\"get_attr\": [\"AnsibleGroupVars\", \"value\"]}]}, \"keystone_resources\": {\"get_attr\": [\"KeystoneResourcesConfigs\", \"value\"]}, \"firewall_rules\": {\"get_attr\": [\"FirewallRules\", \"value\"]}, \"firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"puppet_config\": {\"get_attr\": [\"PuppetConfig\", \"value\"]}, \"kolla_config\": {\"get_attr\": [\"KollaConfig\", \"value\"]}, \"docker_config\": {\"get_attr\": [\"DockerConfig\", \"value\"]}, \"container_config_scripts\": {\"get_attr\": [\"DockerConfigScripts\", \"value\"]}, \"container_puppet_tasks\": {\"map_merge\": [{\"get_attr\": [\"ContainerPuppetTasks\", \"value\"]}, {\"get_attr\": [\"DockerPuppetTasks\", \"value\"]}]}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"HostFirewallTasks\", \"value\"]}, {\"get_attr\": [\"HostPrepTasks\", \"value\"]}]}, \"pre_deploy_step_tasks\": {\"list_concat\": [{\"get_attr\": [\"PreDeployStepTasks\", \"value\"]}, {\"get_attr\": [\"IpaRegistrationTasks\", \"value\"]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"Services\": \"\", \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(25,'2026-06-10 07:46:38',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Utility stack to convert an array of services into a set of combined role configs.\\n\", \"parameters\": {\"Services\": {\"default\": [], \"description\": \"List nested stack service templates.\\n\", \"type\": \"comma_delimited_list\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"description\": \"Parameters specific to the role\", \"default\": {}, \"type\": \"json\"}}, \"resources\": {\"ServiceChain\": {\"type\": \"OS::Heat::ResourceChain\", \"properties\": {\"resources\": {\"get_param\": \"Services\"}, \"concurrent\": true, \"resource_properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}}, \"ServiceServerMetadataHook\": {\"type\": \"OS::TripleO::CellControllerServiceServerMetadataHook\", \"properties\": {\"RoleData\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}, \"PuppetStepConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"string\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.step_config, []), coalesce($.data.docker_config, [])).where($[2] = null).where($[1] != null).select($[1]).join(\\\"\\\\n\\\")\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}, \"step_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"step_config\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.docker_config, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfigScripts\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.container_config_scripts, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"container_config_scripts\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"container_config_scripts\"]}}}}}}, \"MonitoringSubscriptionsConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'monitoring_subscription\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"ServiceNames\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"filter\": [[null], {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}]}}}, \"GlobalConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'global_config_settings\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"KeystoneResourcesConfigs\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'keystone_resources\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"ServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'service_config_settings\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DeployStepsTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'deploy_steps_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalPostDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_post_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ScaleTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'scale_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreUpgradeRollingTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_upgrade_rolling_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeBatchTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_batch_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PuppetConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'puppet_config\')).where($ != null).distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"KollaConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'kolla_config\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DockerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'docker_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ContainerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'container_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostFirewallTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_firewall_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostPrepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_prep_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreDeployStepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_deploy_step_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"IpaRegistrationTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'ipa_registration_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"AnsibleGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'ansible_group_vars\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallFrontendRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ssl_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_sslfrontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}}}, \"outputs\": {\"role_data\": {\"description\": \"Combined Role data for this set of services.\", \"value\": {\"service_names\": {\"get_attr\": [\"ServiceNames\", \"value\"]}, \"monitoring_subscriptions\": {\"get_attr\": [\"MonitoringSubscriptionsConfig\", \"value\"]}, \"config_settings\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"config_settings\"]}}}, \"global_config_settings\": {\"get_attr\": [\"GlobalConfigSettings\", \"value\"]}, \"service_config_settings\": {\"get_attr\": [\"ServiceConfigSettings\", \"value\"]}, \"step_config\": {\"get_attr\": [\"PuppetStepConfig\", \"value\"]}, \"deploy_steps_tasks\": {\"get_attr\": [\"DeployStepsTasks\", \"value\"]}, \"external_deploy_tasks\": {\"get_attr\": [\"ExternalDeployTasks\", \"value\"]}, \"external_post_deploy_tasks\": {\"get_attr\": [\"ExternalPostDeployTasks\", \"value\"]}, \"external_update_tasks\": {\"get_attr\": [\"ExternalUpdateTasks\", \"value\"]}, \"external_upgrade_tasks\": {\"get_attr\": [\"ExternalUpgradeTasks\", \"value\"]}, \"scale_tasks\": {\"get_attr\": [\"ScaleTasks\", \"value\"]}, \"pre_upgrade_rolling_tasks\": {\"get_attr\": [\"PreUpgradeRollingTasks\", \"value\"]}, \"upgrade_tasks\": {\"get_attr\": [\"UpgradeTasks\", \"value\"]}, \"post_upgrade_tasks\": {\"get_attr\": [\"PostUpgradeTasks\", \"value\"]}, \"update_tasks\": {\"get_attr\": [\"UpdateTasks\", \"value\"]}, \"post_update_tasks\": {\"get_attr\": [\"PostUpdateTasks\", \"value\"]}, \"upgrade_batch_tasks\": {\"get_attr\": [\"UpgradeBatchTasks\", \"value\"]}, \"service_metadata_settings\": {\"get_attr\": [\"ServiceServerMetadataHook\", \"metadata\"]}, \"ansible_group_vars\": {\"map_merge\": [{\"ansible_async_dir\": \"/tmp/.ansible_async\"}, {\"get_attr\": [\"AnsibleGroupVars\", \"value\"]}]}, \"keystone_resources\": {\"get_attr\": [\"KeystoneResourcesConfigs\", \"value\"]}, \"firewall_rules\": {\"get_attr\": [\"FirewallRules\", \"value\"]}, \"firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"puppet_config\": {\"get_attr\": [\"PuppetConfig\", \"value\"]}, \"kolla_config\": {\"get_attr\": [\"KollaConfig\", \"value\"]}, \"docker_config\": {\"get_attr\": [\"DockerConfig\", \"value\"]}, \"container_config_scripts\": {\"get_attr\": [\"DockerConfigScripts\", \"value\"]}, \"container_puppet_tasks\": {\"map_merge\": [{\"get_attr\": [\"ContainerPuppetTasks\", \"value\"]}, {\"get_attr\": [\"DockerPuppetTasks\", \"value\"]}]}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"HostFirewallTasks\", \"value\"]}, {\"get_attr\": [\"HostPrepTasks\", \"value\"]}]}, \"pre_deploy_step_tasks\": {\"list_concat\": [{\"get_attr\": [\"PreDeployStepTasks\", \"value\"]}, {\"get_attr\": [\"IpaRegistrationTasks\", \"value\"]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"Services\": \"\", \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"RoleName\": \"CellController\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(26,'2026-06-10 07:46:38',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Utility stack to convert an array of services into a set of combined role configs.\\n\", \"parameters\": {\"Services\": {\"default\": [], \"description\": \"List nested stack service templates.\\n\", \"type\": \"comma_delimited_list\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"description\": \"Parameters specific to the role\", \"default\": {}, \"type\": \"json\"}}, \"resources\": {\"ServiceChain\": {\"type\": \"OS::Heat::ResourceChain\", \"properties\": {\"resources\": {\"get_param\": \"Services\"}, \"concurrent\": true, \"resource_properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}}, \"ServiceServerMetadataHook\": {\"type\": \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\", \"properties\": {\"RoleData\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}, \"PuppetStepConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"string\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.step_config, []), coalesce($.data.docker_config, [])).where($[2] = null).where($[1] != null).select($[1]).join(\\\"\\\\n\\\")\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}, \"step_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"step_config\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.docker_config, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfigScripts\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.container_config_scripts, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"container_config_scripts\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"container_config_scripts\"]}}}}}}, \"MonitoringSubscriptionsConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'monitoring_subscription\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"ServiceNames\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"filter\": [[null], {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}]}}}, \"GlobalConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'global_config_settings\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"KeystoneResourcesConfigs\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'keystone_resources\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"ServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'service_config_settings\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DeployStepsTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'deploy_steps_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalPostDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_post_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ScaleTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'scale_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreUpgradeRollingTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_upgrade_rolling_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeBatchTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_batch_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PuppetConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'puppet_config\')).where($ != null).distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"KollaConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'kolla_config\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DockerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'docker_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ContainerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'container_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostFirewallTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_firewall_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostPrepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_prep_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreDeployStepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_deploy_step_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"IpaRegistrationTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'ipa_registration_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"AnsibleGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'ansible_group_vars\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallFrontendRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ssl_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_sslfrontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}}}, \"outputs\": {\"role_data\": {\"description\": \"Combined Role data for this set of services.\", \"value\": {\"service_names\": {\"get_attr\": [\"ServiceNames\", \"value\"]}, \"monitoring_subscriptions\": {\"get_attr\": [\"MonitoringSubscriptionsConfig\", \"value\"]}, \"config_settings\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"config_settings\"]}}}, \"global_config_settings\": {\"get_attr\": [\"GlobalConfigSettings\", \"value\"]}, \"service_config_settings\": {\"get_attr\": [\"ServiceConfigSettings\", \"value\"]}, \"step_config\": {\"get_attr\": [\"PuppetStepConfig\", \"value\"]}, \"deploy_steps_tasks\": {\"get_attr\": [\"DeployStepsTasks\", \"value\"]}, \"external_deploy_tasks\": {\"get_attr\": [\"ExternalDeployTasks\", \"value\"]}, \"external_post_deploy_tasks\": {\"get_attr\": [\"ExternalPostDeployTasks\", \"value\"]}, \"external_update_tasks\": {\"get_attr\": [\"ExternalUpdateTasks\", \"value\"]}, \"external_upgrade_tasks\": {\"get_attr\": [\"ExternalUpgradeTasks\", \"value\"]}, \"scale_tasks\": {\"get_attr\": [\"ScaleTasks\", \"value\"]}, \"pre_upgrade_rolling_tasks\": {\"get_attr\": [\"PreUpgradeRollingTasks\", \"value\"]}, \"upgrade_tasks\": {\"get_attr\": [\"UpgradeTasks\", \"value\"]}, \"post_upgrade_tasks\": {\"get_attr\": [\"PostUpgradeTasks\", \"value\"]}, \"update_tasks\": {\"get_attr\": [\"UpdateTasks\", \"value\"]}, \"post_update_tasks\": {\"get_attr\": [\"PostUpdateTasks\", \"value\"]}, \"upgrade_batch_tasks\": {\"get_attr\": [\"UpgradeBatchTasks\", \"value\"]}, \"service_metadata_settings\": {\"get_attr\": [\"ServiceServerMetadataHook\", \"metadata\"]}, \"ansible_group_vars\": {\"map_merge\": [{\"ansible_async_dir\": \"/tmp/.ansible_async\"}, {\"get_attr\": [\"AnsibleGroupVars\", \"value\"]}]}, \"keystone_resources\": {\"get_attr\": [\"KeystoneResourcesConfigs\", \"value\"]}, \"firewall_rules\": {\"get_attr\": [\"FirewallRules\", \"value\"]}, \"firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"puppet_config\": {\"get_attr\": [\"PuppetConfig\", \"value\"]}, \"kolla_config\": {\"get_attr\": [\"KollaConfig\", \"value\"]}, \"docker_config\": {\"get_attr\": [\"DockerConfig\", \"value\"]}, \"container_config_scripts\": {\"get_attr\": [\"DockerConfigScripts\", \"value\"]}, \"container_puppet_tasks\": {\"map_merge\": [{\"get_attr\": [\"ContainerPuppetTasks\", \"value\"]}, {\"get_attr\": [\"DockerPuppetTasks\", \"value\"]}]}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"HostFirewallTasks\", \"value\"]}, {\"get_attr\": [\"HostPrepTasks\", \"value\"]}]}, \"pre_deploy_step_tasks\": {\"list_concat\": [{\"get_attr\": [\"PreDeployStepTasks\", \"value\"]}, {\"get_attr\": [\"IpaRegistrationTasks\", \"value\"]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"Services\": \"\", \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"RoleName\": \"CellControllerCompute\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(27,'2026-06-10 07:46:38',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Utility stack to convert an array of services into a set of combined role configs.\\n\", \"parameters\": {\"Services\": {\"default\": [], \"description\": \"List nested stack service templates.\\n\", \"type\": \"comma_delimited_list\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"description\": \"Parameters specific to the role\", \"default\": {}, \"type\": \"json\"}}, \"resources\": {\"ServiceChain\": {\"type\": \"OS::Heat::ResourceChain\", \"properties\": {\"resources\": {\"get_param\": \"Services\"}, \"concurrent\": true, \"resource_properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}}, \"ServiceServerMetadataHook\": {\"type\": \"OS::TripleO::NetworkerServiceServerMetadataHook\", \"properties\": {\"RoleData\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}, \"PuppetStepConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"string\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.step_config, []), coalesce($.data.docker_config, [])).where($[2] = null).where($[1] != null).select($[1]).join(\\\"\\\\n\\\")\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}, \"step_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"step_config\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.docker_config, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfigScripts\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.container_config_scripts, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"container_config_scripts\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"container_config_scripts\"]}}}}}}, \"MonitoringSubscriptionsConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'monitoring_subscription\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"ServiceNames\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"filter\": [[null], {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}]}}}, \"GlobalConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'global_config_settings\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"KeystoneResourcesConfigs\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'keystone_resources\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"ServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'service_config_settings\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DeployStepsTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'deploy_steps_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalPostDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_post_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ScaleTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'scale_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreUpgradeRollingTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_upgrade_rolling_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeBatchTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_batch_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PuppetConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'puppet_config\')).where($ != null).distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"KollaConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'kolla_config\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DockerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'docker_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ContainerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'container_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostFirewallTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_firewall_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostPrepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_prep_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreDeployStepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_deploy_step_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"IpaRegistrationTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'ipa_registration_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"AnsibleGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'ansible_group_vars\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallFrontendRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ssl_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_sslfrontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}}}, \"outputs\": {\"role_data\": {\"description\": \"Combined Role data for this set of services.\", \"value\": {\"service_names\": {\"get_attr\": [\"ServiceNames\", \"value\"]}, \"monitoring_subscriptions\": {\"get_attr\": [\"MonitoringSubscriptionsConfig\", \"value\"]}, \"config_settings\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"config_settings\"]}}}, \"global_config_settings\": {\"get_attr\": [\"GlobalConfigSettings\", \"value\"]}, \"service_config_settings\": {\"get_attr\": [\"ServiceConfigSettings\", \"value\"]}, \"step_config\": {\"get_attr\": [\"PuppetStepConfig\", \"value\"]}, \"deploy_steps_tasks\": {\"get_attr\": [\"DeployStepsTasks\", \"value\"]}, \"external_deploy_tasks\": {\"get_attr\": [\"ExternalDeployTasks\", \"value\"]}, \"external_post_deploy_tasks\": {\"get_attr\": [\"ExternalPostDeployTasks\", \"value\"]}, \"external_update_tasks\": {\"get_attr\": [\"ExternalUpdateTasks\", \"value\"]}, \"external_upgrade_tasks\": {\"get_attr\": [\"ExternalUpgradeTasks\", \"value\"]}, \"scale_tasks\": {\"get_attr\": [\"ScaleTasks\", \"value\"]}, \"pre_upgrade_rolling_tasks\": {\"get_attr\": [\"PreUpgradeRollingTasks\", \"value\"]}, \"upgrade_tasks\": {\"get_attr\": [\"UpgradeTasks\", \"value\"]}, \"post_upgrade_tasks\": {\"get_attr\": [\"PostUpgradeTasks\", \"value\"]}, \"update_tasks\": {\"get_attr\": [\"UpdateTasks\", \"value\"]}, \"post_update_tasks\": {\"get_attr\": [\"PostUpdateTasks\", \"value\"]}, \"upgrade_batch_tasks\": {\"get_attr\": [\"UpgradeBatchTasks\", \"value\"]}, \"service_metadata_settings\": {\"get_attr\": [\"ServiceServerMetadataHook\", \"metadata\"]}, \"ansible_group_vars\": {\"map_merge\": [{\"ansible_async_dir\": \"/tmp/.ansible_async\"}, {\"get_attr\": [\"AnsibleGroupVars\", \"value\"]}]}, \"keystone_resources\": {\"get_attr\": [\"KeystoneResourcesConfigs\", \"value\"]}, \"firewall_rules\": {\"get_attr\": [\"FirewallRules\", \"value\"]}, \"firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"puppet_config\": {\"get_attr\": [\"PuppetConfig\", \"value\"]}, \"kolla_config\": {\"get_attr\": [\"KollaConfig\", \"value\"]}, \"docker_config\": {\"get_attr\": [\"DockerConfig\", \"value\"]}, \"container_config_scripts\": {\"get_attr\": [\"DockerConfigScripts\", \"value\"]}, \"container_puppet_tasks\": {\"map_merge\": [{\"get_attr\": [\"ContainerPuppetTasks\", \"value\"]}, {\"get_attr\": [\"DockerPuppetTasks\", \"value\"]}]}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"HostFirewallTasks\", \"value\"]}, {\"get_attr\": [\"HostPrepTasks\", \"value\"]}]}, \"pre_deploy_step_tasks\": {\"list_concat\": [{\"get_attr\": [\"PreDeployStepTasks\", \"value\"]}, {\"get_attr\": [\"IpaRegistrationTasks\", \"value\"]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"Services\": \"\", \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"RoleName\": \"Networker\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (28,'2026-06-10 07:46:38',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Utility stack to convert an array of services into a set of combined role configs.\\n\", \"parameters\": {\"Services\": {\"default\": [], \"description\": \"List nested stack service templates.\\n\", \"type\": \"comma_delimited_list\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"description\": \"Parameters specific to the role\", \"default\": {}, \"type\": \"json\"}}, \"resources\": {\"ServiceChain\": {\"type\": \"OS::Heat::ResourceChain\", \"properties\": {\"resources\": {\"get_param\": \"Services\"}, \"concurrent\": true, \"resource_properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}}, \"ServiceServerMetadataHook\": {\"type\": \"OS::TripleO::BlockStorageServiceServerMetadataHook\", \"properties\": {\"RoleData\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}, \"PuppetStepConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"string\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.step_config, []), coalesce($.data.docker_config, [])).where($[2] = null).where($[1] != null).select($[1]).join(\\\"\\\\n\\\")\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}, \"step_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"step_config\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.docker_config, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfigScripts\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.container_config_scripts, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"container_config_scripts\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"container_config_scripts\"]}}}}}}, \"MonitoringSubscriptionsConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'monitoring_subscription\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"ServiceNames\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"filter\": [[null], {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}]}}}, \"GlobalConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'global_config_settings\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"KeystoneResourcesConfigs\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'keystone_resources\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"ServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'service_config_settings\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DeployStepsTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'deploy_steps_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalPostDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_post_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ScaleTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'scale_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreUpgradeRollingTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_upgrade_rolling_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeBatchTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_batch_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PuppetConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'puppet_config\')).where($ != null).distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"KollaConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'kolla_config\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DockerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'docker_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ContainerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'container_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostFirewallTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_firewall_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostPrepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_prep_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreDeployStepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_deploy_step_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"IpaRegistrationTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'ipa_registration_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"AnsibleGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'ansible_group_vars\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallFrontendRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ssl_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_sslfrontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}}}, \"outputs\": {\"role_data\": {\"description\": \"Combined Role data for this set of services.\", \"value\": {\"service_names\": {\"get_attr\": [\"ServiceNames\", \"value\"]}, \"monitoring_subscriptions\": {\"get_attr\": [\"MonitoringSubscriptionsConfig\", \"value\"]}, \"config_settings\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"config_settings\"]}}}, \"global_config_settings\": {\"get_attr\": [\"GlobalConfigSettings\", \"value\"]}, \"service_config_settings\": {\"get_attr\": [\"ServiceConfigSettings\", \"value\"]}, \"step_config\": {\"get_attr\": [\"PuppetStepConfig\", \"value\"]}, \"deploy_steps_tasks\": {\"get_attr\": [\"DeployStepsTasks\", \"value\"]}, \"external_deploy_tasks\": {\"get_attr\": [\"ExternalDeployTasks\", \"value\"]}, \"external_post_deploy_tasks\": {\"get_attr\": [\"ExternalPostDeployTasks\", \"value\"]}, \"external_update_tasks\": {\"get_attr\": [\"ExternalUpdateTasks\", \"value\"]}, \"external_upgrade_tasks\": {\"get_attr\": [\"ExternalUpgradeTasks\", \"value\"]}, \"scale_tasks\": {\"get_attr\": [\"ScaleTasks\", \"value\"]}, \"pre_upgrade_rolling_tasks\": {\"get_attr\": [\"PreUpgradeRollingTasks\", \"value\"]}, \"upgrade_tasks\": {\"get_attr\": [\"UpgradeTasks\", \"value\"]}, \"post_upgrade_tasks\": {\"get_attr\": [\"PostUpgradeTasks\", \"value\"]}, \"update_tasks\": {\"get_attr\": [\"UpdateTasks\", \"value\"]}, \"post_update_tasks\": {\"get_attr\": [\"PostUpdateTasks\", \"value\"]}, \"upgrade_batch_tasks\": {\"get_attr\": [\"UpgradeBatchTasks\", \"value\"]}, \"service_metadata_settings\": {\"get_attr\": [\"ServiceServerMetadataHook\", \"metadata\"]}, \"ansible_group_vars\": {\"map_merge\": [{\"ansible_async_dir\": \"/tmp/.ansible_async\"}, {\"get_attr\": [\"AnsibleGroupVars\", \"value\"]}]}, \"keystone_resources\": {\"get_attr\": [\"KeystoneResourcesConfigs\", \"value\"]}, \"firewall_rules\": {\"get_attr\": [\"FirewallRules\", \"value\"]}, \"firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"puppet_config\": {\"get_attr\": [\"PuppetConfig\", \"value\"]}, \"kolla_config\": {\"get_attr\": [\"KollaConfig\", \"value\"]}, \"docker_config\": {\"get_attr\": [\"DockerConfig\", \"value\"]}, \"container_config_scripts\": {\"get_attr\": [\"DockerConfigScripts\", \"value\"]}, \"container_puppet_tasks\": {\"map_merge\": [{\"get_attr\": [\"ContainerPuppetTasks\", \"value\"]}, {\"get_attr\": [\"DockerPuppetTasks\", \"value\"]}]}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"HostFirewallTasks\", \"value\"]}, {\"get_attr\": [\"HostPrepTasks\", \"value\"]}]}, \"pre_deploy_step_tasks\": {\"list_concat\": [{\"get_attr\": [\"PreDeployStepTasks\", \"value\"]}, {\"get_attr\": [\"IpaRegistrationTasks\", \"value\"]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"Services\": \"\", \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"RoleName\": \"BlockStorage\", \"RoleParameters\": {}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(29,'2026-06-10 07:46:38',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Utility stack to convert an array of services into a set of combined role configs.\\n\", \"parameters\": {\"Services\": {\"default\": [], \"description\": \"List nested stack service templates.\\n\", \"type\": \"comma_delimited_list\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"description\": \"Parameters specific to the role\", \"default\": {}, \"type\": \"json\"}}, \"resources\": {\"ServiceChain\": {\"type\": \"OS::Heat::ResourceChain\", \"properties\": {\"resources\": {\"get_param\": \"Services\"}, \"concurrent\": true, \"resource_properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}}, \"ServiceServerMetadataHook\": {\"type\": \"OS::TripleO::CephStorageServiceServerMetadataHook\", \"properties\": {\"RoleData\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}, \"PuppetStepConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"string\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.step_config, []), coalesce($.data.docker_config, [])).where($[2] = null).where($[1] != null).select($[1]).join(\\\"\\\\n\\\")\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}, \"step_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"step_config\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.docker_config, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfigScripts\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.container_config_scripts, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"container_config_scripts\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"container_config_scripts\"]}}}}}}, \"MonitoringSubscriptionsConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'monitoring_subscription\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"ServiceNames\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"filter\": [[null], {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}]}}}, \"GlobalConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'global_config_settings\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"KeystoneResourcesConfigs\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'keystone_resources\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"ServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'service_config_settings\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DeployStepsTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'deploy_steps_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalPostDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_post_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ScaleTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'scale_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreUpgradeRollingTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_upgrade_rolling_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeBatchTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_batch_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PuppetConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'puppet_config\')).where($ != null).distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"KollaConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'kolla_config\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DockerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'docker_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ContainerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'container_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostFirewallTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_firewall_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostPrepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_prep_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreDeployStepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_deploy_step_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"IpaRegistrationTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'ipa_registration_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"AnsibleGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'ansible_group_vars\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallFrontendRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ssl_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_sslfrontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}}}, \"outputs\": {\"role_data\": {\"description\": \"Combined Role data for this set of services.\", \"value\": {\"service_names\": {\"get_attr\": [\"ServiceNames\", \"value\"]}, \"monitoring_subscriptions\": {\"get_attr\": [\"MonitoringSubscriptionsConfig\", \"value\"]}, \"config_settings\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"config_settings\"]}}}, \"global_config_settings\": {\"get_attr\": [\"GlobalConfigSettings\", \"value\"]}, \"service_config_settings\": {\"get_attr\": [\"ServiceConfigSettings\", \"value\"]}, \"step_config\": {\"get_attr\": [\"PuppetStepConfig\", \"value\"]}, \"deploy_steps_tasks\": {\"get_attr\": [\"DeployStepsTasks\", \"value\"]}, \"external_deploy_tasks\": {\"get_attr\": [\"ExternalDeployTasks\", \"value\"]}, \"external_post_deploy_tasks\": {\"get_attr\": [\"ExternalPostDeployTasks\", \"value\"]}, \"external_update_tasks\": {\"get_attr\": [\"ExternalUpdateTasks\", \"value\"]}, \"external_upgrade_tasks\": {\"get_attr\": [\"ExternalUpgradeTasks\", \"value\"]}, \"scale_tasks\": {\"get_attr\": [\"ScaleTasks\", \"value\"]}, \"pre_upgrade_rolling_tasks\": {\"get_attr\": [\"PreUpgradeRollingTasks\", \"value\"]}, \"upgrade_tasks\": {\"get_attr\": [\"UpgradeTasks\", \"value\"]}, \"post_upgrade_tasks\": {\"get_attr\": [\"PostUpgradeTasks\", \"value\"]}, \"update_tasks\": {\"get_attr\": [\"UpdateTasks\", \"value\"]}, \"post_update_tasks\": {\"get_attr\": [\"PostUpdateTasks\", \"value\"]}, \"upgrade_batch_tasks\": {\"get_attr\": [\"UpgradeBatchTasks\", \"value\"]}, \"service_metadata_settings\": {\"get_attr\": [\"ServiceServerMetadataHook\", \"metadata\"]}, \"ansible_group_vars\": {\"map_merge\": [{\"ansible_async_dir\": \"/tmp/.ansible_async\"}, {\"get_attr\": [\"AnsibleGroupVars\", \"value\"]}]}, \"keystone_resources\": {\"get_attr\": [\"KeystoneResourcesConfigs\", \"value\"]}, \"firewall_rules\": {\"get_attr\": [\"FirewallRules\", \"value\"]}, \"firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"puppet_config\": {\"get_attr\": [\"PuppetConfig\", \"value\"]}, \"kolla_config\": {\"get_attr\": [\"KollaConfig\", \"value\"]}, \"docker_config\": {\"get_attr\": [\"DockerConfig\", \"value\"]}, \"container_config_scripts\": {\"get_attr\": [\"DockerConfigScripts\", \"value\"]}, \"container_puppet_tasks\": {\"map_merge\": [{\"get_attr\": [\"ContainerPuppetTasks\", \"value\"]}, {\"get_attr\": [\"DockerPuppetTasks\", \"value\"]}]}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"HostFirewallTasks\", \"value\"]}, {\"get_attr\": [\"HostPrepTasks\", \"value\"]}]}, \"pre_deploy_step_tasks\": {\"list_concat\": [{\"get_attr\": [\"PreDeployStepTasks\", \"value\"]}, {\"get_attr\": [\"IpaRegistrationTasks\", \"value\"]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"Services\": \"\", \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"RoleName\": \"CephStorage\", \"RoleParameters\": {}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(30,'2026-06-10 07:46:39',NULL,'{\"heat_template_version\": \"2015-04-30\", \"outputs\": {\"role_data, docker_config\": {\"value\": []}, \"role_data, step_config\": {\"value\": []}, \"role_data, container_config_scripts\": {\"value\": []}, \"role_data, service_names\": {\"value\": []}, \"role_data, config_settings\": {\"value\": []}, \"role_data\": {\"value\": []}, \"role_data, service_name\": {\"value\": []}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(31,'2026-06-10 07:46:39',NULL,'{\"heat_template_version\": \"2015-04-30\", \"outputs\": {\"role_data, docker_config\": {\"value\": []}, \"role_data, step_config\": {\"value\": []}, \"role_data, container_config_scripts\": {\"value\": []}, \"role_data, service_names\": {\"value\": []}, \"role_data, config_settings\": {\"value\": []}, \"role_data\": {\"value\": []}, \"role_data, service_name\": {\"value\": []}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (32,'2026-06-10 07:46:39',NULL,'{\"heat_template_version\": \"2015-04-30\", \"resources\": {\"0\": {\"type\": \"OS::TripleO::Services::BootParams\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}}, \"1\": {\"type\": \"OS::TripleO::Services::CACerts\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}}, \"2\": {\"type\": \"OS::TripleO::Services::CeilometerAgentCentral\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}}, \"3\": {\"type\": \"OS::TripleO::Services::CeilometerAgentNotification\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}}, \"4\": {\"type\": \"OS::TripleO::Services::CinderApi\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"0\"]}, \"5\": {\"type\": \"OS::TripleO::Services::CinderBackup\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"1\"]}, \"6\": {\"type\": \"OS::TripleO::Services::CinderScheduler\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"2\"]}, \"7\": {\"type\": \"OS::TripleO::Services::CinderVolume\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"3\"]}, \"8\": {\"type\": \"OS::TripleO::Services::Clustercheck\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"4\"]}, \"9\": {\"type\": \"OS::TripleO::Services::Collectd\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"5\"]}, \"10\": {\"type\": \"OS::TripleO::Services::ContainerImagePrepare\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"6\"]}, \"11\": {\"type\": \"OS::TripleO::Services::GlanceApi\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"7\"]}, \"12\": {\"type\": \"OS::TripleO::Services::GlanceApiInternal\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"8\"]}, \"13\": {\"type\": \"OS::TripleO::Services::HAproxy\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"9\"]}, \"14\": {\"type\": \"OS::TripleO::Services::HeatApi\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"10\"]}, \"15\": {\"type\": \"OS::TripleO::Services::HeatApiCloudwatch\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"11\"]}, \"16\": {\"type\": \"OS::TripleO::Services::HeatApiCfn\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"12\"]}, \"17\": {\"type\": \"OS::TripleO::Services::HeatEngine\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"13\"]}, \"18\": {\"type\": \"OS::TripleO::Services::Horizon\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"14\"]}, \"19\": {\"type\": \"OS::TripleO::Services::Iscsid\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"15\"]}, \"20\": {\"type\": \"OS::TripleO::Services::Kernel\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"16\"]}, \"21\": {\"type\": \"OS::TripleO::Services::Keystone\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"17\"]}, \"22\": {\"type\": \"OS::TripleO::Services::ManilaApi\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"18\"]}, \"23\": {\"type\": \"OS::TripleO::Services::ManilaBackendCephFs\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"19\"]}, \"24\": {\"type\": \"OS::TripleO::Services::ManilaScheduler\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"20\"]}, \"25\": {\"type\": \"OS::TripleO::Services::ManilaShare\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"21\"]}, \"26\": {\"type\": \"OS::TripleO::Services::Memcached\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"22\"]}, \"27\": {\"type\": \"OS::TripleO::Services::MetricsQdr\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"23\"]}, \"28\": {\"type\": \"OS::TripleO::Services::MySQL\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"24\"]}, \"29\": {\"type\": \"OS::TripleO::Services::MySQLClient\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"25\"]}, \"30\": {\"type\": \"OS::TripleO::Services::NeutronApi\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"26\"]}, \"31\": {\"type\": \"OS::TripleO::Services::NeutronCorePlugin\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"27\"]}, \"32\": {\"type\": \"OS::TripleO::Services::NovaApi\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"28\"]}, \"33\": {\"type\": \"OS::TripleO::Services::NovaConductor\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"29\"]}, \"34\": {\"type\": \"OS::TripleO::Services::NovaMetadata\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"30\"]}, \"35\": {\"type\": \"OS::TripleO::Services::NovaScheduler\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"31\"]}, \"36\": {\"type\": \"OS::TripleO::Services::NovaVncProxy\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"32\"]}, \"37\": {\"type\": \"OS::TripleO::Services::ContainersLogrotateCrond\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"33\"]}, \"38\": {\"type\": \"OS::TripleO::Services::OVNDBs\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"34\"]}, \"39\": {\"type\": \"OS::TripleO::Services::OVNController\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"35\"]}, \"40\": {\"type\": \"OS::TripleO::Services::Pacemaker\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"36\"]}, \"41\": {\"type\": \"OS::TripleO::Services::PlacementApi\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"37\"]}, \"42\": {\"type\": \"OS::TripleO::Services::OsloMessagingRpc\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"38\"]}, \"43\": {\"type\": \"OS::TripleO::Services::OsloMessagingNotify\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"39\"]}, \"44\": {\"type\": \"OS::TripleO::Services::Podman\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"40\"]}, \"45\": {\"type\": \"OS::TripleO::Services::Redis\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"41\"]}, \"46\": {\"type\": \"OS::TripleO::Services::Rsyslog\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"42\"]}, \"47\": {\"type\": \"OS::TripleO::Services::Snmp\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"43\"]}, \"48\": {\"type\": \"OS::TripleO::Services::Sshd\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"44\"]}, \"49\": {\"type\": \"OS::TripleO::Services::SwiftProxy\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"45\"]}, \"50\": {\"type\": \"OS::TripleO::Services::SwiftRingBuilder\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"46\"]}, \"51\": {\"type\": \"OS::TripleO::Services::SwiftStorage\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"47\"]}, \"52\": {\"type\": \"OS::TripleO::Services::Timesync\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"48\"]}, \"53\": {\"type\": \"OS::TripleO::Services::Timezone\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"49\"]}, \"54\": {\"type\": \"OS::TripleO::Services::TripleoFirewall\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"50\"]}, \"55\": {\"type\": \"OS::TripleO::Services::TripleoPackages\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"51\"]}, \"56\": {\"type\": \"OS::TripleO::Services::Tuned\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"52\"]}}, \"outputs\": {\"role_data, docker_config\": {\"value\": [{\"get_attr\": [\"0\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"1\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"2\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"3\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"4\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"5\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"6\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"7\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"8\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"9\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"10\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"11\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"12\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"13\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"14\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"15\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"16\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"17\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"18\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"19\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"20\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"21\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"22\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"23\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"24\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"25\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"26\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"27\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"28\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"29\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"30\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"31\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"32\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"33\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"34\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"35\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"36\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"37\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"38\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"39\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"40\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"41\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"42\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"43\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"44\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"45\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"46\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"47\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"48\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"49\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"50\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"51\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"52\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"53\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"54\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"55\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"56\", \"role_data\", \"docker_config\"]}]}, \"role_data, step_config\": {\"value\": [{\"get_attr\": [\"0\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"1\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"2\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"3\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"4\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"5\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"6\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"7\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"8\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"9\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"10\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"11\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"12\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"13\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"14\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"15\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"16\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"17\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"18\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"19\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"20\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"21\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"22\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"23\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"24\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"25\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"26\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"27\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"28\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"29\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"30\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"31\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"32\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"33\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"34\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"35\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"36\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"37\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"38\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"39\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"40\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"41\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"42\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"43\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"44\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"45\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"46\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"47\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"48\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"49\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"50\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"51\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"52\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"53\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"54\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"55\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"56\", \"role_data\", \"step_config\"]}]}, \"role_data, container_config_scripts\": {\"value\": [{\"get_attr\": [\"0\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"1\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"2\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"3\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"4\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"5\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"6\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"7\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"8\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"9\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"10\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"11\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"12\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"13\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"14\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"15\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"16\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"17\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"18\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"19\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"20\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"21\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"22\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"23\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"24\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"25\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"26\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"27\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"28\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"29\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"30\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"31\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"32\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"33\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"34\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"35\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"36\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"37\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"38\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"39\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"40\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"41\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"42\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"43\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"44\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"45\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"46\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"47\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"48\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"49\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"50\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"51\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"52\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"53\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"54\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"55\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"56\", \"role_data\", \"container_config_scripts\"]}]}, \"role_data, service_names\": {\"value\": [{\"get_attr\": [\"0\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"1\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"2\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"3\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"4\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"5\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"6\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"7\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"8\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"9\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"10\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"11\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"12\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"13\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"14\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"15\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"16\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"17\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"18\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"19\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"20\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"21\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"22\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"23\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"24\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"25\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"26\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"27\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"28\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"29\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"30\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"31\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"32\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"33\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"34\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"35\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"36\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"37\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"38\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"39\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"40\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"41\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"42\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"43\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"44\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"45\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"46\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"47\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"48\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"49\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"50\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"51\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"52\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"53\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"54\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"55\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"56\", \"role_data\", \"service_names\"]}]}, \"role_data, config_settings\": {\"value\": [{\"get_attr\": [\"0\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"1\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"2\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"3\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"4\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"5\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"6\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"7\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"8\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"9\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"10\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"11\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"12\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"13\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"14\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"15\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"16\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"17\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"18\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"19\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"20\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"21\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"22\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"23\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"24\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"25\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"26\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"27\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"28\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"29\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"30\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"31\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"32\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"33\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"34\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"35\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"36\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"37\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"38\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"39\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"40\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"41\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"42\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"43\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"44\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"45\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"46\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"47\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"48\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"49\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"50\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"51\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"52\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"53\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"54\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"55\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"56\", \"role_data\", \"config_settings\"]}]}, \"role_data\": {\"value\": [{\"get_attr\": [\"0\", \"role_data\"]}, {\"get_attr\": [\"1\", \"role_data\"]}, {\"get_attr\": [\"2\", \"role_data\"]}, {\"get_attr\": [\"3\", \"role_data\"]}, {\"get_attr\": [\"4\", \"role_data\"]}, {\"get_attr\": [\"5\", \"role_data\"]}, {\"get_attr\": [\"6\", \"role_data\"]}, {\"get_attr\": [\"7\", \"role_data\"]}, {\"get_attr\": [\"8\", \"role_data\"]}, {\"get_attr\": [\"9\", \"role_data\"]}, {\"get_attr\": [\"10\", \"role_data\"]}, {\"get_attr\": [\"11\", \"role_data\"]}, {\"get_attr\": [\"12\", \"role_data\"]}, {\"get_attr\": [\"13\", \"role_data\"]}, {\"get_attr\": [\"14\", \"role_data\"]}, {\"get_attr\": [\"15\", \"role_data\"]}, {\"get_attr\": [\"16\", \"role_data\"]}, {\"get_attr\": [\"17\", \"role_data\"]}, {\"get_attr\": [\"18\", \"role_data\"]}, {\"get_attr\": [\"19\", \"role_data\"]}, {\"get_attr\": [\"20\", \"role_data\"]}, {\"get_attr\": [\"21\", \"role_data\"]}, {\"get_attr\": [\"22\", \"role_data\"]}, {\"get_attr\": [\"23\", \"role_data\"]}, {\"get_attr\": [\"24\", \"role_data\"]}, {\"get_attr\": [\"25\", \"role_data\"]}, {\"get_attr\": [\"26\", \"role_data\"]}, {\"get_attr\": [\"27\", \"role_data\"]}, {\"get_attr\": [\"28\", \"role_data\"]}, {\"get_attr\": [\"29\", \"role_data\"]}, {\"get_attr\": [\"30\", \"role_data\"]}, {\"get_attr\": [\"31\", \"role_data\"]}, {\"get_attr\": [\"32\", \"role_data\"]}, {\"get_attr\": [\"33\", \"role_data\"]}, {\"get_attr\": [\"34\", \"role_data\"]}, {\"get_attr\": [\"35\", \"role_data\"]}, {\"get_attr\": [\"36\", \"role_data\"]}, {\"get_attr\": [\"37\", \"role_data\"]}, {\"get_attr\": [\"38\", \"role_data\"]}, {\"get_attr\": [\"39\", \"role_data\"]}, {\"get_attr\": [\"40\", \"role_data\"]}, {\"get_attr\": [\"41\", \"role_data\"]}, {\"get_attr\": [\"42\", \"role_data\"]}, {\"get_attr\": [\"43\", \"role_data\"]}, {\"get_attr\": [\"44\", \"role_data\"]}, {\"get_attr\": [\"45\", \"role_data\"]}, {\"get_attr\": [\"46\", \"role_data\"]}, {\"get_attr\": [\"47\", \"role_data\"]}, {\"get_attr\": [\"48\", \"role_data\"]}, {\"get_attr\": [\"49\", \"role_data\"]}, {\"get_attr\": [\"50\", \"role_data\"]}, {\"get_attr\": [\"51\", \"role_data\"]}, {\"get_attr\": [\"52\", \"role_data\"]}, {\"get_attr\": [\"53\", \"role_data\"]}, {\"get_attr\": [\"54\", \"role_data\"]}, {\"get_attr\": [\"55\", \"role_data\"]}, {\"get_attr\": [\"56\", \"role_data\"]}]}, \"role_data, service_name\": {\"value\": [{\"get_attr\": [\"0\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"1\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"2\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"3\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"4\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"5\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"6\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"7\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"8\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"9\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"10\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"11\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"12\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"13\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"14\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"15\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"16\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"17\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"18\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"19\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"20\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"21\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"22\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"23\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"24\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"25\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"26\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"27\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"28\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"29\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"30\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"31\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"32\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"33\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"34\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"35\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"36\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"37\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"38\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"39\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"40\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"41\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"42\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"43\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"44\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"45\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"46\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"47\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"48\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"49\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"50\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"51\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"52\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"53\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"54\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"55\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"56\", \"role_data\", \"service_name\"]}]}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (33,'2026-06-10 07:46:39',NULL,'{\"heat_template_version\": \"2015-04-30\", \"outputs\": {\"role_data, docker_config\": {\"value\": []}, \"role_data, step_config\": {\"value\": []}, \"role_data, container_config_scripts\": {\"value\": []}, \"role_data, service_names\": {\"value\": []}, \"role_data, config_settings\": {\"value\": []}, \"role_data\": {\"value\": []}, \"role_data, service_name\": {\"value\": []}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(34,'2026-06-10 07:46:39',NULL,'{\"heat_template_version\": \"2015-04-30\", \"outputs\": {\"role_data, docker_config\": {\"value\": []}, \"role_data, step_config\": {\"value\": []}, \"role_data, container_config_scripts\": {\"value\": []}, \"role_data, service_names\": {\"value\": []}, \"role_data, config_settings\": {\"value\": []}, \"role_data\": {\"value\": []}, \"role_data, service_name\": {\"value\": []}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(35,'2026-06-10 07:46:39',NULL,'{\"heat_template_version\": \"2015-04-30\", \"outputs\": {\"role_data, docker_config\": {\"value\": []}, \"role_data, step_config\": {\"value\": []}, \"role_data, container_config_scripts\": {\"value\": []}, \"role_data, service_names\": {\"value\": []}, \"role_data, config_settings\": {\"value\": []}, \"role_data\": {\"value\": []}, \"role_data, service_name\": {\"value\": []}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(36,'2026-06-10 07:46:40',NULL,'{\"heat_template_version\": \"2015-04-30\", \"outputs\": {\"role_data, docker_config\": {\"value\": []}, \"role_data, step_config\": {\"value\": []}, \"role_data, container_config_scripts\": {\"value\": []}, \"role_data, service_names\": {\"value\": []}, \"role_data, config_settings\": {\"value\": []}, \"role_data\": {\"value\": []}, \"role_data, service_name\": {\"value\": []}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(37,'2026-06-10 07:46:40',NULL,'{\"heat_template_version\": \"2015-04-30\", \"outputs\": {\"role_data, docker_config\": {\"value\": []}, \"role_data, step_config\": {\"value\": []}, \"role_data, container_config_scripts\": {\"value\": []}, \"role_data, service_names\": {\"value\": []}, \"role_data, config_settings\": {\"value\": []}, \"role_data\": {\"value\": []}, \"role_data, service_name\": {\"value\": []}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(38,'2026-06-10 07:46:44',NULL,'{\"heat_template_version\": \"2015-04-30\", \"outputs\": {\"internal_api_ip_address\": {\"value\": []}, \"hostname\": {\"value\": []}, \"ansible_host_vars_map\": {\"value\": []}, \"hosts_entry\": {\"value\": []}, \"hostname_map\": {\"value\": []}, \"storage_ip_address\": {\"value\": []}, \"blacklist_ip_address\": {\"value\": []}, \"storage_mgmt_ip_address\": {\"value\": []}, \"attributes, nova_server_resource\": {\"value\": {}}, \"blacklist_hostname\": {\"value\": []}, \"ip_address\": {\"value\": []}, \"nova_server_resource\": {\"value\": []}, \"refs_map\": {\"value\": {}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(39,'2026-06-10 07:46:45',NULL,'{\"heat_template_version\": \"2015-04-30\", \"outputs\": {\"internal_api_ip_address\": {\"value\": []}, \"hostname\": {\"value\": []}, \"ansible_host_vars_map\": {\"value\": []}, \"hosts_entry\": {\"value\": []}, \"hostname_map\": {\"value\": []}, \"tenant_ip_address\": {\"value\": []}, \"storage_ip_address\": {\"value\": []}, \"blacklist_ip_address\": {\"value\": []}, \"storage_mgmt_ip_address\": {\"value\": []}, \"attributes, nova_server_resource\": {\"value\": {}}, \"blacklist_hostname\": {\"value\": []}, \"ip_address\": {\"value\": []}, \"nova_server_resource\": {\"value\": []}, \"refs_map\": {\"value\": {}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(40,'2026-06-10 07:46:45',NULL,'{\"heat_template_version\": \"2015-04-30\", \"outputs\": {\"internal_api_ip_address\": {\"value\": []}, \"hostname\": {\"value\": []}, \"ansible_host_vars_map\": {\"value\": []}, \"hosts_entry\": {\"value\": []}, \"hostname_map\": {\"value\": []}, \"storage_ip_address\": {\"value\": []}, \"blacklist_ip_address\": {\"value\": []}, \"storage_mgmt_ip_address\": {\"value\": []}, \"attributes, nova_server_resource\": {\"value\": {}}, \"blacklist_hostname\": {\"value\": []}, \"ip_address\": {\"value\": []}, \"nova_server_resource\": {\"value\": []}, \"refs_map\": {\"value\": {}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(41,'2026-06-10 07:46:45',NULL,'{\"heat_template_version\": \"2015-04-30\", \"outputs\": {\"hostname\": {\"value\": []}, \"ansible_host_vars_map\": {\"value\": []}, \"hosts_entry\": {\"value\": []}, \"hostname_map\": {\"value\": []}, \"storage_ip_address\": {\"value\": []}, \"blacklist_ip_address\": {\"value\": []}, \"storage_mgmt_ip_address\": {\"value\": []}, \"attributes, nova_server_resource\": {\"value\": {}}, \"blacklist_hostname\": {\"value\": []}, \"ip_address\": {\"value\": []}, \"nova_server_resource\": {\"value\": []}, \"refs_map\": {\"value\": {}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(42,'2026-06-10 07:46:45',NULL,'{\"heat_template_version\": \"2015-04-30\", \"outputs\": {\"hostname\": {\"value\": []}, \"ansible_host_vars_map\": {\"value\": []}, \"hosts_entry\": {\"value\": []}, \"hostname_map\": {\"value\": []}, \"tenant_ip_address\": {\"value\": []}, \"blacklist_ip_address\": {\"value\": []}, \"internal_api_ip_address\": {\"value\": []}, \"attributes, nova_server_resource\": {\"value\": {}}, \"blacklist_hostname\": {\"value\": []}, \"ip_address\": {\"value\": []}, \"nova_server_resource\": {\"value\": []}, \"refs_map\": {\"value\": {}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(43,'2026-06-10 07:46:45',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Ceilometer Agent Central service\\n\", \"parameters\": {\"ContainerCeilometerCentralImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\"}, \"ContainerCeilometerConfigImage\": {\"description\": \"The container image to use for the ceilometer config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\"}, \"CeilometerAgentCentralLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.ceilometer.agent.central\", \"file\": \"/var/log/containers/ceilometer/central.log\"}}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"RedisPassword\": {\"description\": \"The password for the redis service account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"PeixZYMWlure0PQXGfRipmgn4\"}, \"MonitoringSubscriptionCeilometerCentral\": {\"default\": \"overcloud-ceilometer-agent-central\", \"type\": \"string\"}, \"CeilometerEnableGnocchi\": {\"default\": false, \"description\": \"Whether to enable gnocchi usage.\", \"type\": \"boolean\"}, \"CeilometerPassword\": {\"description\": \"The password for the ceilometer service account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\"}, \"CeilometerEnableTenantDiscovery\": {\"default\": false, \"description\": \"Identify user and project names from polled metrics.\", \"type\": \"boolean\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml\"}, \"CeilometerServiceBase\": {\"type\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-base-container-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerCeilometerCentralImage\": \"ContainerCeilometerCentralImage\", \"ContainerCeilometerConfigImage\": \"ContainerCeilometerConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerCeilometerCentralImage\": {\"get_param\": \"ContainerCeilometerCentralImage\"}, \"ContainerCeilometerConfigImage\": {\"get_param\": \"ContainerCeilometerConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Ceilometer Agent Central role.\", \"value\": {\"service_name\": \"ceilometer_agent_central\", \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionCeilometerCentral\"}, \"keystone_resources\": {\"ceilometer\": {\"users\": {\"ceilometer\": {\"password\": {\"get_param\": \"CeilometerPassword\"}, \"roles\": [\"admin\", \"ResellerAdmin\"]}}, \"roles\": [\"ResellerAdmin\"]}}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"CeilometerServiceBase\", \"role_data\", \"config_settings\"]}, {\"ceilometer_redis_password\": {\"get_param\": \"RedisPassword\"}, \"central_namespace\": true, \"ceilometer::agent::polling::tenant_name_discovery\": {\"get_param\": \"CeilometerEnableTenantDiscovery\"}}]}, \"service_config_settings\": {\"map_merge\": [{\"get_attr\": [\"CeilometerServiceBase\", \"role_data\", \"service_config_settings\"]}, {\"rsyslog\": {\"tripleo_logging_sources_ceilometer_agent_central\": [{\"get_param\": \"CeilometerAgentCentralLoggingSource\"}]}}]}, \"puppet_config\": {\"config_volume\": \"ceilometer\", \"puppet_tags\": \"ceilometer_config\", \"step_config\": \"include tripleo::profile::base::ceilometer::agent::polling\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCeilometerConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/ceilometer_agent_central.json\": {\"command\": \"/usr/bin/ceilometer-polling --polling-namespaces central --logfile /var/log/ceilometer/central.log\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]}, \"/var/lib/kolla/config_files/ceilometer_agent_gnocchi_upgrade.json\": {\"command\": \"/usr/bin/bootstrap_host_exec ceilometer_agent_central su ceilometer -s /bin/bash -c \'for n in {1..10}; do /usr/bin/ceilometer-upgrade && exit 0 || sleep 30; done; exit 1\'\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]}}, \"docker_config\": {\"step_3\": {\"ceilometer_init_log\": {\"start_order\": 0, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCeilometerCentralImage\"]}, \"net\": \"none\", \"user\": \"root\", \"command\": [\"/bin/bash\", \"-c\", \"chown -R ceilometer:ceilometer /var/log/ceilometer\"], \"volumes\": [\"/var/log/containers/ceilometer:/var/log/ceilometer:z\"]}}, \"step_4\": {\"ceilometer_agent_central\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCeilometerCentralImage\"]}, \"net\": \"host\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/ceilometer_agent_central.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/ceilometer:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/ceilometer:/var/log/ceilometer:z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}, \"step_5\": {\"if\": [{\"get_param\": \"CeilometerEnableGnocchi\"}, {\"ceilometer_gnocchi_upgrade\": {\"start_order\": 99, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCeilometerCentralImage\"]}, \"net\": \"host\", \"detach\": false, \"privileged\": false, \"user\": \"root\", \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/ceilometer_agent_gnocchi_upgrade.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/ceilometer:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/ceilometer:/var/log/ceilometer:z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}]}}, \"host_prep_tasks\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/ceilometer\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}], \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop ceilometer agent central container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"ceilometer_agent_central\"], \"tripleo_delegate_to\": \"{{ groups[\'ceilometer_agent_central\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(44,'2026-06-10 07:46:46',NULL,'{\"heat_template_version\": \"2015-04-30\", \"outputs\": {\"internal_api_ip_address\": {\"value\": []}, \"hostname\": {\"value\": []}, \"ansible_host_vars_map\": {\"value\": []}, \"hosts_entry\": {\"value\": []}, \"hostname_map\": {\"value\": []}, \"tenant_ip_address\": {\"value\": []}, \"storage_ip_address\": {\"value\": []}, \"blacklist_ip_address\": {\"value\": []}, \"storage_mgmt_ip_address\": {\"value\": []}, \"attributes, nova_server_resource\": {\"value\": {}}, \"blacklist_hostname\": {\"value\": []}, \"ip_address\": {\"value\": []}, \"nova_server_resource\": {\"value\": []}, \"refs_map\": {\"value\": {}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (45,'2026-06-10 07:46:46',NULL,'{\"heat_template_version\": \"2015-04-30\", \"outputs\": {\"hostname\": {\"value\": []}, \"ansible_host_vars_map\": {\"value\": []}, \"hosts_entry\": {\"value\": []}, \"hostname_map\": {\"value\": []}, \"tenant_ip_address\": {\"value\": []}, \"storage_ip_address\": {\"value\": []}, \"blacklist_ip_address\": {\"value\": []}, \"internal_api_ip_address\": {\"value\": []}, \"attributes, nova_server_resource\": {\"value\": {}}, \"blacklist_hostname\": {\"value\": []}, \"ip_address\": {\"value\": []}, \"nova_server_resource\": {\"value\": []}, \"refs_map\": {\"value\": {}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(46,'2026-06-10 07:46:46',NULL,'{\"heat_template_version\": \"wallaby\", \"parameters\": {\"ControlPlaneIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageNetName\": {\"default\": \"storage\", \"description\": \"The name of the storage network.\", \"type\": \"string\"}, \"StorageMgmtIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageMgmtNetName\": {\"default\": \"storage_mgmt\", \"description\": \"The name of the storage_mgmt network.\", \"type\": \"string\"}, \"InternalApiIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"InternalApiNetName\": {\"default\": \"internal_api\", \"description\": \"The name of the internal_api network.\", \"type\": \"string\"}, \"TenantIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"TenantNetName\": {\"default\": \"tenant\", \"description\": \"The name of the tenant network.\", \"type\": \"string\"}, \"ExternalIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ExternalNetName\": {\"default\": \"external\", \"description\": \"The name of the external network.\", \"type\": \"string\"}, \"EnabledServices\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"type\": \"json\"}, \"ServiceHostnameList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"NetworkHostnameMap\": {\"default\": [], \"type\": \"json\"}, \"NovaAdditionalCell\": {\"default\": false, \"description\": \"Whether this is an cell additional to the default cell.\", \"type\": \"boolean\"}, \"RoleNetworks\": {\"default\": \"ctlplane\", \"type\": \"comma_delimited_list\"}}, \"conditions\": {\"is_cell\": {\"equals\": [{\"get_param\": \"NovaAdditionalCell\"}, true]}}, \"resources\": {\"EnabledServicesValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> $.data.extra_services.items().where($[0] in $root.data.enabled_services).select($[1]).flatten() + $root.data.enabled_services\", \"data\": {\"enabled_services\": {\"get_param\": \"EnabledServices\"}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"NetIpMapValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"yaql\": {\"expression\": \"let(root => $) -> dict($.data.net_ip_map.items().where($[0] in $root.data.role_networks))\", \"data\": {\"role_networks\": {\"get_param\": \"RoleNetworks\"}, \"net_ip_map\": {\"ctlplane\": {\"get_param\": \"ControlPlaneIpList\"}, \"storage\": {\"get_param\": \"StorageIpList\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtIpList\"}, \"internal_api\": {\"get_param\": \"InternalApiIpList\"}, \"tenant\": {\"get_param\": \"TenantIpList\"}, \"external\": {\"get_param\": \"ExternalIpList\"}}}}}, {\"keys\": {\"ctlplane\": \"ctlplane\", \"storage\": {\"get_param\": \"StorageNetName\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtNetName\"}, \"internal_api\": {\"get_param\": \"InternalApiNetName\"}, \"tenant\": {\"get_param\": \"TenantNetName\"}, \"external\": {\"get_param\": \"ExternalNetName\"}}}]}}}}, \"outputs\": {\"net_ip_map\": {\"description\": \"A Hash containing a mapping of network names to assigned lists of IP addresses.\\n\", \"value\": {\"get_attr\": [\"NetIpMapValue\", \"value\"]}}, \"ctlplane_service_ips\": {\"description\": \"Map of enabled services to a list of their ctlplane IP addresses\\n\", \"value\": {\"map_merge\": {\"repeat\": {\"template\": {\"SERVICE_ctlplane_node_ips\": \"$$ groups[\'SERVICE\'] | default ([]) | map(\'extract\', hostvars, \'ctlplane_ip\') | list | to_json $$\"}, \"for_each\": {\"SERVICE\": {\"get_attr\": [\"EnabledServicesValue\", \"value\"]}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ControlPlaneIpList\": \"\", \"StorageIpList\": \"\", \"StorageMgmtIpList\": \"\", \"InternalApiIpList\": \"\", \"EnabledServices\": \"\", \"ServiceNetMap\": {\"apache_network\": \"internal_api\", \"neutron_tenant_network\": \"tenant\", \"aodh_api_network\": \"internal_api\", \"barbican_api_network\": \"internal_api\", \"gnocchi_api_network\": \"internal_api\", \"mongodb_network\": \"internal_api\", \"cinder_api_network\": \"internal_api\", \"cinder_iscsi_network\": \"storage\", \"glance_api_network\": \"internal_api\", \"glance_api_edge_network\": \"internal_api\", \"glance_api_internal_network\": \"internal_api\", \"ironic_api_network\": \"ctlplane\", \"ironic_network\": \"ctlplane\", \"ironic_inspector_network\": \"ctlplane\", \"keystone_admin_api_network\": \"ctlplane\", \"keystone_public_api_network\": \"internal_api\", \"manila_api_network\": \"internal_api\", \"neutron_api_network\": \"internal_api\", \"octavia_api_network\": \"internal_api\", \"heat_api_network\": \"internal_api\", \"heat_api_cfn_network\": \"internal_api\", \"heat_api_cloudwatch_network\": \"internal_api\", \"nova_api_network\": \"internal_api\", \"placement_network\": \"internal_api\", \"nova_metadata_network\": \"internal_api\", \"nova_libvirt_network\": \"internal_api\", \"novajoin_network\": \"internal_api\", \"swift_storage_network\": \"storage_mgmt\", \"swift_proxy_network\": \"storage\", \"horizon_network\": \"internal_api\", \"memcached_network\": \"internal_api\", \"oslo_messaging_rpc_network\": \"internal_api\", \"oslo_messaging_notify_network\": \"internal_api\", \"rabbitmq_network\": \"internal_api\", \"rabbitmq_management_network\": \"internal_api\", \"qdr_network\": \"internal_api\", \"redis_network\": \"internal_api\", \"ganesha_network\": \"external\", \"mysql_network\": \"internal_api\", \"snmpd_network\": \"ctlplane\", \"ceph_cluster_network\": \"storage_mgmt\", \"ceph_dashboard_network\": \"ctlplane\", \"ceph_grafana_network\": \"storage\", \"ceph_mon_network\": \"storage\", \"ceph_rgw_network\": \"storage\", \"public_network\": \"external\", \"internal_api_network\": \"internal_api\", \"opendaylight_api_network\": \"internal_api\", \"ovn_dbs_network\": \"internal_api\", \"docker_registry_network\": \"ctlplane\", \"pacemaker_network\": \"internal_api\", \"pacemaker_remote_network\": \"internal_api\", \"designate_api_network\": \"internal_api\", \"designate_mdns_network\": \"internal_api\", \"designate_worker_network\": \"external\", \"designate_bind_network\": \"external\", \"bindnetwork\": \"external\", \"etcd_network\": \"internal_api\", \"haproxy_network\": \"ctlplane\", \"unbound_network\": \"external\", \"controller_hostname_resolve_network\": \"internal_api\", \"controller_metrics_qdr_network\": \"internal_api\", \"cell_controller_hostname_resolve_network\": \"internal_api\", \"cell_controller_metrics_qdr_network\": \"internal_api\", \"cell_controller_compute_hostname_resolve_network\": \"internal_api\", \"cell_controller_compute_metrics_qdr_network\": \"internal_api\", \"compute_hostname_resolve_network\": \"internal_api\", \"compute_metrics_qdr_network\": \"internal_api\", \"block_storage_hostname_resolve_network\": \"internal_api\", \"block_storage_metrics_qdr_network\": \"internal_api\", \"object_storage_hostname_resolve_network\": \"internal_api\", \"object_storage_metrics_qdr_network\": \"internal_api\", \"ceph_storage_hostname_resolve_network\": \"storage\", \"ceph_storage_metrics_qdr_network\": \"storage\", \"networker_hostname_resolve_network\": \"internal_api\", \"networker_metrics_qdr_network\": \"internal_api\", \"nova_vnc_proxy_network\": \"internal_api\"}, \"ServiceHostnameList\": \"\", \"NetworkHostnameMap\": {}, \"RoleNetworks\": \"ctlplane,storage,storage_mgmt,internal_api\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(47,'2026-06-10 07:46:46',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"HAproxy service configured with Puppet\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"CAMap\": {\"description\": \"Map containing the CA certs and information needed for deploying them.\\n\", \"default\": {}, \"type\": \"json\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for injecting CA certificates.\", \"value\": {\"service_name\": \"ca_certs\", \"config_settings\": {\"tripleo::trusted_cas::ca_map\": {\"get_param\": \"CAMap\"}}, \"step_config\": \"include tripleo::trusted_cas\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(48,'2026-06-10 07:46:46',NULL,'{\"heat_template_version\": \"wallaby\", \"parameters\": {\"ControlPlaneIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageNetName\": {\"default\": \"storage\", \"description\": \"The name of the storage network.\", \"type\": \"string\"}, \"StorageMgmtIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageMgmtNetName\": {\"default\": \"storage_mgmt\", \"description\": \"The name of the storage_mgmt network.\", \"type\": \"string\"}, \"InternalApiIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"InternalApiNetName\": {\"default\": \"internal_api\", \"description\": \"The name of the internal_api network.\", \"type\": \"string\"}, \"TenantIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"TenantNetName\": {\"default\": \"tenant\", \"description\": \"The name of the tenant network.\", \"type\": \"string\"}, \"ExternalIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ExternalNetName\": {\"default\": \"external\", \"description\": \"The name of the external network.\", \"type\": \"string\"}, \"EnabledServices\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"type\": \"json\"}, \"ServiceHostnameList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"NetworkHostnameMap\": {\"default\": [], \"type\": \"json\"}, \"NovaAdditionalCell\": {\"default\": false, \"description\": \"Whether this is an cell additional to the default cell.\", \"type\": \"boolean\"}, \"RoleNetworks\": {\"default\": \"ctlplane\", \"type\": \"comma_delimited_list\"}}, \"conditions\": {\"is_cell\": {\"equals\": [{\"get_param\": \"NovaAdditionalCell\"}, true]}}, \"resources\": {\"EnabledServicesValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> $.data.extra_services.items().where($[0] in $root.data.enabled_services).select($[1]).flatten() + $root.data.enabled_services\", \"data\": {\"enabled_services\": {\"get_param\": \"EnabledServices\"}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"NetIpMapValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"yaql\": {\"expression\": \"let(root => $) -> dict($.data.net_ip_map.items().where($[0] in $root.data.role_networks))\", \"data\": {\"role_networks\": {\"get_param\": \"RoleNetworks\"}, \"net_ip_map\": {\"ctlplane\": {\"get_param\": \"ControlPlaneIpList\"}, \"storage\": {\"get_param\": \"StorageIpList\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtIpList\"}, \"internal_api\": {\"get_param\": \"InternalApiIpList\"}, \"tenant\": {\"get_param\": \"TenantIpList\"}, \"external\": {\"get_param\": \"ExternalIpList\"}}}}}, {\"keys\": {\"ctlplane\": \"ctlplane\", \"storage\": {\"get_param\": \"StorageNetName\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtNetName\"}, \"internal_api\": {\"get_param\": \"InternalApiNetName\"}, \"tenant\": {\"get_param\": \"TenantNetName\"}, \"external\": {\"get_param\": \"ExternalNetName\"}}}]}}}}, \"outputs\": {\"net_ip_map\": {\"description\": \"A Hash containing a mapping of network names to assigned lists of IP addresses.\\n\", \"value\": {\"get_attr\": [\"NetIpMapValue\", \"value\"]}}, \"ctlplane_service_ips\": {\"description\": \"Map of enabled services to a list of their ctlplane IP addresses\\n\", \"value\": {\"map_merge\": {\"repeat\": {\"template\": {\"SERVICE_ctlplane_node_ips\": \"$$ groups[\'SERVICE\'] | default ([]) | map(\'extract\', hostvars, \'ctlplane_ip\') | list | to_json $$\"}, \"for_each\": {\"SERVICE\": {\"get_attr\": [\"EnabledServicesValue\", \"value\"]}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ControlPlaneIpList\": \"\", \"StorageIpList\": \"\", \"StorageMgmtIpList\": \"\", \"InternalApiIpList\": \"\", \"EnabledServices\": \"\", \"ServiceNetMap\": {\"apache_network\": \"internal_api\", \"neutron_tenant_network\": \"tenant\", \"aodh_api_network\": \"internal_api\", \"barbican_api_network\": \"internal_api\", \"gnocchi_api_network\": \"internal_api\", \"mongodb_network\": \"internal_api\", \"cinder_api_network\": \"internal_api\", \"cinder_iscsi_network\": \"storage\", \"glance_api_network\": \"internal_api\", \"glance_api_edge_network\": \"internal_api\", \"glance_api_internal_network\": \"internal_api\", \"ironic_api_network\": \"ctlplane\", \"ironic_network\": \"ctlplane\", \"ironic_inspector_network\": \"ctlplane\", \"keystone_admin_api_network\": \"ctlplane\", \"keystone_public_api_network\": \"internal_api\", \"manila_api_network\": \"internal_api\", \"neutron_api_network\": \"internal_api\", \"octavia_api_network\": \"internal_api\", \"heat_api_network\": \"internal_api\", \"heat_api_cfn_network\": \"internal_api\", \"heat_api_cloudwatch_network\": \"internal_api\", \"nova_api_network\": \"internal_api\", \"placement_network\": \"internal_api\", \"nova_metadata_network\": \"internal_api\", \"nova_libvirt_network\": \"internal_api\", \"novajoin_network\": \"internal_api\", \"swift_storage_network\": \"storage_mgmt\", \"swift_proxy_network\": \"storage\", \"horizon_network\": \"internal_api\", \"memcached_network\": \"internal_api\", \"oslo_messaging_rpc_network\": \"internal_api\", \"oslo_messaging_notify_network\": \"internal_api\", \"rabbitmq_network\": \"internal_api\", \"rabbitmq_management_network\": \"internal_api\", \"qdr_network\": \"internal_api\", \"redis_network\": \"internal_api\", \"ganesha_network\": \"external\", \"mysql_network\": \"internal_api\", \"snmpd_network\": \"ctlplane\", \"ceph_cluster_network\": \"storage_mgmt\", \"ceph_dashboard_network\": \"ctlplane\", \"ceph_grafana_network\": \"storage\", \"ceph_mon_network\": \"storage\", \"ceph_rgw_network\": \"storage\", \"public_network\": \"external\", \"internal_api_network\": \"internal_api\", \"opendaylight_api_network\": \"internal_api\", \"ovn_dbs_network\": \"internal_api\", \"docker_registry_network\": \"ctlplane\", \"pacemaker_network\": \"internal_api\", \"pacemaker_remote_network\": \"internal_api\", \"designate_api_network\": \"internal_api\", \"designate_mdns_network\": \"internal_api\", \"designate_worker_network\": \"external\", \"designate_bind_network\": \"external\", \"bindnetwork\": \"external\", \"etcd_network\": \"internal_api\", \"haproxy_network\": \"ctlplane\", \"unbound_network\": \"external\", \"controller_hostname_resolve_network\": \"internal_api\", \"controller_metrics_qdr_network\": \"internal_api\", \"cell_controller_hostname_resolve_network\": \"internal_api\", \"cell_controller_metrics_qdr_network\": \"internal_api\", \"cell_controller_compute_hostname_resolve_network\": \"internal_api\", \"cell_controller_compute_metrics_qdr_network\": \"internal_api\", \"compute_hostname_resolve_network\": \"internal_api\", \"compute_metrics_qdr_network\": \"internal_api\", \"block_storage_hostname_resolve_network\": \"internal_api\", \"block_storage_metrics_qdr_network\": \"internal_api\", \"object_storage_hostname_resolve_network\": \"internal_api\", \"object_storage_metrics_qdr_network\": \"internal_api\", \"ceph_storage_hostname_resolve_network\": \"storage\", \"ceph_storage_metrics_qdr_network\": \"storage\", \"networker_hostname_resolve_network\": \"internal_api\", \"networker_metrics_qdr_network\": \"internal_api\", \"nova_vnc_proxy_network\": \"internal_api\"}, \"ServiceHostnameList\": \"\", \"NetworkHostnameMap\": {}, \"RoleNetworks\": \"ctlplane,storage,storage_mgmt,internal_api\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(49,'2026-06-10 07:46:46',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(50,'2026-06-10 07:46:47',NULL,'{\"heat_template_version\": \"wallaby\", \"parameters\": {\"ControlPlaneIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageNetName\": {\"default\": \"storage\", \"description\": \"The name of the storage network.\", \"type\": \"string\"}, \"StorageMgmtIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageMgmtNetName\": {\"default\": \"storage_mgmt\", \"description\": \"The name of the storage_mgmt network.\", \"type\": \"string\"}, \"InternalApiIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"InternalApiNetName\": {\"default\": \"internal_api\", \"description\": \"The name of the internal_api network.\", \"type\": \"string\"}, \"TenantIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"TenantNetName\": {\"default\": \"tenant\", \"description\": \"The name of the tenant network.\", \"type\": \"string\"}, \"ExternalIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ExternalNetName\": {\"default\": \"external\", \"description\": \"The name of the external network.\", \"type\": \"string\"}, \"EnabledServices\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"type\": \"json\"}, \"ServiceHostnameList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"NetworkHostnameMap\": {\"default\": [], \"type\": \"json\"}, \"NovaAdditionalCell\": {\"default\": false, \"description\": \"Whether this is an cell additional to the default cell.\", \"type\": \"boolean\"}, \"RoleNetworks\": {\"default\": \"ctlplane\", \"type\": \"comma_delimited_list\"}}, \"conditions\": {\"is_cell\": {\"equals\": [{\"get_param\": \"NovaAdditionalCell\"}, true]}}, \"resources\": {\"EnabledServicesValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> $.data.extra_services.items().where($[0] in $root.data.enabled_services).select($[1]).flatten() + $root.data.enabled_services\", \"data\": {\"enabled_services\": {\"get_param\": \"EnabledServices\"}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"NetIpMapValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"yaql\": {\"expression\": \"let(root => $) -> dict($.data.net_ip_map.items().where($[0] in $root.data.role_networks))\", \"data\": {\"role_networks\": {\"get_param\": \"RoleNetworks\"}, \"net_ip_map\": {\"ctlplane\": {\"get_param\": \"ControlPlaneIpList\"}, \"storage\": {\"get_param\": \"StorageIpList\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtIpList\"}, \"internal_api\": {\"get_param\": \"InternalApiIpList\"}, \"tenant\": {\"get_param\": \"TenantIpList\"}, \"external\": {\"get_param\": \"ExternalIpList\"}}}}}, {\"keys\": {\"ctlplane\": \"ctlplane\", \"storage\": {\"get_param\": \"StorageNetName\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtNetName\"}, \"internal_api\": {\"get_param\": \"InternalApiNetName\"}, \"tenant\": {\"get_param\": \"TenantNetName\"}, \"external\": {\"get_param\": \"ExternalNetName\"}}}]}}}}, \"outputs\": {\"net_ip_map\": {\"description\": \"A Hash containing a mapping of network names to assigned lists of IP addresses.\\n\", \"value\": {\"get_attr\": [\"NetIpMapValue\", \"value\"]}}, \"ctlplane_service_ips\": {\"description\": \"Map of enabled services to a list of their ctlplane IP addresses\\n\", \"value\": {\"map_merge\": {\"repeat\": {\"template\": {\"SERVICE_ctlplane_node_ips\": \"$$ groups[\'SERVICE\'] | default ([]) | map(\'extract\', hostvars, \'ctlplane_ip\') | list | to_json $$\"}, \"for_each\": {\"SERVICE\": {\"get_attr\": [\"EnabledServicesValue\", \"value\"]}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ControlPlaneIpList\": \"\", \"StorageIpList\": \"\", \"StorageMgmtIpList\": \"\", \"InternalApiIpList\": \"\", \"TenantIpList\": \"\", \"EnabledServices\": \"\", \"ServiceNetMap\": {\"apache_network\": \"internal_api\", \"neutron_tenant_network\": \"tenant\", \"aodh_api_network\": \"internal_api\", \"barbican_api_network\": \"internal_api\", \"gnocchi_api_network\": \"internal_api\", \"mongodb_network\": \"internal_api\", \"cinder_api_network\": \"internal_api\", \"cinder_iscsi_network\": \"storage\", \"glance_api_network\": \"internal_api\", \"glance_api_edge_network\": \"internal_api\", \"glance_api_internal_network\": \"internal_api\", \"ironic_api_network\": \"ctlplane\", \"ironic_network\": \"ctlplane\", \"ironic_inspector_network\": \"ctlplane\", \"keystone_admin_api_network\": \"ctlplane\", \"keystone_public_api_network\": \"internal_api\", \"manila_api_network\": \"internal_api\", \"neutron_api_network\": \"internal_api\", \"octavia_api_network\": \"internal_api\", \"heat_api_network\": \"internal_api\", \"heat_api_cfn_network\": \"internal_api\", \"heat_api_cloudwatch_network\": \"internal_api\", \"nova_api_network\": \"internal_api\", \"placement_network\": \"internal_api\", \"nova_metadata_network\": \"internal_api\", \"nova_libvirt_network\": \"internal_api\", \"novajoin_network\": \"internal_api\", \"swift_storage_network\": \"storage_mgmt\", \"swift_proxy_network\": \"storage\", \"horizon_network\": \"internal_api\", \"memcached_network\": \"internal_api\", \"oslo_messaging_rpc_network\": \"internal_api\", \"oslo_messaging_notify_network\": \"internal_api\", \"rabbitmq_network\": \"internal_api\", \"rabbitmq_management_network\": \"internal_api\", \"qdr_network\": \"internal_api\", \"redis_network\": \"internal_api\", \"ganesha_network\": \"external\", \"mysql_network\": \"internal_api\", \"snmpd_network\": \"ctlplane\", \"ceph_cluster_network\": \"storage_mgmt\", \"ceph_dashboard_network\": \"ctlplane\", \"ceph_grafana_network\": \"storage\", \"ceph_mon_network\": \"storage\", \"ceph_rgw_network\": \"storage\", \"public_network\": \"external\", \"internal_api_network\": \"internal_api\", \"opendaylight_api_network\": \"internal_api\", \"ovn_dbs_network\": \"internal_api\", \"docker_registry_network\": \"ctlplane\", \"pacemaker_network\": \"internal_api\", \"pacemaker_remote_network\": \"internal_api\", \"designate_api_network\": \"internal_api\", \"designate_mdns_network\": \"internal_api\", \"designate_worker_network\": \"external\", \"designate_bind_network\": \"external\", \"bindnetwork\": \"external\", \"etcd_network\": \"internal_api\", \"haproxy_network\": \"ctlplane\", \"unbound_network\": \"external\", \"controller_hostname_resolve_network\": \"internal_api\", \"controller_metrics_qdr_network\": \"internal_api\", \"cell_controller_hostname_resolve_network\": \"internal_api\", \"cell_controller_metrics_qdr_network\": \"internal_api\", \"cell_controller_compute_hostname_resolve_network\": \"internal_api\", \"cell_controller_compute_metrics_qdr_network\": \"internal_api\", \"compute_hostname_resolve_network\": \"internal_api\", \"compute_metrics_qdr_network\": \"internal_api\", \"block_storage_hostname_resolve_network\": \"internal_api\", \"block_storage_metrics_qdr_network\": \"internal_api\", \"object_storage_hostname_resolve_network\": \"internal_api\", \"object_storage_metrics_qdr_network\": \"internal_api\", \"ceph_storage_hostname_resolve_network\": \"storage\", \"ceph_storage_metrics_qdr_network\": \"storage\", \"networker_hostname_resolve_network\": \"internal_api\", \"networker_metrics_qdr_network\": \"internal_api\", \"nova_vnc_proxy_network\": \"internal_api\"}, \"ServiceHostnameList\": \"\", \"NetworkHostnameMap\": {}, \"RoleNetworks\": \"ctlplane,storage,storage_mgmt,internal_api,tenant\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(51,'2026-06-10 07:46:47',NULL,'{\"heat_template_version\": \"wallaby\", \"parameters\": {\"ControlPlaneIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageNetName\": {\"default\": \"storage\", \"description\": \"The name of the storage network.\", \"type\": \"string\"}, \"StorageMgmtIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageMgmtNetName\": {\"default\": \"storage_mgmt\", \"description\": \"The name of the storage_mgmt network.\", \"type\": \"string\"}, \"InternalApiIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"InternalApiNetName\": {\"default\": \"internal_api\", \"description\": \"The name of the internal_api network.\", \"type\": \"string\"}, \"TenantIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"TenantNetName\": {\"default\": \"tenant\", \"description\": \"The name of the tenant network.\", \"type\": \"string\"}, \"ExternalIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ExternalNetName\": {\"default\": \"external\", \"description\": \"The name of the external network.\", \"type\": \"string\"}, \"EnabledServices\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"type\": \"json\"}, \"ServiceHostnameList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"NetworkHostnameMap\": {\"default\": [], \"type\": \"json\"}, \"NovaAdditionalCell\": {\"default\": false, \"description\": \"Whether this is an cell additional to the default cell.\", \"type\": \"boolean\"}, \"RoleNetworks\": {\"default\": \"ctlplane\", \"type\": \"comma_delimited_list\"}}, \"conditions\": {\"is_cell\": {\"equals\": [{\"get_param\": \"NovaAdditionalCell\"}, true]}}, \"resources\": {\"EnabledServicesValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> $.data.extra_services.items().where($[0] in $root.data.enabled_services).select($[1]).flatten() + $root.data.enabled_services\", \"data\": {\"enabled_services\": {\"get_param\": \"EnabledServices\"}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"NetIpMapValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"yaql\": {\"expression\": \"let(root => $) -> dict($.data.net_ip_map.items().where($[0] in $root.data.role_networks))\", \"data\": {\"role_networks\": {\"get_param\": \"RoleNetworks\"}, \"net_ip_map\": {\"ctlplane\": {\"get_param\": \"ControlPlaneIpList\"}, \"storage\": {\"get_param\": \"StorageIpList\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtIpList\"}, \"internal_api\": {\"get_param\": \"InternalApiIpList\"}, \"tenant\": {\"get_param\": \"TenantIpList\"}, \"external\": {\"get_param\": \"ExternalIpList\"}}}}}, {\"keys\": {\"ctlplane\": \"ctlplane\", \"storage\": {\"get_param\": \"StorageNetName\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtNetName\"}, \"internal_api\": {\"get_param\": \"InternalApiNetName\"}, \"tenant\": {\"get_param\": \"TenantNetName\"}, \"external\": {\"get_param\": \"ExternalNetName\"}}}]}}}}, \"outputs\": {\"net_ip_map\": {\"description\": \"A Hash containing a mapping of network names to assigned lists of IP addresses.\\n\", \"value\": {\"get_attr\": [\"NetIpMapValue\", \"value\"]}}, \"ctlplane_service_ips\": {\"description\": \"Map of enabled services to a list of their ctlplane IP addresses\\n\", \"value\": {\"map_merge\": {\"repeat\": {\"template\": {\"SERVICE_ctlplane_node_ips\": \"$$ groups[\'SERVICE\'] | default ([]) | map(\'extract\', hostvars, \'ctlplane_ip\') | list | to_json $$\"}, \"for_each\": {\"SERVICE\": {\"get_attr\": [\"EnabledServicesValue\", \"value\"]}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ControlPlaneIpList\": \"\", \"InternalApiIpList\": \"\", \"TenantIpList\": \"\", \"EnabledServices\": \"\", \"ServiceNetMap\": {\"apache_network\": \"internal_api\", \"neutron_tenant_network\": \"tenant\", \"aodh_api_network\": \"internal_api\", \"barbican_api_network\": \"internal_api\", \"gnocchi_api_network\": \"internal_api\", \"mongodb_network\": \"internal_api\", \"cinder_api_network\": \"internal_api\", \"cinder_iscsi_network\": \"storage\", \"glance_api_network\": \"internal_api\", \"glance_api_edge_network\": \"internal_api\", \"glance_api_internal_network\": \"internal_api\", \"ironic_api_network\": \"ctlplane\", \"ironic_network\": \"ctlplane\", \"ironic_inspector_network\": \"ctlplane\", \"keystone_admin_api_network\": \"ctlplane\", \"keystone_public_api_network\": \"internal_api\", \"manila_api_network\": \"internal_api\", \"neutron_api_network\": \"internal_api\", \"octavia_api_network\": \"internal_api\", \"heat_api_network\": \"internal_api\", \"heat_api_cfn_network\": \"internal_api\", \"heat_api_cloudwatch_network\": \"internal_api\", \"nova_api_network\": \"internal_api\", \"placement_network\": \"internal_api\", \"nova_metadata_network\": \"internal_api\", \"nova_libvirt_network\": \"internal_api\", \"novajoin_network\": \"internal_api\", \"swift_storage_network\": \"storage_mgmt\", \"swift_proxy_network\": \"storage\", \"horizon_network\": \"internal_api\", \"memcached_network\": \"internal_api\", \"oslo_messaging_rpc_network\": \"internal_api\", \"oslo_messaging_notify_network\": \"internal_api\", \"rabbitmq_network\": \"internal_api\", \"rabbitmq_management_network\": \"internal_api\", \"qdr_network\": \"internal_api\", \"redis_network\": \"internal_api\", \"ganesha_network\": \"external\", \"mysql_network\": \"internal_api\", \"snmpd_network\": \"ctlplane\", \"ceph_cluster_network\": \"storage_mgmt\", \"ceph_dashboard_network\": \"ctlplane\", \"ceph_grafana_network\": \"storage\", \"ceph_mon_network\": \"storage\", \"ceph_rgw_network\": \"storage\", \"public_network\": \"external\", \"internal_api_network\": \"internal_api\", \"opendaylight_api_network\": \"internal_api\", \"ovn_dbs_network\": \"internal_api\", \"docker_registry_network\": \"ctlplane\", \"pacemaker_network\": \"internal_api\", \"pacemaker_remote_network\": \"internal_api\", \"designate_api_network\": \"internal_api\", \"designate_mdns_network\": \"internal_api\", \"designate_worker_network\": \"external\", \"designate_bind_network\": \"external\", \"bindnetwork\": \"external\", \"etcd_network\": \"internal_api\", \"haproxy_network\": \"ctlplane\", \"unbound_network\": \"external\", \"controller_hostname_resolve_network\": \"internal_api\", \"controller_metrics_qdr_network\": \"internal_api\", \"cell_controller_hostname_resolve_network\": \"internal_api\", \"cell_controller_metrics_qdr_network\": \"internal_api\", \"cell_controller_compute_hostname_resolve_network\": \"internal_api\", \"cell_controller_compute_metrics_qdr_network\": \"internal_api\", \"compute_hostname_resolve_network\": \"internal_api\", \"compute_metrics_qdr_network\": \"internal_api\", \"block_storage_hostname_resolve_network\": \"internal_api\", \"block_storage_metrics_qdr_network\": \"internal_api\", \"object_storage_hostname_resolve_network\": \"internal_api\", \"object_storage_metrics_qdr_network\": \"internal_api\", \"ceph_storage_hostname_resolve_network\": \"storage\", \"ceph_storage_metrics_qdr_network\": \"storage\", \"networker_hostname_resolve_network\": \"internal_api\", \"networker_metrics_qdr_network\": \"internal_api\", \"nova_vnc_proxy_network\": \"internal_api\"}, \"ServiceHostnameList\": \"\", \"NetworkHostnameMap\": {}, \"RoleNetworks\": \"ctlplane,internal_api,tenant\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(52,'2026-06-10 07:46:47',NULL,'{\"heat_template_version\": \"wallaby\", \"parameters\": {\"ControlPlaneIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageNetName\": {\"default\": \"storage\", \"description\": \"The name of the storage network.\", \"type\": \"string\"}, \"StorageMgmtIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageMgmtNetName\": {\"default\": \"storage_mgmt\", \"description\": \"The name of the storage_mgmt network.\", \"type\": \"string\"}, \"InternalApiIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"InternalApiNetName\": {\"default\": \"internal_api\", \"description\": \"The name of the internal_api network.\", \"type\": \"string\"}, \"TenantIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"TenantNetName\": {\"default\": \"tenant\", \"description\": \"The name of the tenant network.\", \"type\": \"string\"}, \"ExternalIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ExternalNetName\": {\"default\": \"external\", \"description\": \"The name of the external network.\", \"type\": \"string\"}, \"EnabledServices\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"type\": \"json\"}, \"ServiceHostnameList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"NetworkHostnameMap\": {\"default\": [], \"type\": \"json\"}, \"NovaAdditionalCell\": {\"default\": false, \"description\": \"Whether this is an cell additional to the default cell.\", \"type\": \"boolean\"}, \"RoleNetworks\": {\"default\": \"ctlplane\", \"type\": \"comma_delimited_list\"}}, \"conditions\": {\"is_cell\": {\"equals\": [{\"get_param\": \"NovaAdditionalCell\"}, true]}}, \"resources\": {\"EnabledServicesValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> $.data.extra_services.items().where($[0] in $root.data.enabled_services).select($[1]).flatten() + $root.data.enabled_services\", \"data\": {\"enabled_services\": {\"get_param\": \"EnabledServices\"}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"NetIpMapValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"yaql\": {\"expression\": \"let(root => $) -> dict($.data.net_ip_map.items().where($[0] in $root.data.role_networks))\", \"data\": {\"role_networks\": {\"get_param\": \"RoleNetworks\"}, \"net_ip_map\": {\"ctlplane\": {\"get_param\": \"ControlPlaneIpList\"}, \"storage\": {\"get_param\": \"StorageIpList\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtIpList\"}, \"internal_api\": {\"get_param\": \"InternalApiIpList\"}, \"tenant\": {\"get_param\": \"TenantIpList\"}, \"external\": {\"get_param\": \"ExternalIpList\"}}}}}, {\"keys\": {\"ctlplane\": \"ctlplane\", \"storage\": {\"get_param\": \"StorageNetName\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtNetName\"}, \"internal_api\": {\"get_param\": \"InternalApiNetName\"}, \"tenant\": {\"get_param\": \"TenantNetName\"}, \"external\": {\"get_param\": \"ExternalNetName\"}}}]}}}}, \"outputs\": {\"net_ip_map\": {\"description\": \"A Hash containing a mapping of network names to assigned lists of IP addresses.\\n\", \"value\": {\"get_attr\": [\"NetIpMapValue\", \"value\"]}}, \"ctlplane_service_ips\": {\"description\": \"Map of enabled services to a list of their ctlplane IP addresses\\n\", \"value\": {\"map_merge\": {\"repeat\": {\"template\": {\"SERVICE_ctlplane_node_ips\": \"$$ groups[\'SERVICE\'] | default ([]) | map(\'extract\', hostvars, \'ctlplane_ip\') | list | to_json $$\"}, \"for_each\": {\"SERVICE\": {\"get_attr\": [\"EnabledServicesValue\", \"value\"]}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ControlPlaneIpList\": \"\", \"StorageIpList\": \"\", \"StorageMgmtIpList\": \"\", \"EnabledServices\": \"\", \"ServiceNetMap\": {\"apache_network\": \"internal_api\", \"neutron_tenant_network\": \"tenant\", \"aodh_api_network\": \"internal_api\", \"barbican_api_network\": \"internal_api\", \"gnocchi_api_network\": \"internal_api\", \"mongodb_network\": \"internal_api\", \"cinder_api_network\": \"internal_api\", \"cinder_iscsi_network\": \"storage\", \"glance_api_network\": \"internal_api\", \"glance_api_edge_network\": \"internal_api\", \"glance_api_internal_network\": \"internal_api\", \"ironic_api_network\": \"ctlplane\", \"ironic_network\": \"ctlplane\", \"ironic_inspector_network\": \"ctlplane\", \"keystone_admin_api_network\": \"ctlplane\", \"keystone_public_api_network\": \"internal_api\", \"manila_api_network\": \"internal_api\", \"neutron_api_network\": \"internal_api\", \"octavia_api_network\": \"internal_api\", \"heat_api_network\": \"internal_api\", \"heat_api_cfn_network\": \"internal_api\", \"heat_api_cloudwatch_network\": \"internal_api\", \"nova_api_network\": \"internal_api\", \"placement_network\": \"internal_api\", \"nova_metadata_network\": \"internal_api\", \"nova_libvirt_network\": \"internal_api\", \"novajoin_network\": \"internal_api\", \"swift_storage_network\": \"storage_mgmt\", \"swift_proxy_network\": \"storage\", \"horizon_network\": \"internal_api\", \"memcached_network\": \"internal_api\", \"oslo_messaging_rpc_network\": \"internal_api\", \"oslo_messaging_notify_network\": \"internal_api\", \"rabbitmq_network\": \"internal_api\", \"rabbitmq_management_network\": \"internal_api\", \"qdr_network\": \"internal_api\", \"redis_network\": \"internal_api\", \"ganesha_network\": \"external\", \"mysql_network\": \"internal_api\", \"snmpd_network\": \"ctlplane\", \"ceph_cluster_network\": \"storage_mgmt\", \"ceph_dashboard_network\": \"ctlplane\", \"ceph_grafana_network\": \"storage\", \"ceph_mon_network\": \"storage\", \"ceph_rgw_network\": \"storage\", \"public_network\": \"external\", \"internal_api_network\": \"internal_api\", \"opendaylight_api_network\": \"internal_api\", \"ovn_dbs_network\": \"internal_api\", \"docker_registry_network\": \"ctlplane\", \"pacemaker_network\": \"internal_api\", \"pacemaker_remote_network\": \"internal_api\", \"designate_api_network\": \"internal_api\", \"designate_mdns_network\": \"internal_api\", \"designate_worker_network\": \"external\", \"designate_bind_network\": \"external\", \"bindnetwork\": \"external\", \"etcd_network\": \"internal_api\", \"haproxy_network\": \"ctlplane\", \"unbound_network\": \"external\", \"controller_hostname_resolve_network\": \"internal_api\", \"controller_metrics_qdr_network\": \"internal_api\", \"cell_controller_hostname_resolve_network\": \"internal_api\", \"cell_controller_metrics_qdr_network\": \"internal_api\", \"cell_controller_compute_hostname_resolve_network\": \"internal_api\", \"cell_controller_compute_metrics_qdr_network\": \"internal_api\", \"compute_hostname_resolve_network\": \"internal_api\", \"compute_metrics_qdr_network\": \"internal_api\", \"block_storage_hostname_resolve_network\": \"internal_api\", \"block_storage_metrics_qdr_network\": \"internal_api\", \"object_storage_hostname_resolve_network\": \"internal_api\", \"object_storage_metrics_qdr_network\": \"internal_api\", \"ceph_storage_hostname_resolve_network\": \"storage\", \"ceph_storage_metrics_qdr_network\": \"storage\", \"networker_hostname_resolve_network\": \"internal_api\", \"networker_metrics_qdr_network\": \"internal_api\", \"nova_vnc_proxy_network\": \"internal_api\"}, \"ServiceHostnameList\": \"\", \"NetworkHostnameMap\": {}, \"RoleNetworks\": \"ctlplane,storage,storage_mgmt\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(53,'2026-06-10 07:46:47',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Cinder Backup service\\n\", \"parameters\": {\"ContainerCinderBackupImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\"}, \"ContainerCinderConfigImage\": {\"description\": \"The container image to use for the cinder config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\"}, \"ClusterCommonTag\": {\"default\": false, \"description\": \"When set to false, a pacemaker service is configured to use a floating tag for its container image name, e.g. \'REGISTRY/NAMESPACE/IMAGENAME:pcmklatest\'. When set to true, the service uses a floating prefix as well, e.g. \'cluster.common.tag/IMAGENAME:pcmklatest\'.\", \"type\": \"boolean\"}, \"ClusterFullTag\": {\"default\": true, \"description\": \"When set to true, the pacemaker service uses a fully constant tag for its container image name, e.g. \'cluster.common.tag/SERVICENAME:pcmklatest\'.\", \"type\": \"boolean\"}, \"CinderBackupBackend\": {\"default\": \"swift\", \"description\": \"The short name of the Cinder Backup backend to use.\", \"type\": \"string\", \"constraints\": [{\"allowed_values\": [\"swift\", \"ceph\", \"nfs\", \"gcs\", \"s3\"]}]}, \"CinderBackupRbdPoolName\": {\"default\": \"backups\", \"type\": \"string\"}, \"CephClientUserName\": {\"default\": \"openstack\", \"type\": \"string\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ConfigDebug\": {\"default\": false, \"description\": \"Whether to run config management (e.g. Puppet) in debug mode.\", \"type\": \"boolean\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}, \"DeployIdentifier\": {\"default\": 1781077560, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}, \"DockerCinderBackupLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.cinder.backup\", \"file\": \"/var/log/containers/cinder/cinder-backup.log\"}}, \"CephConfigPath\": {\"type\": \"string\", \"default\": \"/var/lib/tripleo-config/ceph\", \"description\": \"The path where the Ceph Cluster config files are stored on the host.\\n\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MySQLClient\": {\"type\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-client.yaml\"}, \"CinderBackupBase\": {\"type\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-container-puppet.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}, \"CinderBackupBackend\": {\"get_param\": \"CinderBackupBackend\"}, \"CinderBackupRbdPoolName\": {\"get_param\": \"CinderBackupRbdPoolName\"}, \"CephClientUserName\": {\"get_param\": \"CephClientUserName\"}}}, \"CinderCommon\": {\"type\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerCinderBackupImage\": \"ContainerCinderBackupImage\", \"ContainerCinderConfigImage\": \"ContainerCinderConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerCinderBackupImage\": {\"get_param\": \"ContainerCinderBackupImage\"}, \"ContainerCinderConfigImage\": {\"get_param\": \"ContainerCinderConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Cinder Backup role.\", \"value\": {\"service_name\": \"cinder_backup\", \"monitoring_subscription\": {\"get_attr\": [\"CinderBackupBase\", \"role_data\", \"monitoring_subscription\"]}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"CinderBackupBase\", \"role_data\", \"config_settings\"]}, {\"tripleo::profile::pacemaker::cinder::backup_bundle::cinder_backup_docker_image\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/cinder-backup:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"tripleo::profile::pacemaker::cinder::backup_bundle::docker_volumes\": {\"get_attr\": [\"CinderCommon\", \"cinder_backup_volumes\"]}, \"tripleo::profile::pacemaker::cinder::backup_bundle::docker_environment\": {\"get_attr\": [\"CinderCommon\", \"cinder_backup_environment\"]}, \"tripleo::profile::pacemaker::cinder::backup_bundle::container_backend\": {\"get_param\": \"ContainerCli\"}, \"tripleo::profile::pacemaker::cinder::backup_bundle::ceph_conf_path\": {\"get_param\": \"CephConfigPath\"}, \"cinder::backup::manage_service\": false, \"cinder::backup::enabled\": false}]}, \"service_config_settings\": {\"get_attr\": [\"CinderBackupBase\", \"role_data\", \"service_config_settings\"]}, \"puppet_config\": {\"config_volume\": \"cinder\", \"puppet_tags\": \"cinder_config,file,concat,file_line\", \"step_config\": {\"list_join\": [\"\\n\", [{\"get_attr\": [\"CinderBackupBase\", \"role_data\", \"puppet_config\", \"step_config\"]}, \"include tripleo::profile::pacemaker::cinder::backup_bundle\"]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/cinder_backup.json\": {\"command\": \"/usr/bin/cinder-backup --config-file /usr/share/cinder/cinder-dist.conf --config-file /etc/cinder/cinder.conf\", \"config_files\": {\"get_attr\": [\"CinderCommon\", \"cinder_common_kolla_config_files\"]}, \"permissions\": {\"get_attr\": [\"CinderCommon\", \"cinder_common_kolla_permissions\"]}}}, \"container_config_scripts\": {\"get_attr\": [\"ContainersCommon\", \"container_config_scripts\"]}, \"docker_config\": {\"step_3\": {\"cinder_backup_init_logs\": {\"start_order\": 0, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}, \"net\": \"none\", \"privileged\": false, \"user\": \"root\", \"volumes\": [\"/var/log/containers/cinder:/var/log/cinder:z\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R cinder:cinder /var/log/cinder\"]}}}, \"host_prep_tasks\": {\"get_attr\": [\"CinderCommon\", \"cinder_backup_host_prep_tasks\"]}, \"deploy_steps_tasks\": [{\"name\": \"Cinder Backup tag container image for pacemaker\", \"when\": \"step|int == 1\", \"import_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}, \"container_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/cinder-backup:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}}}, {\"name\": \"Cinder Backup HA Wrappers Step\", \"when\": \"step|int == 5\", \"block\": [{\"name\": \"Cinder backup puppet bundle\", \"import_role\": {\"name\": \"tripleo_ha_wrapper\"}, \"vars\": {\"tripleo_ha_wrapper_service_name\": \"cinder_backup\", \"tripleo_ha_wrapper_resource_name\": \"openstack-cinder-backup\", \"tripleo_ha_wrapper_bundle_name\": \"openstack-cinder-backup\", \"tripleo_ha_wrapper_resource_state\": \"_ Started\", \"tripleo_ha_wrapper_puppet_config_volume\": \"cinder\", \"tripleo_ha_wrapper_puppet_execute\": \"include ::tripleo::profile::base::pacemaker; include ::tripleo::profile::pacemaker::cinder::backup_bundle\", \"tripleo_ha_wrapper_puppet_tags\": \"pacemaker::resource::bundle,pacemaker::property,pacemaker::resource::ip,pacemaker::resource::ocf,pacemaker::constraint::order,pacemaker::constraint::colocation\", \"tripleo_ha_wrapper_puppet_debug\": {\"get_param\": \"ConfigDebug\"}, \"tripleo_ha_wrapper_config_suffix\": \".cinder_backup_previous_run\"}}]}], \"external_update_tasks\": [{\"when\": \"step|int == 1\", \"tags\": \"ha_image_update\", \"block\": [{\"block\": [{\"name\": \"Get cinder_backup image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_cinder_backup_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'openstack-cinder-backup\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container cinder_backup image\", \"set_fact\": {\"cinder_backup_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}, \"cinder_backup_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/cinder-backup:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"pcmk_cinder_backup_image\": \"{{xmllint_pcmk_cinder_backup_image.stdout}}\"}}], \"delegate_to\": \"{{ (groups[\\\"cinder_backup\\\"] | difference(groups[\\\"excluded_overcloud\\\"]))[0] }}\"}, {\"name\": \"cinder-backup temporary pacemaker container tag in case of image switch\", \"become\": true, \"import_role\": {\"name\": \"tripleo_ha_image_update\"}, \"vars\": {\"tripleo_ha_image_update_node_names\": \"{{ groups[\\\"cinder_backup\\\"] | difference(groups[\\\"excluded_overcloud\\\"]) }}\", \"tripleo_ha_image_update_bundle\": \"openstack-cinder-backup\", \"tripleo_ha_image_update_new_image\": \"{{cinder_backup_image_latest}}\", \"tripleo_ha_image_update_old_image\": \"{{pcmk_cinder_backup_image}}\"}, \"when\": [\"(pcmk_cinder_backup_image != \\\"\\\")\", \"(pcmk_cinder_backup_image != cinder_backup_image_latest)\"]}]}], \"update_tasks\": [{\"block\": [{\"name\": \"Get cinder_backup image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_cinder_backup_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'openstack-cinder-backup\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container cinder_backup image\", \"set_fact\": {\"cinder_backup_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}, \"cinder_backup_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/cinder-backup:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"pcmk_cinder_backup_image\": \"{{xmllint_pcmk_cinder_backup_image.stdout}}\"}}], \"when\": \"(step|int == 0 or step|int == 2)\"}, {\"name\": \"Check for update of cinder-backup container image name\", \"when\": \"step|int == 0\", \"assert\": {\"that\": \"pcmk_cinder_backup_image == cinder_backup_image_latest\", \"fail_msg\": \"cinder-backup image change detected, run overcloud external-update --tags ha_image_update first\"}}, {\"name\": \"Tear-down non-HA cinder-backup container\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"Remove non-HA cinder-backup container\", \"include_role\": {\"name\": \"tripleo_container_rm\"}, \"vars\": {\"tripleo_container_cli\": \"{{ container_cli }}\", \"tripleo_containers_to_rm\": [\"cinder_backup\"]}}]}, {\"name\": \"cinder_backup fetch and retag container image for pacemaker\", \"when\": \"step|int == 2\", \"block\": [{\"name\": \"Retag pcmklatest to latest cinder_backup image\", \"include_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{cinder_backup_image}}\", \"container_image_latest\": \"{{cinder_backup_image_latest}}\"}}]}], \"post_update_tasks\": [{\"name\": \"Cinder backup bundle post update\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"Cinder backup puppet bundle\", \"import_role\": {\"name\": \"tripleo_ha_wrapper\"}, \"vars\": {\"tripleo_ha_wrapper_service_name\": \"cinder_backup\", \"tripleo_ha_wrapper_resource_name\": \"openstack-cinder-backup\", \"tripleo_ha_wrapper_bundle_name\": \"openstack-cinder-backup\", \"tripleo_ha_wrapper_resource_state\": \"_ Started\", \"tripleo_ha_wrapper_puppet_config_volume\": \"cinder\", \"tripleo_ha_wrapper_puppet_execute\": \"include ::tripleo::profile::base::pacemaker; include ::tripleo::profile::pacemaker::cinder::backup_bundle\", \"tripleo_ha_wrapper_puppet_tags\": \"pacemaker::resource::bundle,pacemaker::property,pacemaker::resource::ip,pacemaker::resource::ocf,pacemaker::constraint::order,pacemaker::constraint::colocation\", \"tripleo_ha_wrapper_puppet_debug\": {\"get_param\": \"ConfigDebug\"}, \"tripleo_ha_wrapper_config_suffix\": \".cinder_backup_previous_run\"}}], \"vars\": {\"tripleo_ha_wrapper_minor_update\": true}}], \"upgrade_tasks\": [{\"name\": \"Tear-down non-HA cinder_backup container\", \"when\": [\"step|int == 0\"], \"block\": [{\"name\": \"Remove non-HA cinder-backup container\", \"include_role\": {\"name\": \"tripleo_container_rm\"}, \"vars\": {\"tripleo_container_cli\": \"{{ container_cli }}\", \"tripleo_containers_to_rm\": [\"cinder_backup\"]}}]}, {\"name\": \"Prepare switch of cinder_backup image name\", \"when\": [\"step|int == 0\"], \"block\": [{\"name\": \"Get cinder_backup image id currently used by pacemaker\", \"shell\": \"pcs resource config openstack-cinder-backup | grep -Eo \'image=[^ ]+\' | awk -F= \'{print $2;}\'\", \"register\": \"cinder_backup_image_current_res\", \"failed_when\": false}, {\"name\": \"cinder_backup image facts\", \"set_fact\": {\"cinder_backup_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/cinder-backup:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"cinder_backup_image_current\": \"{{cinder_backup_image_current_res.stdout}}\"}}, {\"name\": \"Temporarily tag the current cinder_backup image id with the upgraded image name\", \"import_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{cinder_backup_image_current}}\", \"container_image_latest\": \"{{cinder_backup_image_latest}}\", \"pull_image\": false}, \"when\": [\"cinder_backup_image_current != \'\'\", \"cinder_backup_image_current != cinder_backup_image_latest\"]}, {\"name\": \"Create cinder_backup retag statefile\", \"file\": {\"path\": \"/var/lib/tripleo/cinder_backup_needs_retag\", \"state\": \"touch\"}, \"when\": [\"cinder_backup_image_current != \'\'\", \"cinder_backup_image_current != cinder_backup_image_latest\"]}]}, {\"name\": \"Update cinder_backup pcs resource bundle for new container image - check\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"set is_cinder_backup_bootstrap_node fact\", \"tags\": \"common\", \"set_fact\": \"is_cinder_backup_bootstrap_node={{cinder_backup_short_bootstrap_node_name|lower == ansible_facts[\'hostname\']|lower}}\"}, {\"name\": \"Check for cinder_backup retag statefile\", \"stat\": {\"path\": \"/var/lib/tripleo/cinder_backup_needs_retag\"}, \"register\": \"cinder_backup_retag_state_file\"}]}, {\"name\": \"Update cinder_backup pcs resource bundle for new container image\", \"when\": [\"step|int == 1\", \"is_cinder_backup_bootstrap_node\", \"cinder_backup_retag_state_file.stat.exists|bool\"], \"block\": [{\"name\": \"Disable the cinder_backup cluster resource before container upgrade step1\", \"pacemaker_resource\": {\"resource\": \"openstack-cinder-backup\", \"state\": \"disable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}, {\"name\": \"Update the cinder_backup bundle to use the new container image name\", \"command\": \"pcs resource bundle update openstack-cinder-backup container image={{cinder_backup_image_latest}}\"}, {\"name\": \"Enable the cinder_backup cluster resource\", \"pacemaker_resource\": {\"resource\": \"openstack-cinder-backup\", \"state\": \"enable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}]}, {\"name\": \"Check for cinder_backup retag statefile\", \"when\": [\"step|int == 3\"], \"stat\": {\"path\": \"/var/lib/tripleo/cinder_backup_needs_retag\"}, \"register\": \"cinder_backup_retag_state_file\"}, {\"name\": \"Retag the pacemaker image for cinder_backup\", \"when\": [\"step|int == 3\", \"cinder_backup_retag_state_file.stat.exists|bool\"], \"block\": [{\"name\": \"Disable the cinder_backup cluster resource before container upgrade step3\", \"pacemaker_resource\": {\"resource\": \"openstack-cinder-backup\", \"state\": \"disable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}, {\"name\": \"Retag the pacemaker image if containerized\", \"block\": [{\"block\": [{\"name\": \"Get cinder_backup image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_cinder_backup_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'openstack-cinder-backup\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container cinder_backup image\", \"set_fact\": {\"cinder_backup_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}, \"cinder_backup_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/cinder-backup:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"pcmk_cinder_backup_image\": \"{{xmllint_pcmk_cinder_backup_image.stdout}}\"}}]}, {\"block\": [{\"name\": \"Retag pcmklatest to latest cinder_backup image\", \"include_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{cinder_backup_image}}\", \"container_image_latest\": \"{{cinder_backup_image_latest}}\"}}]}]}, {\"name\": \"Enable the cinder_backup cluster resource\", \"pacemaker_resource\": {\"resource\": \"openstack-cinder-backup\", \"state\": \"enable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}, {\"name\": \"Remove cinder_backup retag statefile\", \"file\": {\"path\": \"/var/lib/tripleo/cinder_backup_needs_retag\", \"state\": \"absent\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(54,'2026-06-10 07:46:47',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mysql client settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role for setting mysql client parameters\", \"value\": {\"service_name\": \"mysql_client\", \"config_settings\": {\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"tripleo::profile::base::database::mysql::client::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}}, \"step_config\": \"include tripleo::profile::base::database::mysql::client\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(55,'2026-06-10 07:46:47',NULL,'{\"heat_template_version\": \"wallaby\", \"parameters\": {\"ControlPlaneIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageNetName\": {\"default\": \"storage\", \"description\": \"The name of the storage network.\", \"type\": \"string\"}, \"StorageMgmtIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageMgmtNetName\": {\"default\": \"storage_mgmt\", \"description\": \"The name of the storage_mgmt network.\", \"type\": \"string\"}, \"InternalApiIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"InternalApiNetName\": {\"default\": \"internal_api\", \"description\": \"The name of the internal_api network.\", \"type\": \"string\"}, \"TenantIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"TenantNetName\": {\"default\": \"tenant\", \"description\": \"The name of the tenant network.\", \"type\": \"string\"}, \"ExternalIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ExternalNetName\": {\"default\": \"external\", \"description\": \"The name of the external network.\", \"type\": \"string\"}, \"EnabledServices\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"type\": \"json\"}, \"ServiceHostnameList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"NetworkHostnameMap\": {\"default\": [], \"type\": \"json\"}, \"NovaAdditionalCell\": {\"default\": false, \"description\": \"Whether this is an cell additional to the default cell.\", \"type\": \"boolean\"}, \"RoleNetworks\": {\"default\": \"ctlplane\", \"type\": \"comma_delimited_list\"}}, \"conditions\": {\"is_cell\": {\"equals\": [{\"get_param\": \"NovaAdditionalCell\"}, true]}}, \"resources\": {\"EnabledServicesValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> $.data.extra_services.items().where($[0] in $root.data.enabled_services).select($[1]).flatten() + $root.data.enabled_services\", \"data\": {\"enabled_services\": {\"get_param\": \"EnabledServices\"}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"NetIpMapValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"yaql\": {\"expression\": \"let(root => $) -> dict($.data.net_ip_map.items().where($[0] in $root.data.role_networks))\", \"data\": {\"role_networks\": {\"get_param\": \"RoleNetworks\"}, \"net_ip_map\": {\"ctlplane\": {\"get_param\": \"ControlPlaneIpList\"}, \"storage\": {\"get_param\": \"StorageIpList\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtIpList\"}, \"internal_api\": {\"get_param\": \"InternalApiIpList\"}, \"tenant\": {\"get_param\": \"TenantIpList\"}, \"external\": {\"get_param\": \"ExternalIpList\"}}}}}, {\"keys\": {\"ctlplane\": \"ctlplane\", \"storage\": {\"get_param\": \"StorageNetName\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtNetName\"}, \"internal_api\": {\"get_param\": \"InternalApiNetName\"}, \"tenant\": {\"get_param\": \"TenantNetName\"}, \"external\": {\"get_param\": \"ExternalNetName\"}}}]}}}}, \"outputs\": {\"net_ip_map\": {\"description\": \"A Hash containing a mapping of network names to assigned lists of IP addresses.\\n\", \"value\": {\"get_attr\": [\"NetIpMapValue\", \"value\"]}}, \"ctlplane_service_ips\": {\"description\": \"Map of enabled services to a list of their ctlplane IP addresses\\n\", \"value\": {\"map_merge\": {\"repeat\": {\"template\": {\"SERVICE_ctlplane_node_ips\": \"$$ groups[\'SERVICE\'] | default ([]) | map(\'extract\', hostvars, \'ctlplane_ip\') | list | to_json $$\"}, \"for_each\": {\"SERVICE\": {\"get_attr\": [\"EnabledServicesValue\", \"value\"]}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ControlPlaneIpList\": \"\", \"StorageIpList\": \"\", \"StorageMgmtIpList\": \"\", \"InternalApiIpList\": \"\", \"TenantIpList\": \"\", \"EnabledServices\": \"\", \"ServiceNetMap\": {\"apache_network\": \"internal_api\", \"neutron_tenant_network\": \"tenant\", \"aodh_api_network\": \"internal_api\", \"barbican_api_network\": \"internal_api\", \"gnocchi_api_network\": \"internal_api\", \"mongodb_network\": \"internal_api\", \"cinder_api_network\": \"internal_api\", \"cinder_iscsi_network\": \"storage\", \"glance_api_network\": \"internal_api\", \"glance_api_edge_network\": \"internal_api\", \"glance_api_internal_network\": \"internal_api\", \"ironic_api_network\": \"ctlplane\", \"ironic_network\": \"ctlplane\", \"ironic_inspector_network\": \"ctlplane\", \"keystone_admin_api_network\": \"ctlplane\", \"keystone_public_api_network\": \"internal_api\", \"manila_api_network\": \"internal_api\", \"neutron_api_network\": \"internal_api\", \"octavia_api_network\": \"internal_api\", \"heat_api_network\": \"internal_api\", \"heat_api_cfn_network\": \"internal_api\", \"heat_api_cloudwatch_network\": \"internal_api\", \"nova_api_network\": \"internal_api\", \"placement_network\": \"internal_api\", \"nova_metadata_network\": \"internal_api\", \"nova_libvirt_network\": \"internal_api\", \"novajoin_network\": \"internal_api\", \"swift_storage_network\": \"storage_mgmt\", \"swift_proxy_network\": \"storage\", \"horizon_network\": \"internal_api\", \"memcached_network\": \"internal_api\", \"oslo_messaging_rpc_network\": \"internal_api\", \"oslo_messaging_notify_network\": \"internal_api\", \"rabbitmq_network\": \"internal_api\", \"rabbitmq_management_network\": \"internal_api\", \"qdr_network\": \"internal_api\", \"redis_network\": \"internal_api\", \"ganesha_network\": \"external\", \"mysql_network\": \"internal_api\", \"snmpd_network\": \"ctlplane\", \"ceph_cluster_network\": \"storage_mgmt\", \"ceph_dashboard_network\": \"ctlplane\", \"ceph_grafana_network\": \"storage\", \"ceph_mon_network\": \"storage\", \"ceph_rgw_network\": \"storage\", \"public_network\": \"external\", \"internal_api_network\": \"internal_api\", \"opendaylight_api_network\": \"internal_api\", \"ovn_dbs_network\": \"internal_api\", \"docker_registry_network\": \"ctlplane\", \"pacemaker_network\": \"internal_api\", \"pacemaker_remote_network\": \"internal_api\", \"designate_api_network\": \"internal_api\", \"designate_mdns_network\": \"internal_api\", \"designate_worker_network\": \"external\", \"designate_bind_network\": \"external\", \"bindnetwork\": \"external\", \"etcd_network\": \"internal_api\", \"haproxy_network\": \"ctlplane\", \"unbound_network\": \"external\", \"controller_hostname_resolve_network\": \"internal_api\", \"controller_metrics_qdr_network\": \"internal_api\", \"cell_controller_hostname_resolve_network\": \"internal_api\", \"cell_controller_metrics_qdr_network\": \"internal_api\", \"cell_controller_compute_hostname_resolve_network\": \"internal_api\", \"cell_controller_compute_metrics_qdr_network\": \"internal_api\", \"compute_hostname_resolve_network\": \"internal_api\", \"compute_metrics_qdr_network\": \"internal_api\", \"block_storage_hostname_resolve_network\": \"internal_api\", \"block_storage_metrics_qdr_network\": \"internal_api\", \"object_storage_hostname_resolve_network\": \"internal_api\", \"object_storage_metrics_qdr_network\": \"internal_api\", \"ceph_storage_hostname_resolve_network\": \"storage\", \"ceph_storage_metrics_qdr_network\": \"storage\", \"networker_hostname_resolve_network\": \"internal_api\", \"networker_metrics_qdr_network\": \"internal_api\", \"nova_vnc_proxy_network\": \"internal_api\"}, \"ServiceHostnameList\": \"\", \"NetworkHostnameMap\": {}, \"RoleNetworks\": \"ctlplane,storage,storage_mgmt,internal_api,tenant\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (56,'2026-06-10 07:46:47',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Ceilometer Agent Notification service\\n\", \"parameters\": {\"ContainerCeilometerNotificationImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\"}, \"ContainerCeilometerConfigImage\": {\"description\": \"The container image to use for the ceilometer config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\"}, \"CeilometerAgentNotificationLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.ceilometer.agent.notification\", \"file\": \"/var/log/containers/ceilometer/agent-notification.log\"}}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"MonitoringSubscriptionCeilometerNotification\": {\"default\": \"overcloud-ceilometer-agent-notification\", \"type\": \"string\"}, \"MetricsQdrPort\": {\"default\": 5666, \"description\": \"Service name or port number on which the qdrouterd will accept connections.\", \"type\": \"number\"}, \"CeilometerQdrPublishEvents\": {\"default\": false, \"description\": \"Whether to send events to MetricsQdr service.\", \"type\": \"boolean\"}, \"CeilometerQdrPublishMetrics\": {\"default\": false, \"description\": \"Whether to send telemetry data to MetricsQdr service.\", \"type\": \"boolean\"}, \"CeilometerQdrEventsConfig\": {\"default\": {\"driver\": \"amqp\", \"topic\": \"event\"}, \"description\": \"Configuration for notifier publisher for events.\", \"type\": \"json\"}, \"CeilometerQdrMetricsConfig\": {\"default\": {\"driver\": \"amqp\", \"topic\": \"metering\"}, \"description\": \"Configuration for notifier publisher for metrics.\", \"type\": \"json\"}, \"ManageEventPipeline\": {\"default\": true, \"description\": \"Whether to manage event_pipeline.yaml.\", \"type\": \"boolean\"}, \"EventPipelinePublishers\": {\"default\": [], \"description\": \"A list of publishers to put in event_pipeline.yaml. When the collector is used, override this with notifier:// publisher. Set ManageEventPipeline to true for override to take effect.\\n\", \"type\": \"comma_delimited_list\"}, \"ManagePipeline\": {\"default\": false, \"description\": \"Whether to manage pipeline.yaml.\", \"type\": \"boolean\"}, \"PipelinePublishers\": {\"default\": [], \"description\": \"A list of publishers to put in pipeline.yaml. When the collector is used, override this with notifier:// publisher. Set ManagePipeline to true for override to take effect.\\n\", \"type\": \"comma_delimited_list\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml\"}, \"CeilometerServiceBase\": {\"type\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-base-container-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerCeilometerNotificationImage\": \"ContainerCeilometerNotificationImage\", \"ContainerCeilometerConfigImage\": \"ContainerCeilometerConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerCeilometerNotificationImage\": {\"get_param\": \"ContainerCeilometerNotificationImage\"}, \"ContainerCeilometerConfigImage\": {\"get_param\": \"ContainerCeilometerConfigImage\"}}}]}}}}, \"conditions\": {\"ceilometer_qdr_publish\": {\"or\": [{\"get_param\": \"CeilometerQdrPublishEvents\"}, {\"get_param\": \"CeilometerQdrPublishMetrics\"}]}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Ceilometer Agent Notification role.\", \"value\": {\"service_name\": \"ceilometer_agent_notification\", \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionCeilometerNotification\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"CeilometerServiceBase\", \"role_data\", \"config_settings\"]}, {\"ceilometer::agent::notification::manage_event_pipeline\": {\"get_param\": \"ManageEventPipeline\"}, \"ceilometer::agent::notification::manage_pipeline\": {\"get_param\": \"ManagePipeline\"}, \"tripleo::profile::base::ceilometer::agent::notification::notifier_enabled\": {\"get_param\": \"CeilometerQdrPublishMetrics\"}, \"tripleo::profile::base::ceilometer::agent::notification::notifier_events_enabled\": {\"get_param\": \"CeilometerQdrPublishEvents\"}, \"tripleo::profile::base::ceilometer::agent::notification::pipeline_publishers\": {\"get_param\": \"PipelinePublishers\"}, \"tripleo::profile::base::ceilometer::agent::notification::event_pipeline_publishers\": {\"get_param\": \"EventPipelinePublishers\"}, \"tripleo::profile::base::ceilometer::agent::notification::notifier_params\": {\"get_param\": \"CeilometerQdrMetricsConfig\"}, \"tripleo::profile::base::ceilometer::agent::notification::notifier_event_params\": {\"get_param\": \"CeilometerQdrEventsConfig\"}}, {\"if\": [\"ceilometer_qdr_publish\", {\"tripleo::profile::base::ceilometer::agent::notification::notifier_host_addr\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", {\"str_replace\": {\"template\": \"ROLENAMEMetricsQdrNetwork\", \"params\": {\"ROLENAME\": {\"get_param\": \"RoleName\"}}}}]}}}}, \"tripleo::profile::base::ceilometer::agent::notification::notifier_host_port\": {\"get_param\": \"MetricsQdrPort\"}}]}]}, \"service_config_settings\": {\"map_merge\": [{\"get_attr\": [\"CeilometerServiceBase\", \"role_data\", \"service_config_settings\"]}, {\"rsyslog\": {\"tripleo_logging_sources_ceilometer_agent_notification\": [{\"get_param\": \"CeilometerAgentNotificationLoggingSource\"}]}}]}, \"puppet_config\": {\"config_volume\": \"ceilometer\", \"puppet_tags\": \"ceilometer_config\", \"step_config\": \"include tripleo::profile::base::ceilometer::agent::notification\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCeilometerConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/ceilometer_agent_notification.json\": {\"command\": \"/usr/bin/ceilometer-agent-notification --logfile /var/log/ceilometer/agent-notification.log\", \"config_files\": {\"list_concat\": [[{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]]}}}, \"docker_config\": {\"step_3\": {\"ceilometer_init_log\": {\"start_order\": 0, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCeilometerNotificationImage\"]}, \"net\": \"none\", \"user\": \"root\", \"command\": [\"/bin/bash\", \"-c\", \"chown -R ceilometer:ceilometer /var/log/ceilometer\"], \"volumes\": [\"/var/log/containers/ceilometer:/var/log/ceilometer:z\"]}}, \"step_4\": {\"ceilometer_agent_notification\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCeilometerNotificationImage\"]}, \"net\": \"host\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"get_attr\": [\"ContainersCommon\", \"healthcheck_rpc_port\"]}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/ceilometer_agent_notification.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/ceilometer:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/ceilometer:/var/log/ceilometer:z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"host_prep_tasks\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/ceilometer\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}, {\"name\": \"enable virt_sandbox_use_netlink for healthcheck\", \"seboolean\": {\"name\": \"virt_sandbox_use_netlink\", \"persistent\": true, \"state\": true}, \"when\": [\"ansible_facts.selinux is defined\", \"ansible_facts.selinux.status == \\\"enabled\\\"\"]}], \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop ceilometer agent notification container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"ceilometer_agent_notification\"], \"tripleo_delegate_to\": \"{{ groups[\'ceilometer_agent_notification\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(57,'2026-06-10 07:46:47',NULL,'{\"heat_template_version\": \"wallaby\", \"parameters\": {\"ControlPlaneIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageNetName\": {\"default\": \"storage\", \"description\": \"The name of the storage network.\", \"type\": \"string\"}, \"StorageMgmtIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageMgmtNetName\": {\"default\": \"storage_mgmt\", \"description\": \"The name of the storage_mgmt network.\", \"type\": \"string\"}, \"InternalApiIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"InternalApiNetName\": {\"default\": \"internal_api\", \"description\": \"The name of the internal_api network.\", \"type\": \"string\"}, \"TenantIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"TenantNetName\": {\"default\": \"tenant\", \"description\": \"The name of the tenant network.\", \"type\": \"string\"}, \"ExternalIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ExternalNetName\": {\"default\": \"external\", \"description\": \"The name of the external network.\", \"type\": \"string\"}, \"EnabledServices\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"type\": \"json\"}, \"ServiceHostnameList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"NetworkHostnameMap\": {\"default\": [], \"type\": \"json\"}, \"NovaAdditionalCell\": {\"default\": false, \"description\": \"Whether this is an cell additional to the default cell.\", \"type\": \"boolean\"}, \"RoleNetworks\": {\"default\": \"ctlplane\", \"type\": \"comma_delimited_list\"}}, \"conditions\": {\"is_cell\": {\"equals\": [{\"get_param\": \"NovaAdditionalCell\"}, true]}}, \"resources\": {\"EnabledServicesValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> $.data.extra_services.items().where($[0] in $root.data.enabled_services).select($[1]).flatten() + $root.data.enabled_services\", \"data\": {\"enabled_services\": {\"get_param\": \"EnabledServices\"}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"NetIpMapValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"yaql\": {\"expression\": \"let(root => $) -> dict($.data.net_ip_map.items().where($[0] in $root.data.role_networks))\", \"data\": {\"role_networks\": {\"get_param\": \"RoleNetworks\"}, \"net_ip_map\": {\"ctlplane\": {\"get_param\": \"ControlPlaneIpList\"}, \"storage\": {\"get_param\": \"StorageIpList\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtIpList\"}, \"internal_api\": {\"get_param\": \"InternalApiIpList\"}, \"tenant\": {\"get_param\": \"TenantIpList\"}, \"external\": {\"get_param\": \"ExternalIpList\"}}}}}, {\"keys\": {\"ctlplane\": \"ctlplane\", \"storage\": {\"get_param\": \"StorageNetName\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtNetName\"}, \"internal_api\": {\"get_param\": \"InternalApiNetName\"}, \"tenant\": {\"get_param\": \"TenantNetName\"}, \"external\": {\"get_param\": \"ExternalNetName\"}}}]}}}}, \"outputs\": {\"net_ip_map\": {\"description\": \"A Hash containing a mapping of network names to assigned lists of IP addresses.\\n\", \"value\": {\"get_attr\": [\"NetIpMapValue\", \"value\"]}}, \"ctlplane_service_ips\": {\"description\": \"Map of enabled services to a list of their ctlplane IP addresses\\n\", \"value\": {\"map_merge\": {\"repeat\": {\"template\": {\"SERVICE_ctlplane_node_ips\": \"$$ groups[\'SERVICE\'] | default ([]) | map(\'extract\', hostvars, \'ctlplane_ip\') | list | to_json $$\"}, \"for_each\": {\"SERVICE\": {\"get_attr\": [\"EnabledServicesValue\", \"value\"]}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ControlPlaneIpList\": \"\", \"StorageIpList\": \"\", \"InternalApiIpList\": \"\", \"TenantIpList\": \"\", \"EnabledServices\": \"\", \"ServiceNetMap\": {\"apache_network\": \"internal_api\", \"neutron_tenant_network\": \"tenant\", \"aodh_api_network\": \"internal_api\", \"barbican_api_network\": \"internal_api\", \"gnocchi_api_network\": \"internal_api\", \"mongodb_network\": \"internal_api\", \"cinder_api_network\": \"internal_api\", \"cinder_iscsi_network\": \"storage\", \"glance_api_network\": \"internal_api\", \"glance_api_edge_network\": \"internal_api\", \"glance_api_internal_network\": \"internal_api\", \"ironic_api_network\": \"ctlplane\", \"ironic_network\": \"ctlplane\", \"ironic_inspector_network\": \"ctlplane\", \"keystone_admin_api_network\": \"ctlplane\", \"keystone_public_api_network\": \"internal_api\", \"manila_api_network\": \"internal_api\", \"neutron_api_network\": \"internal_api\", \"octavia_api_network\": \"internal_api\", \"heat_api_network\": \"internal_api\", \"heat_api_cfn_network\": \"internal_api\", \"heat_api_cloudwatch_network\": \"internal_api\", \"nova_api_network\": \"internal_api\", \"placement_network\": \"internal_api\", \"nova_metadata_network\": \"internal_api\", \"nova_libvirt_network\": \"internal_api\", \"novajoin_network\": \"internal_api\", \"swift_storage_network\": \"storage_mgmt\", \"swift_proxy_network\": \"storage\", \"horizon_network\": \"internal_api\", \"memcached_network\": \"internal_api\", \"oslo_messaging_rpc_network\": \"internal_api\", \"oslo_messaging_notify_network\": \"internal_api\", \"rabbitmq_network\": \"internal_api\", \"rabbitmq_management_network\": \"internal_api\", \"qdr_network\": \"internal_api\", \"redis_network\": \"internal_api\", \"ganesha_network\": \"external\", \"mysql_network\": \"internal_api\", \"snmpd_network\": \"ctlplane\", \"ceph_cluster_network\": \"storage_mgmt\", \"ceph_dashboard_network\": \"ctlplane\", \"ceph_grafana_network\": \"storage\", \"ceph_mon_network\": \"storage\", \"ceph_rgw_network\": \"storage\", \"public_network\": \"external\", \"internal_api_network\": \"internal_api\", \"opendaylight_api_network\": \"internal_api\", \"ovn_dbs_network\": \"internal_api\", \"docker_registry_network\": \"ctlplane\", \"pacemaker_network\": \"internal_api\", \"pacemaker_remote_network\": \"internal_api\", \"designate_api_network\": \"internal_api\", \"designate_mdns_network\": \"internal_api\", \"designate_worker_network\": \"external\", \"designate_bind_network\": \"external\", \"bindnetwork\": \"external\", \"etcd_network\": \"internal_api\", \"haproxy_network\": \"ctlplane\", \"unbound_network\": \"external\", \"controller_hostname_resolve_network\": \"internal_api\", \"controller_metrics_qdr_network\": \"internal_api\", \"cell_controller_hostname_resolve_network\": \"internal_api\", \"cell_controller_metrics_qdr_network\": \"internal_api\", \"cell_controller_compute_hostname_resolve_network\": \"internal_api\", \"cell_controller_compute_metrics_qdr_network\": \"internal_api\", \"compute_hostname_resolve_network\": \"internal_api\", \"compute_metrics_qdr_network\": \"internal_api\", \"block_storage_hostname_resolve_network\": \"internal_api\", \"block_storage_metrics_qdr_network\": \"internal_api\", \"object_storage_hostname_resolve_network\": \"internal_api\", \"object_storage_metrics_qdr_network\": \"internal_api\", \"ceph_storage_hostname_resolve_network\": \"storage\", \"ceph_storage_metrics_qdr_network\": \"storage\", \"networker_hostname_resolve_network\": \"internal_api\", \"networker_metrics_qdr_network\": \"internal_api\", \"nova_vnc_proxy_network\": \"internal_api\"}, \"ServiceHostnameList\": \"\", \"NetworkHostnameMap\": {}, \"RoleNetworks\": \"ctlplane,storage,internal_api,tenant\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(58,'2026-06-10 07:46:47',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Ceilometer service configured with Puppet\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"CeilometerMeteringSecret\": {\"description\": \"Secret shared by the ceilometer services.\", \"type\": \"string\", \"hidden\": true, \"default\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\"}, \"CeilometerPassword\": {\"description\": \"The password for the ceilometer service account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\"}, \"AmqpRpcAddressPrefix\": {\"default\": \"\", \"description\": \"Address prefix for RPC addresses\", \"type\": \"string\"}, \"AmqpNotifyAddressPrefix\": {\"default\": \"\", \"description\": \"Address prefix for Notification addresses\", \"type\": \"string\"}, \"ManagePolling\": {\"default\": false, \"description\": \"Whether to manage polling.yaml.\", \"type\": \"boolean\"}, \"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"CeilometerDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Ceilometer services.\", \"type\": \"boolean\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"SnmpdReadonlyUserName\": {\"default\": \"ro_snmp_user\", \"description\": \"The user name for SNMPd with readonly rights running on all Overcloud nodes\", \"type\": \"string\"}, \"SnmpdReadonlyUserPassword\": {\"description\": \"The user password for SNMPd with readonly rights running on all Overcloud nodes\", \"type\": \"string\", \"hidden\": true, \"default\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"noop\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"GnocchiArchivePolicy\": {\"default\": \"ceilometer-low-rate\", \"type\": \"string\", \"description\": \"(DEPRECATED) archive policy to use with gnocchi backend\"}, \"EnableCache\": {\"description\": \"Enable caching with memcached\", \"type\": \"boolean\", \"default\": true}, \"MemcachedTLS\": {\"default\": false, \"description\": \"Set to True to enable TLS on Memcached service. Because not all services support Memcached TLS, during the migration period, Memcached will listen on 2 ports - on the port set with MemcachedPort parameter (above) and on 11211, without TLS.\", \"type\": \"boolean\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"The following parameters are deprecated and will be removed. They should not\\nbe relied on for new deployments. If you have concerns regarding deprecated\\nparameters, please contact the TripleO development team on IRC or the\\nOpenStack mailing list.\\n\", \"parameters\": [\"GnocchiArchivePolicy\"]}], \"conditions\": {\"tls_cache_enabled\": {\"and\": [{\"get_param\": \"EnableCache\"}, {\"get_param\": \"MemcachedTLS\"}]}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Ceilometer role.\", \"value\": {\"service_name\": \"ceilometer_base\", \"config_settings\": {\"map_merge\": [{\"ceilometer::logging::debug\": {\"if\": [{\"get_param\": \"CeilometerDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"ceilometer::agent::polling::manage_polling\": {\"get_param\": \"ManagePolling\"}, \"ceilometer::agent::service_credentials::password\": {\"get_param\": \"CeilometerPassword\"}, \"ceilometer::agent::service_credentials::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"ceilometer::agent::service_credentials::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"ceilometer::agent::service_credentials::project_name\": \"service\", \"ceilometer::agent::service_credentials::user_domain_name\": \"Default\", \"ceilometer::agent::service_credentials::auth_project_domain_name\": \"Default\", \"ceilometer::agent::service_credentials::interface\": \"internalURL\", \"ceilometer::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"ceilometer::amqp_rpc_address_prefix\": {\"get_param\": \"AmqpRpcAddressPrefix\"}, \"ceilometer::amqp_notify_address_prefix\": {\"get_param\": \"AmqpNotifyAddressPrefix\"}, \"ceilometer::telemetry_secret\": {\"get_param\": \"CeilometerMeteringSecret\"}, \"ceilometer::snmpd_readonly_username\": {\"get_param\": \"SnmpdReadonlyUserName\"}, \"ceilometer::snmpd_readonly_user_password\": {\"get_param\": \"SnmpdReadonlyUserPassword\"}, \"ceilometer::host\": \"%{hiera(\'fqdn_canonical\')}\", \"ceilometer::rabbit_heartbeat_in_pthread\": false, \"ceilometer::cache::enabled\": {\"get_param\": \"EnableCache\"}, \"ceilometer::cache::tls_enabled\": {\"get_param\": \"MemcachedTLS\"}}, {\"if\": [\"tls_cache_enabled\", {\"ceilometer::cache::backend\": \"dogpile.cache.pymemcache\", \"ceilometer::cache::enable_socket_keepalive\": true}, {\"ceilometer::cache::backend\": \"dogpile.cache.memcached\"}]}]}, \"service_config_settings\": {\"keystone\": {\"tripleo::profile::base::keystone::ceilometer_notification_topics\": [\"notifications\"]}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(59,'2026-06-10 07:46:47',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Ceilometer service configured with Puppet\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"CeilometerMeteringSecret\": {\"description\": \"Secret shared by the ceilometer services.\", \"type\": \"string\", \"hidden\": true, \"default\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\"}, \"CeilometerPassword\": {\"description\": \"The password for the ceilometer service account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\"}, \"AmqpRpcAddressPrefix\": {\"default\": \"\", \"description\": \"Address prefix for RPC addresses\", \"type\": \"string\"}, \"AmqpNotifyAddressPrefix\": {\"default\": \"\", \"description\": \"Address prefix for Notification addresses\", \"type\": \"string\"}, \"ManagePolling\": {\"default\": false, \"description\": \"Whether to manage polling.yaml.\", \"type\": \"boolean\"}, \"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"CeilometerDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Ceilometer services.\", \"type\": \"boolean\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"SnmpdReadonlyUserName\": {\"default\": \"ro_snmp_user\", \"description\": \"The user name for SNMPd with readonly rights running on all Overcloud nodes\", \"type\": \"string\"}, \"SnmpdReadonlyUserPassword\": {\"description\": \"The user password for SNMPd with readonly rights running on all Overcloud nodes\", \"type\": \"string\", \"hidden\": true, \"default\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"noop\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"GnocchiArchivePolicy\": {\"default\": \"ceilometer-low-rate\", \"type\": \"string\", \"description\": \"(DEPRECATED) archive policy to use with gnocchi backend\"}, \"EnableCache\": {\"description\": \"Enable caching with memcached\", \"type\": \"boolean\", \"default\": true}, \"MemcachedTLS\": {\"default\": false, \"description\": \"Set to True to enable TLS on Memcached service. Because not all services support Memcached TLS, during the migration period, Memcached will listen on 2 ports - on the port set with MemcachedPort parameter (above) and on 11211, without TLS.\", \"type\": \"boolean\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"The following parameters are deprecated and will be removed. They should not\\nbe relied on for new deployments. If you have concerns regarding deprecated\\nparameters, please contact the TripleO development team on IRC or the\\nOpenStack mailing list.\\n\", \"parameters\": [\"GnocchiArchivePolicy\"]}], \"conditions\": {\"tls_cache_enabled\": {\"and\": [{\"get_param\": \"EnableCache\"}, {\"get_param\": \"MemcachedTLS\"}]}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Ceilometer role.\", \"value\": {\"service_name\": \"ceilometer_base\", \"config_settings\": {\"map_merge\": [{\"ceilometer::logging::debug\": {\"if\": [{\"get_param\": \"CeilometerDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"ceilometer::agent::polling::manage_polling\": {\"get_param\": \"ManagePolling\"}, \"ceilometer::agent::service_credentials::password\": {\"get_param\": \"CeilometerPassword\"}, \"ceilometer::agent::service_credentials::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"ceilometer::agent::service_credentials::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"ceilometer::agent::service_credentials::project_name\": \"service\", \"ceilometer::agent::service_credentials::user_domain_name\": \"Default\", \"ceilometer::agent::service_credentials::auth_project_domain_name\": \"Default\", \"ceilometer::agent::service_credentials::interface\": \"internalURL\", \"ceilometer::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"ceilometer::amqp_rpc_address_prefix\": {\"get_param\": \"AmqpRpcAddressPrefix\"}, \"ceilometer::amqp_notify_address_prefix\": {\"get_param\": \"AmqpNotifyAddressPrefix\"}, \"ceilometer::telemetry_secret\": {\"get_param\": \"CeilometerMeteringSecret\"}, \"ceilometer::snmpd_readonly_username\": {\"get_param\": \"SnmpdReadonlyUserName\"}, \"ceilometer::snmpd_readonly_user_password\": {\"get_param\": \"SnmpdReadonlyUserPassword\"}, \"ceilometer::host\": \"%{hiera(\'fqdn_canonical\')}\", \"ceilometer::rabbit_heartbeat_in_pthread\": false, \"ceilometer::cache::enabled\": {\"get_param\": \"EnableCache\"}, \"ceilometer::cache::tls_enabled\": {\"get_param\": \"MemcachedTLS\"}}, {\"if\": [\"tls_cache_enabled\", {\"ceilometer::cache::backend\": \"dogpile.cache.pymemcache\", \"ceilometer::cache::enable_socket_keepalive\": true}, {\"ceilometer::cache::backend\": \"dogpile.cache.memcached\"}]}]}, \"service_config_settings\": {\"keystone\": {\"tripleo::profile::base::keystone::ceilometer_notification_topics\": [\"notifications\"]}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(60,'2026-06-10 07:46:48',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Provides the list of common container volumes and environment used by various cinder services.\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"CinderVolumeOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\"}, \"CinderBackupOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\"}, \"CinderVolumeOptEnvVars\": {\"default\": {}, \"description\": \"hash of optional environment variables\", \"type\": \"json\"}, \"CinderEnableIscsiBackend\": {\"default\": true, \"description\": \"Whether to enable or not the Iscsi backend for Cinder\", \"type\": \"boolean\"}, \"CinderEnableNVMeOFBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NVMeOF backend for Cinder\", \"type\": \"boolean\"}, \"CinderLVMConfigureVG\": {\"default\": true, \"description\": \"Whether to configure the \'cinder-volumes\' VG used by the LVM driver. When disabled (set to False), the LVM driver will work as long as the \'cinder-volumes\' VG has been created through some other means.\\n\", \"type\": \"boolean\"}, \"CinderLVMLoopDeviceSize\": {\"default\": 20480, \"description\": \"The size of the loopback file used by the cinder LVM driver.\", \"type\": \"number\"}, \"MultipathdEnable\": {\"default\": false, \"description\": \"Whether to enable the multipath daemon\", \"type\": \"boolean\"}, \"CinderVolumeCluster\": {\"default\": \"\", \"description\": \"The cluster name used for deploying the cinder-volume service in an active-active (A/A) configuration. This configuration requires the Cinder backend drivers support A/A, and the cinder-volume service not be managed by pacemaker. If these criteria are not met then the cluster name must be left blank.\\n\", \"type\": \"string\"}, \"CinderImageConversionNfsShare\": {\"default\": \"\", \"description\": \"When set, the NFS share to be used for Cinder\'s image conversion directory.\", \"type\": \"string\"}, \"CinderImageConversionNfsOptions\": {\"default\": \"_netdev,bg,intr,context=system_u:object_r:container_file_t:s0\", \"description\": \"NFS mount options when using an NFS share for Cinder\'s image conversion directory.\", \"type\": \"string\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"EnableEtcdInternalTLS\": {\"description\": \"Controls whether etcd and the cinder-volume service use TLS for cinder\'s lock manager, even when the rest of the internal API network is using TLS.\", \"type\": \"boolean\", \"default\": true}, \"CephConfigPath\": {\"type\": \"string\", \"default\": \"/var/lib/tripleo-config/ceph\", \"description\": \"The path where the Ceph Cluster config files are stored on the host.\\n\"}, \"CephClientUserName\": {\"default\": \"openstack\", \"type\": \"string\"}, \"CephClusterName\": {\"type\": \"string\", \"default\": \"ceph\", \"description\": \"The Ceph cluster name.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9]+\", \"description\": \"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\n\"}]}, \"CephExternalMultiConfig\": {\"type\": \"json\", \"hidden\": true, \"description\": \"List of maps describing extra overrides which will be applied when configuring\\nextra external Ceph clusters. If this list is non-empty, ceph-ansible will run\\nan extra count(list) times using the same parameters as the first run except\\neach parameter within each map will override the defaults. If the following\\nwere used, the second run would configure the overcloud to also use the ceph2\\ncluster with all the previous parameters except /etc/ceph/ceph2.conf would have\\na mon_host entry containing the value of external_cluster_mon_ips below, and\\nnot the default CephExternalMonHost. Subsequent ceph-ansible runs are restricted\\nto just ceph clients. CephExternalMultiConfig may not be used to deploy additional\\ninternal Ceph clusters within one Heat stack. The map for each list should contain\\nnot tripleo-heat-template parameters but ceph-ansible parameters.\\n  - cluster: \'ceph2\'\\n    fsid: \'e2cba068-5f14-4b0f-b047-acf375c0004a\'\\n    external_cluster_mon_ips: \'172.18.0.5,172.18.0.6,172.18.0.7\'\\n    keys:\\n      - name: \\\"client.openstack\\\"\\n        caps:\\n          mgr: \\\"allow *\\\"\\n          mon: \\\"profile rbd\\\"\\n          osd: \\\"osd: profile rbd pool=volumes, profile rbd pool=backups, profile rbd pool=vms, profile rbd pool=images\\\"\\n        key: \\\"AQCwmeRcAAAAABAA6SQU/bGqFjlfLro5KxrB1Q==\\\"\\n        mode: \\\"0600\\\"\\n    dashboard_enabled: false\\n\", \"default\": []}}, \"conditions\": {\"cvol_active_active_tls_enabled\": {\"and\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderVolumeCluster\"}, \"\"]}}, {\"get_param\": \"EnableInternalTLS\"}, {\"get_param\": \"EnableEtcdInternalTLS\"}]}, \"cinder_nfs_conversion_dir_enabled\": {\"not\": {\"equals\": [{\"get_param\": \"CinderImageConversionNfsShare\"}, \"\"]}}, \"cinder_configure_lvm\": {\"and\": [{\"get_param\": \"CinderLVMConfigureVG\"}, {\"or\": [{\"get_param\": \"CinderEnableIscsiBackend\"}, {\"get_param\": \"CinderEnableNVMeOFBackend\"}]}]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml\"}, \"CinderNVMeOF\": {\"type\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml\"}}, \"outputs\": {\"cinder_image_conversion_nfs_dir\": {\"description\": \"The directory where cinder does its image conversion when the directory is backed by an NFS share.\", \"value\": \"/var/lib/cinder_image_conversion\"}, \"cinder_common_host_prep_tasks\": {\"description\": \"Common host prep tasks for cinder-volume and cinder-backup services\", \"value\": {\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}}, \"cinder_common_volumes\": {\"description\": \"Common volumes for all cinder services\", \"value\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}}, \"cinder_common_kolla_config_files\": {\"description\": \"Common kolla config_files for cinder-volume and cinder-backup services\", \"value\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-ceph/\", \"dest\": \"/etc/ceph/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-iscsid/*\", \"dest\": \"/etc/iscsi/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true, \"optional\": true}]}, \"cinder_common_kolla_permissions\": {\"description\": \"Common kolla permissions for cinder-volume and cinder-backup services\", \"value\": {\"list_concat\": [[{\"path\": \"/var/log/cinder\", \"owner\": \"cinder:cinder\", \"recurse\": true}, {\"path\": {\"str_replace\": {\"template\": \"/etc/ceph/CLUSTER.client.USER.keyring\", \"params\": {\"CLUSTER\": {\"get_param\": \"CephClusterName\"}, \"USER\": {\"get_param\": \"CephClientUserName\"}}}}, \"owner\": \"cinder:cinder\", \"perm\": \"0600\"}, {\"path\": \"/etc/pki/tls/certs/etcd.crt\", \"owner\": \"cinder:cinder\"}, {\"path\": \"/etc/pki/tls/private/etcd.key\", \"owner\": \"cinder:cinder\"}], {\"repeat\": {\"template\": {\"path\": \"/etc/ceph/<%cluster%>.client.*.keyring\", \"owner\": \"cinder:cinder\", \"perm\": \"0600\"}, \"for_each\": {\"<%cluster%>\": {\"yaql\": {\"expression\": \"$.data.multiconfig.select($.cluster)\", \"data\": {\"multiconfig\": {\"get_param\": \"CephExternalMultiConfig\"}}}}}}}]}}, \"cinder_volume_host_prep_and_system_upgrade_post_tasks\": {\"description\": \"Common host_prep and system_upgrade post tasks for cinder-volume\", \"value\": [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}]}, \"cinder_volume_host_prep_tasks\": {\"description\": \"Host prep tasks for the cinder-volume service (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}, [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}], [{\"name\": \"cinder_configure_lvm fact\", \"set_fact\": {\"cinder_configure_lvm\": {\"if\": [\"cinder_configure_lvm\", true, false]}}}, {\"when\": \"cinder_configure_lvm|bool\", \"block\": [{\"name\": \"ensure LVM rpm dependencies are installed\", \"package\": {\"name\": \"lvm2\", \"state\": \"latest\"}}, {\"name\": \"cinder create LVM volume group dd\", \"command\": {\"list_join\": [\"\", [\"dd if=/dev/zero of=/var/lib/cinder/cinder-volumes bs=1 count=0 seek=\", {\"str_replace\": {\"template\": \"VALUE\", \"params\": {\"VALUE\": {\"get_param\": \"CinderLVMLoopDeviceSize\"}}}}, \"M\"]]}, \"args\": {\"creates\": \"/var/lib/cinder/cinder-volumes\"}}, {\"name\": \"Get or create LVM loopback device\", \"shell\": \"exit_code=0\\nexisting_device=$(losetup -j /var/lib/cinder/cinder-volumes -l -n -O NAME)\\nif [[ -z \\\"${existing_device}\\\" ]]; then\\n    losetup -f /var/lib/cinder/cinder-volumes --show\\n    exit_code=2\\nelse\\n    echo ${existing_device%$\'\\\\n\'*}\\nfi\\nexit ${exit_code}\", \"args\": {\"executable\": \"/bin/bash\"}, \"register\": \"_loopback_device\", \"changed_when\": \"_loopback_device.rc == 2\", \"failed_when\": \"_loopback_device.rc not in [0,2]\"}, {\"name\": \"Create LVM volume group\", \"community.general.lvg\": {\"vg\": \"cinder-volumes\", \"pvs\": \"{{ _loopback_device.stdout }}\", \"state\": \"present\"}, \"when\": [\"not (ansible_check_mode | bool)\"]}, {\"name\": \"cinder create service to run losetup for LVM on startup\", \"copy\": {\"dest\": \"/etc/systemd/system/cinder-lvm-losetup.service\", \"content\": \"[Unit]\\nDescription=Cinder LVM losetup\\nDefaultDependencies=no\\nConflicts=umount.target\\nRequires=lvm2-monitor.service systemd-udev-settle.service\\nBefore=local-fs.target umount.target\\nAfter=var.mount lvm2-monitor.service systemd-udev-settle.service\\n\\n[Service]\\nType=oneshot\\nExecStart=/sbin/losetup {{ _loopback_device.stdout }} /var/lib/cinder/cinder-volumes\\nExecStop=/sbin/losetup -d {{ _loopback_device.stdout }}\\nRemainAfterExit=yes\\n\\n[Install]\\nWantedBy=local-fs-pre.target\\n\"}, \"when\": [\"not (ansible_check_mode | bool)\"]}, {\"name\": \"cinder enable the LVM losetup service\", \"systemd\": {\"name\": \"cinder-lvm-losetup\", \"enabled\": true, \"daemon_reload\": true}}]}]]}}, \"cinder_volume_upgrade_tasks\": {\"description\": \"Upgrade tasks for the cinder-volume service (HA or non-HA)\", \"value\": [{\"name\": \"cinder-volume pre system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 3\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Unmount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}, \"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": \"image_conversion_nfs_enabled|bool\", \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"absent\", \"fstype\": \"nfs4\"}}]}, {\"name\": \"cinder-volume post system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 5\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}]}]}, \"cinder_volume_config_settings\": {\"description\": \"Config settings for the cinder-volume container (HA or non-HA)\", \"value\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", {\"cinder::image_conversion_dir\": \"/var/lib/cinder_image_conversion\"}, {}]}}, \"cinder_volume_volumes\": {\"description\": \"Volumes for the cinder-volume container (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}, {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}, {\"get_param\": \"CinderVolumeOptVolumes\"}, [\"/var/lib/kolla/config_files/cinder_volume.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/lib/modules:/lib/modules:ro\", \"/dev:/dev\", \"/run:/run\", \"/sys:/sys\", \"/var/lib/cinder:/var/lib/cinder:z\", \"/var/lib/iscsi:/var/lib/iscsi:z\"], {\"if\": [{\"get_param\": \"CinderEnableIscsiBackend\"}, [\"/etc/target:/etc/target:z\"]]}, {\"if\": [{\"get_param\": \"MultipathdEnable\"}, [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}, {\"if\": [\"cinder_nfs_conversion_dir_enabled\", [{\"str_replace\": {\"template\": \"DIR:DIR:slave\", \"params\": {\"DIR\": \"/var/lib/cinder_image_conversion\"}}}]]}]}}, \"cinder_volume_environment\": {\"description\": \"Docker environment for the cinder-volume container (HA or non-HA)\", \"value\": {\"map_merge\": [{\"get_param\": \"CinderVolumeOptEnvVars\"}, {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}]}}, \"cinder_backup_host_prep_tasks\": {\"description\": \"Host prep tasks for the cinder-backup service (HA or non-HA)\", \"value\": {\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}}, \"cinder_backup_volumes\": {\"description\": \"Volumes for the cinder-backup container (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}, {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}, {\"get_param\": \"CinderBackupOptVolumes\"}, [\"/var/lib/kolla/config_files/cinder_backup.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/dev:/dev\", \"/run:/run\", \"/sys:/sys\", \"/lib/modules:/lib/modules:ro\", \"/var/lib/cinder:/var/lib/cinder:z\", \"/var/lib/iscsi:/var/lib/iscsi:z\"], {\"if\": [{\"get_param\": \"MultipathdEnable\"}, [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}]}}, \"cinder_backup_environment\": {\"description\": \"Docker environment for the cinder-backup container (HA or non-HA)\", \"value\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(61,'2026-06-10 07:46:48',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Host config and reboot service which configures Kernel Args and reboot\", \"parameters\": {\"RoleNetIpMap\": {\"default\": {}, \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"KernelArgs\": {\"default\": \"\", \"type\": \"string\", \"description\": \"Kernel Args to apply to the host\", \"tags\": [\"role_specific\"]}, \"KernelArgsDeferReboot\": {\"default\": false, \"type\": \"boolean\", \"description\": \"When enabled, nodes will not get rebooted automatically by tripleo-kernel if KernelArgs have been changed. Operators will have to manually reboot nodes after the deployment or update process is completed.\\nLeaving this enabled during a scale-up operation will prevent reboot on new nodes. This might cause deployment errors as the KernelArgs will not be applied.\\n\", \"tags\": [\"role_specific\"]}, \"TunedProfileName\": {\"default\": \"throughput-performance\", \"type\": \"string\", \"description\": \"Tuned Profile to apply to the host\", \"tags\": [\"role_specific\"]}, \"IsolCpusList\": {\"default\": \"\", \"type\": \"string\", \"description\": \"List of logical CPU ids whic need to be isolated from the host processes. This input is provided to the tuned profile cpu-partitioning to configure systemd and repin interrupts (IRQ repinning).\\n\", \"tags\": [\"role_specific\"]}, \"NodeRebootWaitTimeout\": {\"default\": 900, \"type\": \"number\", \"description\": \"Timeout in seconds to specify the wait time for ansible node reboot\"}, \"Hugepages\": {\"default\": {}, \"type\": \"json\", \"description\": \"Hash for hugepage configuration Example:\\n  Hugepages:\\n    2048:\\n      count: 100\\n      default: false\\n    1048576:\\n      count: 100\\n      default: true\\n\", \"tags\": [\"role_specific\"]}, \"ReconfigureHugepages\": {\"default\": false, \"type\": \"boolean\", \"description\": \"By default, tripleo-kernel will configure the provided Hugepages as specified by operators but it won\'t try to remove Hugepages configured on the host that are not part of the TripleO paramater. Enabling this setting will make sure everything is reconfigured exactly like the TripleO parameter, otherwise we just add the content of the Hugepages parameter to what\'s already in place.\\n\", \"tags\": [\"role_specific\"]}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"tuned_profile\": \"TunedProfileName\", \"isolated_cores\": \"IsolCpusList\", \"kernel_args\": \"KernelArgs\", \"kernel_args_defer_reboot\": \"KernelArgsDeferReboot\", \"hugepages\": \"Hugepages\", \"reconfigure_hugepages\": \"ReconfigureHugepages\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"TunedProfileName\": {\"get_param\": \"TunedProfileName\"}, \"IsolCpusList\": {\"get_param\": \"IsolCpusList\"}, \"KernelArgs\": {\"get_param\": \"KernelArgs\"}, \"KernelArgsDeferReboot\": {\"get_param\": \"KernelArgsDeferReboot\"}, \"Hugepages\": {\"get_param\": \"Hugepages\"}, \"ReconfigureHugepages\": {\"get_param\": \"ReconfigureHugepages\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Host Config Service\", \"value\": {\"service_name\": \"boot_params_service\", \"deploy_steps_tasks\": [{\"name\": \"Configure tuned before reboot\", \"when\": \"step|int == 0\", \"include_role\": {\"name\": \"tuned\"}, \"vars\": {\"tuned_profile\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"tuned_profile\"]}, \"tuned_isolated_cores\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"isolated_cores\"]}}}, {\"name\": \"Configure kernel args and reboot\", \"when\": \"step|int == 0\", \"include_role\": {\"name\": \"tripleo_kernel\", \"tasks_from\": \"kernelargs.yml\"}, \"vars\": {\"tripleo_kernel_args\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"kernel_args\"]}, \"tripleo_kernel_hugepages\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"hugepages\"]}, \"tripleo_kernel_hugepages_remove\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"reconfigure_hugepages\"]}, \"tripleo_kernel_defer_reboot\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"kernel_args_defer_reboot\"]}, \"tripleo_kernel_reboot_timeout\": {\"get_param\": \"NodeRebootWaitTimeout\"}}}], \"upgrade_tasks\": [{\"name\": \"upgrade prepare for leapp to align kernel arg shortcommings in leapp\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_prepare\"], \"when\": [\"step|int == 3\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"fix grub entries to have name start with GRUB_\", \"replace\": {\"path\": \"/etc/default/grub\", \"regexp\": \"^(TRIPLEO_HEAT_TEMPLATE_KERNEL_ARGS)(.*)\", \"replace\": \"GRUB_\\\\1\\\\2\"}}, {\"name\": \"fix grub entries in append statement\", \"replace\": {\"path\": \"/etc/default/grub\", \"regexp\": \"(.*){(TRIPLEO_HEAT_TEMPLATE_KERNEL_ARGS)}(.*)\", \"replace\": \"\\\\1{GRUB_\\\\2}\\\\3\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(62,'2026-06-10 07:46:48',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Openstack Cinder NVMeOF backend\\n\", \"parameters\": {\"CinderEnableNVMeOFBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NVMeOF backend for Cinder\", \"type\": \"boolean\"}, \"CinderNVMeOFBackendName\": {\"type\": \"string\", \"default\": \"tripleo_nvmeof\"}, \"CinderNVMeOFAvailabilityZone\": {\"default\": \"\", \"description\": \"The availability zone of the NVMeOF Cinder backend. When set, it overrides the default CinderStorageAvailabilityZone.\\n\", \"type\": \"string\"}, \"CinderNVMeOFTargetPort\": {\"type\": \"number\", \"default\": 4420}, \"CinderNVMeOFTargetHelper\": {\"type\": \"string\", \"default\": \"nvmet\"}, \"CinderNVMeOFTargetProtocol\": {\"type\": \"string\", \"default\": \"nvmet_rdma\", \"description\": \"The target protocol, supported values are nvmet_rdma and nvmet_tcp.\\n\", \"constraints\": [{\"allowed_values\": [\"nvmet_rdma\", \"nvmet_tcp\"]}]}, \"CinderNVMeOFTargetPrefix\": {\"type\": \"string\", \"default\": \"nvme-subsystem\"}, \"CinderNVMeOFTargetPortId\": {\"type\": \"number\", \"default\": 1}, \"CinderNVMeOFTargetNameSpaceId\": {\"type\": \"number\", \"default\": 10}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"type\": \"json\", \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\"}}, \"outputs\": {\"cinder_nvmeof_host_prep_tasks\": {\"description\": \"Host prep tasks related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [{\"name\": \"ensure /etc/nvme exists\", \"file\": {\"path\": \"/etc/nvme\", \"state\": \"directory\", \"setype\": \"container_file_t\"}}]]}}, \"cinder_nvmeof_volumes\": {\"description\": \"Volumes related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [\"/etc/nvme:/etc/nvme:z\"]]}}, \"role_data\": {\"description\": \"Role data for the Cinder NVMeOF backend.\", \"value\": {\"service_name\": \"cinder_backend_nvmeof\", \"firewall_rules\": {\"120 LVM nvmet target\": {\"dport\": {\"get_param\": \"CinderNVMeOFTargetPort\"}}}, \"config_settings\": {\"map_merge\": [{\"tripleo::profile::base::cinder::volume::cinder_enable_nvmeof_backend\": {\"get_param\": \"CinderEnableNVMeOFBackend\"}, \"tripleo::profile::base::cinder::volume::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_port\": {\"get_param\": \"CinderNVMeOFTargetPort\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_helper\": {\"get_param\": \"CinderNVMeOFTargetHelper\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_protocol\": {\"get_param\": \"CinderNVMeOFTargetProtocol\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_prefix\": {\"get_param\": \"CinderNVMeOFTargetPrefix\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_port_id\": {\"get_param\": \"CinderNVMeOFTargetPortId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_ns_id\": {\"get_param\": \"CinderNVMeOFTargetNameSpaceId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_ip_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderIscsiNetwork\"]}}}}, \"cinder::backend::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}}, {\"if\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderNVMeOFAvailabilityZone\"}, \"\"]}}, {\"tripleo::profile::base::cinder::volume::nvmeof::backend_availability_zone\": {\"get_param\": \"CinderNVMeOFAvailabilityZone\"}}]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(63,'2026-06-10 07:46:49',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(64,'2026-06-10 07:46:49',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(65,'2026-06-10 07:46:49',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (66,'2026-06-10 07:46:50',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Cinder API service\\n\", \"parameters\": {\"ContainerCinderApiImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\"}, \"ContainerCinderConfigImage\": {\"description\": \"The container image to use for the cinder config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\"}, \"CinderApiLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.cinder.api\", \"file\": \"/var/log/containers/cinder/cinder-api.log\"}}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"DeployIdentifier\": {\"default\": 1781077560, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"CinderDefaultVolumeType\": {\"default\": \"tripleo\", \"description\": \"The name of Cinder\'s default volume type.\", \"type\": \"string\", \"constraints\": [{\"allowed_pattern\": \".*\\\\S.*\", \"description\": \"The default volume type name cannot be empty.\\n\"}]}, \"CinderEnableDBPurge\": {\"default\": true, \"description\": \"Whether to create cron job for purging soft deleted rows in Cinder database.\\n\", \"type\": \"boolean\"}, \"CinderPassword\": {\"description\": \"The password for the cinder service and db account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"gtBv0TkCYxjriNwpG4AlCd1ll\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"MonitoringSubscriptionCinderApi\": {\"default\": \"overcloud-cinder-api\", \"type\": \"string\"}, \"CinderWorkers\": {\"type\": \"string\", \"description\": \"Set the number of workers for cinder::wsgi::apache\", \"default\": 1}, \"CinderApiPolicies\": {\"description\": \"A hash of policies to configure for Cinder API.\\ne.g. { cinder-context_is_admin: { key: context_is_admin, value: \'role:admin\' } }\\n\", \"default\": {}, \"type\": \"json\"}, \"CinderApiWsgiTimeout\": {\"default\": 60, \"description\": \"The number of seconds until a Cinder API WSGI connection times out.\", \"type\": \"number\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"noop\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"RootStackName\": {\"description\": \"The name of the stack/plan.\", \"type\": \"string\", \"default\": \"overcloud\"}, \"MemcacheUseAdvancedPool\": {\"type\": \"boolean\", \"description\": \"Use the advanced (eventlet safe) memcached client pool.\\n\", \"default\": true}, \"AuthCloudName\": {\"description\": \"Entry in clouds.yaml to use for authentication\", \"type\": \"string\", \"default\": \"\"}}, \"conditions\": {\"auth_cloud_name_set\": {\"not\": {\"equals\": [{\"get_param\": \"AuthCloudName\"}, \"\"]}}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MySQLClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\"}, \"CinderBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-base.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"CinderCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml\"}, \"ApacheServiceBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}, \"EnableInternalTLS\": {\"get_param\": \"EnableInternalTLS\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerCinderApiImage\": \"ContainerCinderApiImage\", \"ContainerCinderConfigImage\": \"ContainerCinderConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerCinderApiImage\": {\"get_param\": \"ContainerCinderApiImage\"}, \"ContainerCinderConfigImage\": {\"get_param\": \"ContainerCinderConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Cinder API role.\", \"value\": {\"service_name\": \"cinder_api\", \"firewall_rules\": {\"119 cinder\": {\"dport\": [8776]}}, \"firewall_frontend_rules\": {\"100 cinder_haproxy_frontend\": {\"dport\": [8776]}}, \"firewall_ssl_frontend_rules\": {\"100 cinder_haproxy_frontend_ssl\": {\"dport\": [13776]}}, \"keystone_resources\": {\"cinder\": {\"users\": {\"cinder\": {\"password\": {\"get_param\": \"CinderPassword\"}, \"roles\": [\"admin\", \"service\"]}}}, \"cinderv3\": {\"endpoints\": {\"public\": {\"get_param\": [\"EndpointMap\", \"CinderV3Public\", \"uri\"]}, \"internal\": {\"get_param\": [\"EndpointMap\", \"CinderV3Internal\", \"uri\"]}, \"admin\": {\"get_param\": [\"EndpointMap\", \"CinderV3Admin\", \"uri\"]}}, \"users\": {\"cinderv3\": {\"password\": {\"get_param\": \"CinderPassword\"}, \"roles\": [\"admin\", \"service\"]}}, \"region\": {\"get_param\": \"KeystoneRegion\"}, \"service\": \"volumev3\"}}, \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionCinderApi\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"CinderBase\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"ApacheServiceBase\", \"role_data\", \"config_settings\"]}, {\"keystone_resources_managed\": false}, {\"cinder::keystone::authtoken::www_authenticate_uri\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"uri_no_suffix\"]}, \"cinder::keystone::authtoken::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"cinder::keystone::authtoken::password\": {\"get_param\": \"CinderPassword\"}, \"cinder::keystone::authtoken::project_name\": \"service\", \"cinder::keystone::authtoken::user_domain_name\": \"Default\", \"cinder::keystone::authtoken::project_domain_name\": \"Default\", \"cinder::keystone::authtoken::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"cinder::keystone::authtoken::interface\": \"internal\", \"cinder::keystone::authtoken::memcache_use_advanced_pool\": {\"get_param\": \"MemcacheUseAdvancedPool\"}, \"cinder::policy::policies\": {\"get_param\": \"CinderApiPolicies\"}, \"cinder::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"cinder::api::default_volume_type\": {\"get_param\": \"CinderDefaultVolumeType\"}, \"cinder::api::enable_proxy_headers_parsing\": true, \"tripleo::profile::base::cinder::cinder_enable_db_purge\": {\"get_param\": \"CinderEnableDBPurge\"}, \"cinder::api::bind_host\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}}}, \"cinder::wsgi::apache::ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"cinder::api::service_name\": \"httpd\", \"cinder::wsgi::apache::bind_host\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}}}, \"cinder::wsgi::apache::servername\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}}}, \"cinder::wsgi::apache::vhost_custom_fragment\": {\"str_replace\": {\"template\": \"Timeout TIMEOUT\", \"params\": {\"TIMEOUT\": {\"get_param\": \"CinderApiWsgiTimeout\"}}}}, \"cinder::wsgi::apache::workers\": {\"get_param\": \"CinderWorkers\"}}]}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_cinder_api\": [{\"get_param\": \"CinderApiLoggingSource\"}]}, \"mysql\": {\"cinder::db::mysql::password\": {\"get_param\": \"CinderPassword\"}, \"cinder::db::mysql::user\": \"cinder\", \"cinder::db::mysql::host\": \"%\", \"cinder::db::mysql::dbname\": \"cinder\"}}, \"puppet_config\": {\"config_volume\": \"cinder\", \"puppet_tags\": \"cinder_config,file,concat,file_line,cinder_api_paste_ini\", \"step_config\": {\"list_join\": [\"\\n\", [\"include tripleo::profile::base::cinder::api\", {\"get_attr\": [\"MySQLClient\", \"role_data\", \"step_config\"]}]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/cinder_api.json\": {\"command\": \"/usr/sbin/httpd -DFOREGROUND\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.d\", \"dest\": \"/etc/httpd/conf.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.modules.d\", \"dest\": \"/etc/httpd/conf.modules.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true, \"optional\": true}], \"permissions\": [{\"path\": \"/var/log/cinder\", \"owner\": \"cinder:cinder\", \"recurse\": true}, {\"path\": \"/etc/pki/tls/certs/etcd.crt\", \"owner\": \"cinder:cinder\"}, {\"path\": \"/etc/pki/tls/private/etcd.key\", \"owner\": \"cinder:cinder\"}]}, \"/var/lib/kolla/config_files/cinder_api_db_sync.json\": {\"command\": \"/usr/bin/bootstrap_host_exec cinder_api su cinder -s /bin/bash -c \'cinder-manage db sync --bump-versions\'\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.d\", \"dest\": \"/etc/httpd/conf.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.modules.d\", \"dest\": \"/etc/httpd/conf.modules.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true, \"optional\": true}], \"permissions\": [{\"path\": \"/var/log/cinder\", \"owner\": \"cinder:cinder\", \"recurse\": true}, {\"path\": \"/etc/pki/tls/certs/etcd.crt\", \"owner\": \"cinder:cinder\"}, {\"path\": \"/etc/pki/tls/private/etcd.key\", \"owner\": \"cinder:cinder\"}]}, \"/var/lib/kolla/config_files/cinder_api_cron.json\": {\"command\": \"/usr/sbin/crond -n\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/cinder\", \"owner\": \"cinder:cinder\", \"recurse\": true}]}}, \"docker_config\": {\"step_2\": {\"cinder_api_init_logs\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderApiImage\"]}, \"net\": \"none\", \"privileged\": false, \"user\": \"root\", \"volumes\": [\"/var/log/containers/cinder:/var/log/cinder:z\", \"/var/log/containers/httpd/cinder-api:/var/log/httpd:z\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R cinder:cinder /var/log/cinder\"]}}, \"step_3\": {\"cinder_api_db_sync\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderApiImage\"]}, \"cap_add\": [\"AUDIT_WRITE\"], \"net\": \"host\", \"privileged\": false, \"detach\": false, \"user\": \"root\", \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/cinder_api_db_sync.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [\"/etc/pki/tls/certs/httpd:/etc/pki/tls/certs/httpd:ro\", \"/etc/pki/tls/private/httpd:/etc/pki/tls/private/httpd:ro\"]]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\", \"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}}}}, \"step_4\": {\"cinder_api\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderApiImage\"]}, \"net\": \"host\", \"privileged\": false, \"restart\": \"always\", \"user\": \"root\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/cinder_api.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\", \"/var/log/containers/httpd/cinder-api:/var/log/httpd:z\"], {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [\"/etc/pki/tls/certs/httpd:/etc/pki/tls/certs/httpd:ro\", \"/etc/pki/tls/private/httpd:/etc/pki/tls/private/httpd:ro\"]]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}, \"cinder_api_cron\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderApiImage\"]}, \"net\": \"host\", \"user\": \"root\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/usr/share/openstack-tripleo-common/healthcheck/cron cinder\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/cinder_api_cron.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\", \"/var/log/containers/httpd/cinder-api:/var/log/httpd:z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"metadata_settings\": {\"get_attr\": [\"ApacheServiceBase\", \"role_data\", \"metadata_settings\"]}, \"deploy_steps_tasks\": {\"get_attr\": [\"ApacheServiceBase\", \"role_data\", \"deploy_steps_tasks\"]}, \"host_prep_tasks\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/log/containers/httpd/cinder-api\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}], \"external_upgrade_tasks\": [{\"when\": \"step|int == 1\", \"block\": [{\"name\": \"Online data migration for Cinder\", \"command\": \"{{ container_cli }} exec cinder_api cinder-manage db online_data_migrations\", \"delegate_to\": \"{{ (groups[\'cinder_api\'] | difference(groups[\'excluded_overcloud\']))[0] }}\", \"become\": true, \"tags\": [\"online_upgrade\", \"online_upgrade_cinder\"]}]}, {\"when\": \"step|int == 1\", \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop cinder api container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"cinder_api\", \"cinder_api_cron\"], \"tripleo_delegate_to\": \"{{ groups[\'cinder_api\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}], \"external_update_tasks\": [{\"when\": \"step|int == 1\", \"block\": [{\"name\": \"Online data migration for Cinder\", \"command\": \"{{ container_cli }} exec cinder_api cinder-manage db online_data_migrations\", \"delegate_to\": \"{{ (groups[\'cinder_api\'] | difference(groups[\'excluded_overcloud\']))[0] }}\", \"become\": true, \"tags\": [\"online_upgrade\", \"online_upgrade_cinder\"]}]}], \"external_deploy_tasks\": [{\"name\": \"Clean up legacy Cinder keystone catalog entries\", \"become\": true, \"openstack.cloud.catalog_service\": {\"cloud\": {\"if\": [\"auth_cloud_name_set\", {\"get_param\": \"AuthCloudName\"}, {\"get_param\": \"RootStackName\"}]}, \"name\": \"{{ item.service_name }}\", \"service_type\": \"{{ item.service_type }}\", \"state\": \"absent\"}, \"loop\": [{\"service_name\": \"cinderv2\", \"service_type\": \"volumev2\"}, {\"service_name\": \"cinderv3\", \"service_type\": \"volume\"}], \"loop_control\": {\"index_var\": \"cinder_api_service\"}, \"when\": [\"step|int == 4\", \"not ansible_check_mode|bool\"]}, {\"name\": \"Manage Cinder\'s default volume type\", \"become\": true, \"vars\": {\"default_volume_type\": {\"get_param\": \"CinderDefaultVolumeType\"}}, \"environment\": {\"OS_CLOUD\": {\"if\": [\"auth_cloud_name_set\", {\"get_param\": \"AuthCloudName\"}, {\"get_param\": \"RootStackName\"}]}}, \"when\": [\"step|int == 5\", \"not ansible_check_mode|bool\"], \"shell\": \"if ! openstack volume type show \\\"{{ default_volume_type }}\\\"; then\\n    openstack volume type create --public \\\"{{ default_volume_type }}\\\"\\nfi\\neval $(openstack volume type show __DEFAULT__ -f shell -c id -c description)\\nif [ -n \\\"$id\\\" ]; then\\n    if ! openstack volume type delete $id ; then\\n        tripleo_descr=\\\"For internal use, \'{{ default_volume_type }}\' is the default volume type\\\"\\n        if [ \\\"$description\\\" != \\\"$tripleo_descr\\\" ]; then\\n            openstack volume type set $id --description \\\"$tripleo_descr\\\"\\n        fi\\n    fi\\nfi\\n\", \"args\": {\"executable\": \"/bin/bash\"}, \"changed_when\": false}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(67,'2026-06-10 07:46:50',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Cinder Scheduler service\\n\", \"parameters\": {\"ContainerCinderSchedulerImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\"}, \"ContainerCinderConfigImage\": {\"description\": \"The container image to use for the cinder config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\"}, \"CinderSchedulerLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.cinder.scheduler\", \"file\": \"/var/log/containers/cinder/cinder-scheduler.log\"}}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"MonitoringSubscriptionCinderScheduler\": {\"default\": \"overcloud-cinder-scheduler\", \"type\": \"string\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MySQLClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\"}, \"CinderBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-base.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"CinderCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerCinderSchedulerImage\": \"ContainerCinderSchedulerImage\", \"ContainerCinderConfigImage\": \"ContainerCinderConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerCinderSchedulerImage\": {\"get_param\": \"ContainerCinderSchedulerImage\"}, \"ContainerCinderConfigImage\": {\"get_param\": \"ContainerCinderConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Cinder Scheduler role.\", \"value\": {\"service_name\": \"cinder_scheduler\", \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionCinderScheduler\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"CinderBase\", \"role_data\", \"config_settings\"]}, {\"cinder::scheduler::scheduler_driver\": \"cinder.scheduler.filter_scheduler.FilterScheduler\"}]}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_cinder_scheduler\": [{\"get_param\": \"CinderSchedulerLoggingSource\"}]}}, \"puppet_config\": {\"config_volume\": \"cinder\", \"puppet_tags\": \"cinder_config,file,concat,file_line\", \"step_config\": {\"list_join\": [\"\\n\", [\"include tripleo::profile::base::cinder::scheduler\"], [{\"get_attr\": [\"CinderBase\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"MySQLClient\", \"role_data\", \"step_config\"]}]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/cinder_scheduler.json\": {\"command\": \"/usr/bin/cinder-scheduler --config-file /usr/share/cinder/cinder-dist.conf --config-file /etc/cinder/cinder.conf\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true, \"optional\": true}], \"permissions\": [{\"path\": \"/var/log/cinder\", \"owner\": \"cinder:cinder\", \"recurse\": true}, {\"path\": \"/etc/pki/tls/certs/etcd.crt\", \"owner\": \"cinder:cinder\"}, {\"path\": \"/etc/pki/tls/private/etcd.key\", \"owner\": \"cinder:cinder\"}]}}, \"docker_config\": {\"step_2\": {\"cinder_scheduler_init_logs\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderSchedulerImage\"]}, \"net\": \"none\", \"privileged\": false, \"user\": \"root\", \"volumes\": [\"/var/log/containers/cinder:/var/log/cinder:z\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R cinder:cinder /var/log/cinder\"]}}, \"step_4\": {\"cinder_scheduler\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderSchedulerImage\"]}, \"net\": \"host\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"get_attr\": [\"ContainersCommon\", \"healthcheck_rpc_port\"]}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"CinderCommon\", \"cinder_common_volumes\"]}, [\"/var/lib/kolla/config_files/cinder_scheduler.json:/var/lib/kolla/config_files/config.json:ro\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"host_prep_tasks\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}, {\"name\": \"enable virt_sandbox_use_netlink for healthcheck\", \"seboolean\": {\"name\": \"virt_sandbox_use_netlink\", \"persistent\": true, \"state\": true}, \"when\": [\"ansible_facts.selinux is defined\", \"ansible_facts.selinux.status == \\\"enabled\\\"\"]}], \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop cinder scheduler container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"cinder_scheduler\"], \"tripleo_delegate_to\": \"{{ groups[\'cinder_scheduler\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(68,'2026-06-10 07:46:50',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Provides the list of common container volumes and environment used by various cinder services.\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"CinderVolumeOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\"}, \"CinderBackupOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\"}, \"CinderVolumeOptEnvVars\": {\"default\": {}, \"description\": \"hash of optional environment variables\", \"type\": \"json\"}, \"CinderEnableIscsiBackend\": {\"default\": true, \"description\": \"Whether to enable or not the Iscsi backend for Cinder\", \"type\": \"boolean\"}, \"CinderEnableNVMeOFBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NVMeOF backend for Cinder\", \"type\": \"boolean\"}, \"CinderLVMConfigureVG\": {\"default\": true, \"description\": \"Whether to configure the \'cinder-volumes\' VG used by the LVM driver. When disabled (set to False), the LVM driver will work as long as the \'cinder-volumes\' VG has been created through some other means.\\n\", \"type\": \"boolean\"}, \"CinderLVMLoopDeviceSize\": {\"default\": 20480, \"description\": \"The size of the loopback file used by the cinder LVM driver.\", \"type\": \"number\"}, \"MultipathdEnable\": {\"default\": false, \"description\": \"Whether to enable the multipath daemon\", \"type\": \"boolean\"}, \"CinderVolumeCluster\": {\"default\": \"\", \"description\": \"The cluster name used for deploying the cinder-volume service in an active-active (A/A) configuration. This configuration requires the Cinder backend drivers support A/A, and the cinder-volume service not be managed by pacemaker. If these criteria are not met then the cluster name must be left blank.\\n\", \"type\": \"string\"}, \"CinderImageConversionNfsShare\": {\"default\": \"\", \"description\": \"When set, the NFS share to be used for Cinder\'s image conversion directory.\", \"type\": \"string\"}, \"CinderImageConversionNfsOptions\": {\"default\": \"_netdev,bg,intr,context=system_u:object_r:container_file_t:s0\", \"description\": \"NFS mount options when using an NFS share for Cinder\'s image conversion directory.\", \"type\": \"string\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"EnableEtcdInternalTLS\": {\"description\": \"Controls whether etcd and the cinder-volume service use TLS for cinder\'s lock manager, even when the rest of the internal API network is using TLS.\", \"type\": \"boolean\", \"default\": true}, \"CephConfigPath\": {\"type\": \"string\", \"default\": \"/var/lib/tripleo-config/ceph\", \"description\": \"The path where the Ceph Cluster config files are stored on the host.\\n\"}, \"CephClientUserName\": {\"default\": \"openstack\", \"type\": \"string\"}, \"CephClusterName\": {\"type\": \"string\", \"default\": \"ceph\", \"description\": \"The Ceph cluster name.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9]+\", \"description\": \"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\n\"}]}, \"CephExternalMultiConfig\": {\"type\": \"json\", \"hidden\": true, \"description\": \"List of maps describing extra overrides which will be applied when configuring\\nextra external Ceph clusters. If this list is non-empty, ceph-ansible will run\\nan extra count(list) times using the same parameters as the first run except\\neach parameter within each map will override the defaults. If the following\\nwere used, the second run would configure the overcloud to also use the ceph2\\ncluster with all the previous parameters except /etc/ceph/ceph2.conf would have\\na mon_host entry containing the value of external_cluster_mon_ips below, and\\nnot the default CephExternalMonHost. Subsequent ceph-ansible runs are restricted\\nto just ceph clients. CephExternalMultiConfig may not be used to deploy additional\\ninternal Ceph clusters within one Heat stack. The map for each list should contain\\nnot tripleo-heat-template parameters but ceph-ansible parameters.\\n  - cluster: \'ceph2\'\\n    fsid: \'e2cba068-5f14-4b0f-b047-acf375c0004a\'\\n    external_cluster_mon_ips: \'172.18.0.5,172.18.0.6,172.18.0.7\'\\n    keys:\\n      - name: \\\"client.openstack\\\"\\n        caps:\\n          mgr: \\\"allow *\\\"\\n          mon: \\\"profile rbd\\\"\\n          osd: \\\"osd: profile rbd pool=volumes, profile rbd pool=backups, profile rbd pool=vms, profile rbd pool=images\\\"\\n        key: \\\"AQCwmeRcAAAAABAA6SQU/bGqFjlfLro5KxrB1Q==\\\"\\n        mode: \\\"0600\\\"\\n    dashboard_enabled: false\\n\", \"default\": []}}, \"conditions\": {\"cvol_active_active_tls_enabled\": {\"and\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderVolumeCluster\"}, \"\"]}}, {\"get_param\": \"EnableInternalTLS\"}, {\"get_param\": \"EnableEtcdInternalTLS\"}]}, \"cinder_nfs_conversion_dir_enabled\": {\"not\": {\"equals\": [{\"get_param\": \"CinderImageConversionNfsShare\"}, \"\"]}}, \"cinder_configure_lvm\": {\"and\": [{\"get_param\": \"CinderLVMConfigureVG\"}, {\"or\": [{\"get_param\": \"CinderEnableIscsiBackend\"}, {\"get_param\": \"CinderEnableNVMeOFBackend\"}]}]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"CinderNVMeOF\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml\"}}, \"outputs\": {\"cinder_image_conversion_nfs_dir\": {\"description\": \"The directory where cinder does its image conversion when the directory is backed by an NFS share.\", \"value\": \"/var/lib/cinder_image_conversion\"}, \"cinder_common_host_prep_tasks\": {\"description\": \"Common host prep tasks for cinder-volume and cinder-backup services\", \"value\": {\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}}, \"cinder_common_volumes\": {\"description\": \"Common volumes for all cinder services\", \"value\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}}, \"cinder_common_kolla_config_files\": {\"description\": \"Common kolla config_files for cinder-volume and cinder-backup services\", \"value\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-ceph/\", \"dest\": \"/etc/ceph/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-iscsid/*\", \"dest\": \"/etc/iscsi/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true, \"optional\": true}]}, \"cinder_common_kolla_permissions\": {\"description\": \"Common kolla permissions for cinder-volume and cinder-backup services\", \"value\": {\"list_concat\": [[{\"path\": \"/var/log/cinder\", \"owner\": \"cinder:cinder\", \"recurse\": true}, {\"path\": {\"str_replace\": {\"template\": \"/etc/ceph/CLUSTER.client.USER.keyring\", \"params\": {\"CLUSTER\": {\"get_param\": \"CephClusterName\"}, \"USER\": {\"get_param\": \"CephClientUserName\"}}}}, \"owner\": \"cinder:cinder\", \"perm\": \"0600\"}, {\"path\": \"/etc/pki/tls/certs/etcd.crt\", \"owner\": \"cinder:cinder\"}, {\"path\": \"/etc/pki/tls/private/etcd.key\", \"owner\": \"cinder:cinder\"}], {\"repeat\": {\"template\": {\"path\": \"/etc/ceph/<%cluster%>.client.*.keyring\", \"owner\": \"cinder:cinder\", \"perm\": \"0600\"}, \"for_each\": {\"<%cluster%>\": {\"yaql\": {\"expression\": \"$.data.multiconfig.select($.cluster)\", \"data\": {\"multiconfig\": {\"get_param\": \"CephExternalMultiConfig\"}}}}}}}]}}, \"cinder_volume_host_prep_and_system_upgrade_post_tasks\": {\"description\": \"Common host_prep and system_upgrade post tasks for cinder-volume\", \"value\": [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}]}, \"cinder_volume_host_prep_tasks\": {\"description\": \"Host prep tasks for the cinder-volume service (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}, [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}], [{\"name\": \"cinder_configure_lvm fact\", \"set_fact\": {\"cinder_configure_lvm\": {\"if\": [\"cinder_configure_lvm\", true, false]}}}, {\"when\": \"cinder_configure_lvm|bool\", \"block\": [{\"name\": \"ensure LVM rpm dependencies are installed\", \"package\": {\"name\": \"lvm2\", \"state\": \"latest\"}}, {\"name\": \"cinder create LVM volume group dd\", \"command\": {\"list_join\": [\"\", [\"dd if=/dev/zero of=/var/lib/cinder/cinder-volumes bs=1 count=0 seek=\", {\"str_replace\": {\"template\": \"VALUE\", \"params\": {\"VALUE\": {\"get_param\": \"CinderLVMLoopDeviceSize\"}}}}, \"M\"]]}, \"args\": {\"creates\": \"/var/lib/cinder/cinder-volumes\"}}, {\"name\": \"Get or create LVM loopback device\", \"shell\": \"exit_code=0\\nexisting_device=$(losetup -j /var/lib/cinder/cinder-volumes -l -n -O NAME)\\nif [[ -z \\\"${existing_device}\\\" ]]; then\\n    losetup -f /var/lib/cinder/cinder-volumes --show\\n    exit_code=2\\nelse\\n    echo ${existing_device%$\'\\\\n\'*}\\nfi\\nexit ${exit_code}\", \"args\": {\"executable\": \"/bin/bash\"}, \"register\": \"_loopback_device\", \"changed_when\": \"_loopback_device.rc == 2\", \"failed_when\": \"_loopback_device.rc not in [0,2]\"}, {\"name\": \"Create LVM volume group\", \"community.general.lvg\": {\"vg\": \"cinder-volumes\", \"pvs\": \"{{ _loopback_device.stdout }}\", \"state\": \"present\"}, \"when\": [\"not (ansible_check_mode | bool)\"]}, {\"name\": \"cinder create service to run losetup for LVM on startup\", \"copy\": {\"dest\": \"/etc/systemd/system/cinder-lvm-losetup.service\", \"content\": \"[Unit]\\nDescription=Cinder LVM losetup\\nDefaultDependencies=no\\nConflicts=umount.target\\nRequires=lvm2-monitor.service systemd-udev-settle.service\\nBefore=local-fs.target umount.target\\nAfter=var.mount lvm2-monitor.service systemd-udev-settle.service\\n\\n[Service]\\nType=oneshot\\nExecStart=/sbin/losetup {{ _loopback_device.stdout }} /var/lib/cinder/cinder-volumes\\nExecStop=/sbin/losetup -d {{ _loopback_device.stdout }}\\nRemainAfterExit=yes\\n\\n[Install]\\nWantedBy=local-fs-pre.target\\n\"}, \"when\": [\"not (ansible_check_mode | bool)\"]}, {\"name\": \"cinder enable the LVM losetup service\", \"systemd\": {\"name\": \"cinder-lvm-losetup\", \"enabled\": true, \"daemon_reload\": true}}]}]]}}, \"cinder_volume_upgrade_tasks\": {\"description\": \"Upgrade tasks for the cinder-volume service (HA or non-HA)\", \"value\": [{\"name\": \"cinder-volume pre system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 3\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Unmount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}, \"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": \"image_conversion_nfs_enabled|bool\", \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"absent\", \"fstype\": \"nfs4\"}}]}, {\"name\": \"cinder-volume post system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 5\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}]}]}, \"cinder_volume_config_settings\": {\"description\": \"Config settings for the cinder-volume container (HA or non-HA)\", \"value\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", {\"cinder::image_conversion_dir\": \"/var/lib/cinder_image_conversion\"}, {}]}}, \"cinder_volume_volumes\": {\"description\": \"Volumes for the cinder-volume container (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}, {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}, {\"get_param\": \"CinderVolumeOptVolumes\"}, [\"/var/lib/kolla/config_files/cinder_volume.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/lib/modules:/lib/modules:ro\", \"/dev:/dev\", \"/run:/run\", \"/sys:/sys\", \"/var/lib/cinder:/var/lib/cinder:z\", \"/var/lib/iscsi:/var/lib/iscsi:z\"], {\"if\": [{\"get_param\": \"CinderEnableIscsiBackend\"}, [\"/etc/target:/etc/target:z\"]]}, {\"if\": [{\"get_param\": \"MultipathdEnable\"}, [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}, {\"if\": [\"cinder_nfs_conversion_dir_enabled\", [{\"str_replace\": {\"template\": \"DIR:DIR:slave\", \"params\": {\"DIR\": \"/var/lib/cinder_image_conversion\"}}}]]}]}}, \"cinder_volume_environment\": {\"description\": \"Docker environment for the cinder-volume container (HA or non-HA)\", \"value\": {\"map_merge\": [{\"get_param\": \"CinderVolumeOptEnvVars\"}, {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}]}}, \"cinder_backup_host_prep_tasks\": {\"description\": \"Host prep tasks for the cinder-backup service (HA or non-HA)\", \"value\": {\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}}, \"cinder_backup_volumes\": {\"description\": \"Volumes for the cinder-backup container (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}, {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}, {\"get_param\": \"CinderBackupOptVolumes\"}, [\"/var/lib/kolla/config_files/cinder_backup.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/dev:/dev\", \"/run:/run\", \"/sys:/sys\", \"/lib/modules:/lib/modules:ro\", \"/var/lib/cinder:/var/lib/cinder:z\", \"/var/lib/iscsi:/var/lib/iscsi:z\"], {\"if\": [{\"get_param\": \"MultipathdEnable\"}, [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}]}}, \"cinder_backup_environment\": {\"description\": \"Docker environment for the cinder-backup container (HA or non-HA)\", \"value\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(69,'2026-06-10 07:46:50',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Provides the list of common container volumes and environment used by various cinder services.\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"CinderVolumeOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\"}, \"CinderBackupOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\"}, \"CinderVolumeOptEnvVars\": {\"default\": {}, \"description\": \"hash of optional environment variables\", \"type\": \"json\"}, \"CinderEnableIscsiBackend\": {\"default\": true, \"description\": \"Whether to enable or not the Iscsi backend for Cinder\", \"type\": \"boolean\"}, \"CinderEnableNVMeOFBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NVMeOF backend for Cinder\", \"type\": \"boolean\"}, \"CinderLVMConfigureVG\": {\"default\": true, \"description\": \"Whether to configure the \'cinder-volumes\' VG used by the LVM driver. When disabled (set to False), the LVM driver will work as long as the \'cinder-volumes\' VG has been created through some other means.\\n\", \"type\": \"boolean\"}, \"CinderLVMLoopDeviceSize\": {\"default\": 20480, \"description\": \"The size of the loopback file used by the cinder LVM driver.\", \"type\": \"number\"}, \"MultipathdEnable\": {\"default\": false, \"description\": \"Whether to enable the multipath daemon\", \"type\": \"boolean\"}, \"CinderVolumeCluster\": {\"default\": \"\", \"description\": \"The cluster name used for deploying the cinder-volume service in an active-active (A/A) configuration. This configuration requires the Cinder backend drivers support A/A, and the cinder-volume service not be managed by pacemaker. If these criteria are not met then the cluster name must be left blank.\\n\", \"type\": \"string\"}, \"CinderImageConversionNfsShare\": {\"default\": \"\", \"description\": \"When set, the NFS share to be used for Cinder\'s image conversion directory.\", \"type\": \"string\"}, \"CinderImageConversionNfsOptions\": {\"default\": \"_netdev,bg,intr,context=system_u:object_r:container_file_t:s0\", \"description\": \"NFS mount options when using an NFS share for Cinder\'s image conversion directory.\", \"type\": \"string\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"EnableEtcdInternalTLS\": {\"description\": \"Controls whether etcd and the cinder-volume service use TLS for cinder\'s lock manager, even when the rest of the internal API network is using TLS.\", \"type\": \"boolean\", \"default\": true}, \"CephConfigPath\": {\"type\": \"string\", \"default\": \"/var/lib/tripleo-config/ceph\", \"description\": \"The path where the Ceph Cluster config files are stored on the host.\\n\"}, \"CephClientUserName\": {\"default\": \"openstack\", \"type\": \"string\"}, \"CephClusterName\": {\"type\": \"string\", \"default\": \"ceph\", \"description\": \"The Ceph cluster name.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9]+\", \"description\": \"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\n\"}]}, \"CephExternalMultiConfig\": {\"type\": \"json\", \"hidden\": true, \"description\": \"List of maps describing extra overrides which will be applied when configuring\\nextra external Ceph clusters. If this list is non-empty, ceph-ansible will run\\nan extra count(list) times using the same parameters as the first run except\\neach parameter within each map will override the defaults. If the following\\nwere used, the second run would configure the overcloud to also use the ceph2\\ncluster with all the previous parameters except /etc/ceph/ceph2.conf would have\\na mon_host entry containing the value of external_cluster_mon_ips below, and\\nnot the default CephExternalMonHost. Subsequent ceph-ansible runs are restricted\\nto just ceph clients. CephExternalMultiConfig may not be used to deploy additional\\ninternal Ceph clusters within one Heat stack. The map for each list should contain\\nnot tripleo-heat-template parameters but ceph-ansible parameters.\\n  - cluster: \'ceph2\'\\n    fsid: \'e2cba068-5f14-4b0f-b047-acf375c0004a\'\\n    external_cluster_mon_ips: \'172.18.0.5,172.18.0.6,172.18.0.7\'\\n    keys:\\n      - name: \\\"client.openstack\\\"\\n        caps:\\n          mgr: \\\"allow *\\\"\\n          mon: \\\"profile rbd\\\"\\n          osd: \\\"osd: profile rbd pool=volumes, profile rbd pool=backups, profile rbd pool=vms, profile rbd pool=images\\\"\\n        key: \\\"AQCwmeRcAAAAABAA6SQU/bGqFjlfLro5KxrB1Q==\\\"\\n        mode: \\\"0600\\\"\\n    dashboard_enabled: false\\n\", \"default\": []}}, \"conditions\": {\"cvol_active_active_tls_enabled\": {\"and\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderVolumeCluster\"}, \"\"]}}, {\"get_param\": \"EnableInternalTLS\"}, {\"get_param\": \"EnableEtcdInternalTLS\"}]}, \"cinder_nfs_conversion_dir_enabled\": {\"not\": {\"equals\": [{\"get_param\": \"CinderImageConversionNfsShare\"}, \"\"]}}, \"cinder_configure_lvm\": {\"and\": [{\"get_param\": \"CinderLVMConfigureVG\"}, {\"or\": [{\"get_param\": \"CinderEnableIscsiBackend\"}, {\"get_param\": \"CinderEnableNVMeOFBackend\"}]}]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"CinderNVMeOF\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml\"}}, \"outputs\": {\"cinder_image_conversion_nfs_dir\": {\"description\": \"The directory where cinder does its image conversion when the directory is backed by an NFS share.\", \"value\": \"/var/lib/cinder_image_conversion\"}, \"cinder_common_host_prep_tasks\": {\"description\": \"Common host prep tasks for cinder-volume and cinder-backup services\", \"value\": {\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}}, \"cinder_common_volumes\": {\"description\": \"Common volumes for all cinder services\", \"value\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}}, \"cinder_common_kolla_config_files\": {\"description\": \"Common kolla config_files for cinder-volume and cinder-backup services\", \"value\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-ceph/\", \"dest\": \"/etc/ceph/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-iscsid/*\", \"dest\": \"/etc/iscsi/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true, \"optional\": true}]}, \"cinder_common_kolla_permissions\": {\"description\": \"Common kolla permissions for cinder-volume and cinder-backup services\", \"value\": {\"list_concat\": [[{\"path\": \"/var/log/cinder\", \"owner\": \"cinder:cinder\", \"recurse\": true}, {\"path\": {\"str_replace\": {\"template\": \"/etc/ceph/CLUSTER.client.USER.keyring\", \"params\": {\"CLUSTER\": {\"get_param\": \"CephClusterName\"}, \"USER\": {\"get_param\": \"CephClientUserName\"}}}}, \"owner\": \"cinder:cinder\", \"perm\": \"0600\"}, {\"path\": \"/etc/pki/tls/certs/etcd.crt\", \"owner\": \"cinder:cinder\"}, {\"path\": \"/etc/pki/tls/private/etcd.key\", \"owner\": \"cinder:cinder\"}], {\"repeat\": {\"template\": {\"path\": \"/etc/ceph/<%cluster%>.client.*.keyring\", \"owner\": \"cinder:cinder\", \"perm\": \"0600\"}, \"for_each\": {\"<%cluster%>\": {\"yaql\": {\"expression\": \"$.data.multiconfig.select($.cluster)\", \"data\": {\"multiconfig\": {\"get_param\": \"CephExternalMultiConfig\"}}}}}}}]}}, \"cinder_volume_host_prep_and_system_upgrade_post_tasks\": {\"description\": \"Common host_prep and system_upgrade post tasks for cinder-volume\", \"value\": [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}]}, \"cinder_volume_host_prep_tasks\": {\"description\": \"Host prep tasks for the cinder-volume service (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}, [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}], [{\"name\": \"cinder_configure_lvm fact\", \"set_fact\": {\"cinder_configure_lvm\": {\"if\": [\"cinder_configure_lvm\", true, false]}}}, {\"when\": \"cinder_configure_lvm|bool\", \"block\": [{\"name\": \"ensure LVM rpm dependencies are installed\", \"package\": {\"name\": \"lvm2\", \"state\": \"latest\"}}, {\"name\": \"cinder create LVM volume group dd\", \"command\": {\"list_join\": [\"\", [\"dd if=/dev/zero of=/var/lib/cinder/cinder-volumes bs=1 count=0 seek=\", {\"str_replace\": {\"template\": \"VALUE\", \"params\": {\"VALUE\": {\"get_param\": \"CinderLVMLoopDeviceSize\"}}}}, \"M\"]]}, \"args\": {\"creates\": \"/var/lib/cinder/cinder-volumes\"}}, {\"name\": \"Get or create LVM loopback device\", \"shell\": \"exit_code=0\\nexisting_device=$(losetup -j /var/lib/cinder/cinder-volumes -l -n -O NAME)\\nif [[ -z \\\"${existing_device}\\\" ]]; then\\n    losetup -f /var/lib/cinder/cinder-volumes --show\\n    exit_code=2\\nelse\\n    echo ${existing_device%$\'\\\\n\'*}\\nfi\\nexit ${exit_code}\", \"args\": {\"executable\": \"/bin/bash\"}, \"register\": \"_loopback_device\", \"changed_when\": \"_loopback_device.rc == 2\", \"failed_when\": \"_loopback_device.rc not in [0,2]\"}, {\"name\": \"Create LVM volume group\", \"community.general.lvg\": {\"vg\": \"cinder-volumes\", \"pvs\": \"{{ _loopback_device.stdout }}\", \"state\": \"present\"}, \"when\": [\"not (ansible_check_mode | bool)\"]}, {\"name\": \"cinder create service to run losetup for LVM on startup\", \"copy\": {\"dest\": \"/etc/systemd/system/cinder-lvm-losetup.service\", \"content\": \"[Unit]\\nDescription=Cinder LVM losetup\\nDefaultDependencies=no\\nConflicts=umount.target\\nRequires=lvm2-monitor.service systemd-udev-settle.service\\nBefore=local-fs.target umount.target\\nAfter=var.mount lvm2-monitor.service systemd-udev-settle.service\\n\\n[Service]\\nType=oneshot\\nExecStart=/sbin/losetup {{ _loopback_device.stdout }} /var/lib/cinder/cinder-volumes\\nExecStop=/sbin/losetup -d {{ _loopback_device.stdout }}\\nRemainAfterExit=yes\\n\\n[Install]\\nWantedBy=local-fs-pre.target\\n\"}, \"when\": [\"not (ansible_check_mode | bool)\"]}, {\"name\": \"cinder enable the LVM losetup service\", \"systemd\": {\"name\": \"cinder-lvm-losetup\", \"enabled\": true, \"daemon_reload\": true}}]}]]}}, \"cinder_volume_upgrade_tasks\": {\"description\": \"Upgrade tasks for the cinder-volume service (HA or non-HA)\", \"value\": [{\"name\": \"cinder-volume pre system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 3\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Unmount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}, \"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": \"image_conversion_nfs_enabled|bool\", \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"absent\", \"fstype\": \"nfs4\"}}]}, {\"name\": \"cinder-volume post system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 5\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}]}]}, \"cinder_volume_config_settings\": {\"description\": \"Config settings for the cinder-volume container (HA or non-HA)\", \"value\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", {\"cinder::image_conversion_dir\": \"/var/lib/cinder_image_conversion\"}, {}]}}, \"cinder_volume_volumes\": {\"description\": \"Volumes for the cinder-volume container (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}, {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}, {\"get_param\": \"CinderVolumeOptVolumes\"}, [\"/var/lib/kolla/config_files/cinder_volume.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/lib/modules:/lib/modules:ro\", \"/dev:/dev\", \"/run:/run\", \"/sys:/sys\", \"/var/lib/cinder:/var/lib/cinder:z\", \"/var/lib/iscsi:/var/lib/iscsi:z\"], {\"if\": [{\"get_param\": \"CinderEnableIscsiBackend\"}, [\"/etc/target:/etc/target:z\"]]}, {\"if\": [{\"get_param\": \"MultipathdEnable\"}, [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}, {\"if\": [\"cinder_nfs_conversion_dir_enabled\", [{\"str_replace\": {\"template\": \"DIR:DIR:slave\", \"params\": {\"DIR\": \"/var/lib/cinder_image_conversion\"}}}]]}]}}, \"cinder_volume_environment\": {\"description\": \"Docker environment for the cinder-volume container (HA or non-HA)\", \"value\": {\"map_merge\": [{\"get_param\": \"CinderVolumeOptEnvVars\"}, {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}]}}, \"cinder_backup_host_prep_tasks\": {\"description\": \"Host prep tasks for the cinder-backup service (HA or non-HA)\", \"value\": {\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}}, \"cinder_backup_volumes\": {\"description\": \"Volumes for the cinder-backup container (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}, {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}, {\"get_param\": \"CinderBackupOptVolumes\"}, [\"/var/lib/kolla/config_files/cinder_backup.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/dev:/dev\", \"/run:/run\", \"/sys:/sys\", \"/lib/modules:/lib/modules:ro\", \"/var/lib/cinder:/var/lib/cinder:z\", \"/var/lib/iscsi:/var/lib/iscsi:z\"], {\"if\": [{\"get_param\": \"MultipathdEnable\"}, [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}]}}, \"cinder_backup_environment\": {\"description\": \"Docker environment for the cinder-backup container (HA or non-HA)\", \"value\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(70,'2026-06-10 07:46:50',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Cinder Backup service\\n\", \"parameters\": {\"ContainerCinderBackupImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\"}, \"ContainerCinderConfigImage\": {\"description\": \"The container image to use for the cinder config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"CephClusterName\": {\"type\": \"string\", \"default\": \"ceph\", \"description\": \"The Ceph cluster name.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9]+\", \"description\": \"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\n\"}]}, \"CephClientUserName\": {\"default\": \"openstack\", \"type\": \"string\"}, \"DockerCinderBackupLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.cinder.backup\", \"file\": \"/var/log/containers/cinder/cinder-backup.log\"}}, \"CinderBackupBackend\": {\"default\": \"swift\", \"description\": \"The short name of the Cinder Backup backend to use.\", \"type\": \"string\", \"constraints\": [{\"allowed_values\": [\"swift\", \"ceph\", \"nfs\", \"gcs\", \"s3\"]}]}, \"CinderBackupWorkers\": {\"type\": \"number\", \"default\": 1, \"description\": \"The number of cinder-backup processes to launch.\"}, \"CinderBackupMaxOperations\": {\"type\": \"number\", \"default\": 15, \"description\": \"The maximum number of concurrent cinder backup/restore operations (0 means unlimited).\"}, \"CinderBackupCompressionAlgorithm\": {\"default\": \"zlib\", \"description\": \"The compression algorithm used by Cinder Backup backends that are based on Cinder\'s \\\"chunked\\\" backup driver. This includes the swift, nfs, gcs and s3 backends. The ceph backend does not support the feature.\", \"type\": \"string\", \"constraints\": [{\"allowed_values\": [\"none\", \"zlib\", \"bzip2\", \"zstd\"]}]}, \"CinderBackupRbdClusterName\": {\"type\": \"string\", \"default\": \"\", \"description\": \"The Ceph cluster where backups are to be stored. If no value is specified then the CephClusterName value is used.\"}, \"CinderBackupRbdClientUserName\": {\"default\": \"\", \"type\": \"string\", \"description\": \"The Ceph client name used by the backup service. If no value is specified then the CephClientUserName value is used.\"}, \"CinderBackupRbdPoolName\": {\"default\": \"backups\", \"type\": \"string\"}, \"CinderBackupNfsShare\": {\"default\": \"\", \"description\": \"NFS share to be mounted\", \"type\": \"string\"}, \"CinderBackupNfsMountOptions\": {\"default\": \"context=system_u:object_r:container_file_t:s0\", \"description\": \"Mount options passed to the NFS client. See NFS man page for details.\", \"type\": \"string\"}, \"CinderBackupGcsCredentials\": {\"default\": {}, \"description\": \"The GCS service account credentials, in JSON format.\", \"type\": \"json\"}, \"CinderBackupGcsProjectId\": {\"default\": \"\", \"description\": \"The GCS project ID.\", \"type\": \"string\"}, \"CinderBackupGcsBucket\": {\"default\": \"volumebackups\", \"description\": \"The GCS bucket where backups are to be stored.\", \"type\": \"string\"}, \"CinderBackupGcsBucketLocation\": {\"default\": \"\", \"description\": \"If set, it specifies the location where the GCS bucket should be created.\", \"type\": \"string\"}, \"CinderBackupS3EndpointUrl\": {\"default\": \"\", \"description\": \"The URL where the S3 server is listening.\", \"type\": \"string\"}, \"CinderBackupS3AccessKey\": {\"default\": \"\", \"description\": \"The S3 query token access key.\", \"type\": \"string\"}, \"CinderBackupS3SecretKey\": {\"default\": \"\", \"description\": \"The S3 query token secret key.\", \"type\": \"string\"}, \"CinderBackupS3Bucket\": {\"default\": \"volumebackups\", \"description\": \"The S3 bucket where backups are to be stored.\", \"type\": \"string\"}, \"MonitoringSubscriptionCinderBackup\": {\"default\": \"overcloud-cinder-backup\", \"type\": \"string\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MySQLClient\": {\"type\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-client.yaml\"}, \"CinderBase\": {\"type\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-base.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"CinderCommon\": {\"type\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerCinderBackupImage\": \"ContainerCinderBackupImage\", \"ContainerCinderConfigImage\": \"ContainerCinderConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerCinderBackupImage\": {\"get_param\": \"ContainerCinderBackupImage\"}, \"ContainerCinderConfigImage\": {\"get_param\": \"ContainerCinderConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Cinder Backup role.\", \"value\": {\"service_name\": \"cinder_backup\", \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionCinderBackup\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"CinderBase\", \"role_data\", \"config_settings\"]}, {\"cinder::backup::backup_workers\": {\"get_param\": \"CinderBackupWorkers\"}, \"cinder::backup::backup_max_operations\": {\"get_param\": \"CinderBackupMaxOperations\"}}, {\"if\": [{\"equals\": [{\"get_param\": \"CinderBackupBackend\"}, \"ceph\"]}, {\"cinder::backup::ceph::backup_ceph_user\": {\"str_replace\": {\"template\": \"USERNAME\", \"params\": {\"USERNAME\": {\"if\": [{\"equals\": [{\"get_param\": \"CinderBackupRbdClientUserName\"}, \"\"]}, {\"get_param\": \"CephClientUserName\"}, {\"get_param\": \"CinderBackupRbdClientUserName\"}]}}}}, \"cinder::backup::ceph::backup_ceph_pool\": {\"get_param\": \"CinderBackupRbdPoolName\"}, \"cinder::backup::ceph::backup_ceph_conf\": {\"str_replace\": {\"template\": \"/etc/ceph/CLUSTER.conf\", \"params\": {\"CLUSTER\": {\"if\": [{\"equals\": [{\"get_param\": \"CinderBackupRbdClusterName\"}, \"\"]}, {\"get_param\": \"CephClusterName\"}, {\"get_param\": \"CinderBackupRbdClusterName\"}]}}}}}]}, {\"if\": [{\"equals\": [{\"get_param\": \"CinderBackupBackend\"}, \"swift\"]}, {\"cinder::backup::swift::backup_swift_container\": \"volumebackups\", \"cinder::backup::swift::backup_compression_algorithm\": {\"get_param\": \"CinderBackupCompressionAlgorithm\"}, \"cinder::backup::swift::swift_catalog_info\": \"object-store:swift:internalURL\"}]}, {\"if\": [{\"equals\": [{\"get_param\": \"CinderBackupBackend\"}, \"nfs\"]}, {\"cinder::backup::nfs::backup_share\": {\"get_param\": \"CinderBackupNfsShare\"}, \"cinder::backup::nfs::backup_mount_options\": {\"get_param\": \"CinderBackupNfsMountOptions\"}, \"cinder::backup::nfs::backup_compression_algorithm\": {\"get_param\": \"CinderBackupCompressionAlgorithm\"}}]}, {\"if\": [{\"equals\": [{\"get_param\": \"CinderBackupBackend\"}, \"gcs\"]}, {\"tripleo::profile::base::cinder::backup::gcs::credentials\": {\"get_param\": \"CinderBackupGcsCredentials\"}, \"cinder::backup::google::backup_gcs_project_id\": {\"get_param\": \"CinderBackupGcsProjectId\"}, \"cinder::backup::google::backup_gcs_bucket\": {\"get_param\": \"CinderBackupGcsBucket\"}, \"cinder::backup::google::backup_gcs_bucket_location\": {\"get_param\": \"CinderBackupGcsBucketLocation\"}, \"cinder::config::cinder_config\": {\"DEFAULT/backup_compression_algorithm\": {\"value\": {\"get_param\": \"CinderBackupCompressionAlgorithm\"}}}}]}, {\"if\": [{\"equals\": [{\"get_param\": \"CinderBackupBackend\"}, \"s3\"]}, {\"cinder::backup::s3::backup_s3_endpoint_url\": {\"get_param\": \"CinderBackupS3EndpointUrl\"}, \"cinder::backup::s3::backup_s3_store_access_key\": {\"get_param\": \"CinderBackupS3AccessKey\"}, \"cinder::backup::s3::backup_s3_store_secret_key\": {\"get_param\": \"CinderBackupS3SecretKey\"}, \"cinder::backup::s3::backup_s3_store_bucket\": {\"get_param\": \"CinderBackupS3Bucket\"}, \"cinder::backup::s3::backup_compression_algorithm\": {\"get_param\": \"CinderBackupCompressionAlgorithm\"}}]}]}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_cinder_backup\": [{\"get_param\": \"DockerCinderBackupLoggingSource\"}]}}, \"puppet_config\": {\"config_volume\": \"cinder\", \"puppet_tags\": \"cinder_config,file,concat,file_line\", \"step_config\": {\"list_join\": [\"\\n\", [{\"get_attr\": [\"CinderBase\", \"role_data\", \"step_config\"]}, {\"str_replace\": {\"template\": \"include tripleo::profile::base::cinder::backup::DRIVER\", \"params\": {\"DRIVER\": {\"get_param\": \"CinderBackupBackend\"}}}}, {\"get_attr\": [\"MySQLClient\", \"role_data\", \"step_config\"]}]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/cinder_backup.json\": {\"command\": \"/usr/bin/cinder-backup --config-file /usr/share/cinder/cinder-dist.conf --config-file /etc/cinder/cinder.conf\", \"config_files\": {\"get_attr\": [\"CinderCommon\", \"cinder_common_kolla_config_files\"]}, \"permissions\": {\"get_attr\": [\"CinderCommon\", \"cinder_common_kolla_permissions\"]}}}, \"docker_config\": {\"step_3\": {\"cinder_backup_init_logs\": {\"start_order\": 0, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}, \"net\": \"none\", \"privileged\": false, \"user\": \"root\", \"volumes\": [\"/var/log/containers/cinder:/var/log/cinder:z\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R cinder:cinder /var/log/cinder\"]}}, \"step_4\": {\"cinder_backup\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}, \"ipc\": \"host\", \"net\": \"host\", \"privileged\": true, \"user\": \"root\", \"restart\": \"always\", \"healthcheck\": {\"get_attr\": [\"ContainersCommon\", \"healthcheck_rpc_port\"]}, \"volumes\": {\"get_attr\": [\"CinderCommon\", \"cinder_backup_volumes\"]}, \"environment\": {\"get_attr\": [\"CinderCommon\", \"cinder_backup_environment\"]}}}}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"CinderCommon\", \"cinder_backup_host_prep_tasks\"]}, [{\"name\": \"enable virt_sandbox_use_netlink for healthcheck\", \"seboolean\": {\"name\": \"virt_sandbox_use_netlink\", \"persistent\": true, \"state\": true}, \"when\": [\"ansible_facts.selinux is defined\", \"ansible_facts.selinux.status == \\\"enabled\\\"\"]}]]}, \"deploy_steps_tasks\": [{\"name\": \"Clean up when switching cinder-backup from pcmk to active-active\", \"when\": [\"step|int == 1\"], \"become\": true, \"block\": [{\"name\": \"Check if cinder-backup is running under pacemaker\", \"command\": \"pcs status\", \"register\": \"cinder_backup_pcs_status\", \"check_mode\": false, \"failed_when\": false, \"changed_when\": false}, {\"when\": [\"\\\"cinder-backup\\\" in cinder_backup_pcs_status.stdout\"], \"block\": [{\"name\": \"Remove the openstack-cinder-backup pcs resource\", \"pacemaker_resource\": {\"resource\": \"openstack-cinder-backup\", \"state\": \"delete\"}, \"run_once\": true}, {\"name\": \"Identify the cinder-backup pcmklatest container image\", \"shell\": \"{{container_cli}} images | awk \'$1 ~ \\\"cinder-backup\\\" && $2 == \\\"pcmklatest\\\" {print $1\\\":\\\"$2}\'\", \"register\": \"cinder_backup_pcmklatest_image\", \"check_mode\": false, \"changed_when\": false}, {\"name\": \"Remove the cinder-backup pcmklatest container image\", \"command\": \"{{container_cli}} rmi {{cinder_backup_pcmklatest_image.stdout}}\", \"when\": [\"cinder_backup_pcmklatest_image.stdout|length > 0\"]}]}]}], \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop cinder backup container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"cinder_backup\"], \"tripleo_delegate_to\": \"{{ groups[\'cinder_backup\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"CephClientUserName\": \"openstack\", \"CinderBackupBackend\": \"swift\", \"CinderBackupRbdPoolName\": \"backups\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(71,'2026-06-10 07:46:50',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Openstack Cinder NVMeOF backend\\n\", \"parameters\": {\"CinderEnableNVMeOFBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NVMeOF backend for Cinder\", \"type\": \"boolean\"}, \"CinderNVMeOFBackendName\": {\"type\": \"string\", \"default\": \"tripleo_nvmeof\"}, \"CinderNVMeOFAvailabilityZone\": {\"default\": \"\", \"description\": \"The availability zone of the NVMeOF Cinder backend. When set, it overrides the default CinderStorageAvailabilityZone.\\n\", \"type\": \"string\"}, \"CinderNVMeOFTargetPort\": {\"type\": \"number\", \"default\": 4420}, \"CinderNVMeOFTargetHelper\": {\"type\": \"string\", \"default\": \"nvmet\"}, \"CinderNVMeOFTargetProtocol\": {\"type\": \"string\", \"default\": \"nvmet_rdma\", \"description\": \"The target protocol, supported values are nvmet_rdma and nvmet_tcp.\\n\", \"constraints\": [{\"allowed_values\": [\"nvmet_rdma\", \"nvmet_tcp\"]}]}, \"CinderNVMeOFTargetPrefix\": {\"type\": \"string\", \"default\": \"nvme-subsystem\"}, \"CinderNVMeOFTargetPortId\": {\"type\": \"number\", \"default\": 1}, \"CinderNVMeOFTargetNameSpaceId\": {\"type\": \"number\", \"default\": 10}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"type\": \"json\", \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\"}}, \"outputs\": {\"cinder_nvmeof_host_prep_tasks\": {\"description\": \"Host prep tasks related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [{\"name\": \"ensure /etc/nvme exists\", \"file\": {\"path\": \"/etc/nvme\", \"state\": \"directory\", \"setype\": \"container_file_t\"}}]]}}, \"cinder_nvmeof_volumes\": {\"description\": \"Volumes related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [\"/etc/nvme:/etc/nvme:z\"]]}}, \"role_data\": {\"description\": \"Role data for the Cinder NVMeOF backend.\", \"value\": {\"service_name\": \"cinder_backend_nvmeof\", \"firewall_rules\": {\"120 LVM nvmet target\": {\"dport\": {\"get_param\": \"CinderNVMeOFTargetPort\"}}}, \"config_settings\": {\"map_merge\": [{\"tripleo::profile::base::cinder::volume::cinder_enable_nvmeof_backend\": {\"get_param\": \"CinderEnableNVMeOFBackend\"}, \"tripleo::profile::base::cinder::volume::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_port\": {\"get_param\": \"CinderNVMeOFTargetPort\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_helper\": {\"get_param\": \"CinderNVMeOFTargetHelper\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_protocol\": {\"get_param\": \"CinderNVMeOFTargetProtocol\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_prefix\": {\"get_param\": \"CinderNVMeOFTargetPrefix\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_port_id\": {\"get_param\": \"CinderNVMeOFTargetPortId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_ns_id\": {\"get_param\": \"CinderNVMeOFTargetNameSpaceId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_ip_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderIscsiNetwork\"]}}}}, \"cinder::backend::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}}, {\"if\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderNVMeOFAvailabilityZone\"}, \"\"]}}, {\"tripleo::profile::base::cinder::volume::nvmeof::backend_availability_zone\": {\"get_param\": \"CinderNVMeOFAvailabilityZone\"}}]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(72,'2026-06-10 07:46:50',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Openstack Cinder NVMeOF backend\\n\", \"parameters\": {\"CinderEnableNVMeOFBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NVMeOF backend for Cinder\", \"type\": \"boolean\"}, \"CinderNVMeOFBackendName\": {\"type\": \"string\", \"default\": \"tripleo_nvmeof\"}, \"CinderNVMeOFAvailabilityZone\": {\"default\": \"\", \"description\": \"The availability zone of the NVMeOF Cinder backend. When set, it overrides the default CinderStorageAvailabilityZone.\\n\", \"type\": \"string\"}, \"CinderNVMeOFTargetPort\": {\"type\": \"number\", \"default\": 4420}, \"CinderNVMeOFTargetHelper\": {\"type\": \"string\", \"default\": \"nvmet\"}, \"CinderNVMeOFTargetProtocol\": {\"type\": \"string\", \"default\": \"nvmet_rdma\", \"description\": \"The target protocol, supported values are nvmet_rdma and nvmet_tcp.\\n\", \"constraints\": [{\"allowed_values\": [\"nvmet_rdma\", \"nvmet_tcp\"]}]}, \"CinderNVMeOFTargetPrefix\": {\"type\": \"string\", \"default\": \"nvme-subsystem\"}, \"CinderNVMeOFTargetPortId\": {\"type\": \"number\", \"default\": 1}, \"CinderNVMeOFTargetNameSpaceId\": {\"type\": \"number\", \"default\": 10}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"type\": \"json\", \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\"}}, \"outputs\": {\"cinder_nvmeof_host_prep_tasks\": {\"description\": \"Host prep tasks related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [{\"name\": \"ensure /etc/nvme exists\", \"file\": {\"path\": \"/etc/nvme\", \"state\": \"directory\", \"setype\": \"container_file_t\"}}]]}}, \"cinder_nvmeof_volumes\": {\"description\": \"Volumes related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [\"/etc/nvme:/etc/nvme:z\"]]}}, \"role_data\": {\"description\": \"Role data for the Cinder NVMeOF backend.\", \"value\": {\"service_name\": \"cinder_backend_nvmeof\", \"firewall_rules\": {\"120 LVM nvmet target\": {\"dport\": {\"get_param\": \"CinderNVMeOFTargetPort\"}}}, \"config_settings\": {\"map_merge\": [{\"tripleo::profile::base::cinder::volume::cinder_enable_nvmeof_backend\": {\"get_param\": \"CinderEnableNVMeOFBackend\"}, \"tripleo::profile::base::cinder::volume::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_port\": {\"get_param\": \"CinderNVMeOFTargetPort\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_helper\": {\"get_param\": \"CinderNVMeOFTargetHelper\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_protocol\": {\"get_param\": \"CinderNVMeOFTargetProtocol\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_prefix\": {\"get_param\": \"CinderNVMeOFTargetPrefix\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_port_id\": {\"get_param\": \"CinderNVMeOFTargetPortId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_ns_id\": {\"get_param\": \"CinderNVMeOFTargetNameSpaceId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_ip_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderIscsiNetwork\"]}}}}, \"cinder::backend::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}}, {\"if\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderNVMeOFAvailabilityZone\"}, \"\"]}}, {\"tripleo::profile::base::cinder::volume::nvmeof::backend_availability_zone\": {\"get_param\": \"CinderNVMeOFAvailabilityZone\"}}]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(73,'2026-06-10 07:46:50',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(74,'2026-06-10 07:46:51',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Apache service configured with Puppet. Note this is typically included automatically via other services which run via Apache.\\n\", \"parameters\": {\"ApacheMaxRequestWorkers\": {\"default\": 100, \"description\": \"Maximum number of simultaneously processed requests.\", \"type\": \"number\"}, \"ApacheServerLimit\": {\"default\": 100, \"description\": \"Maximum number of Apache processes.\", \"type\": \"number\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"ApacheCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}, \"ApacheTimeout\": {\"type\": \"number\", \"default\": 90, \"description\": \"The timeout in seconds for Apache, which defines duration Apache waits for I/O operations\"}}, \"conditions\": {\"key_size_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"ApacheCertificateKeySize\"}, \"\"]}}}, \"resources\": {\"ApacheNetworks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"Controller\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"CellController\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"CellControllerCompute\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"Compute\": [\"ctlplane\", \"storage\", \"internal_api\"], \"BlockStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"ObjectStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"CephStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\"], \"Networker\": [\"ctlplane\", \"internal_api\"]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Apache role.\", \"value\": {\"service_name\": \"apache\", \"config_settings\": {\"map_merge\": [{\"apache::ip\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ApacheNetwork\"]}}}}, \"apache::default_vhost\": false, \"apache::trace_enable\": \"Off\", \"apache::server_signature\": \"Off\", \"apache::server_tokens\": \"Prod\", \"apache::timeout\": {\"get_param\": \"ApacheTimeout\"}, \"apache::default_mods\": false, \"apache::mod::prefork::maxrequestworkers\": {\"get_param\": \"ApacheMaxRequestWorkers\"}, \"apache::mod::prefork::serverlimit\": {\"get_param\": \"ApacheServerLimit\"}, \"apache::mod::remoteip::proxy_ips\": {\"get_param\": [\"ServiceData\", \"net_cidr_map\", {\"get_param\": [\"ServiceNetMap\", \"ApacheNetwork\"]}]}, \"apache::mod::alias::icons_options\": \"None\"}, {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"apache::mod::ssl::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}, \"apache::mod::ssl::ssl_protocol\": [\"all\", \"-SSLv2\", \"-SSLv3\", \"-TLSv1\"], \"apache_certificates_specs\": {\"map_merge\": {\"repeat\": {\"template\": {\"httpd-NETWORK\": {\"service_certificate\": \"/etc/pki/tls/certs/httpd/httpd-NETWORK.crt\", \"service_key\": \"/etc/pki/tls/private/httpd/httpd-NETWORK.key\"}}, \"for_each\": {\"NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}}}]}]}, \"metadata_settings\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"repeat\": {\"template\": [{\"service\": \"HTTP\", \"network\": \"$NETWORK\", \"type\": \"node\"}], \"for_each\": {\"$NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}]}, \"upgrade_tasks\": [], \"deploy_steps_tasks\": [{\"name\": \"Certificate generation\", \"when\": [\"step|int == 1\", \"enable_internal_tls\"], \"block\": [{\"name\": \"Create dirs for certificates and keys\", \"file\": {\"path\": \"{{ item }}\", \"state\": \"directory\", \"serole\": \"object_r\", \"setype\": \"cert_t\", \"seuser\": \"system_u\"}, \"with_items\": [\"/etc/pki/tls/certs/httpd\", \"/etc/pki/tls/private/httpd\"]}, {\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": {\"repeat\": {\"template\": {\"name\": \"httpd-NETWORK\", \"dns\": \"{{ fqdn_NETWORK }}\", \"principal\": \"HTTP/{{ fqdn_NETWORK }}@{{ idm_realm }}\", \"run_after\": \"cp /etc/pki/tls/certs/httpd-NETWORK.crt /etc/pki/tls/certs/httpd/httpd-NETWORK.crt\\ncp /etc/pki/tls/private/httpd-NETWORK.key /etc/pki/tls/private/httpd/httpd-NETWORK.key\\npkill -USR1 httpd\\n\", \"key_size\": {\"if\": [\"key_size_override_set\", {\"get_param\": \"ApacheCertificateKeySize\"}, {\"get_param\": \"CertificateKeySize\"}]}, \"ca\": \"ipa\"}, \"for_each\": {\"NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"EnableInternalTLS\": false}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(75,'2026-06-10 07:46:51',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (76,'2026-06-10 07:46:51',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(77,'2026-06-10 07:46:52',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Cinder Volume service\\n\", \"parameters\": {\"ContainerCinderVolumeImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\"}, \"ContainerCinderConfigImage\": {\"description\": \"The container image to use for the cinder config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\"}, \"ClusterCommonTag\": {\"default\": false, \"description\": \"When set to false, a pacemaker service is configured to use a floating tag for its container image name, e.g. \'REGISTRY/NAMESPACE/IMAGENAME:pcmklatest\'. When set to true, the service uses a floating prefix as well, e.g. \'cluster.common.tag/IMAGENAME:pcmklatest\'.\", \"type\": \"boolean\"}, \"ClusterFullTag\": {\"default\": true, \"description\": \"When set to true, the pacemaker service uses a fully constant tag for its container image name, e.g. \'cluster.common.tag/SERVICENAME:pcmklatest\'.\", \"type\": \"boolean\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ConfigDebug\": {\"default\": false, \"description\": \"Whether to run config management (e.g. Puppet) in debug mode.\", \"type\": \"boolean\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}, \"DeployIdentifier\": {\"default\": 1781077560, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}, \"CinderVolumeLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.cinder.volume\", \"file\": \"/var/log/containers/cinder/cinder-volume.log\"}}, \"CephConfigPath\": {\"type\": \"string\", \"default\": \"/var/lib/tripleo-config/ceph\", \"description\": \"The path where the Ceph Cluster config files are stored on the host.\\n\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MySQLClient\": {\"type\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-client.yaml\"}, \"CinderBase\": {\"type\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"CinderCommon\": {\"type\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerCinderVolumeImage\": \"ContainerCinderVolumeImage\", \"ContainerCinderConfigImage\": \"ContainerCinderConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerCinderVolumeImage\": {\"get_param\": \"ContainerCinderVolumeImage\"}, \"ContainerCinderConfigImage\": {\"get_param\": \"ContainerCinderConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Cinder Volume role.\", \"value\": {\"service_name\": \"cinder_volume\", \"firewall_rules\": {\"get_attr\": [\"CinderBase\", \"role_data\", \"firewall_rules\"]}, \"monitoring_subscription\": {\"get_attr\": [\"CinderBase\", \"role_data\", \"monitoring_subscription\"]}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"CinderBase\", \"role_data\", \"config_settings\"]}, {\"tripleo::profile::base::lvm::enable_udev\": false, \"tripleo::profile::pacemaker::cinder::volume_bundle::cinder_volume_docker_image\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/cinder-volume:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"tripleo::profile::pacemaker::cinder::volume_bundle::docker_volumes\": {\"get_attr\": [\"CinderCommon\", \"cinder_volume_volumes\"]}, \"tripleo::profile::pacemaker::cinder::volume_bundle::docker_environment\": {\"get_attr\": [\"CinderCommon\", \"cinder_volume_environment\"]}, \"tripleo::profile::pacemaker::cinder::volume_bundle::container_backend\": {\"get_param\": \"ContainerCli\"}, \"tripleo::profile::pacemaker::cinder::volume_bundle::ceph_conf_path\": {\"get_param\": \"CephConfigPath\"}, \"cinder::volume::manage_service\": false, \"cinder::volume::enabled\": false, \"cinder::backend_host\": \"hostgroup\"}]}, \"service_config_settings\": {\"get_attr\": [\"CinderBase\", \"role_data\", \"service_config_settings\"]}, \"puppet_config\": {\"config_volume\": \"cinder\", \"puppet_tags\": \"cinder_config,file,concat,file_line\", \"step_config\": {\"list_join\": [\"\\n\", [\"include tripleo::profile::base::lvm\"], [\"include tripleo::profile::pacemaker::cinder::volume_bundle\", {\"get_attr\": [\"MySQLClient\", \"role_data\", \"step_config\"]}]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/cinder_volume.json\": {\"command\": \"/usr/bin/cinder-volume --config-file /usr/share/cinder/cinder-dist.conf --config-file /etc/cinder/cinder.conf\", \"config_files\": {\"get_attr\": [\"CinderCommon\", \"cinder_common_kolla_config_files\"]}, \"permissions\": {\"get_attr\": [\"CinderCommon\", \"cinder_common_kolla_permissions\"]}}}, \"container_config_scripts\": {\"get_attr\": [\"ContainersCommon\", \"container_config_scripts\"]}, \"docker_config\": {\"step_3\": {\"cinder_volume_init_logs\": {\"start_order\": 0, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}, \"net\": \"none\", \"privileged\": false, \"user\": \"root\", \"volumes\": [\"/var/log/containers/cinder:/var/log/cinder\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R cinder:cinder /var/log/cinder\"]}}}, \"host_prep_tasks\": {\"get_attr\": [\"CinderCommon\", \"cinder_volume_host_prep_tasks\"]}, \"deploy_steps_tasks\": [{\"name\": \"Cinder Volume tag container image for pacemaker\", \"when\": \"step|int == 1\", \"import_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}, \"container_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/cinder-volume:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}}}, {\"name\": \"Cinder Volume HA Wrappers Step\", \"when\": \"step|int == 5\", \"block\": [{\"name\": \"Cinder volume puppet bundle\", \"import_role\": {\"name\": \"tripleo_ha_wrapper\"}, \"vars\": {\"tripleo_ha_wrapper_service_name\": \"cinder_volume\", \"tripleo_ha_wrapper_resource_name\": \"openstack-cinder-volume\", \"tripleo_ha_wrapper_bundle_name\": \"openstack-cinder-volume\", \"tripleo_ha_wrapper_resource_state\": \"_ Started\", \"tripleo_ha_wrapper_puppet_config_volume\": \"cinder\", \"tripleo_ha_wrapper_puppet_execute\": \"include ::tripleo::profile::base::pacemaker; include ::tripleo::profile::pacemaker::cinder::volume_bundle\", \"tripleo_ha_wrapper_puppet_tags\": \"pacemaker::resource::bundle,pacemaker::property,pacemaker::resource::ip,pacemaker::resource::ocf,pacemaker::constraint::order,pacemaker::constraint::colocation\", \"tripleo_ha_wrapper_puppet_debug\": {\"get_param\": \"ConfigDebug\"}, \"tripleo_ha_wrapper_config_suffix\": \".cinder_volume_previous_run\"}}]}], \"external_update_tasks\": [{\"when\": \"step|int == 1\", \"tags\": \"ha_image_update\", \"block\": [{\"block\": [{\"name\": \"Get cinder_volume image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_cinder_volume_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'openstack-cinder-volume\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container cinder_volume image\", \"set_fact\": {\"cinder_volume_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}, \"cinder_volume_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/cinder-volume:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"pcmk_cinder_volume_image\": \"{{xmllint_pcmk_cinder_volume_image.stdout}}\"}}], \"delegate_to\": \"{{ (groups[\\\"cinder_volume\\\"] | difference(groups[\\\"excluded_overcloud\\\"]))[0] }}\"}, {\"name\": \"cinder-volume temporary pacemaker container tag in case of image switch\", \"become\": true, \"import_role\": {\"name\": \"tripleo_ha_image_update\"}, \"vars\": {\"tripleo_ha_image_update_node_names\": \"{{ groups[\\\"cinder_volume\\\"] | difference(groups[\\\"excluded_overcloud\\\"]) }}\", \"tripleo_ha_image_update_bundle\": \"openstack-cinder-volume\", \"tripleo_ha_image_update_new_image\": \"{{cinder_volume_image_latest}}\", \"tripleo_ha_image_update_old_image\": \"{{pcmk_cinder_volume_image}}\"}, \"when\": [\"(pcmk_cinder_volume_image != \\\"\\\")\", \"(pcmk_cinder_volume_image != cinder_volume_image_latest)\"]}]}], \"update_tasks\": [{\"block\": [{\"name\": \"Get cinder_volume image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_cinder_volume_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'openstack-cinder-volume\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container cinder_volume image\", \"set_fact\": {\"cinder_volume_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}, \"cinder_volume_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/cinder-volume:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"pcmk_cinder_volume_image\": \"{{xmllint_pcmk_cinder_volume_image.stdout}}\"}}], \"when\": \"(step|int == 0 or step|int == 2)\"}, {\"name\": \"Check for update of cinder-volume container image name\", \"when\": \"step|int == 0\", \"assert\": {\"that\": \"pcmk_cinder_volume_image == cinder_volume_image_latest\", \"fail_msg\": \"cinder-volume image change detected, run overcloud external-update --tags ha_image_update first\"}}, {\"name\": \"Tear-down non-HA cinder_volume container\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"Remove non-HA cinder_volume container\", \"include_role\": {\"name\": \"tripleo_container_rm\"}, \"vars\": {\"tripleo_container_cli\": \"{{ container_cli }}\", \"tripleo_containers_to_rm\": [\"cinder_volume\"]}}]}, {\"name\": \"cinder_volume fetch and retag container image for pacemaker\", \"when\": \"step|int == 2\", \"block\": [{\"name\": \"Retag pcmklatest to latest cinder_volume image\", \"include_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{cinder_volume_image}}\", \"container_image_latest\": \"{{cinder_volume_image_latest}}\"}}]}], \"post_update_tasks\": [{\"name\": \"Cinder volume bundle post update\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"Cinder volume puppet bundle\", \"import_role\": {\"name\": \"tripleo_ha_wrapper\"}, \"vars\": {\"tripleo_ha_wrapper_service_name\": \"cinder_volume\", \"tripleo_ha_wrapper_resource_name\": \"openstack-cinder-volume\", \"tripleo_ha_wrapper_bundle_name\": \"openstack-cinder-volume\", \"tripleo_ha_wrapper_resource_state\": \"_ Started\", \"tripleo_ha_wrapper_puppet_config_volume\": \"cinder\", \"tripleo_ha_wrapper_puppet_execute\": \"include ::tripleo::profile::base::pacemaker; include ::tripleo::profile::pacemaker::cinder::volume_bundle\", \"tripleo_ha_wrapper_puppet_tags\": \"pacemaker::resource::bundle,pacemaker::property,pacemaker::resource::ip,pacemaker::resource::ocf,pacemaker::constraint::order,pacemaker::constraint::colocation\", \"tripleo_ha_wrapper_puppet_debug\": {\"get_param\": \"ConfigDebug\"}, \"tripleo_ha_wrapper_config_suffix\": \".cinder_volume_previous_run\"}}], \"vars\": {\"tripleo_ha_wrapper_minor_update\": true}}], \"upgrade_tasks\": {\"list_concat\": [[{\"name\": \"Tear-down non-HA cinder_volume container\", \"when\": [\"step|int == 0\"], \"block\": [{\"name\": \"Remove non-HA cinder_volume container\", \"include_role\": {\"name\": \"tripleo_container_rm\"}, \"vars\": {\"tripleo_container_cli\": \"{{ container_cli }}\", \"tripleo_containers_to_rm\": [\"cinder_volume\"]}}]}, {\"name\": \"Prepare switch of cinder_volume image name\", \"when\": [\"step|int == 0\"], \"block\": [{\"name\": \"Get cinder_volume image id currently used by pacemaker\", \"shell\": \"pcs resource config openstack-cinder-volume | grep -Eo \'image=[^ ]+\' | awk -F= \'{print $2;}\'\", \"register\": \"cinder_volume_image_current_res\", \"failed_when\": false}, {\"name\": \"cinder_volume image facts\", \"set_fact\": {\"cinder_volume_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/cinder-volume:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"cinder_volume_image_current\": \"{{cinder_volume_image_current_res.stdout}}\"}}, {\"name\": \"Temporarily tag the current cinder_volume image id with the upgraded image name\", \"import_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{cinder_volume_image_current}}\", \"container_image_latest\": \"{{cinder_volume_image_latest}}\", \"pull_image\": false}, \"when\": [\"cinder_volume_image_current != \'\'\", \"cinder_volume_image_current != cinder_volume_image_latest\"]}, {\"name\": \"Create cinder_volume retag statefile\", \"file\": {\"path\": \"/var/lib/tripleo/cinder_volume_needs_retag\", \"state\": \"touch\"}, \"when\": [\"cinder_volume_image_current != \'\'\", \"cinder_volume_image_current != cinder_volume_image_latest\"]}]}, {\"name\": \"Update cinder_volume pcs resource bundle for new container image\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"set is_cinder_volume_bootstrap_node fact\", \"tags\": \"common\", \"set_fact\": \"is_cinder_volume_bootstrap_node={{cinder_volume_short_bootstrap_node_name|lower == ansible_facts[\'hostname\']|lower}}\"}, {\"name\": \"Check for cinder_volume retag statefile\", \"stat\": {\"path\": \"/var/lib/tripleo/cinder_volume_needs_retag\"}, \"register\": \"cinder_volume_retag_state_file\"}]}, {\"name\": \"Update cinder_volume pcs resource bundle for new container image\", \"when\": [\"step|int == 1\", \"is_cinder_volume_bootstrap_node\", \"cinder_volume_retag_state_file.stat.exists|bool\"], \"block\": [{\"name\": \"Disable the cinder_volume cluster resource before container upgrade\", \"pacemaker_resource\": {\"resource\": \"openstack-cinder-volume\", \"state\": \"disable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}, {\"name\": \"pcs resource bundle update cinder_volume for new container image name\", \"command\": \"pcs resource bundle update openstack-cinder-volume container image={{cinder_volume_image_latest}}\"}, {\"name\": \"Enable the cinder_volume cluster resource\", \"pacemaker_resource\": {\"resource\": \"openstack-cinder-volume\", \"state\": \"enable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}]}, {\"name\": \"Check for cinder_volume retag statefile\", \"when\": [\"step|int == 3\"], \"stat\": {\"path\": \"/var/lib/tripleo/cinder_volume_needs_retag\"}, \"register\": \"cinder_volume_retag_state_file\"}, {\"name\": \"Retag pacemaker cinder_volume\", \"when\": [\"step|int == 3\", \"cinder_volume_retag_state_file.stat.exists|bool\"], \"block\": [{\"name\": \"Disable the cinder_volume cluster resource before container upgrade\", \"pacemaker_resource\": {\"resource\": \"openstack-cinder-volume\", \"state\": \"disable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}, {\"name\": \"Retag the pacemaker image if containerized\", \"block\": [{\"block\": [{\"name\": \"Get cinder_volume image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_cinder_volume_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'openstack-cinder-volume\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container cinder_volume image\", \"set_fact\": {\"cinder_volume_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}, \"cinder_volume_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/cinder-volume:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"pcmk_cinder_volume_image\": \"{{xmllint_pcmk_cinder_volume_image.stdout}}\"}}]}, {\"block\": [{\"name\": \"Retag pcmklatest to latest cinder_volume image\", \"include_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{cinder_volume_image}}\", \"container_image_latest\": \"{{cinder_volume_image_latest}}\"}}]}]}, {\"name\": \"Enable the cinder_volume cluster resource\", \"pacemaker_resource\": {\"resource\": \"openstack-cinder-volume\", \"state\": \"enable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}, {\"name\": \"Remove cinder_volume retag statefile\", \"file\": {\"path\": \"/var/lib/tripleo/cinder_volume_needs_retag\", \"state\": \"absent\"}}]}], {\"get_attr\": [\"CinderCommon\", \"cinder_volume_upgrade_tasks\"]}]}, \"post_upgrade_tasks\": [{\"name\": \"Start cinder_volume service (pacemaker)\", \"become\": true, \"when\": \"step|int == 1\", \"pacemaker_resource\": {\"resource\": \"openstack-cinder-volume\", \"state\": \"enable\"}}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(78,'2026-06-10 07:46:52',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mysql client settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role for setting mysql client parameters\", \"value\": {\"service_name\": \"mysql_client\", \"config_settings\": {\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"tripleo::profile::base::database::mysql::client::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}}, \"step_config\": \"include tripleo::profile::base::database::mysql::client\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(79,'2026-06-10 07:46:52',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(80,'2026-06-10 07:46:52',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Provides the list of common container volumes and environment used by various cinder services.\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"CinderVolumeOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\"}, \"CinderBackupOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\"}, \"CinderVolumeOptEnvVars\": {\"default\": {}, \"description\": \"hash of optional environment variables\", \"type\": \"json\"}, \"CinderEnableIscsiBackend\": {\"default\": true, \"description\": \"Whether to enable or not the Iscsi backend for Cinder\", \"type\": \"boolean\"}, \"CinderEnableNVMeOFBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NVMeOF backend for Cinder\", \"type\": \"boolean\"}, \"CinderLVMConfigureVG\": {\"default\": true, \"description\": \"Whether to configure the \'cinder-volumes\' VG used by the LVM driver. When disabled (set to False), the LVM driver will work as long as the \'cinder-volumes\' VG has been created through some other means.\\n\", \"type\": \"boolean\"}, \"CinderLVMLoopDeviceSize\": {\"default\": 20480, \"description\": \"The size of the loopback file used by the cinder LVM driver.\", \"type\": \"number\"}, \"MultipathdEnable\": {\"default\": false, \"description\": \"Whether to enable the multipath daemon\", \"type\": \"boolean\"}, \"CinderVolumeCluster\": {\"default\": \"\", \"description\": \"The cluster name used for deploying the cinder-volume service in an active-active (A/A) configuration. This configuration requires the Cinder backend drivers support A/A, and the cinder-volume service not be managed by pacemaker. If these criteria are not met then the cluster name must be left blank.\\n\", \"type\": \"string\"}, \"CinderImageConversionNfsShare\": {\"default\": \"\", \"description\": \"When set, the NFS share to be used for Cinder\'s image conversion directory.\", \"type\": \"string\"}, \"CinderImageConversionNfsOptions\": {\"default\": \"_netdev,bg,intr,context=system_u:object_r:container_file_t:s0\", \"description\": \"NFS mount options when using an NFS share for Cinder\'s image conversion directory.\", \"type\": \"string\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"EnableEtcdInternalTLS\": {\"description\": \"Controls whether etcd and the cinder-volume service use TLS for cinder\'s lock manager, even when the rest of the internal API network is using TLS.\", \"type\": \"boolean\", \"default\": true}, \"CephConfigPath\": {\"type\": \"string\", \"default\": \"/var/lib/tripleo-config/ceph\", \"description\": \"The path where the Ceph Cluster config files are stored on the host.\\n\"}, \"CephClientUserName\": {\"default\": \"openstack\", \"type\": \"string\"}, \"CephClusterName\": {\"type\": \"string\", \"default\": \"ceph\", \"description\": \"The Ceph cluster name.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9]+\", \"description\": \"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\n\"}]}, \"CephExternalMultiConfig\": {\"type\": \"json\", \"hidden\": true, \"description\": \"List of maps describing extra overrides which will be applied when configuring\\nextra external Ceph clusters. If this list is non-empty, ceph-ansible will run\\nan extra count(list) times using the same parameters as the first run except\\neach parameter within each map will override the defaults. If the following\\nwere used, the second run would configure the overcloud to also use the ceph2\\ncluster with all the previous parameters except /etc/ceph/ceph2.conf would have\\na mon_host entry containing the value of external_cluster_mon_ips below, and\\nnot the default CephExternalMonHost. Subsequent ceph-ansible runs are restricted\\nto just ceph clients. CephExternalMultiConfig may not be used to deploy additional\\ninternal Ceph clusters within one Heat stack. The map for each list should contain\\nnot tripleo-heat-template parameters but ceph-ansible parameters.\\n  - cluster: \'ceph2\'\\n    fsid: \'e2cba068-5f14-4b0f-b047-acf375c0004a\'\\n    external_cluster_mon_ips: \'172.18.0.5,172.18.0.6,172.18.0.7\'\\n    keys:\\n      - name: \\\"client.openstack\\\"\\n        caps:\\n          mgr: \\\"allow *\\\"\\n          mon: \\\"profile rbd\\\"\\n          osd: \\\"osd: profile rbd pool=volumes, profile rbd pool=backups, profile rbd pool=vms, profile rbd pool=images\\\"\\n        key: \\\"AQCwmeRcAAAAABAA6SQU/bGqFjlfLro5KxrB1Q==\\\"\\n        mode: \\\"0600\\\"\\n    dashboard_enabled: false\\n\", \"default\": []}}, \"conditions\": {\"cvol_active_active_tls_enabled\": {\"and\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderVolumeCluster\"}, \"\"]}}, {\"get_param\": \"EnableInternalTLS\"}, {\"get_param\": \"EnableEtcdInternalTLS\"}]}, \"cinder_nfs_conversion_dir_enabled\": {\"not\": {\"equals\": [{\"get_param\": \"CinderImageConversionNfsShare\"}, \"\"]}}, \"cinder_configure_lvm\": {\"and\": [{\"get_param\": \"CinderLVMConfigureVG\"}, {\"or\": [{\"get_param\": \"CinderEnableIscsiBackend\"}, {\"get_param\": \"CinderEnableNVMeOFBackend\"}]}]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml\"}, \"CinderNVMeOF\": {\"type\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml\"}}, \"outputs\": {\"cinder_image_conversion_nfs_dir\": {\"description\": \"The directory where cinder does its image conversion when the directory is backed by an NFS share.\", \"value\": \"/var/lib/cinder_image_conversion\"}, \"cinder_common_host_prep_tasks\": {\"description\": \"Common host prep tasks for cinder-volume and cinder-backup services\", \"value\": {\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}}, \"cinder_common_volumes\": {\"description\": \"Common volumes for all cinder services\", \"value\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}}, \"cinder_common_kolla_config_files\": {\"description\": \"Common kolla config_files for cinder-volume and cinder-backup services\", \"value\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-ceph/\", \"dest\": \"/etc/ceph/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-iscsid/*\", \"dest\": \"/etc/iscsi/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true, \"optional\": true}]}, \"cinder_common_kolla_permissions\": {\"description\": \"Common kolla permissions for cinder-volume and cinder-backup services\", \"value\": {\"list_concat\": [[{\"path\": \"/var/log/cinder\", \"owner\": \"cinder:cinder\", \"recurse\": true}, {\"path\": {\"str_replace\": {\"template\": \"/etc/ceph/CLUSTER.client.USER.keyring\", \"params\": {\"CLUSTER\": {\"get_param\": \"CephClusterName\"}, \"USER\": {\"get_param\": \"CephClientUserName\"}}}}, \"owner\": \"cinder:cinder\", \"perm\": \"0600\"}, {\"path\": \"/etc/pki/tls/certs/etcd.crt\", \"owner\": \"cinder:cinder\"}, {\"path\": \"/etc/pki/tls/private/etcd.key\", \"owner\": \"cinder:cinder\"}], {\"repeat\": {\"template\": {\"path\": \"/etc/ceph/<%cluster%>.client.*.keyring\", \"owner\": \"cinder:cinder\", \"perm\": \"0600\"}, \"for_each\": {\"<%cluster%>\": {\"yaql\": {\"expression\": \"$.data.multiconfig.select($.cluster)\", \"data\": {\"multiconfig\": {\"get_param\": \"CephExternalMultiConfig\"}}}}}}}]}}, \"cinder_volume_host_prep_and_system_upgrade_post_tasks\": {\"description\": \"Common host_prep and system_upgrade post tasks for cinder-volume\", \"value\": [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}]}, \"cinder_volume_host_prep_tasks\": {\"description\": \"Host prep tasks for the cinder-volume service (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}, [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}], [{\"name\": \"cinder_configure_lvm fact\", \"set_fact\": {\"cinder_configure_lvm\": {\"if\": [\"cinder_configure_lvm\", true, false]}}}, {\"when\": \"cinder_configure_lvm|bool\", \"block\": [{\"name\": \"ensure LVM rpm dependencies are installed\", \"package\": {\"name\": \"lvm2\", \"state\": \"latest\"}}, {\"name\": \"cinder create LVM volume group dd\", \"command\": {\"list_join\": [\"\", [\"dd if=/dev/zero of=/var/lib/cinder/cinder-volumes bs=1 count=0 seek=\", {\"str_replace\": {\"template\": \"VALUE\", \"params\": {\"VALUE\": {\"get_param\": \"CinderLVMLoopDeviceSize\"}}}}, \"M\"]]}, \"args\": {\"creates\": \"/var/lib/cinder/cinder-volumes\"}}, {\"name\": \"Get or create LVM loopback device\", \"shell\": \"exit_code=0\\nexisting_device=$(losetup -j /var/lib/cinder/cinder-volumes -l -n -O NAME)\\nif [[ -z \\\"${existing_device}\\\" ]]; then\\n    losetup -f /var/lib/cinder/cinder-volumes --show\\n    exit_code=2\\nelse\\n    echo ${existing_device%$\'\\\\n\'*}\\nfi\\nexit ${exit_code}\", \"args\": {\"executable\": \"/bin/bash\"}, \"register\": \"_loopback_device\", \"changed_when\": \"_loopback_device.rc == 2\", \"failed_when\": \"_loopback_device.rc not in [0,2]\"}, {\"name\": \"Create LVM volume group\", \"community.general.lvg\": {\"vg\": \"cinder-volumes\", \"pvs\": \"{{ _loopback_device.stdout }}\", \"state\": \"present\"}, \"when\": [\"not (ansible_check_mode | bool)\"]}, {\"name\": \"cinder create service to run losetup for LVM on startup\", \"copy\": {\"dest\": \"/etc/systemd/system/cinder-lvm-losetup.service\", \"content\": \"[Unit]\\nDescription=Cinder LVM losetup\\nDefaultDependencies=no\\nConflicts=umount.target\\nRequires=lvm2-monitor.service systemd-udev-settle.service\\nBefore=local-fs.target umount.target\\nAfter=var.mount lvm2-monitor.service systemd-udev-settle.service\\n\\n[Service]\\nType=oneshot\\nExecStart=/sbin/losetup {{ _loopback_device.stdout }} /var/lib/cinder/cinder-volumes\\nExecStop=/sbin/losetup -d {{ _loopback_device.stdout }}\\nRemainAfterExit=yes\\n\\n[Install]\\nWantedBy=local-fs-pre.target\\n\"}, \"when\": [\"not (ansible_check_mode | bool)\"]}, {\"name\": \"cinder enable the LVM losetup service\", \"systemd\": {\"name\": \"cinder-lvm-losetup\", \"enabled\": true, \"daemon_reload\": true}}]}]]}}, \"cinder_volume_upgrade_tasks\": {\"description\": \"Upgrade tasks for the cinder-volume service (HA or non-HA)\", \"value\": [{\"name\": \"cinder-volume pre system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 3\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Unmount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}, \"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": \"image_conversion_nfs_enabled|bool\", \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"absent\", \"fstype\": \"nfs4\"}}]}, {\"name\": \"cinder-volume post system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 5\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}]}]}, \"cinder_volume_config_settings\": {\"description\": \"Config settings for the cinder-volume container (HA or non-HA)\", \"value\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", {\"cinder::image_conversion_dir\": \"/var/lib/cinder_image_conversion\"}, {}]}}, \"cinder_volume_volumes\": {\"description\": \"Volumes for the cinder-volume container (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}, {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}, {\"get_param\": \"CinderVolumeOptVolumes\"}, [\"/var/lib/kolla/config_files/cinder_volume.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/lib/modules:/lib/modules:ro\", \"/dev:/dev\", \"/run:/run\", \"/sys:/sys\", \"/var/lib/cinder:/var/lib/cinder:z\", \"/var/lib/iscsi:/var/lib/iscsi:z\"], {\"if\": [{\"get_param\": \"CinderEnableIscsiBackend\"}, [\"/etc/target:/etc/target:z\"]]}, {\"if\": [{\"get_param\": \"MultipathdEnable\"}, [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}, {\"if\": [\"cinder_nfs_conversion_dir_enabled\", [{\"str_replace\": {\"template\": \"DIR:DIR:slave\", \"params\": {\"DIR\": \"/var/lib/cinder_image_conversion\"}}}]]}]}}, \"cinder_volume_environment\": {\"description\": \"Docker environment for the cinder-volume container (HA or non-HA)\", \"value\": {\"map_merge\": [{\"get_param\": \"CinderVolumeOptEnvVars\"}, {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}]}}, \"cinder_backup_host_prep_tasks\": {\"description\": \"Host prep tasks for the cinder-backup service (HA or non-HA)\", \"value\": {\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}}, \"cinder_backup_volumes\": {\"description\": \"Volumes for the cinder-backup container (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}, {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}, {\"get_param\": \"CinderBackupOptVolumes\"}, [\"/var/lib/kolla/config_files/cinder_backup.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/dev:/dev\", \"/run:/run\", \"/sys:/sys\", \"/lib/modules:/lib/modules:ro\", \"/var/lib/cinder:/var/lib/cinder:z\", \"/var/lib/iscsi:/var/lib/iscsi:z\"], {\"if\": [{\"get_param\": \"MultipathdEnable\"}, [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}]}}, \"cinder_backup_environment\": {\"description\": \"Docker environment for the cinder-backup container (HA or non-HA)\", \"value\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(81,'2026-06-10 07:46:52',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Openstack Cinder NVMeOF backend\\n\", \"parameters\": {\"CinderEnableNVMeOFBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NVMeOF backend for Cinder\", \"type\": \"boolean\"}, \"CinderNVMeOFBackendName\": {\"type\": \"string\", \"default\": \"tripleo_nvmeof\"}, \"CinderNVMeOFAvailabilityZone\": {\"default\": \"\", \"description\": \"The availability zone of the NVMeOF Cinder backend. When set, it overrides the default CinderStorageAvailabilityZone.\\n\", \"type\": \"string\"}, \"CinderNVMeOFTargetPort\": {\"type\": \"number\", \"default\": 4420}, \"CinderNVMeOFTargetHelper\": {\"type\": \"string\", \"default\": \"nvmet\"}, \"CinderNVMeOFTargetProtocol\": {\"type\": \"string\", \"default\": \"nvmet_rdma\", \"description\": \"The target protocol, supported values are nvmet_rdma and nvmet_tcp.\\n\", \"constraints\": [{\"allowed_values\": [\"nvmet_rdma\", \"nvmet_tcp\"]}]}, \"CinderNVMeOFTargetPrefix\": {\"type\": \"string\", \"default\": \"nvme-subsystem\"}, \"CinderNVMeOFTargetPortId\": {\"type\": \"number\", \"default\": 1}, \"CinderNVMeOFTargetNameSpaceId\": {\"type\": \"number\", \"default\": 10}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"type\": \"json\", \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\"}}, \"outputs\": {\"cinder_nvmeof_host_prep_tasks\": {\"description\": \"Host prep tasks related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [{\"name\": \"ensure /etc/nvme exists\", \"file\": {\"path\": \"/etc/nvme\", \"state\": \"directory\", \"setype\": \"container_file_t\"}}]]}}, \"cinder_nvmeof_volumes\": {\"description\": \"Volumes related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [\"/etc/nvme:/etc/nvme:z\"]]}}, \"role_data\": {\"description\": \"Role data for the Cinder NVMeOF backend.\", \"value\": {\"service_name\": \"cinder_backend_nvmeof\", \"firewall_rules\": {\"120 LVM nvmet target\": {\"dport\": {\"get_param\": \"CinderNVMeOFTargetPort\"}}}, \"config_settings\": {\"map_merge\": [{\"tripleo::profile::base::cinder::volume::cinder_enable_nvmeof_backend\": {\"get_param\": \"CinderEnableNVMeOFBackend\"}, \"tripleo::profile::base::cinder::volume::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_port\": {\"get_param\": \"CinderNVMeOFTargetPort\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_helper\": {\"get_param\": \"CinderNVMeOFTargetHelper\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_protocol\": {\"get_param\": \"CinderNVMeOFTargetProtocol\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_prefix\": {\"get_param\": \"CinderNVMeOFTargetPrefix\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_port_id\": {\"get_param\": \"CinderNVMeOFTargetPortId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_ns_id\": {\"get_param\": \"CinderNVMeOFTargetNameSpaceId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_ip_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderIscsiNetwork\"]}}}}, \"cinder::backend::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}}, {\"if\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderNVMeOFAvailabilityZone\"}, \"\"]}}, {\"tripleo::profile::base::cinder::volume::nvmeof::backend_availability_zone\": {\"get_param\": \"CinderNVMeOFAvailabilityZone\"}}]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(82,'2026-06-10 07:46:52',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Provides the list of common container volumes and environment used by various cinder services.\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"CinderVolumeOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\"}, \"CinderBackupOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\"}, \"CinderVolumeOptEnvVars\": {\"default\": {}, \"description\": \"hash of optional environment variables\", \"type\": \"json\"}, \"CinderEnableIscsiBackend\": {\"default\": true, \"description\": \"Whether to enable or not the Iscsi backend for Cinder\", \"type\": \"boolean\"}, \"CinderEnableNVMeOFBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NVMeOF backend for Cinder\", \"type\": \"boolean\"}, \"CinderLVMConfigureVG\": {\"default\": true, \"description\": \"Whether to configure the \'cinder-volumes\' VG used by the LVM driver. When disabled (set to False), the LVM driver will work as long as the \'cinder-volumes\' VG has been created through some other means.\\n\", \"type\": \"boolean\"}, \"CinderLVMLoopDeviceSize\": {\"default\": 20480, \"description\": \"The size of the loopback file used by the cinder LVM driver.\", \"type\": \"number\"}, \"MultipathdEnable\": {\"default\": false, \"description\": \"Whether to enable the multipath daemon\", \"type\": \"boolean\"}, \"CinderVolumeCluster\": {\"default\": \"\", \"description\": \"The cluster name used for deploying the cinder-volume service in an active-active (A/A) configuration. This configuration requires the Cinder backend drivers support A/A, and the cinder-volume service not be managed by pacemaker. If these criteria are not met then the cluster name must be left blank.\\n\", \"type\": \"string\"}, \"CinderImageConversionNfsShare\": {\"default\": \"\", \"description\": \"When set, the NFS share to be used for Cinder\'s image conversion directory.\", \"type\": \"string\"}, \"CinderImageConversionNfsOptions\": {\"default\": \"_netdev,bg,intr,context=system_u:object_r:container_file_t:s0\", \"description\": \"NFS mount options when using an NFS share for Cinder\'s image conversion directory.\", \"type\": \"string\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"EnableEtcdInternalTLS\": {\"description\": \"Controls whether etcd and the cinder-volume service use TLS for cinder\'s lock manager, even when the rest of the internal API network is using TLS.\", \"type\": \"boolean\", \"default\": true}, \"CephConfigPath\": {\"type\": \"string\", \"default\": \"/var/lib/tripleo-config/ceph\", \"description\": \"The path where the Ceph Cluster config files are stored on the host.\\n\"}, \"CephClientUserName\": {\"default\": \"openstack\", \"type\": \"string\"}, \"CephClusterName\": {\"type\": \"string\", \"default\": \"ceph\", \"description\": \"The Ceph cluster name.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9]+\", \"description\": \"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\n\"}]}, \"CephExternalMultiConfig\": {\"type\": \"json\", \"hidden\": true, \"description\": \"List of maps describing extra overrides which will be applied when configuring\\nextra external Ceph clusters. If this list is non-empty, ceph-ansible will run\\nan extra count(list) times using the same parameters as the first run except\\neach parameter within each map will override the defaults. If the following\\nwere used, the second run would configure the overcloud to also use the ceph2\\ncluster with all the previous parameters except /etc/ceph/ceph2.conf would have\\na mon_host entry containing the value of external_cluster_mon_ips below, and\\nnot the default CephExternalMonHost. Subsequent ceph-ansible runs are restricted\\nto just ceph clients. CephExternalMultiConfig may not be used to deploy additional\\ninternal Ceph clusters within one Heat stack. The map for each list should contain\\nnot tripleo-heat-template parameters but ceph-ansible parameters.\\n  - cluster: \'ceph2\'\\n    fsid: \'e2cba068-5f14-4b0f-b047-acf375c0004a\'\\n    external_cluster_mon_ips: \'172.18.0.5,172.18.0.6,172.18.0.7\'\\n    keys:\\n      - name: \\\"client.openstack\\\"\\n        caps:\\n          mgr: \\\"allow *\\\"\\n          mon: \\\"profile rbd\\\"\\n          osd: \\\"osd: profile rbd pool=volumes, profile rbd pool=backups, profile rbd pool=vms, profile rbd pool=images\\\"\\n        key: \\\"AQCwmeRcAAAAABAA6SQU/bGqFjlfLro5KxrB1Q==\\\"\\n        mode: \\\"0600\\\"\\n    dashboard_enabled: false\\n\", \"default\": []}}, \"conditions\": {\"cvol_active_active_tls_enabled\": {\"and\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderVolumeCluster\"}, \"\"]}}, {\"get_param\": \"EnableInternalTLS\"}, {\"get_param\": \"EnableEtcdInternalTLS\"}]}, \"cinder_nfs_conversion_dir_enabled\": {\"not\": {\"equals\": [{\"get_param\": \"CinderImageConversionNfsShare\"}, \"\"]}}, \"cinder_configure_lvm\": {\"and\": [{\"get_param\": \"CinderLVMConfigureVG\"}, {\"or\": [{\"get_param\": \"CinderEnableIscsiBackend\"}, {\"get_param\": \"CinderEnableNVMeOFBackend\"}]}]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml\"}, \"CinderNVMeOF\": {\"type\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml\"}}, \"outputs\": {\"cinder_image_conversion_nfs_dir\": {\"description\": \"The directory where cinder does its image conversion when the directory is backed by an NFS share.\", \"value\": \"/var/lib/cinder_image_conversion\"}, \"cinder_common_host_prep_tasks\": {\"description\": \"Common host prep tasks for cinder-volume and cinder-backup services\", \"value\": {\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}}, \"cinder_common_volumes\": {\"description\": \"Common volumes for all cinder services\", \"value\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}}, \"cinder_common_kolla_config_files\": {\"description\": \"Common kolla config_files for cinder-volume and cinder-backup services\", \"value\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-ceph/\", \"dest\": \"/etc/ceph/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-iscsid/*\", \"dest\": \"/etc/iscsi/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true, \"optional\": true}]}, \"cinder_common_kolla_permissions\": {\"description\": \"Common kolla permissions for cinder-volume and cinder-backup services\", \"value\": {\"list_concat\": [[{\"path\": \"/var/log/cinder\", \"owner\": \"cinder:cinder\", \"recurse\": true}, {\"path\": {\"str_replace\": {\"template\": \"/etc/ceph/CLUSTER.client.USER.keyring\", \"params\": {\"CLUSTER\": {\"get_param\": \"CephClusterName\"}, \"USER\": {\"get_param\": \"CephClientUserName\"}}}}, \"owner\": \"cinder:cinder\", \"perm\": \"0600\"}, {\"path\": \"/etc/pki/tls/certs/etcd.crt\", \"owner\": \"cinder:cinder\"}, {\"path\": \"/etc/pki/tls/private/etcd.key\", \"owner\": \"cinder:cinder\"}], {\"repeat\": {\"template\": {\"path\": \"/etc/ceph/<%cluster%>.client.*.keyring\", \"owner\": \"cinder:cinder\", \"perm\": \"0600\"}, \"for_each\": {\"<%cluster%>\": {\"yaql\": {\"expression\": \"$.data.multiconfig.select($.cluster)\", \"data\": {\"multiconfig\": {\"get_param\": \"CephExternalMultiConfig\"}}}}}}}]}}, \"cinder_volume_host_prep_and_system_upgrade_post_tasks\": {\"description\": \"Common host_prep and system_upgrade post tasks for cinder-volume\", \"value\": [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}]}, \"cinder_volume_host_prep_tasks\": {\"description\": \"Host prep tasks for the cinder-volume service (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}, [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}], [{\"name\": \"cinder_configure_lvm fact\", \"set_fact\": {\"cinder_configure_lvm\": {\"if\": [\"cinder_configure_lvm\", true, false]}}}, {\"when\": \"cinder_configure_lvm|bool\", \"block\": [{\"name\": \"ensure LVM rpm dependencies are installed\", \"package\": {\"name\": \"lvm2\", \"state\": \"latest\"}}, {\"name\": \"cinder create LVM volume group dd\", \"command\": {\"list_join\": [\"\", [\"dd if=/dev/zero of=/var/lib/cinder/cinder-volumes bs=1 count=0 seek=\", {\"str_replace\": {\"template\": \"VALUE\", \"params\": {\"VALUE\": {\"get_param\": \"CinderLVMLoopDeviceSize\"}}}}, \"M\"]]}, \"args\": {\"creates\": \"/var/lib/cinder/cinder-volumes\"}}, {\"name\": \"Get or create LVM loopback device\", \"shell\": \"exit_code=0\\nexisting_device=$(losetup -j /var/lib/cinder/cinder-volumes -l -n -O NAME)\\nif [[ -z \\\"${existing_device}\\\" ]]; then\\n    losetup -f /var/lib/cinder/cinder-volumes --show\\n    exit_code=2\\nelse\\n    echo ${existing_device%$\'\\\\n\'*}\\nfi\\nexit ${exit_code}\", \"args\": {\"executable\": \"/bin/bash\"}, \"register\": \"_loopback_device\", \"changed_when\": \"_loopback_device.rc == 2\", \"failed_when\": \"_loopback_device.rc not in [0,2]\"}, {\"name\": \"Create LVM volume group\", \"community.general.lvg\": {\"vg\": \"cinder-volumes\", \"pvs\": \"{{ _loopback_device.stdout }}\", \"state\": \"present\"}, \"when\": [\"not (ansible_check_mode | bool)\"]}, {\"name\": \"cinder create service to run losetup for LVM on startup\", \"copy\": {\"dest\": \"/etc/systemd/system/cinder-lvm-losetup.service\", \"content\": \"[Unit]\\nDescription=Cinder LVM losetup\\nDefaultDependencies=no\\nConflicts=umount.target\\nRequires=lvm2-monitor.service systemd-udev-settle.service\\nBefore=local-fs.target umount.target\\nAfter=var.mount lvm2-monitor.service systemd-udev-settle.service\\n\\n[Service]\\nType=oneshot\\nExecStart=/sbin/losetup {{ _loopback_device.stdout }} /var/lib/cinder/cinder-volumes\\nExecStop=/sbin/losetup -d {{ _loopback_device.stdout }}\\nRemainAfterExit=yes\\n\\n[Install]\\nWantedBy=local-fs-pre.target\\n\"}, \"when\": [\"not (ansible_check_mode | bool)\"]}, {\"name\": \"cinder enable the LVM losetup service\", \"systemd\": {\"name\": \"cinder-lvm-losetup\", \"enabled\": true, \"daemon_reload\": true}}]}]]}}, \"cinder_volume_upgrade_tasks\": {\"description\": \"Upgrade tasks for the cinder-volume service (HA or non-HA)\", \"value\": [{\"name\": \"cinder-volume pre system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 3\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Unmount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}, \"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": \"image_conversion_nfs_enabled|bool\", \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"absent\", \"fstype\": \"nfs4\"}}]}, {\"name\": \"cinder-volume post system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 5\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}]}]}, \"cinder_volume_config_settings\": {\"description\": \"Config settings for the cinder-volume container (HA or non-HA)\", \"value\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", {\"cinder::image_conversion_dir\": \"/var/lib/cinder_image_conversion\"}, {}]}}, \"cinder_volume_volumes\": {\"description\": \"Volumes for the cinder-volume container (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}, {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}, {\"get_param\": \"CinderVolumeOptVolumes\"}, [\"/var/lib/kolla/config_files/cinder_volume.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/lib/modules:/lib/modules:ro\", \"/dev:/dev\", \"/run:/run\", \"/sys:/sys\", \"/var/lib/cinder:/var/lib/cinder:z\", \"/var/lib/iscsi:/var/lib/iscsi:z\"], {\"if\": [{\"get_param\": \"CinderEnableIscsiBackend\"}, [\"/etc/target:/etc/target:z\"]]}, {\"if\": [{\"get_param\": \"MultipathdEnable\"}, [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}, {\"if\": [\"cinder_nfs_conversion_dir_enabled\", [{\"str_replace\": {\"template\": \"DIR:DIR:slave\", \"params\": {\"DIR\": \"/var/lib/cinder_image_conversion\"}}}]]}]}}, \"cinder_volume_environment\": {\"description\": \"Docker environment for the cinder-volume container (HA or non-HA)\", \"value\": {\"map_merge\": [{\"get_param\": \"CinderVolumeOptEnvVars\"}, {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}]}}, \"cinder_backup_host_prep_tasks\": {\"description\": \"Host prep tasks for the cinder-backup service (HA or non-HA)\", \"value\": {\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}}, \"cinder_backup_volumes\": {\"description\": \"Volumes for the cinder-backup container (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}, {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}, {\"get_param\": \"CinderBackupOptVolumes\"}, [\"/var/lib/kolla/config_files/cinder_backup.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/dev:/dev\", \"/run:/run\", \"/sys:/sys\", \"/lib/modules:/lib/modules:ro\", \"/var/lib/cinder:/var/lib/cinder:z\", \"/var/lib/iscsi:/var/lib/iscsi:z\"], {\"if\": [{\"get_param\": \"MultipathdEnable\"}, [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}]}}, \"cinder_backup_environment\": {\"description\": \"Docker environment for the cinder-backup container (HA or non-HA)\", \"value\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(83,'2026-06-10 07:46:52',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(84,'2026-06-10 07:46:53',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(85,'2026-06-10 07:46:53',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mysql client settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role for setting mysql client parameters\", \"value\": {\"service_name\": \"mysql_client\", \"config_settings\": {\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"tripleo::profile::base::database::mysql::client::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}}, \"step_config\": \"include tripleo::profile::base::database::mysql::client\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(86,'2026-06-10 07:46:53',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (87,'2026-06-10 07:46:53',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(88,'2026-06-10 07:46:53',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Cinder base service. Shared by all Cinder services.\\n\", \"parameters\": {\"CinderStorageAvailabilityZone\": {\"default\": \"nova\", \"description\": \"The Cinder service\'s storage availability zone.\", \"type\": \"string\"}, \"CinderPassword\": {\"description\": \"The password for the cinder service and db account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"gtBv0TkCYxjriNwpG4AlCd1ll\"}, \"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"CinderDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging on Cinder services.\", \"type\": \"boolean\"}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"CinderCronDbPurgeMinute\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Minute\\n\", \"default\": \"1\"}, \"CinderCronDbPurgeHour\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Hour\\n\", \"default\": \"0\"}, \"CinderCronDbPurgeMonthday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month Day\\n\", \"default\": \"*\"}, \"CinderCronDbPurgeMonth\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month\\n\", \"default\": \"*\"}, \"CinderCronDbPurgeWeekday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Week Day\\n\", \"default\": \"*\"}, \"CinderCronDbPurgeUser\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - User\\n\", \"default\": \"cinder\"}, \"CinderCronDbPurgeAge\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Age\\n\", \"default\": \"30\"}, \"CinderCronDbPurgeDestination\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Log destination\\n\", \"default\": \"/var/log/cinder/cinder-rowsflush.log\"}, \"CinderCronDbPurgeMaxDelay\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Max Delay\\n\", \"default\": \"3600\"}, \"CinderRpcResponseTimeout\": {\"default\": 60, \"description\": \"Cinder\'s RPC response timeout, in seconds.\", \"type\": \"number\"}, \"NovaPassword\": {\"type\": \"string\", \"description\": \"The password for the nova service and db account\", \"hidden\": true, \"default\": \"btE80AtSdL16lZ5QqRx6f9I9L\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Cinder base service.\", \"value\": {\"service_name\": \"cinder_base\", \"config_settings\": {\"cinder::database_connection\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"protocol\"]}, \"username\": \"cinder\", \"password\": {\"get_param\": \"CinderPassword\"}, \"host\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"host\"]}, \"path\": \"/cinder\", \"query\": {\"if\": [{\"get_param\": \"EnableSQLAlchemyCollectd\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\", \"plugin\": \"collectd\", \"collectd_program_name\": \"cinder\", \"collectd_host\": \"localhost\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\"}]}}}, \"cinder::logging::debug\": {\"if\": [{\"get_param\": \"CinderDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"cinder::storage_availability_zone\": {\"get_param\": \"CinderStorageAvailabilityZone\"}, \"cinder::rabbit_heartbeat_timeout_threshold\": 60, \"cinder::rpc_response_timeout\": {\"get_param\": \"CinderRpcResponseTimeout\"}, \"cinder::rabbit_heartbeat_in_pthread\": false, \"cinder::db::database_db_max_retries\": -1, \"cinder::db::database_max_retries\": -1, \"cinder::cron::db_purge::minute\": {\"get_param\": \"CinderCronDbPurgeMinute\"}, \"cinder::cron::db_purge::hour\": {\"get_param\": \"CinderCronDbPurgeHour\"}, \"cinder::cron::db_purge::monthday\": {\"get_param\": \"CinderCronDbPurgeMonthday\"}, \"cinder::cron::db_purge::month\": {\"get_param\": \"CinderCronDbPurgeMonth\"}, \"cinder::cron::db_purge::weekday\": {\"get_param\": \"CinderCronDbPurgeWeekday\"}, \"cinder::cron::db_purge::user\": {\"get_param\": \"CinderCronDbPurgeUser\"}, \"cinder::cron::db_purge::age\": {\"get_param\": \"CinderCronDbPurgeAge\"}, \"cinder::cron::db_purge::destination\": {\"get_param\": \"CinderCronDbPurgeDestination\"}, \"cinder::cron::db_purge::maxdelay\": {\"get_param\": \"CinderCronDbPurgeMaxDelay\"}, \"cinder::glance::glance_api_servers\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"uri\"]}, \"cinder::keystone::service_user::send_service_user_token\": true, \"cinder::keystone::service_user::project_name\": \"service\", \"cinder::keystone::service_user::auth_type\": \"password\", \"cinder::keystone::service_user::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri\"]}, \"cinder::keystone::service_user::password\": {\"get_param\": \"CinderPassword\"}, \"cinder::keystone::service_user::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"cinder::nova::interface\": \"admin\", \"cinder::nova::project_name\": \"service\", \"cinder::nova::auth_type\": \"password\", \"cinder::nova::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri\"]}, \"cinder::nova::password\": {\"get_param\": \"NovaPassword\"}, \"cinder::nova::region_name\": {\"get_param\": \"KeystoneRegion\"}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(89,'2026-06-10 07:46:53',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Openstack Cinder NVMeOF backend\\n\", \"parameters\": {\"CinderEnableNVMeOFBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NVMeOF backend for Cinder\", \"type\": \"boolean\"}, \"CinderNVMeOFBackendName\": {\"type\": \"string\", \"default\": \"tripleo_nvmeof\"}, \"CinderNVMeOFAvailabilityZone\": {\"default\": \"\", \"description\": \"The availability zone of the NVMeOF Cinder backend. When set, it overrides the default CinderStorageAvailabilityZone.\\n\", \"type\": \"string\"}, \"CinderNVMeOFTargetPort\": {\"type\": \"number\", \"default\": 4420}, \"CinderNVMeOFTargetHelper\": {\"type\": \"string\", \"default\": \"nvmet\"}, \"CinderNVMeOFTargetProtocol\": {\"type\": \"string\", \"default\": \"nvmet_rdma\", \"description\": \"The target protocol, supported values are nvmet_rdma and nvmet_tcp.\\n\", \"constraints\": [{\"allowed_values\": [\"nvmet_rdma\", \"nvmet_tcp\"]}]}, \"CinderNVMeOFTargetPrefix\": {\"type\": \"string\", \"default\": \"nvme-subsystem\"}, \"CinderNVMeOFTargetPortId\": {\"type\": \"number\", \"default\": 1}, \"CinderNVMeOFTargetNameSpaceId\": {\"type\": \"number\", \"default\": 10}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"type\": \"json\", \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\"}}, \"outputs\": {\"cinder_nvmeof_host_prep_tasks\": {\"description\": \"Host prep tasks related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [{\"name\": \"ensure /etc/nvme exists\", \"file\": {\"path\": \"/etc/nvme\", \"state\": \"directory\", \"setype\": \"container_file_t\"}}]]}}, \"cinder_nvmeof_volumes\": {\"description\": \"Volumes related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [\"/etc/nvme:/etc/nvme:z\"]]}}, \"role_data\": {\"description\": \"Role data for the Cinder NVMeOF backend.\", \"value\": {\"service_name\": \"cinder_backend_nvmeof\", \"firewall_rules\": {\"120 LVM nvmet target\": {\"dport\": {\"get_param\": \"CinderNVMeOFTargetPort\"}}}, \"config_settings\": {\"map_merge\": [{\"tripleo::profile::base::cinder::volume::cinder_enable_nvmeof_backend\": {\"get_param\": \"CinderEnableNVMeOFBackend\"}, \"tripleo::profile::base::cinder::volume::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_port\": {\"get_param\": \"CinderNVMeOFTargetPort\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_helper\": {\"get_param\": \"CinderNVMeOFTargetHelper\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_protocol\": {\"get_param\": \"CinderNVMeOFTargetProtocol\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_prefix\": {\"get_param\": \"CinderNVMeOFTargetPrefix\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_port_id\": {\"get_param\": \"CinderNVMeOFTargetPortId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_ns_id\": {\"get_param\": \"CinderNVMeOFTargetNameSpaceId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_ip_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderIscsiNetwork\"]}}}}, \"cinder::backend::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}}, {\"if\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderNVMeOFAvailabilityZone\"}, \"\"]}}, {\"tripleo::profile::base::cinder::volume::nvmeof::backend_availability_zone\": {\"get_param\": \"CinderNVMeOFAvailabilityZone\"}}]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(90,'2026-06-10 07:46:54',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Cinder base service. Shared by all Cinder services.\\n\", \"parameters\": {\"CinderStorageAvailabilityZone\": {\"default\": \"nova\", \"description\": \"The Cinder service\'s storage availability zone.\", \"type\": \"string\"}, \"CinderPassword\": {\"description\": \"The password for the cinder service and db account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"gtBv0TkCYxjriNwpG4AlCd1ll\"}, \"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"CinderDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging on Cinder services.\", \"type\": \"boolean\"}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"CinderCronDbPurgeMinute\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Minute\\n\", \"default\": \"1\"}, \"CinderCronDbPurgeHour\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Hour\\n\", \"default\": \"0\"}, \"CinderCronDbPurgeMonthday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month Day\\n\", \"default\": \"*\"}, \"CinderCronDbPurgeMonth\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month\\n\", \"default\": \"*\"}, \"CinderCronDbPurgeWeekday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Week Day\\n\", \"default\": \"*\"}, \"CinderCronDbPurgeUser\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - User\\n\", \"default\": \"cinder\"}, \"CinderCronDbPurgeAge\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Age\\n\", \"default\": \"30\"}, \"CinderCronDbPurgeDestination\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Log destination\\n\", \"default\": \"/var/log/cinder/cinder-rowsflush.log\"}, \"CinderCronDbPurgeMaxDelay\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Max Delay\\n\", \"default\": \"3600\"}, \"CinderRpcResponseTimeout\": {\"default\": 60, \"description\": \"Cinder\'s RPC response timeout, in seconds.\", \"type\": \"number\"}, \"NovaPassword\": {\"type\": \"string\", \"description\": \"The password for the nova service and db account\", \"hidden\": true, \"default\": \"btE80AtSdL16lZ5QqRx6f9I9L\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Cinder base service.\", \"value\": {\"service_name\": \"cinder_base\", \"config_settings\": {\"cinder::database_connection\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"protocol\"]}, \"username\": \"cinder\", \"password\": {\"get_param\": \"CinderPassword\"}, \"host\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"host\"]}, \"path\": \"/cinder\", \"query\": {\"if\": [{\"get_param\": \"EnableSQLAlchemyCollectd\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\", \"plugin\": \"collectd\", \"collectd_program_name\": \"cinder\", \"collectd_host\": \"localhost\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\"}]}}}, \"cinder::logging::debug\": {\"if\": [{\"get_param\": \"CinderDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"cinder::storage_availability_zone\": {\"get_param\": \"CinderStorageAvailabilityZone\"}, \"cinder::rabbit_heartbeat_timeout_threshold\": 60, \"cinder::rpc_response_timeout\": {\"get_param\": \"CinderRpcResponseTimeout\"}, \"cinder::rabbit_heartbeat_in_pthread\": false, \"cinder::db::database_db_max_retries\": -1, \"cinder::db::database_max_retries\": -1, \"cinder::cron::db_purge::minute\": {\"get_param\": \"CinderCronDbPurgeMinute\"}, \"cinder::cron::db_purge::hour\": {\"get_param\": \"CinderCronDbPurgeHour\"}, \"cinder::cron::db_purge::monthday\": {\"get_param\": \"CinderCronDbPurgeMonthday\"}, \"cinder::cron::db_purge::month\": {\"get_param\": \"CinderCronDbPurgeMonth\"}, \"cinder::cron::db_purge::weekday\": {\"get_param\": \"CinderCronDbPurgeWeekday\"}, \"cinder::cron::db_purge::user\": {\"get_param\": \"CinderCronDbPurgeUser\"}, \"cinder::cron::db_purge::age\": {\"get_param\": \"CinderCronDbPurgeAge\"}, \"cinder::cron::db_purge::destination\": {\"get_param\": \"CinderCronDbPurgeDestination\"}, \"cinder::cron::db_purge::maxdelay\": {\"get_param\": \"CinderCronDbPurgeMaxDelay\"}, \"cinder::glance::glance_api_servers\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"uri\"]}, \"cinder::keystone::service_user::send_service_user_token\": true, \"cinder::keystone::service_user::project_name\": \"service\", \"cinder::keystone::service_user::auth_type\": \"password\", \"cinder::keystone::service_user::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri\"]}, \"cinder::keystone::service_user::password\": {\"get_param\": \"CinderPassword\"}, \"cinder::keystone::service_user::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"cinder::nova::interface\": \"admin\", \"cinder::nova::project_name\": \"service\", \"cinder::nova::auth_type\": \"password\", \"cinder::nova::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri\"]}, \"cinder::nova::password\": {\"get_param\": \"NovaPassword\"}, \"cinder::nova::region_name\": {\"get_param\": \"KeystoneRegion\"}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(91,'2026-06-10 07:46:54',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mysql client settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role for setting mysql client parameters\", \"value\": {\"service_name\": \"mysql_client\", \"config_settings\": {\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"tripleo::profile::base::database::mysql::client::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}}, \"step_config\": \"include tripleo::profile::base::database::mysql::client\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(92,'2026-06-10 07:46:55',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Cinder base service. Shared by all Cinder services.\\n\", \"parameters\": {\"CinderStorageAvailabilityZone\": {\"default\": \"nova\", \"description\": \"The Cinder service\'s storage availability zone.\", \"type\": \"string\"}, \"CinderPassword\": {\"description\": \"The password for the cinder service and db account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"gtBv0TkCYxjriNwpG4AlCd1ll\"}, \"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"CinderDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging on Cinder services.\", \"type\": \"boolean\"}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"CinderCronDbPurgeMinute\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Minute\\n\", \"default\": \"1\"}, \"CinderCronDbPurgeHour\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Hour\\n\", \"default\": \"0\"}, \"CinderCronDbPurgeMonthday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month Day\\n\", \"default\": \"*\"}, \"CinderCronDbPurgeMonth\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month\\n\", \"default\": \"*\"}, \"CinderCronDbPurgeWeekday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Week Day\\n\", \"default\": \"*\"}, \"CinderCronDbPurgeUser\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - User\\n\", \"default\": \"cinder\"}, \"CinderCronDbPurgeAge\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Age\\n\", \"default\": \"30\"}, \"CinderCronDbPurgeDestination\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Log destination\\n\", \"default\": \"/var/log/cinder/cinder-rowsflush.log\"}, \"CinderCronDbPurgeMaxDelay\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Max Delay\\n\", \"default\": \"3600\"}, \"CinderRpcResponseTimeout\": {\"default\": 60, \"description\": \"Cinder\'s RPC response timeout, in seconds.\", \"type\": \"number\"}, \"NovaPassword\": {\"type\": \"string\", \"description\": \"The password for the nova service and db account\", \"hidden\": true, \"default\": \"btE80AtSdL16lZ5QqRx6f9I9L\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Cinder base service.\", \"value\": {\"service_name\": \"cinder_base\", \"config_settings\": {\"cinder::database_connection\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"protocol\"]}, \"username\": \"cinder\", \"password\": {\"get_param\": \"CinderPassword\"}, \"host\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"host\"]}, \"path\": \"/cinder\", \"query\": {\"if\": [{\"get_param\": \"EnableSQLAlchemyCollectd\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\", \"plugin\": \"collectd\", \"collectd_program_name\": \"cinder\", \"collectd_host\": \"localhost\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\"}]}}}, \"cinder::logging::debug\": {\"if\": [{\"get_param\": \"CinderDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"cinder::storage_availability_zone\": {\"get_param\": \"CinderStorageAvailabilityZone\"}, \"cinder::rabbit_heartbeat_timeout_threshold\": 60, \"cinder::rpc_response_timeout\": {\"get_param\": \"CinderRpcResponseTimeout\"}, \"cinder::rabbit_heartbeat_in_pthread\": false, \"cinder::db::database_db_max_retries\": -1, \"cinder::db::database_max_retries\": -1, \"cinder::cron::db_purge::minute\": {\"get_param\": \"CinderCronDbPurgeMinute\"}, \"cinder::cron::db_purge::hour\": {\"get_param\": \"CinderCronDbPurgeHour\"}, \"cinder::cron::db_purge::monthday\": {\"get_param\": \"CinderCronDbPurgeMonthday\"}, \"cinder::cron::db_purge::month\": {\"get_param\": \"CinderCronDbPurgeMonth\"}, \"cinder::cron::db_purge::weekday\": {\"get_param\": \"CinderCronDbPurgeWeekday\"}, \"cinder::cron::db_purge::user\": {\"get_param\": \"CinderCronDbPurgeUser\"}, \"cinder::cron::db_purge::age\": {\"get_param\": \"CinderCronDbPurgeAge\"}, \"cinder::cron::db_purge::destination\": {\"get_param\": \"CinderCronDbPurgeDestination\"}, \"cinder::cron::db_purge::maxdelay\": {\"get_param\": \"CinderCronDbPurgeMaxDelay\"}, \"cinder::glance::glance_api_servers\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"uri\"]}, \"cinder::keystone::service_user::send_service_user_token\": true, \"cinder::keystone::service_user::project_name\": \"service\", \"cinder::keystone::service_user::auth_type\": \"password\", \"cinder::keystone::service_user::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri\"]}, \"cinder::keystone::service_user::password\": {\"get_param\": \"CinderPassword\"}, \"cinder::keystone::service_user::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"cinder::nova::interface\": \"admin\", \"cinder::nova::project_name\": \"service\", \"cinder::nova::auth_type\": \"password\", \"cinder::nova::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri\"]}, \"cinder::nova::password\": {\"get_param\": \"NovaPassword\"}, \"cinder::nova::region_name\": {\"get_param\": \"KeystoneRegion\"}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(93,'2026-06-10 07:46:55',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Cinder Volume service\\n\", \"parameters\": {\"ContainerCinderVolumeImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\"}, \"ContainerCinderConfigImage\": {\"description\": \"The container image to use for the cinder config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\"}, \"DockerCinderVolumeUlimit\": {\"default\": [\"nofile=131072\"], \"description\": \"ulimit for Cinder Volume Container\", \"type\": \"comma_delimited_list\"}, \"CinderVolumeLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.cinder.volume\", \"file\": \"/var/log/containers/cinder/cinder-volume.log\"}}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"CephClientUserName\": {\"default\": \"openstack\", \"type\": \"string\"}, \"CephClusterName\": {\"type\": \"string\", \"default\": \"ceph\", \"description\": \"The Ceph cluster name.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9]+\", \"description\": \"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\n\"}]}, \"CinderVolumeCluster\": {\"default\": \"\", \"description\": \"The cluster name used for deploying the cinder-volume service in an active-active (A/A) configuration. This configuration requires the Cinder backend drivers support A/A, and the cinder-volume service not be managed by pacemaker. If these criteria are not met then the cluster name must be left blank.\\n\", \"type\": \"string\"}, \"CinderEnableNfsBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NFS backend for Cinder\", \"type\": \"boolean\"}, \"CinderEnableIscsiBackend\": {\"default\": true, \"description\": \"Whether to enable or not the Iscsi backend for Cinder\", \"type\": \"boolean\"}, \"CinderEnableRbdBackend\": {\"default\": false, \"description\": \"Whether to enable or not the Rbd backend for Cinder\", \"type\": \"boolean\"}, \"CinderISCSIAvailabilityZone\": {\"default\": \"\", \"description\": \"The availability zone of the Iscsi Cinder backend. When set, it overrides the default CinderStorageAvailabilityZone.\\n\", \"type\": \"string\"}, \"CinderISCSIHelper\": {\"default\": \"lioadm\", \"description\": \"The iSCSI helper to use with cinder.\", \"type\": \"string\"}, \"CinderISCSIProtocol\": {\"default\": \"iscsi\", \"description\": \"Whether to use TCP (\'iscsi\') or iSER RDMA (\'iser\') for iSCSI\", \"type\": \"string\"}, \"CinderNfsAvailabilityZone\": {\"default\": \"\", \"description\": \"The availability zone of the NFS Cinder backend. When set, it overrides the default CinderStorageAvailabilityZone.\\n\", \"type\": \"string\"}, \"CinderNfsMountOptions\": {\"default\": \"context=system_u:object_r:container_file_t:s0\", \"description\": \"Mount options for NFS mounts used by Cinder NFS backend. Effective when CinderEnableNfsBackend is true.\\n\", \"type\": \"string\"}, \"CinderNfsServers\": {\"default\": \"\", \"description\": \"NFS servers used by Cinder NFS backend. Effective when CinderEnableNfsBackend is true.\\n\", \"type\": \"comma_delimited_list\"}, \"CinderNfsSnapshotSupport\": {\"default\": false, \"description\": \"Whether to enable support for snapshots in the NFS driver. Effective when CinderEnableNfsBackend is true.\\n\", \"type\": \"boolean\"}, \"CinderNasSecureFileOperations\": {\"default\": false, \"description\": \"Controls whether security enhanced NFS file operations are enabled. Valid values are \'auto\', \'true\' or \'false\'. Effective when CinderEnableNfsBackend is true.\\n\", \"type\": \"string\"}, \"CinderNasSecureFilePermissions\": {\"default\": false, \"description\": \"Controls whether security enhanced NFS file permissions are enabled. Valid values are \'auto\', \'true\' or \'false\'. Effective when CinderEnableNfsBackend is true.\\n\", \"type\": \"string\"}, \"CinderRbdBackendName\": {\"type\": \"comma_delimited_list\", \"default\": \"tripleo_ceph\", \"description\": \"A list of Cinder RBD backend names.\"}, \"CinderRbdAvailabilityZone\": {\"default\": \"\", \"description\": \"The availability zone of the RBD Cinder backend. When set, it overrides the default CinderStorageAvailabilityZone.\\n\", \"type\": \"string\"}, \"CinderRbdPoolName\": {\"default\": \"volumes\", \"type\": \"string\"}, \"CinderRbdExtraPools\": {\"default\": [], \"description\": \"List of extra Ceph pools for use with RBD backends for Cinder. An extra Cinder RBD backend driver is created for each pool in the list. This is in addition to the standard RBD backend driver associated with the CinderRbdPoolName.\\n\", \"type\": \"comma_delimited_list\"}, \"CinderRbdFlattenVolumeFromSnapshot\": {\"default\": false, \"description\": \"Whether RBD volumes created from a snapshot should be flattened in order to remove a dependency on the snapshot.\\n\", \"type\": \"boolean\"}, \"CinderRbdMultiConfig\": {\"type\": \"json\", \"default\": {}, \"description\": \"Dictionary of settings when configuring multiple RBD backends. The\\nhash key is the backend name, and the value is a dictionary of parameter\\nvalues unique to that backend. The following parameters are required,\\nand must match the corresponding value defined in CephExternalMultiConfig.\\n  CephClusterName (must match the CephExternalMultiConfig entry\'s \'cluster\')\\n  CephClusterFSID (must match the CephExternalMultiConfig entry\'s \'fsid\')\\nThe following parameters are optional, and override the corresponding\\nparameter\'s default value.\\n  CephClientUserName\\n  CinderRbdPoolName\\n  CinderRbdExtraPools\\n  CinderRbdAvailabilityZone\\n  CinderRbdFlattenVolumeFromSnapshot\\n\"}, \"CephClusterFSID\": {\"type\": \"string\", \"description\": \"The Ceph cluster FSID. Must be a UUID.\", \"default\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\"}, \"MonitoringSubscriptionCinderVolume\": {\"default\": \"overcloud-cinder-volume\", \"type\": \"string\"}, \"CinderEtcdLocalConnect\": {\"default\": false, \"type\": \"boolean\", \"description\": \"When running Cinder A/A, whether to connect to Etcd via the local IP for the Etcd network. If set to true, the ip on the local node will be used. If set to false, the VIP on the Etcd network will be used instead. Defaults to false.\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"EnableEtcdInternalTLS\": {\"description\": \"Controls whether etcd and the cinder-volume service use TLS for cinder\'s lock manager, even when the rest of the internal API network is using TLS.\", \"type\": \"boolean\", \"default\": true}, \"CephConfigPath\": {\"type\": \"string\", \"default\": \"/var/lib/tripleo-config/ceph\", \"description\": \"The path where the Ceph Cluster config files are stored on the host.\\n\"}}, \"conditions\": {\"cvol_active_active_tls_enabled\": {\"and\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderVolumeCluster\"}, \"\"]}}, {\"get_param\": \"EnableInternalTLS\"}, {\"get_param\": \"EnableEtcdInternalTLS\"}]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MySQLClient\": {\"type\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-client.yaml\"}, \"CinderBase\": {\"type\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-base.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"CinderCommon\": {\"type\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerCinderVolumeImage\": \"ContainerCinderVolumeImage\", \"ContainerCinderConfigImage\": \"ContainerCinderConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerCinderVolumeImage\": {\"get_param\": \"ContainerCinderVolumeImage\"}, \"ContainerCinderConfigImage\": {\"get_param\": \"ContainerCinderConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Cinder Volume role.\", \"value\": {\"service_name\": \"cinder_volume\", \"firewall_rules\": {\"120 iscsi initiator\": {\"dport\": 3260}}, \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionCinderVolume\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"CinderBase\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"CinderCommon\", \"cinder_volume_config_settings\"]}, {\"tripleo::profile::base::lvm::enable_udev\": false, \"tripleo::profile::base::cinder::volume::cinder_enable_iscsi_backend\": {\"get_param\": \"CinderEnableIscsiBackend\"}, \"tripleo::profile::base::cinder::volume::cinder_enable_nfs_backend\": {\"get_param\": \"CinderEnableNfsBackend\"}, \"tripleo::profile::base::cinder::volume::cinder_enable_rbd_backend\": {\"get_param\": \"CinderEnableRbdBackend\"}, \"tripleo::profile::base::cinder::volume::cinder_volume_cluster\": {\"get_param\": \"CinderVolumeCluster\"}, \"tripleo::profile::base::cinder::volume::nfs::cinder_nfs_mount_options\": {\"get_param\": \"CinderNfsMountOptions\"}, \"tripleo::profile::base::cinder::volume::nfs::cinder_nfs_servers\": {\"get_param\": \"CinderNfsServers\"}, \"tripleo::profile::base::cinder::volume::nfs::cinder_nfs_snapshot_support\": {\"get_param\": \"CinderNfsSnapshotSupport\"}, \"tripleo::profile::base::cinder::volume::nfs::cinder_nas_secure_file_operations\": {\"get_param\": \"CinderNasSecureFileOperations\"}, \"tripleo::profile::base::cinder::volume::nfs::cinder_nas_secure_file_permissions\": {\"get_param\": \"CinderNasSecureFilePermissions\"}, \"tripleo::profile::base::cinder::volume::iscsi::cinder_iscsi_helper\": {\"get_param\": \"CinderISCSIHelper\"}, \"tripleo::profile::base::cinder::volume::iscsi::cinder_iscsi_protocol\": {\"get_param\": \"CinderISCSIProtocol\"}, \"tripleo::profile::base::cinder::volume::rbd::backend_name\": {\"get_param\": \"CinderRbdBackendName\"}, \"tripleo::profile::base::cinder::volume::rbd::cinder_rbd_ceph_conf\": {\"list_join\": [\"\", [\"/etc/ceph/\", {\"get_param\": \"CephClusterName\"}, \".conf\"]]}, \"tripleo::profile::base::cinder::volume::rbd::cinder_rbd_pool_name\": {\"get_param\": \"CinderRbdPoolName\"}, \"tripleo::profile::base::cinder::volume::rbd::cinder_rbd_extra_pools\": {\"get_param\": \"CinderRbdExtraPools\"}, \"tripleo::profile::base::cinder::volume::rbd::cinder_rbd_secret_uuid\": {\"get_param\": \"CephClusterFSID\"}, \"tripleo::profile::base::cinder::volume::rbd::cinder_rbd_user_name\": {\"get_param\": \"CephClientUserName\"}, \"tripleo::profile::base::cinder::volume::rbd::cinder_rbd_flatten_volume_from_snapshot\": {\"get_param\": \"CinderRbdFlattenVolumeFromSnapshot\"}, \"tripleo::profile::base::cinder::volume::rbd::multi_config\": {\"get_param\": \"CinderRbdMultiConfig\"}, \"tripleo::profile::base::cinder::volume::iscsi::cinder_iscsi_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderIscsiNetwork\"]}}}}}, {\"if\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderISCSIAvailabilityZone\"}, \"\"]}}, {\"tripleo::profile::base::cinder::volume::iscsi::backend_availability_zone\": {\"get_param\": \"CinderISCSIAvailabilityZone\"}}]}, {\"if\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderNfsAvailabilityZone\"}, \"\"]}}, {\"tripleo::profile::base::cinder::volume::nfs::backend_availability_zone\": {\"get_param\": \"CinderNfsAvailabilityZone\"}}]}, {\"if\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderRbdAvailabilityZone\"}, \"\"]}}, {\"tripleo::profile::base::cinder::volume::rbd::backend_availability_zone\": {\"get_param\": \"CinderRbdAvailabilityZone\"}}]}, {\"if\": [{\"get_param\": \"CinderEtcdLocalConnect\"}, {\"tripleo::profile::base::cinder::volume::etcd_host\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"EtcdNetwork\"]}}}}}]}]}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_cinder_volume\": [{\"get_param\": \"CinderVolumeLoggingSource\"}]}}, \"puppet_config\": {\"config_volume\": \"cinder\", \"puppet_tags\": \"cinder_config,file,concat,file_line\", \"step_config\": {\"list_join\": [\"\\n\", [\"include tripleo::profile::base::lvm\", \"include tripleo::profile::base::cinder::volume\", {\"get_attr\": [\"MySQLClient\", \"role_data\", \"step_config\"]}]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/cinder_volume.json\": {\"command\": \"/usr/bin/cinder-volume --config-file /usr/share/cinder/cinder-dist.conf --config-file /etc/cinder/cinder.conf\", \"config_files\": {\"get_attr\": [\"CinderCommon\", \"cinder_common_kolla_config_files\"]}, \"permissions\": {\"get_attr\": [\"CinderCommon\", \"cinder_common_kolla_permissions\"]}}}, \"docker_config\": {\"step_3\": {\"cinder_volume_init_logs\": {\"start_order\": 0, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}, \"net\": \"none\", \"privileged\": false, \"user\": \"root\", \"volumes\": [\"/var/log/containers/cinder:/var/log/cinder:z\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R cinder:cinder /var/log/cinder\"]}}, \"step_4\": {\"cinder_volume\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}, \"ulimit\": {\"get_param\": \"DockerCinderVolumeUlimit\"}, \"ipc\": \"host\", \"net\": \"host\", \"privileged\": true, \"restart\": \"always\", \"healthcheck\": {\"get_attr\": [\"ContainersCommon\", \"healthcheck_rpc_port\"]}, \"volumes\": {\"get_attr\": [\"CinderCommon\", \"cinder_volume_volumes\"]}, \"environment\": {\"get_attr\": [\"CinderCommon\", \"cinder_volume_environment\"]}}}}, \"host_prep_tasks\": {\"get_attr\": [\"CinderCommon\", \"cinder_volume_host_prep_tasks\"]}, \"upgrade_tasks\": {\"get_attr\": [\"CinderCommon\", \"cinder_volume_upgrade_tasks\"]}, \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop cinder volume container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"cinder_volume\"], \"tripleo_delegate_to\": \"{{ groups[\'cinder_volume\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(94,'2026-06-10 07:46:56',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(95,'2026-06-10 07:46:56',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mysql client settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role for setting mysql client parameters\", \"value\": {\"service_name\": \"mysql_client\", \"config_settings\": {\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"tripleo::profile::base::database::mysql::client::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}}, \"step_config\": \"include tripleo::profile::base::database::mysql::client\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(96,'2026-06-10 07:46:56',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"MySQL HA clustercheck service deployment using puppet This service is used by HAProxy in a HA scenario to report whether the local galera node is synced\\n\", \"parameters\": {\"ContainerClustercheckImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\"}, \"ContainerClustercheckConfigImage\": {\"description\": \"The container image to use for the clustercheck config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ClustercheckListener\": {\"default\": \"socat\", \"description\": \"How to expose the clustercheck service over TCP\", \"type\": \"string\", \"constraints\": [{\"allowed_values\": [\"socat\", \"xinetd\"]}]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MysqlPuppetBase\": {\"type\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerClustercheckImage\": \"ContainerClustercheckImage\", \"ContainerClustercheckConfigImage\": \"ContainerClustercheckConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerClustercheckImage\": {\"get_param\": \"ContainerClustercheckImage\"}, \"ContainerClustercheckConfigImage\": {\"get_param\": \"ContainerClustercheckConfigImage\"}}}]}}}}, \"conditions\": {\"socat_listener\": {\"equals\": [{\"get_param\": \"ClustercheckListener\"}, \"socat\"]}}, \"outputs\": {\"role_data\": {\"description\": \"Containerized service clustercheck using composable services.\", \"value\": {\"service_name\": \"clustercheck\", \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"MysqlPuppetBase\", \"role_data\", \"config_settings\"]}, {\"tripleo::profile::pacemaker::clustercheck::bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$FQDN$NETWORK\')}\", \"params\": {\"$FQDN\": {\"if\": [\"socat_listener\", \"\", \"fqdn_\"]}, \"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}}]}, \"puppet_config\": {\"config_volume\": \"clustercheck\", \"puppet_tags\": \"file\", \"step_config\": \"include tripleo::profile::pacemaker::clustercheck\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerClustercheckConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/clustercheck.json\": {\"command\": {\"if\": [\"socat_listener\", \"bash -c $* -- eval source /etc/sysconfig/clustercheck; exec socat -T\\\"${TRIPLEO_HEALTHCHECK_TIMEOUT:-2}\\\" \\\"$TRIPLEO_SOCAT_BIND\\\" system:\\\"grep -qPe \\\\\\\"^\\\\\\\\r\\\\$\\\\\\\" && /usr/bin/clustercheck\\\"\", \"/usr/sbin/xinetd -dontfork\"]}, \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]}}, \"docker_config\": {\"step_2\": {\"clustercheck\": {\"start_order\": 1, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerClustercheckImage\"]}, \"restart\": \"always\", \"net\": \"host\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/clustercheck.json:/var/lib/kolla/config_files/config.json\", \"/var/lib/config-data/puppet-generated/clustercheck:/var/lib/kolla/config_files/src:ro\", \"/var/lib/mysql:/var/lib/mysql\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"host_prep_tasks\": null, \"upgrade_tasks\": null, \"update_tasks\": null, \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop clustercheck container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"clustercheck\"], \"tripleo_delegate_to\": \"{{ groups[\'clustercheck\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (97,'2026-06-10 07:46:57',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Cinder base service. Shared by all Cinder services.\\n\", \"parameters\": {\"CinderStorageAvailabilityZone\": {\"default\": \"nova\", \"description\": \"The Cinder service\'s storage availability zone.\", \"type\": \"string\"}, \"CinderPassword\": {\"description\": \"The password for the cinder service and db account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"gtBv0TkCYxjriNwpG4AlCd1ll\"}, \"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"CinderDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging on Cinder services.\", \"type\": \"boolean\"}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"CinderCronDbPurgeMinute\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Minute\\n\", \"default\": \"1\"}, \"CinderCronDbPurgeHour\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Hour\\n\", \"default\": \"0\"}, \"CinderCronDbPurgeMonthday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month Day\\n\", \"default\": \"*\"}, \"CinderCronDbPurgeMonth\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month\\n\", \"default\": \"*\"}, \"CinderCronDbPurgeWeekday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Week Day\\n\", \"default\": \"*\"}, \"CinderCronDbPurgeUser\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - User\\n\", \"default\": \"cinder\"}, \"CinderCronDbPurgeAge\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Age\\n\", \"default\": \"30\"}, \"CinderCronDbPurgeDestination\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Log destination\\n\", \"default\": \"/var/log/cinder/cinder-rowsflush.log\"}, \"CinderCronDbPurgeMaxDelay\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Max Delay\\n\", \"default\": \"3600\"}, \"CinderRpcResponseTimeout\": {\"default\": 60, \"description\": \"Cinder\'s RPC response timeout, in seconds.\", \"type\": \"number\"}, \"NovaPassword\": {\"type\": \"string\", \"description\": \"The password for the nova service and db account\", \"hidden\": true, \"default\": \"btE80AtSdL16lZ5QqRx6f9I9L\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Cinder base service.\", \"value\": {\"service_name\": \"cinder_base\", \"config_settings\": {\"cinder::database_connection\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"protocol\"]}, \"username\": \"cinder\", \"password\": {\"get_param\": \"CinderPassword\"}, \"host\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"host\"]}, \"path\": \"/cinder\", \"query\": {\"if\": [{\"get_param\": \"EnableSQLAlchemyCollectd\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\", \"plugin\": \"collectd\", \"collectd_program_name\": \"cinder\", \"collectd_host\": \"localhost\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\"}]}}}, \"cinder::logging::debug\": {\"if\": [{\"get_param\": \"CinderDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"cinder::storage_availability_zone\": {\"get_param\": \"CinderStorageAvailabilityZone\"}, \"cinder::rabbit_heartbeat_timeout_threshold\": 60, \"cinder::rpc_response_timeout\": {\"get_param\": \"CinderRpcResponseTimeout\"}, \"cinder::rabbit_heartbeat_in_pthread\": false, \"cinder::db::database_db_max_retries\": -1, \"cinder::db::database_max_retries\": -1, \"cinder::cron::db_purge::minute\": {\"get_param\": \"CinderCronDbPurgeMinute\"}, \"cinder::cron::db_purge::hour\": {\"get_param\": \"CinderCronDbPurgeHour\"}, \"cinder::cron::db_purge::monthday\": {\"get_param\": \"CinderCronDbPurgeMonthday\"}, \"cinder::cron::db_purge::month\": {\"get_param\": \"CinderCronDbPurgeMonth\"}, \"cinder::cron::db_purge::weekday\": {\"get_param\": \"CinderCronDbPurgeWeekday\"}, \"cinder::cron::db_purge::user\": {\"get_param\": \"CinderCronDbPurgeUser\"}, \"cinder::cron::db_purge::age\": {\"get_param\": \"CinderCronDbPurgeAge\"}, \"cinder::cron::db_purge::destination\": {\"get_param\": \"CinderCronDbPurgeDestination\"}, \"cinder::cron::db_purge::maxdelay\": {\"get_param\": \"CinderCronDbPurgeMaxDelay\"}, \"cinder::glance::glance_api_servers\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"uri\"]}, \"cinder::keystone::service_user::send_service_user_token\": true, \"cinder::keystone::service_user::project_name\": \"service\", \"cinder::keystone::service_user::auth_type\": \"password\", \"cinder::keystone::service_user::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri\"]}, \"cinder::keystone::service_user::password\": {\"get_param\": \"CinderPassword\"}, \"cinder::keystone::service_user::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"cinder::nova::interface\": \"admin\", \"cinder::nova::project_name\": \"service\", \"cinder::nova::auth_type\": \"password\", \"cinder::nova::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri\"]}, \"cinder::nova::password\": {\"get_param\": \"NovaPassword\"}, \"cinder::nova::region_name\": {\"get_param\": \"KeystoneRegion\"}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(98,'2026-06-10 07:46:57',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Prepare container images\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ContainerImagePrepare\": {\"default\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"description\": \"Used to run \\\"openstack tripleo container image prepare\\\". This is run after the registry is installed to populate the registry with images.\", \"type\": \"json\"}, \"ContainerImagePrepareLogFile\": {\"default\": \"/var/log/tripleo-container-image-prepare.log\", \"type\": \"string\", \"description\": \"Used to store outputs of \\\"openstack tripleo container image prepare\\\".\"}, \"DockerInsecureRegistryAddress\": {\"description\": \"Optional. The IP Address and Port of an insecure docker namespace that will be configured in /etc/sysconfig/docker. The value can be multiple addresses separated by commas.\", \"type\": \"comma_delimited_list\", \"default\": []}, \"NeutronMechanismDrivers\": {\"default\": \"ovn\", \"description\": \"The mechanism drivers for the Neutron tenant network.\\n\", \"type\": \"comma_delimited_list\"}, \"DockerRegistryMirror\": {\"description\": \"Optional. Mirror to use for registry docker.io\", \"default\": \"\", \"type\": \"string\"}, \"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"ContainerImagePrepareDebug\": {\"default\": false, \"description\": \"Whether or not we want to activate --debug in tripleo container image prepare.\", \"type\": \"boolean\"}, \"ContainerImageRegistryCredentials\": {\"type\": \"json\", \"hidden\": true, \"default\": {}, \"description\": \"Mapping of image registry hosts to login credentials. Must be in the following example format\\n\\n  docker.io:\\n    username: pa55word\\n  \'192.0.2.1:8787\':\\n    registry_username: password\\n\"}, \"AdditionalArchitectures\": {\"default\": [], \"description\": \"List of additional architectures to enable.\", \"type\": \"comma_delimited_list\"}, \"ControllerContainerImagePrepare\": {\"description\": \"Used to run \\\"openstack tripleo container image prepare\\\". This is run after the registry is installed to populate the registry with images. This is used for a specific role and replaces the ContainerImagePrepare parameter.\", \"type\": \"json\", \"default\": {}}, \"ControllerServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the Controller role.\", \"type\": \"comma_delimited_list\", \"default\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"]}, \"ControllerCount\": {\"description\": \"Number of Controller nodes to deploy\", \"type\": \"number\", \"default\": 1}, \"CellControllerContainerImagePrepare\": {\"description\": \"Used to run \\\"openstack tripleo container image prepare\\\". This is run after the registry is installed to populate the registry with images. This is used for a specific role and replaces the ContainerImagePrepare parameter.\", \"type\": \"json\", \"default\": {}}, \"CellControllerServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the CellController role.\", \"type\": \"comma_delimited_list\", \"default\": []}, \"CellControllerCount\": {\"description\": \"Number of CellController nodes to deploy\", \"type\": \"number\", \"default\": 0}, \"CellControllerComputeContainerImagePrepare\": {\"description\": \"Used to run \\\"openstack tripleo container image prepare\\\". This is run after the registry is installed to populate the registry with images. This is used for a specific role and replaces the ContainerImagePrepare parameter.\", \"type\": \"json\", \"default\": {}}, \"CellControllerComputeServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the CellControllerCompute role.\", \"type\": \"comma_delimited_list\", \"default\": []}, \"CellControllerComputeCount\": {\"description\": \"Number of CellControllerCompute nodes to deploy\", \"type\": \"number\", \"default\": 0}, \"ComputeContainerImagePrepare\": {\"description\": \"Used to run \\\"openstack tripleo container image prepare\\\". This is run after the registry is installed to populate the registry with images. This is used for a specific role and replaces the ContainerImagePrepare parameter.\", \"type\": \"json\", \"default\": {}}, \"ComputeServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the Compute role.\", \"type\": \"comma_delimited_list\", \"default\": []}, \"ComputeCount\": {\"description\": \"Number of Compute nodes to deploy\", \"type\": \"number\", \"default\": 0}, \"BlockStorageContainerImagePrepare\": {\"description\": \"Used to run \\\"openstack tripleo container image prepare\\\". This is run after the registry is installed to populate the registry with images. This is used for a specific role and replaces the ContainerImagePrepare parameter.\", \"type\": \"json\", \"default\": {}}, \"BlockStorageServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the BlockStorage role.\", \"type\": \"comma_delimited_list\", \"default\": []}, \"BlockStorageCount\": {\"description\": \"Number of BlockStorage nodes to deploy\", \"type\": \"number\", \"default\": 0}, \"ObjectStorageContainerImagePrepare\": {\"description\": \"Used to run \\\"openstack tripleo container image prepare\\\". This is run after the registry is installed to populate the registry with images. This is used for a specific role and replaces the ContainerImagePrepare parameter.\", \"type\": \"json\", \"default\": {}}, \"ObjectStorageServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the ObjectStorage role.\", \"type\": \"comma_delimited_list\", \"default\": []}, \"ObjectStorageCount\": {\"description\": \"Number of ObjectStorage nodes to deploy\", \"type\": \"number\", \"default\": 0}, \"CephStorageContainerImagePrepare\": {\"description\": \"Used to run \\\"openstack tripleo container image prepare\\\". This is run after the registry is installed to populate the registry with images. This is used for a specific role and replaces the ContainerImagePrepare parameter.\", \"type\": \"json\", \"default\": {}}, \"CephStorageServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the CephStorage role.\", \"type\": \"comma_delimited_list\", \"default\": []}, \"CephStorageCount\": {\"description\": \"Number of CephStorage nodes to deploy\", \"type\": \"number\", \"default\": 0}, \"NetworkerContainerImagePrepare\": {\"description\": \"Used to run \\\"openstack tripleo container image prepare\\\". This is run after the registry is installed to populate the registry with images. This is used for a specific role and replaces the ContainerImagePrepare parameter.\", \"type\": \"json\", \"default\": {}}, \"NetworkerServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the Networker role.\", \"type\": \"comma_delimited_list\", \"default\": []}, \"NetworkerCount\": {\"description\": \"Number of Networker nodes to deploy\", \"type\": \"number\", \"default\": 0}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for container image prepare\", \"value\": {\"service_name\": \"container_image_prepare\", \"external_deploy_tasks\": [{\"name\": \"Run tripleo-container-image-prepare role\", \"import_role\": {\"name\": \"tripleo_container_image_prepare\"}, \"vars\": {\"tripleo_container_image_prepare_log_file\": {\"get_param\": \"ContainerImagePrepareLogFile\"}, \"tripleo_container_image_prepare_debug\": {\"if\": [{\"get_param\": \"ContainerImagePrepareDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"tripleo_container_image_prepare_roles\": [{\"name\": \"Controller\", \"description\": \"Controller role that has all the controler services loaded and handles\\\\nDatabase, Messaging and Network functions.\\\\n\", \"CountDefault\": 1, \"tags\": [\"primary\", \"controller\", \"external_bridge\"], \"networks\": {\"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Storage\": {\"subnet\": \"storage_subnet\"}, \"StorageMgmt\": {\"subnet\": \"storage_mgmt_subnet\"}, \"Tenant\": {\"subnet\": \"tenant_subnet\"}}, \"default_route_networks\": [\"ControlPlane\"], \"HostnameFormatDefault\": \"%stackname%-controller-%index%\", \"RoleParametersDefault\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"uses_deprecated_params\": true, \"deprecated_param_extraconfig\": \"controllerExtraConfig\", \"deprecated_param_flavor\": \"OvercloudControlFlavor\", \"deprecated_param_image\": \"controllerImage\", \"deprecated_nic_config_name\": \"controller.yaml\", \"update_serial\": 1, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BarbicanApi\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\", \"OS::TripleO::Services::BarbicanBackendDogtag\", \"OS::TripleO::Services::BarbicanBackendKmip\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephExternal\", \"OS::TripleO::Services::CephGrafana\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CephNfs\", \"OS::TripleO::Services::CephRbdMirror\", \"OS::TripleO::Services::CephRgw\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackendDellSc\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\", \"OS::TripleO::Services::CinderBackendDellEMCSc\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\", \"OS::TripleO::Services::CinderBackendNetApp\", \"OS::TripleO::Services::CinderBackendPure\", \"OS::TripleO::Services::CinderBackendScaleIO\", \"OS::TripleO::Services::CinderBackendNVMeOF\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::DesignateApi\", \"OS::TripleO::Services::DesignateCentral\", \"OS::TripleO::Services::DesignateProducer\", \"OS::TripleO::Services::DesignateWorker\", \"OS::TripleO::Services::DesignateMDNS\", \"OS::TripleO::Services::DesignateSink\", \"OS::TripleO::Services::DesignateBind\", \"OS::TripleO::Services::Etcd\", \"OS::TripleO::Services::ExternalSwiftProxy\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::IronicApi\", \"OS::TripleO::Services::IronicConductor\", \"OS::TripleO::Services::IronicInspector\", \"OS::TripleO::Services::IronicPxe\", \"OS::TripleO::Services::IronicNeutronAgent\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaBackendFlashBlade\", \"OS::TripleO::Services::ManilaBackendIsilon\", \"OS::TripleO::Services::ManilaBackendNetapp\", \"OS::TripleO::Services::ManilaBackendPowerMax\", \"OS::TripleO::Services::ManilaBackendUnity\", \"OS::TripleO::Services::ManilaBackendVNX\", \"OS::TripleO::Services::ManilaBackendVMAX\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::Multipathd\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronBgpVpnApi\", \"OS::TripleO::Services::NeutronSfcApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NeutronDhcpAgent\", \"OS::TripleO::Services::NeutronL2gwAgent\", \"OS::TripleO::Services::NeutronL2gwApi\", \"OS::TripleO::Services::NeutronL3Agent\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\", \"OS::TripleO::Services::NeutronMetadataAgent\", \"OS::TripleO::Services::NeutronOvsAgent\", \"OS::TripleO::Services::NeutronVppAgent\", \"OS::TripleO::Services::NeutronAgentsIBConfig\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaIronic\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OctaviaApi\", \"OS::TripleO::Services::OctaviaDeploymentConfig\", \"OS::TripleO::Services::OctaviaHealthManager\", \"OS::TripleO::Services::OctaviaHousekeeping\", \"OS::TripleO::Services::OctaviaWorker\", \"OS::TripleO::Services::OpenStackClients\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftDispersion\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::Unbound\", \"OS::TripleO::Services::Vpp\"]}, {\"name\": \"CellController\", \"description\": \"Controller role that has the cell controler specific\\\\nservices and handles Database, Messaging and Network functions.\\\\n\", \"CountDefault\": 1, \"tags\": [\"primary\", \"controller\"], \"networks\": {\"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Storage\": {\"subnet\": \"storage_subnet\"}, \"StorageMgmt\": {\"subnet\": \"storage_mgmt_subnet\"}, \"Tenant\": {\"subnet\": \"tenant_subnet\"}}, \"default_route_networks\": [\"ControlPlane\"], \"HostnameFormatDefault\": \"%stackname%-controller-%index%\", \"RoleParametersDefault\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"uses_deprecated_params\": true, \"deprecated_param_extraconfig\": \"controllerExtraConfig\", \"deprecated_param_flavor\": \"OvercloudControlFlavor\", \"deprecated_param_image\": \"controllerImage\", \"deprecated_nic_config_name\": \"controller.yaml\", \"update_serial\": 1, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronMetadataAgent\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Ptp\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::Vpp\"]}, {\"name\": \"CellControllerCompute\", \"description\": \"Controller and Compute AIO role that has compute and cell controler specific\\\\nservices loaded and handles Database, Messaging and Network functions.\\\\n\", \"CountDefault\": 1, \"tags\": [\"primary\", \"controller\", \"external_bridge\"], \"networks\": {\"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Storage\": {\"subnet\": \"storage_subnet\"}, \"StorageMgmt\": {\"subnet\": \"storage_mgmt_subnet\"}, \"Tenant\": {\"subnet\": \"tenant_subnet\"}}, \"default_route_networks\": [\"ControlPlane\"], \"HostnameFormatDefault\": \"%stackname%-controller-compute-%index%\", \"RoleParametersDefault\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"uses_deprecated_params\": true, \"deprecated_param_extraconfig\": \"controllerExtraConfig\", \"deprecated_param_flavor\": \"OvercloudControlFlavor\", \"deprecated_param_image\": \"controllerImage\", \"deprecated_nic_config_name\": \"controller.yaml\", \"update_serial\": 1, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephExternal\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\", \"OS::TripleO::Services::ComputeNeutronL3Agent\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::Multipathd\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\", \"OS::TripleO::Services::NeutronVppAgent\", \"OS::TripleO::Services::NovaAZConfig\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::NeutronMetadataAgent\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Ptp\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::Vpp\"]}, {\"name\": \"Compute\", \"description\": \"Basic Compute Node role\\\\n\", \"CountDefault\": 1, \"tags\": [\"compute\", \"external_bridge\"], \"networks\": {\"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Tenant\": {\"subnet\": \"tenant_subnet\"}, \"Storage\": {\"subnet\": \"storage_subnet\"}}, \"default_route_networks\": [\"ControlPlane\"], \"HostnameFormatDefault\": \"%stackname%-novacompute-%index%\", \"RoleParametersDefault\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"uses_deprecated_params\": true, \"deprecated_param_image\": \"NovaImage\", \"deprecated_param_extraconfig\": \"NovaComputeExtraConfig\", \"deprecated_param_metadata\": \"NovaComputeServerMetadata\", \"deprecated_param_scheduler_hints\": \"NovaComputeSchedulerHints\", \"deprecated_param_ips\": \"NovaComputeIPs\", \"deprecated_server_resource_name\": \"NovaCompute\", \"deprecated_nic_config_name\": \"compute.yaml\", \"update_serial\": 25, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephExternal\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\", \"OS::TripleO::Services::ComputeNeutronL3Agent\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::Multipathd\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\", \"OS::TripleO::Services::NeutronVppAgent\", \"OS::TripleO::Services::NovaAZConfig\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::Vpp\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"]}, {\"name\": \"BlockStorage\", \"description\": \"Cinder Block Storage node role\\\\n\", \"tags\": [\"storage\"], \"networks\": {\"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Storage\": {\"subnet\": \"storage_subnet\"}, \"StorageMgmt\": {\"subnet\": \"storage_mgmt_subnet\"}}, \"uses_deprecated_params\": false, \"deprecated_nic_config_name\": \"cinder-storage.yaml\", \"update_serial\": 25, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BlockStorageCinderVolume\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::Multipathd\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"]}, {\"name\": \"ObjectStorage\", \"description\": \"Swift Object Storage node role\\\\n\", \"tags\": [\"storage\"], \"networks\": {\"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Storage\": {\"subnet\": \"storage_subnet\"}, \"StorageMgmt\": {\"subnet\": \"storage_mgmt_subnet\"}}, \"uses_deprecated_params\": true, \"deprecated_param_metadata\": \"SwiftStorageServerMetadata\", \"deprecated_param_ips\": \"SwiftStorageIPs\", \"deprecated_param_image\": \"SwiftStorageImage\", \"deprecated_param_flavor\": \"OvercloudSwiftStorageFlavor\", \"deprecated_nic_config_name\": \"swift-storage.yaml\", \"deprecated_server_resource_name\": \"SwiftStorage\", \"update_serial\": 1, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::Ptp\"]}, {\"name\": \"CephStorage\", \"description\": \"Ceph OSD Storage node role\\\\n\", \"tags\": [\"ceph\", \"storage\"], \"networks\": {\"Storage\": {\"subnet\": \"storage_subnet\"}, \"StorageMgmt\": {\"subnet\": \"storage_mgmt_subnet\"}}, \"uses_deprecated_params\": false, \"HostnameFormatDefault\": \"%stackname%-cephstorage-%index%\", \"deprecated_nic_config_name\": \"ceph-storage.yaml\", \"update_serial\": 1, \"rhsm_enforce\": false, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"]}, {\"name\": \"Networker\", \"description\": \"Standalone networking role to run Neutron agents on their own.\\\\n\", \"networks\": {\"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Tenant\": {\"subnet\": \"tenant_subnet\"}}, \"tags\": [\"external_bridge\"], \"HostnameFormatDefault\": \"%stackname%-networker-%index%\", \"RoleParametersDefault\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"update_serial\": 1, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::IronicNeutronAgent\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronDhcpAgent\", \"OS::TripleO::Services::NeutronL2gwAgent\", \"OS::TripleO::Services::NeutronL3Agent\", \"OS::TripleO::Services::NeutronMetadataAgent\", \"OS::TripleO::Services::NeutronOvsAgent\", \"OS::TripleO::Services::NeutronVppAgent\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OctaviaDeploymentConfig\", \"OS::TripleO::Services::OctaviaHealthManager\", \"OS::TripleO::Services::OctaviaHousekeeping\", \"OS::TripleO::Services::OctaviaWorker\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"]}], \"tripleo_container_image_prepare_content\": {\"parameter_defaults\": {\"ContainerImagePrepare\": {\"get_param\": \"ContainerImagePrepare\"}, \"DockerInsecureRegistryAddress\": {\"get_param\": \"DockerInsecureRegistryAddress\"}, \"NeutronMechanismDrivers\": {\"get_param\": \"NeutronMechanismDrivers\"}, \"DockerRegistryMirror\": {\"get_param\": \"DockerRegistryMirror\"}, \"ContainerImageRegistryCredentials\": {\"get_param\": \"ContainerImageRegistryCredentials\"}, \"AdditionalArchitectures\": {\"get_param\": \"AdditionalArchitectures\"}, \"ControllerContainerImagePrepare\": {\"get_param\": \"ControllerContainerImagePrepare\"}, \"ControllerServices\": {\"get_param\": \"ControllerServices\"}, \"ControllerCount\": {\"get_param\": \"ControllerCount\"}, \"CellControllerContainerImagePrepare\": {\"get_param\": \"CellControllerContainerImagePrepare\"}, \"CellControllerServices\": {\"get_param\": \"CellControllerServices\"}, \"CellControllerCount\": {\"get_param\": \"CellControllerCount\"}, \"CellControllerComputeContainerImagePrepare\": {\"get_param\": \"CellControllerComputeContainerImagePrepare\"}, \"CellControllerComputeServices\": {\"get_param\": \"CellControllerComputeServices\"}, \"CellControllerComputeCount\": {\"get_param\": \"CellControllerComputeCount\"}, \"ComputeContainerImagePrepare\": {\"get_param\": \"ComputeContainerImagePrepare\"}, \"ComputeServices\": {\"get_param\": \"ComputeServices\"}, \"ComputeCount\": {\"get_param\": \"ComputeCount\"}, \"BlockStorageContainerImagePrepare\": {\"get_param\": \"BlockStorageContainerImagePrepare\"}, \"BlockStorageServices\": {\"get_param\": \"BlockStorageServices\"}, \"BlockStorageCount\": {\"get_param\": \"BlockStorageCount\"}, \"ObjectStorageContainerImagePrepare\": {\"get_param\": \"ObjectStorageContainerImagePrepare\"}, \"ObjectStorageServices\": {\"get_param\": \"ObjectStorageServices\"}, \"ObjectStorageCount\": {\"get_param\": \"ObjectStorageCount\"}, \"CephStorageContainerImagePrepare\": {\"get_param\": \"CephStorageContainerImagePrepare\"}, \"CephStorageServices\": {\"get_param\": \"CephStorageServices\"}, \"CephStorageCount\": {\"get_param\": \"CephStorageCount\"}, \"NetworkerContainerImagePrepare\": {\"get_param\": \"NetworkerContainerImagePrepare\"}, \"NetworkerServices\": {\"get_param\": \"NetworkerServices\"}, \"NetworkerCount\": {\"get_param\": \"NetworkerCount\"}}}}, \"when\": [\"(step | int) == 1\"]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(99,'2026-06-10 07:46:57',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"MySQL service deployment with pacemaker bundle\\n\", \"parameters\": {\"ContainerMysqlImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\"}, \"ContainerMysqlConfigImage\": {\"description\": \"The container image to use for the mysql config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\"}, \"ClusterCommonTag\": {\"default\": false, \"description\": \"When set to false, a pacemaker service is configured to use a floating tag for its container image name, e.g. \'REGISTRY/NAMESPACE/IMAGENAME:pcmklatest\'. When set to true, the service uses a floating prefix as well, e.g. \'cluster.common.tag/IMAGENAME:pcmklatest\'.\", \"type\": \"boolean\"}, \"ClusterFullTag\": {\"default\": true, \"description\": \"When set to true, the pacemaker service uses a fully constant tag for its container image name, e.g. \'cluster.common.tag/SERVICENAME:pcmklatest\'.\", \"type\": \"boolean\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"MysqlRootPassword\": {\"type\": \"string\", \"hidden\": true, \"default\": \"wDcXw6Z0DC\"}, \"MysqlClustercheckPassword\": {\"type\": \"string\", \"hidden\": true, \"default\": \"hepAGELIsa9DMKgtpIM5NwEsU\"}, \"MysqlUpgradePersist\": {\"type\": \"boolean\", \"default\": false}, \"MysqlUpgradeTransfer\": {\"type\": \"boolean\", \"default\": true}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"ConfigDebug\": {\"default\": false, \"description\": \"Whether to run config management (e.g. Puppet) in debug mode.\", \"type\": \"boolean\"}, \"DeployIdentifier\": {\"default\": 1781077560, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}, \"MysqlGaleraSSTMethod\": {\"type\": \"string\", \"default\": \"rsync\", \"description\": \"Method used by galera to perform State Snapshot Transfers\", \"constraints\": [{\"allowed_values\": [\"rsync\", \"mariabackup\"]}]}, \"MysqlMariabackupUser\": {\"type\": \"string\", \"default\": \"mariabackup\", \"description\": \"When MysqlGaleraSSTMethod is set to mariabackup, the name of the database user that executes the SST.\"}, \"MysqlMariabackupPassword\": {\"type\": \"string\", \"hidden\": true, \"description\": \"When MysqlGaleraSSTMethod is set to mariabackup, the password of the database user that executes the SST.\", \"default\": \"8I5mvt66ebeLQhZAOpOekHv6P\"}, \"MysqlGaleraSSLCipher\": {\"type\": \"string\", \"default\": \"AES128-SHA256\", \"description\": \"Symmetric cipher to use.\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MysqlBase\": {\"type\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-base.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerMysqlImage\": \"ContainerMysqlImage\", \"ContainerMysqlConfigImage\": \"ContainerMysqlConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerMysqlImage\": {\"get_param\": \"ContainerMysqlImage\"}, \"ContainerMysqlConfigImage\": {\"get_param\": \"ContainerMysqlConfigImage\"}}}]}}}}, \"conditions\": {\"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"role_data\": {\"description\": \"Containerized service MySQL using composable services.\", \"value\": {\"service_name\": {\"get_attr\": [\"MysqlBase\", \"role_data\", \"service_name\"]}, \"firewall_rules\": {\"104 mysql galera-bundle\": {\"dport\": [873, 3123, 3306, 4444, 4567, 4568, 9200]}}, \"firewall_frontend_rules\": {\"100 mysql_haproxy\": {\"dport\": [3306]}}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"MysqlBase\", \"role_data\", \"config_settings\"]}, {\"tripleo::profile::pacemaker::database::mysql::bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::pacemaker::database::mysql::gmcast_listen_addr\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::pacemaker::database::mysql::ca_file\": {\"get_param\": \"InternalTLSCAFile\"}, \"tripleo::profile::pacemaker::database::mysql_bundle::mysql_docker_image\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/mariadb:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"tripleo::profile::pacemaker::database::mysql_bundle::control_port\": 3123, \"tripleo::profile::pacemaker::database::mysql_bundle::container_backend\": {\"get_param\": \"ContainerCli\"}, \"tripleo::profile::pacemaker::database::mysql_bundle::bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::pacemaker::database::mysql_bundle::ca_file\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"get_param\": \"InternalTLSCAFile\"}]}, \"tripleo::profile::pacemaker::database::mysql_bundle::sst_method\": {\"get_param\": \"MysqlGaleraSSTMethod\"}, \"tripleo::profile::pacemaker::database::mysql_bundle::mariabackup_user\": {\"get_param\": \"MysqlMariabackupUser\"}, \"tripleo::profile::pacemaker::database::mysql_bundle::mariabackup_password\": {\"get_param\": \"MysqlMariabackupPassword\"}, \"tripleo::profile::pacemaker::database::mysql_bundle::force_ocf\": true, \"tripleo::profile::pacemaker::database::mysql_bundle::gcomm_cipher\": {\"get_param\": \"MysqlGaleraSSLCipher\"}}]}, \"puppet_config\": {\"config_volume\": \"mysql\", \"puppet_tags\": \"file\", \"step_config\": {\"list_join\": [\"\\n\", [\"[\'Mysql_datadir\', \'Mysql_user\', \'Mysql_database\', \'Mysql_grant\', \'Mysql_plugin\'].each |String $val| { noop_resource($val) }\", \"exec {\'wait-for-settle\': command => \'/bin/true\' }\", \"include tripleo::profile::pacemaker::database::mysql_bundle\"]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/mysql.json\": {\"command\": \"/usr/sbin/pacemaker_remoted\", \"config_files\": [{\"dest\": \"/etc/libqb/force-filesystem-sockets\", \"source\": \"/dev/null\", \"owner\": \"root\", \"perm\": \"0644\"}, {\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"optional\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/mysql\", \"owner\": \"mysql:mysql\", \"recurse\": true}, {\"path\": \"/etc/pki/tls/certs/mysql.crt\", \"owner\": \"mysql:mysql\", \"perm\": \"0600\", \"optional\": true}, {\"path\": \"/etc/pki/tls/private/mysql.key\", \"owner\": \"mysql:mysql\", \"perm\": \"0600\", \"optional\": true}]}}, \"container_config_scripts\": {\"get_attr\": [\"ContainersCommon\", \"container_config_scripts\"]}, \"docker_config\": {\"step_1\": {\"mysql_data_ownership\": {\"start_order\": 0, \"detach\": false, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"net\": \"host\", \"user\": \"root\", \"command\": [\"chown\", \"-R\", \"mysql:\", \"/var/lib/mysql\"], \"volumes\": [\"/var/lib/mysql:/var/lib/mysql:z\"]}, \"mysql_bootstrap\": {\"start_order\": 1, \"detach\": false, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"net\": \"host\", \"user\": \"root\", \"command\": [\"bash\", \"-ec\", {\"list_join\": [\"\\n\", [\"if [ -e /var/lib/mysql/mysql ]; then exit 0; fi\", \"echo -e \\\"\\\\n[mysqld]\\\\nwsrep_provider=none\\\" >> /etc/my.cnf\", \"export DB_ROOT_PASSWORD=$(hiera \'mysql::server::root_password\')\", \"kolla_set_configs\", \"sudo -u mysql -E kolla_extend_start\", \"timeout ${DB_MAX_TIMEOUT} /bin/bash -c \'while pgrep -af /usr/bin/mysqld_safe | grep -q -v grep; do sleep 1; done\'\", \"mysqld_safe --skip-networking --wsrep-on=OFF &\", \"timeout ${DB_MAX_TIMEOUT} /bin/bash -c \'until mysqladmin -uroot -p\\\"$(hiera \'mysql::server::root_password\')\\\" ping 2>/dev/null; do sleep 1; done\'\"], {\"if\": [{\"equals\": [{\"get_param\": \"MysqlGaleraSSTMethod\"}, \"mariabackup\"]}, [\"mysql -uroot -p\\\"$(hiera \'mysql::server::root_password\')\\\" -e \\\"CREATE USER \'${DB_MARIABACKUP_USER}\'@\'localhost\' IDENTIFIED BY \'${DB_MARIABACKUP_PASSWORD}\';\\\"\", \"mysql -uroot -p\\\"$(hiera \'mysql::server::root_password\')\\\" -e \\\"GRANT RELOAD, PROCESS, LOCK TABLES, REPLICATION CLIENT ON *.* TO \'${DB_MARIABACKUP_USER}\'@\'localhost\';\\\"\"]]}, [\"mysql -uroot -p\\\"$(hiera \'mysql::server::root_password\')\\\" -e \\\"CREATE USER \'clustercheck\'@\'localhost\' IDENTIFIED BY \'$(hiera mysql_clustercheck_password)\';\\\"\", \"mysql -uroot -p\\\"$(hiera \'mysql::server::root_password\')\\\" -e \\\"GRANT PROCESS ON *.* TO \'clustercheck\'@\'localhost\' WITH GRANT OPTION;\\\"\", \"mysql -uroot -p\\\"$(hiera \'mysql::server::root_password\')\\\" -e \\\"DELETE FROM mysql.user WHERE user = \'root\' AND host NOT IN (\'%\',\'localhost\');\\\"\", \"timeout ${DB_MAX_TIMEOUT} mysqladmin -uroot -p\\\"$(hiera \'mysql::server::root_password\')\\\" shutdown\"]]}], \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/mysql.json:/var/lib/kolla/config_files/config.json:rw,z\", \"/var/lib/config-data/puppet-generated/mysql:/var/lib/kolla/config_files/src:ro,z\", \"/var/lib/mysql:/var/lib/mysql:rw,z\"], {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [\"/etc/pki/tls/certs/mysql.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/mysql.crt:ro\", \"/etc/pki/tls/private/mysql.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/mysql.key:ro\"]]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\", \"KOLLA_BOOTSTRAP\": true, \"DB_MAX_TIMEOUT\": 60, \"DB_MARIABACKUP_USER\": {\"get_param\": \"MysqlMariabackupUser\"}, \"DB_MARIABACKUP_PASSWORD\": {\"get_param\": \"MysqlMariabackupPassword\"}}}}, \"step_2\": {\"mysql_wait_bundle\": {\"start_order\": 0, \"detach\": false, \"net\": \"host\", \"ipc\": \"host\", \"user\": \"root\", \"command\": {\"list_concat\": [[\"/container_puppet_apply.sh\", \"2\", \"file,file_line,concat,augeas,galera_ready,mysql_database,mysql_grant,mysql_user\", \"include tripleo::profile::pacemaker::database::mysql_bundle\"], {\"if\": [{\"get_param\": \"ConfigDebug\"}, [\"--debug\"]]}]}, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"container_puppet_apply_volumes\"]}, [\"/var/lib/mysql:/var/lib/mysql:rw,z\", \"/var/lib/config-data/puppet-generated/mysql/root:/root:rw\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"]]}]}, \"environment\": {\"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}}}}}, \"host_prep_tasks\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/mysql\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/mysql\", \"setype\": \"container_file_t\"}, {\"path\": \"/var/log/mariadb\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}], \"metadata_settings\": {\"get_attr\": [\"MysqlBase\", \"role_data\", \"metadata_settings\"]}, \"deploy_steps_tasks\": {\"list_concat\": [{\"get_attr\": [\"MysqlBase\", \"role_data\", \"deploy_steps_tasks\"]}, [{\"name\": \"MySQL tag container image for pacemaker\", \"when\": \"step|int == 1\", \"import_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"container_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/mariadb:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}}}, {\"name\": \"MySQL HA Wrappers Step\", \"when\": \"step|int == 2\", \"block\": [{\"name\": \"Mysql puppet bundle\", \"import_role\": {\"name\": \"tripleo_ha_wrapper\"}, \"vars\": {\"tripleo_ha_wrapper_service_name\": \"mysql\", \"tripleo_ha_wrapper_resource_name\": \"galera\", \"tripleo_ha_wrapper_bundle_name\": \"galera-bundle\", \"tripleo_ha_wrapper_resource_state\": \"Master\", \"tripleo_ha_wrapper_puppet_config_volume\": \"mysql\", \"tripleo_ha_wrapper_puppet_execute\": \"[\\\"Mysql_datadir\\\", \\\"Mysql_user\\\", \\\"Mysql_database\\\", \\\"Mysql_grant\\\", \\\"Mysql_plugin\\\"].each |String $val| { noop_resource($val) }; include ::tripleo::profile::base::pacemaker; include ::tripleo::profile::pacemaker::database::mysql_bundle\", \"tripleo_ha_wrapper_puppet_tags\": \"pacemaker::resource::bundle,pacemaker::property,pacemaker::resource::ocf,pacemaker::constraint::order,pacemaker::constraint::colocation\", \"tripleo_ha_wrapper_puppet_debug\": {\"get_param\": \"ConfigDebug\"}, \"tripleo_ha_wrapper_config_suffix\": \".previous_run\"}}]}]]}, \"external_update_tasks\": [{\"when\": \"step|int == 1\", \"tags\": \"ha_image_update\", \"block\": [{\"block\": [{\"name\": \"Get galera image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_galera_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'galera-bundle\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container galera image\", \"set_fact\": {\"galera_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"galera_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/mariadb:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"pcmk_galera_image\": \"{{xmllint_pcmk_galera_image.stdout}}\"}}], \"delegate_to\": \"{{ (groups[\\\"mysql\\\"] | difference(groups[\\\"excluded_overcloud\\\"]))[0] }}\"}, {\"name\": \"MySQL temporary pacemaker container tag in case of image switch\", \"become\": true, \"import_role\": {\"name\": \"tripleo_ha_image_update\"}, \"vars\": {\"tripleo_ha_image_update_node_names\": \"{{ groups[\\\"mysql\\\"] | difference(groups[\\\"excluded_overcloud\\\"]) }}\", \"tripleo_ha_image_update_bundle\": \"galera-bundle\", \"tripleo_ha_image_update_new_image\": \"{{galera_image_latest}}\", \"tripleo_ha_image_update_old_image\": \"{{pcmk_galera_image}}\"}, \"when\": [\"(pcmk_galera_image != \\\"\\\")\", \"(pcmk_galera_image != galera_image_latest)\"]}]}], \"update_tasks\": [{\"block\": [{\"name\": \"Get galera image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_galera_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'galera-bundle\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container galera image\", \"set_fact\": {\"galera_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"galera_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/mariadb:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"pcmk_galera_image\": \"{{xmllint_pcmk_galera_image.stdout}}\"}}], \"when\": \"(step|int == 0 or step|int == 2)\"}, {\"name\": \"Check for update of galera container image name\", \"when\": \"step|int == 0\", \"assert\": {\"that\": \"pcmk_galera_image == galera_image_latest\", \"fail_msg\": \"galera image change detected, run overcloud external-update --tags ha_image_update first\"}}, {\"name\": \"Tear-down non-HA mysql container\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"stat mysql container\", \"command\": \"podman container exists mysql\", \"failed_when\": false, \"changed_when\": false, \"register\": \"stat_mysql_container\"}, {\"name\": \"Create clustercheck user and permissions\", \"command\": {\"argv\": \"{{ mysql_exec_data | container_exec_cmd }}\"}, \"changed_when\": true, \"when\": [\"stat_mysql_container.rc == 0\"], \"vars\": {\"mysql_exec_data\": {\"environment\": {\"CLUSTERCHECK_PASSWORD\": {\"get_param\": \"MysqlClustercheckPassword\"}}, \"command\": [\"mysql\", \"/bin/sh\", \"-c\", \"mysql -e \\\"CREATE USER IF NOT EXISTS \'clustercheck\'@\'localhost\' IDENTIFIED BY \'${CLUSTERCHECK_PASSWORD}\'; GRANT PROCESS ON *.* TO \'clustercheck\'@\'localhost\' WITH GRANT OPTION;\\\"\"]}}}, {\"name\": \"Remove non-HA mysql container\", \"include_role\": {\"name\": \"tripleo_container_rm\"}, \"vars\": {\"tripleo_container_cli\": \"{{ container_cli }}\", \"tripleo_containers_to_rm\": [\"mysql\"]}}]}, {\"name\": \"Mariadb fetch and retag container image for pacemaker\", \"when\": \"step|int == 2\", \"block\": [{\"name\": \"Retag pcmklatest to latest galera image\", \"include_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{galera_image}}\", \"container_image_latest\": \"{{galera_image_latest}}\"}}]}, {\"name\": \"Ensure mariadb-server is not installed on the host\", \"when\": \"step|int == 2\", \"yum\": {\"name\": \"mariadb-server*\", \"state\": \"absent\"}}], \"post_update_tasks\": [{\"name\": \"Mysql bundle post update\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"Mysql puppet bundle\", \"import_role\": {\"name\": \"tripleo_ha_wrapper\"}, \"vars\": {\"tripleo_ha_wrapper_service_name\": \"mysql\", \"tripleo_ha_wrapper_resource_name\": \"galera\", \"tripleo_ha_wrapper_bundle_name\": \"galera-bundle\", \"tripleo_ha_wrapper_resource_state\": \"Master\", \"tripleo_ha_wrapper_puppet_config_volume\": \"mysql\", \"tripleo_ha_wrapper_puppet_execute\": \"[\\\"Mysql_datadir\\\", \\\"Mysql_user\\\", \\\"Mysql_database\\\", \\\"Mysql_grant\\\", \\\"Mysql_plugin\\\"].each |String $val| { noop_resource($val) }; include ::tripleo::profile::base::pacemaker; include ::tripleo::profile::pacemaker::database::mysql_bundle\", \"tripleo_ha_wrapper_puppet_tags\": \"pacemaker::resource::bundle,pacemaker::property,pacemaker::resource::ocf,pacemaker::constraint::order,pacemaker::constraint::colocation\", \"tripleo_ha_wrapper_puppet_debug\": {\"get_param\": \"ConfigDebug\"}, \"tripleo_ha_wrapper_config_suffix\": \".previous_run\"}}], \"vars\": {\"tripleo_ha_wrapper_minor_update\": true}}], \"upgrade_tasks\": {\"list_concat\": [[{\"name\": \"Tear-down non-HA mysql container\", \"when\": [\"step|int == 0\"], \"block\": [{\"name\": \"stat mysql container\", \"command\": \"podman container exists mysql\", \"failed_when\": false, \"changed_when\": false, \"register\": \"stat_mysql_container\"}, {\"name\": \"Create clustercheck user and permissions\", \"command\": {\"argv\": \"{{ mysql_exec_data | container_exec_cmd }}\"}, \"changed_when\": true, \"when\": [\"stat_mysql_container.rc == 0\"], \"vars\": {\"mysql_exec_data\": {\"environment\": {\"CLUSTERCHECK_PASSWORD\": {\"get_param\": \"MysqlClustercheckPassword\"}}, \"command\": [\"mysql\", \"/bin/sh\", \"-c\", \"mysql -e \\\"CREATE USER IF NOT EXISTS \'clustercheck\'@\'localhost\' IDENTIFIED BY \'${CLUSTERCHECK_PASSWORD}\'; GRANT PROCESS ON *.* TO \'clustercheck\'@\'localhost\' WITH GRANT OPTION;\\\"\"]}}}, {\"name\": \"Remove non-HA mysql container\", \"include_role\": {\"name\": \"tripleo_container_rm\"}, \"vars\": {\"tripleo_container_cli\": \"{{ container_cli }}\", \"tripleo_containers_to_rm\": [\"mysql\"]}}]}], [{\"name\": \"set mysql container name fact\", \"when\": [\"step|int == 1\"], \"set_fact\": {\"mysql_container_name\": \"galera-bundle\"}}], {\"get_attr\": [\"MysqlBase\", \"mysql_drop_unused_users\"]}, [{\"vars\": {\"mysql_upgrade_persist\": {\"get_param\": \"MysqlUpgradePersist\"}}, \"when\": [\"step|int == 3\", \"mysql_upgrade_persist\"], \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_prepare\"], \"block\": [{\"name\": \"Persist mysql data\", \"include_role\": {\"name\": \"tripleo_persist\", \"tasks_from\": \"persist.yml\"}, \"vars\": {\"tripleo_persist_dir\": \"/var/lib/mysql\"}}]}, {\"vars\": {\"mysql_upgrade_persist\": {\"get_param\": \"MysqlUpgradePersist\"}}, \"when\": [\"step|int == 5\", \"mysql_upgrade_persist\"], \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\"], \"block\": [{\"name\": \"Restore mysql data\", \"include_role\": {\"name\": \"tripleo_persist\", \"tasks_from\": \"restore.yml\"}, \"vars\": {\"tripleo_persist_dir\": \"/var/lib/mysql\"}}]}, {\"name\": \"Prepare switch of galera image name\", \"when\": [\"step|int == 0\"], \"block\": [{\"name\": \"Get galera image id currently used by pacemaker\", \"shell\": \"pcs resource config galera-bundle | grep -Eo \'image=[^ ]+\' | awk -F= \'{print $2;}\'\", \"register\": \"galera_image_current_res\", \"failed_when\": false}, {\"name\": \"Image facts for galera\", \"set_fact\": {\"galera_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/mariadb:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"galera_image_current\": \"{{galera_image_current_res.stdout}}\"}}, {\"name\": \"Temporarily tag the current galera image id with the upgraded image name\", \"import_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{galera_image_current}}\", \"container_image_latest\": \"{{galera_image_latest}}\", \"pull_image\": false}, \"when\": [\"galera_image_current != \'\'\", \"galera_image_current != galera_image_latest\"]}, {\"name\": \"Create galera retag statefile\", \"file\": {\"path\": \"/var/lib/tripleo/galera_needs_retag\", \"state\": \"touch\"}, \"when\": [\"galera_image_current != \'\'\", \"galera_image_current != galera_image_latest\"]}]}, {\"name\": \"Update galera pcs resource bundle for new container image - check\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"set is_mysql_bootstrap_node fact\", \"tags\": \"common\", \"set_fact\": \"is_mysql_bootstrap_node={{mysql_short_bootstrap_node_name|lower == ansible_facts[\'hostname\']|lower}}\"}, {\"name\": \"Check for galera retag statefile\", \"stat\": {\"path\": \"/var/lib/tripleo/galera_needs_retag\"}, \"register\": \"galera_retag_state_file\"}]}, {\"name\": \"Update galera pcs resource bundle for new container image\", \"when\": [\"step|int == 1\", \"is_mysql_bootstrap_node|bool\", \"galera_retag_state_file.stat.exists|bool\"], \"block\": [{\"name\": \"Disable the galera cluster resource before container upgrade\", \"pacemaker_resource\": {\"resource\": \"galera-bundle\", \"state\": \"disable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}, {\"name\": \"Move Mysql logging to /var/log/containers\", \"block\": [{\"name\": \"Check Mysql logging configuration in pacemaker\", \"command\": \"cibadmin --query --xpath \\\"//storage-mapping[@id=\'mysql-log\']\\\"\", \"failed_when\": false, \"register\": \"mysql_logs_moved\"}, {\"name\": \"Change Mysql logging configuration in pacemaker\", \"when\": \"mysql_logs_moved.rc == 6\", \"block\": [{\"name\": \"Add a bind mount for logging in the galera bundle\", \"command\": \"pcs resource bundle update galera-bundle storage-map add id=mysql-log source-dir=/var/log/containers/mysql target-dir=/var/log/mysql options=rw\"}, {\"name\": \"Reconfigure Mysql log file in the galera resource agent\", \"command\": \"pcs resource update galera log=/var/log/mysql/mysqld.log\"}]}]}, {\"name\": \"Update the galera bundle to use the new container image name\", \"command\": \"pcs resource bundle update galera-bundle container image={{galera_image_latest}}\"}, {\"name\": \"Enable the galera cluster resource\", \"pacemaker_resource\": {\"resource\": \"galera-bundle\", \"state\": \"enable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}]}, {\"name\": \"Upgrade galera in step3\", \"when\": [\"step|int == 3\"], \"block\": [{\"name\": \"Bind mounts for temporary container\", \"set_fact\": {\"mysql_upgrade_db_bind_mounts\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/mysql.json:/var/lib/kolla/config_files/config.json:rw,z\", \"/var/lib/config-data/puppet-generated/mysql:/var/lib/kolla/config_files/src:ro,z\", \"/var/lib/mysql:/var/lib/mysql:rw,z\"], [\"/var/log/containers/mysql:/var/log/mysql:rw,z\"], {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [\"/etc/pki/tls/certs/mysql.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/mysql.crt:ro\", \"/etc/pki/tls/private/mysql.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/mysql.key:ro\"]]}]}}}, {\"name\": \"Check if Galera needs upgrade\", \"shell\": {\"str_replace\": {\"template\": \"CONTAINER_CLI run --rm --log-driver=k8s-file --log-opt path=LOG_DIR/db-upgrade.log \\\\ -u root --net=host UPGRADE_ENV UPGRADE_VOLUMES \\\"UPGRADE_IMAGE\\\" /bin/bash -ecx \\\"$UPGRADE_SCRIPT\\\"\", \"params\": {\"UPGRADE_ENV\": \"-e \\\"KOLLA_CONFIG_STRATEGY=COPY_ALWAYS\\\"\", \"UPGRADE_IMAGE\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/mariadb:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"UPGRADE_VOLUMES\": \"-v {{ mysql_upgrade_db_bind_mounts | join(\' -v \')}}\", \"CONTAINER_CLI\": \"{{ container_cli }}\", \"LOG_DIR\": \"/var/log/containers/mysql\"}}}, \"environment\": {\"UPGRADE_SCRIPT\": \"kolla_set_configs\\nupgraded_ver=$(cat /var/lib/mysql/mysql_upgrade_info 2>/dev/null || true)\\nmysql_ver=$(mysql --version | awk -F\'[ ,]*\' \'{print $5}\')\\nif [ \\\"${upgraded_ver}\\\" = \\\"${mysql_ver}\\\" ]; then\\n    echo \\\"mysql already upgraded\\\"\\nelse\\n    echo \\\"${upgraded_ver} VS ${mysql_ver}\\\"\\nfi\\n\"}, \"register\": \"mysql_upgrade_needed\"}, {\"name\": \"Set fact upgrade_mysql\", \"set_fact\": {\"upgrade_mysql\": \"{{ (mysql_upgrade_needed.stdout != \\\"mysql already upgraded\\\") | bool }}\"}}, {\"debug\": {\"msg\": \"MYSQL check - {{ mysql_upgrade_needed.stdout }} - Upgrade needed: {{ upgrade_mysql }}\"}}, {\"name\": \"Disable the galera cluster resource before container upgrade\", \"when\": [\"upgrade_mysql|bool\"], \"pacemaker_resource\": {\"resource\": \"galera-bundle\", \"state\": \"disable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}, {\"block\": [{\"name\": \"Get galera image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_galera_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'galera-bundle\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container galera image\", \"set_fact\": {\"galera_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"galera_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/mariadb:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"pcmk_galera_image\": \"{{xmllint_pcmk_galera_image.stdout}}\"}}]}, {\"name\": \"Check for galera retag statefile\", \"stat\": {\"path\": \"/var/lib/tripleo/galera_needs_retag\"}, \"register\": \"galera_retag_state_file\"}, {\"name\": \"Retag the pacemaker image if containerized\", \"when\": [\"galera_retag_state_file.stat.exists|bool\"], \"block\": [{\"name\": \"Retag pcmklatest to latest galera image\", \"include_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{galera_image}}\", \"container_image_latest\": \"{{galera_image_latest}}\"}}]}, {\"name\": \"Remove galera retag statefile\", \"file\": {\"path\": \"/var/lib/tripleo/galera_needs_retag\", \"state\": \"absent\"}}, {\"name\": \"Mysql upgrade script\", \"when\": [\"upgrade_mysql|bool\"], \"set_fact\": {\"mysql_upgrade_script\": {\"list_join\": [\"\\n\", [\"kolla_set_configs\\nif mysqladmin ping --silent; then exit 0; fi\\nupgraded_ver=$(cat /var/lib/mysql/mysql_upgrade_info 2>/dev/null || true)\\nmysql_ver=$(mysql --version | awk -F\'[ ,]*\' \'{print $5}\')\\nif [ \\\"${upgraded_ver}\\\" = \\\"${mysql_ver}\\\" ]; then\\n    echo \\\"mysql already upgraded\\\"\\n    exit 0\\nfi\\nchown -R mysql:mysql /var/lib/mysql\\nchown -R mysql:mysql /var/log/mysql\\nmysqld_safe --user=mysql --wsrep-provider=none --skip-networking --wsrep-on=off --log-error=/var/log/mysql/mysqld-upgrade.log &\\n\", {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/mysql_upgrade_db.sh\"}, \"mysqladmin shutdown\"]]}}}, {\"name\": \"Upgrade Mysql database from a temporary container\", \"when\": [\"upgrade_mysql|bool\"], \"shell\": {\"str_replace\": {\"template\": \"CONTAINER_CLI run --rm --log-driver=k8s-file --log-opt path=LOG_DIR/db-upgrade.log \\\\ -u root --net=host UPGRADE_ENV UPGRADE_VOLUMES \\\"UPGRADE_IMAGE\\\" /bin/bash -ecx \\\"$UPGRADE_SCRIPT\\\"\", \"params\": {\"UPGRADE_ENV\": \"-e \\\"KOLLA_CONFIG_STRATEGY=COPY_ALWAYS\\\"\", \"UPGRADE_IMAGE\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/mariadb:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"UPGRADE_VOLUMES\": \"-v {{ mysql_upgrade_db_bind_mounts | join(\' -v \')}}\", \"CONTAINER_CLI\": \"{{ container_cli }}\", \"LOG_DIR\": \"/var/log/containers/mysql\"}}}, \"environment\": {\"UPGRADE_SCRIPT\": \"{{ mysql_upgrade_script }}\"}}, {\"name\": \"Enable the galera cluster resource\", \"when\": [\"upgrade_mysql|bool\"], \"pacemaker_resource\": {\"resource\": \"galera-bundle\", \"state\": \"enable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}]}]]}, \"external_upgrade_tasks\": [{\"vars\": {\"mysql_upgrade_transfer\": {\"get_param\": \"MysqlUpgradeTransfer\"}}, \"when\": [\"step|int == 2\", \"mysql_upgrade_transfer\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\"], \"block\": [{\"name\": \"Transfer mysql data\", \"include_role\": {\"name\": \"tripleo_transfer\"}, \"vars\": {\"tripleo_transfer_src_dir\": \"/var/lib/mysql\", \"tripleo_transfer_src_host\": \"{{hostvars[groups[\'overcloud\'][0]][\'mysql_short_node_names\'][1]}}\", \"tripleo_transfer_dest_dir\": \"/var/lib/mysql\", \"tripleo_transfer_dest_host\": \"{{hostvars[groups[\'overcloud\'][0]][\'mysql_short_bootstrap_node_name\']}}\", \"tripleo_transfer_flag_file\": \"/var/lib/tripleo/transfer-flags/var-lib-mysql\", \"tripleo_transfer_sync_options\": \"--whole-file --ignore-times --inplace --archive --delete\", \"tripleo_transfer_include\": [\"/ibdata*\", \"/ib_lru_dump\", \"/ib_logfile[0-9]*\", \"/undo*\", \"/*/\"], \"tripleo_transfer_exclude\": \"/*\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(100,'2026-06-10 07:46:57',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"MySQL service deployment using puppet\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"MysqlMaxConnections\": {\"description\": \"Configures MySQL max_connections config setting\", \"type\": \"number\", \"default\": 4096}, \"MysqlIncreaseFileLimit\": {\"description\": \"Flag to increase MySQL open-files-limit to 16384\", \"type\": \"boolean\", \"default\": true}, \"MysqlRootPassword\": {\"type\": \"string\", \"hidden\": true, \"default\": \"wDcXw6Z0DC\"}, \"MysqlClustercheckPassword\": {\"type\": \"string\", \"hidden\": true, \"default\": \"hepAGELIsa9DMKgtpIM5NwEsU\"}, \"EnableGalera\": {\"default\": true, \"description\": \"Whether to use Galera instead of regular MariaDB.\", \"type\": \"boolean\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"EnableMysqlAuthEd25519\": {\"type\": \"boolean\", \"description\": \"Whether to configure MySQL users to connect to the server using the Ed25519-based client authentication.\", \"default\": false}, \"MysqlIPv6\": {\"default\": false, \"description\": \"Enable IPv6 in MySQL\", \"type\": \"boolean\"}, \"MysqlInnodbBufferPoolSize\": {\"type\": \"string\", \"description\": \"Buffer pool size for MySQL database; this needs to be larger for at-scale deployments\", \"default\": \"128M\"}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"MysqlCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"The following parameters are deprecated and will be removed. They should not\\nbe relied on for new deployments. If you have concerns regarding deprecated\\nparameters, please contact the TripleO development team on IRC or the\\nOpenStack mailing list.\\n\", \"parameters\": [\"MysqlIPv6\"]}], \"conditions\": {\"is_ipv6\": {\"equals\": [{\"get_param\": [\"ServiceData\", \"net_ip_version_map\", {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}]}, 6]}, \"innodb_buffer_pool_set\": {\"not\": {\"equals\": [{\"get_param\": \"MysqlInnodbBufferPoolSize\"}, \"\"]}}, \"key_size_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"MysqlCertificateKeySize\"}, \"\"]}}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared docker config scripts\", \"value\": {\"mysql_upgrade_db.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/mysql_upgrade_db.sh\"}}}}, \"mysql_drop_unused_users\": {\"description\": \"Ansible block to clean up unusued Openstack DB users\", \"value\": [{\"name\": \"Drop unused OpenStack DB users\", \"when\": [\"step|int == 1\", \"mysql_short_bootstrap_node_name|lower == ansible_facts[\'hostname\']|lower\"], \"block\": [{\"name\": \"mysql container id\", \"command\": \"podman ps -q --filter name={{ mysql_container_name }} --filter status=running\", \"register\": \"mysql_container_id\"}, {\"name\": \"set mysql container id fact\", \"set_fact\": {\"mysql_container\": \"{{ mysql_container_id.stdout }}\"}}, {\"name\": \"Mysql script to drop unused DB users\", \"when\": \"( mysql_container | length ) > 0\", \"block\": [{\"name\": \"Get the list of all OpenStack DB users\", \"shell\": \"jq -r \'to_entries[] | select(.key|endswith(\\\"::db::mysql::user\\\")) | .value\' /etc/puppet/hieradata/service_configs.json\", \"register\": \"openstack_db_users\"}, {\"name\": \"List all DB users that match the DB users to be dropped\", \"shell\": \"for u in {{ openstack_db_users.stdout_lines | join(\' \') }}; do podman exec -u root -it \\\"{{ mysql_container }}\\\" mysql -sNe \\\"select concat(\'\\\\`\',user,\'\\\\`@\\\\`\',host,\'\\\\`\') from mysql.user where user = \'$u\' and host != \'%\';\\\"; done\", \"register\": \"mysql_db_users\"}, {\"name\": \"resulting DB users to be dropped\", \"debug\": {\"msg\": \"{{ mysql_db_users.stdout_lines }}\"}}, {\"name\": \"Drop all unneeded Openstack DB users\", \"shell\": \"podman exec -u root -it \\\"{{ mysql_container }}\\\" mysql -sNe \'drop user {{ item }};\'\", \"loop\": \"{{ mysql_db_users.stdout_lines }}\"}]}]}]}, \"role_data\": {\"description\": \"Service MySQL using composable services.\", \"value\": {\"service_name\": \"mysql\", \"config_settings\": {\"mysql::server::package_name\": \"mariadb-galera-server\", \"mysql::server::manage_config_file\": true, \"mysql_ipv6\": {\"if\": [\"is_ipv6\", true, false]}, \"mysql_max_connections\": {\"get_param\": \"MysqlMaxConnections\"}, \"mysql::server::root_password\": {\"get_param\": \"MysqlRootPassword\"}, \"mysql_clustercheck_password\": {\"get_param\": \"MysqlClustercheckPassword\"}, \"enable_galera\": {\"get_param\": \"EnableGalera\"}, \"mysql_auth_ed25519\": {\"get_param\": \"EnableMysqlAuthEd25519\"}, \"mysql_bind_host\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::generate_dropin_file_limit\": {\"get_param\": \"MysqlIncreaseFileLimit\"}, \"tripleo::profile::base::database::mysql::certificate_specs\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"service_certificate\": \"/etc/pki/tls/certs/mysql.crt\", \"service_key\": \"/etc/pki/tls/private/mysql.key\"}]}, \"innodb_buffer_pool_size\": {\"if\": [\"innodb_buffer_pool_set\", {\"get_param\": \"MysqlInnodbBufferPoolSize\"}]}}, \"step_config\": \"include tripleo::profile::base::database::mysql\\n\", \"metadata_settings\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [{\"service\": \"mysql\", \"network\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}, \"type\": \"vip\"}, {\"service\": \"mysql\", \"network\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}, \"type\": \"node\"}]]}, \"deploy_steps_tasks\": [{\"name\": \"Certificate generation\", \"when\": [\"step|int == 1\", \"enable_internal_tls\"], \"block\": [{\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": [{\"name\": \"mysql\", \"dns\": [{\"str_replace\": {\"template\": \"{{fqdn_$NETWORK}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, {\"str_replace\": {\"template\": \"{{cloud_names.cloud_name_NETWORK}}\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}], \"principal\": {\"str_replace\": {\"template\": \"mysql/{{fqdn_$NETWORK}}@{{idm_realm}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"key_size\": {\"if\": [\"key_size_override_set\", {\"get_param\": \"MysqlCertificateKeySize\"}, {\"get_param\": \"CertificateKeySize\"}]}, \"ca\": \"ipa\"}]}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(101,'2026-06-10 07:46:58',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mysql client settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role for setting mysql client parameters\", \"value\": {\"service_name\": \"mysql_client\", \"config_settings\": {\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"tripleo::profile::base::database::mysql::client::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}}, \"step_config\": \"include tripleo::profile::base::database::mysql::client\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(102,'2026-06-10 07:46:58',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Containerized collectd service\\n\", \"parameters\": {\"ContainerCollectdImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\"}, \"ContainerCollectdConfigImage\": {\"description\": \"The container image to use for the collectd config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"KeystoneRegion\": {\"type\": \"string\", \"description\": \"Keystone region for endpoint\", \"default\": \"regionOne\"}, \"MetricsQdrPort\": {\"default\": 5666, \"description\": \"Service name or port number on which the qdrouterd will accept connections.\", \"type\": \"number\"}, \"MetricsQdrUsername\": {\"default\": \"guest\", \"description\": \"Username which should be used to authenticate to the deployed qdrouterd.\", \"type\": \"string\"}, \"MetricsQdrPassword\": {\"default\": \"guest\", \"description\": \"Password which should be used to authenticate to the deployed qdrouterd.\", \"type\": \"string\", \"hidden\": true}, \"MonitoringSubscriptionCollectd\": {\"default\": \"overcloud-collectd\", \"type\": \"string\"}, \"CollectdConnectionType\": {\"default\": \"amqp1\", \"description\": \"Define which write plugin should collectd use. Currently supported are \'amqp1\' and \'network\'.\", \"type\": \"string\"}, \"CollectdDefaultPollingInterval\": {\"default\": 120, \"type\": \"number\", \"description\": \"Controls how often registered read functions are called and with that the resolution of the collected data. This value can be overridden per plugin(per role) by setting \\\"::collectd::plugin::<plugin_name>::interval\\\" key in ExtraConfig(<role_name>ExtraConfig) if using puppet, and by setting \\\"collectd_plugin_<plugin_name>_interval\\\" in <role_name>ExtraConfig/CollectdVars if using ansible.\\n\"}, \"CollectdDefaultPlugins\": {\"default\": [\"cpu\", \"df\", \"disk\", \"hugepages\", \"interface\", \"load\", \"memory\", \"unixsock\", \"uptime\"], \"type\": \"comma_delimited_list\", \"description\": \"List of collectd plugins to activate on all overcloud hosts.  See the documentation for the puppet-collectd module for a list plugins supported by the module (https://github.com/voxpupuli/puppet-collectd). Set this key to override the default list of plugins.  Use CollectdExtraPlugins if you want to load additional plugins without overriding the defaults.\\n\"}, \"CollectdExtraPlugins\": {\"default\": [], \"type\": \"comma_delimited_list\", \"description\": \"List of collectd plugins to activate on all overcloud hosts.  See the documentation for the puppet-collectd module for a list plugins supported by the module (https://github.com/voxpupuli/puppet-collectd). Set this key to load plugins in addition to those in CollectdDefaultPlugins.\\n\"}, \"CollectdServer\": {\"type\": \"string\", \"description\": \"Address of remote collectd server to which we will send metrics.\\n\", \"default\": \"\"}, \"CollectdServerPort\": {\"type\": \"number\", \"default\": 25826, \"description\": \"Port on remote collectd server to which we will send metrics.\\n\"}, \"CollectdUsername\": {\"type\": \"string\", \"description\": \"Username for authenticating to the remote collectd server. The default is to not configure any authentication.\\n\", \"default\": \"\"}, \"CollectdPassword\": {\"type\": \"string\", \"hidden\": true, \"description\": \"Password for authenticating to the remote collectd server. The default is to not configure any authentication.\\n\", \"default\": \"\"}, \"CollectdSecurityLevel\": {\"type\": \"string\", \"description\": \"Security level setting for remote collectd connection. If it is set to Sign or Encrypt the CollectdPassword and CollectdUsername parameters need to be set.\\n\", \"default\": \"None\", \"constraints\": [{\"allowed_values\": [\"None\", \"Sign\", \"Encrypt\"]}]}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}, \"CollectdSQLAlchemyLogMessages\": {\"type\": \"string\", \"description\": \"set to \\\"debug\\\" to enable message logging.\", \"default\": \"info\"}, \"CollectdSQLAlchemyBindHost\": {\"type\": \"string\", \"description\": \"hostname for SQLAlchemy-collectd plugin to bind on.  defaults to localhost.\\n\", \"default\": \"localhost\"}, \"CollectdAmqpHost\": {\"type\": \"string\", \"description\": \"Hostname or IP address of the AMQP 1.0 intermediary.\", \"default\": \"nil\"}, \"CollectdAmqpPort\": {\"type\": \"number\", \"description\": \"Service name or port number on which the AMQP 1.0 intermediary accepts connections. This argument must be a string, even if the numeric form is used.\\n\", \"default\": 5666}, \"CollectdAmqpUser\": {\"type\": \"string\", \"description\": \"User part of credentials used to authenticate to the AMQP 1.0 intermediary.\\n\", \"default\": \"guest\"}, \"CollectdAmqpPassword\": {\"type\": \"string\", \"description\": \"Password part of credentials used to authenticate to the AMQP 1.0 intermediary.\\n\", \"default\": \"guest\", \"hidden\": true}, \"CollectdAmqpTransportName\": {\"type\": \"string\", \"description\": \"Name of the AMQP 1.0 transport.\", \"default\": \"metrics\"}, \"CollectdAmqpAddress\": {\"type\": \"string\", \"description\": \"This option specifies the prefix for the send-to value in the message.\\n\", \"default\": \"collectd\"}, \"CollectdAmqpInstances\": {\"type\": \"json\", \"description\": \"Hash of hashes. Each inner hash represent Instance block in plugin configuration file. Key of outter hash represents instance name. The \'address\' value concatenated with the \'name\' given will be used as the send-to address for communications over the messaging link.\\n\", \"default\": {}}, \"CollectdAmqpRetryDelay\": {\"type\": \"number\", \"description\": \"When the AMQP 1.0 connection is lost, defines the time in seconds to wait before attempting to reconnect.\\n\", \"default\": 1}, \"CollectdAmqpInterval\": {\"type\": \"number\", \"description\": \"Interval on which metrics should be sent to AMQP intermediary. If not set the default for all collectd plugins is used.\\n\", \"default\": -666}, \"CollectdAmqpSendQueueLimit\": {\"type\": \"number\", \"description\": \"Number of data sets to be kept in memory, older sets will be discarded, if set to -1, this feature is disabled.\\n\", \"default\": -1}, \"CollectdEnableSensubility\": {\"type\": \"boolean\", \"description\": \"Set to true if sensubility should be executed by exec plugin.\", \"default\": false}, \"CollectdSensubilityExecSudoRule\": {\"type\": \"string\", \"description\": \"Given rule will be created in /etc/sudoers.d for sensubility to enable it calling restricted commands via sensubility executor.\\n\", \"default\": \"\"}, \"CollectdSensubilityLogLevel\": {\"type\": \"string\", \"description\": \"Use for override the default logging level (WARNING).\", \"default\": \"WARNING\"}, \"CollectdSensubilityConnection\": {\"type\": \"string\", \"description\": \"URL to Sensu sever side\", \"default\": \"amqp://sensu:sensu@localhost:5672//sensu\"}, \"CollectdSensubilityKeepaliveInterval\": {\"type\": \"number\", \"description\": \"Interval in seconds for sending keepalive messages to Sensu server side.\", \"default\": 20}, \"CollectdSensubilityTmpDir\": {\"type\": \"string\", \"description\": \"Path to temporary directory which is used for creation of check scripts.\", \"default\": \"/var/tmp/collectd-sensubility-checks\"}, \"CollectdSensubilityShellPath\": {\"type\": \"string\", \"description\": \"Path to shell used for executing check scripts.\", \"default\": \"/usr/bin/sh\"}, \"CollectdSensubilityWorkerCount\": {\"type\": \"number\", \"description\": \"Number of goroutines spawned for executing check scripts.\", \"default\": 2}, \"CollectdSensubilityChecks\": {\"type\": \"json\", \"description\": \"JSON formated definition of standalone checks to be scheduled on client side.\", \"default\": {}}, \"CollectdSensubilityTransport\": {\"type\": \"string\", \"description\": \"Bus type for sent data. Options are \'sensu\' (rabbitmq) and \'amqp1\'\", \"default\": \"sensu\"}, \"CollectdSensubilityResultsChannel\": {\"type\": \"string\", \"description\": \"AMQP1 channel address\", \"default\": \"collectd/notify\"}, \"CollectdSensubilityScripts\": {\"type\": \"json\", \"description\": \"List of hashes of scripts for download for sensubility usage. Value has to be in following format:\\n[{\\\"name\\\": \\\"<script name>\\\", \\\"source\\\": \\\"<http URI to download script>\\\", \\\"checksum\\\": \\\"<alogithm:sum>\\\"}]\\n\", \"default\": []}, \"CollectdEnableContainerHealthCheck\": {\"type\": \"boolean\", \"description\": \"Set to false if container health check should not be defined and attached to CollectdEnableContainerHealthCheck.\\n\", \"default\": true}, \"CollectdContainerHealthCheckCommand\": {\"type\": \"string\", \"default\": \"/config-scripts/collectd_check_health.py\"}, \"CollectdContainerHealthCheckInterval\": {\"type\": \"number\", \"description\": \"The frequency in seconds the docker health check is executed.\", \"default\": 10}, \"CollectdContainerHealthCheckHandlers\": {\"default\": [], \"description\": \"The Sensu event handler to use for events created by the docker health check.\", \"type\": \"comma_delimited_list\"}, \"CollectdContainerHealthCheckOccurrences\": {\"type\": \"number\", \"description\": \"The number of event occurrences before sensu-plugin-aware handler should take action.\", \"default\": 3}, \"CollectdContainerHealthCheckRefresh\": {\"type\": \"number\", \"description\": \"The number of seconds sensu-plugin-aware handlers should wait before taking second action.\", \"default\": 90}, \"EnableSTF\": {\"type\": \"boolean\", \"description\": \"Set to true to enable configuration for STF client.\", \"default\": false}, \"CollectdEnableMcelog\": {\"type\": \"boolean\", \"description\": \"Set to true to enable mcelog\", \"default\": false}, \"CollectdEnableLibpodstats\": {\"type\": \"boolean\", \"description\": \"Set to true if collectd should run the libpodstats plugin\", \"default\": false}, \"CollectdContainerAdditionalCapAdd\": {\"type\": \"comma_delimited_list\", \"description\": \"Additional container capabilities to add to the collectd container. By default is appended to IPC_LOCK.\", \"default\": []}, \"CollectdLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"collectd\", \"file\": \"/var/log/containers/collectd/collectd.log\"}}, \"DeployedCeph\": {\"default\": false, \"type\": \"boolean\", \"description\": \"If the Ceph cluster has already been deployed but needs to be configured\\nso that the overcloud can use it (create cephx keys, pools, configure RGW\\nwith haproxy, etc), then this parameter should be set to true. Set this\\nparameter to false to have cephadm deploy the ceph cluster during overcloud\\ndeployment. DeployedCeph and CephDynamicSpec are mutually exclusive.\\n\"}, \"CephClusterFSID\": {\"type\": \"string\", \"description\": \"The Ceph cluster FSID. Must be a UUID.\", \"default\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\"}}, \"conditions\": {\"amqp_connection\": {\"equals\": [{\"get_param\": \"CollectdConnectionType\"}, \"amqp1\"]}, \"amqp_default_connection\": {\"equals\": [{\"get_param\": \"CollectdAmqpHost\"}, \"nil\"]}, \"amqp_default_interval\": {\"equals\": [{\"get_param\": \"CollectdAmqpInterval\"}, -666]}, \"amqp_default_send_queue_limit\": {\"equals\": [{\"get_param\": \"CollectdAmqpSendQueueLimit\"}, -1]}, \"collectd_connection\": {\"equals\": [{\"get_param\": \"CollectdConnectionType\"}, \"network\"]}, \"enable_sensubility\": {\"equals\": [{\"get_param\": \"CollectdEnableSensubility\"}, true]}, \"enable_stf\": {\"equals\": [{\"get_param\": \"EnableSTF\"}, true]}, \"enable_sqlalchemy_collectd\": {\"equals\": [{\"get_param\": \"EnableSQLAlchemyCollectd\"}, true]}, \"sensubility_needs_sudo\": {\"not\": {\"equals\": [{\"get_param\": \"CollectdSensubilityExecSudoRule\"}, \"\"]}}, \"enable_libpodstats\": {\"equals\": [{\"get_param\": \"CollectdEnableLibpodstats\"}, true]}, \"ipmi_monitor\": {\"not\": {\"equals\": [{\"get_param\": [\"RoleParameters\", \"IpmiMonitor\"]}, \"\"]}}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerCollectdImage\": \"ContainerCollectdImage\", \"ContainerCollectdConfigImage\": \"ContainerCollectdConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerCollectdImage\": {\"get_param\": \"ContainerCollectdImage\"}, \"ContainerCollectdConfigImage\": {\"get_param\": \"ContainerCollectdConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the collectd role.\", \"value\": {\"service_name\": \"collectd\", \"config_settings\": {\"map_merge\": [{\"tripleo::profile::base::metrics::collectd::enable_file_logging\": true, \"collectd::plugin::logfile::log_file\": \"/var/log/collectd/collectd.log\"}, {\"collectd::manage_repo\": false, \"collectd::purge\": true, \"collectd::recurse\": true, \"collectd::purge_config\": true, \"collectd::minimum_version\": \"5.7\", \"collectd::interval\": {\"get_param\": \"CollectdDefaultPollingInterval\"}, \"collectd::plugin::unixsock::socketgroup\": \"root\", \"collectd::plugin::unixsock::socketfile\": \"/run/collectd-socket\", \"collectd::plugin::unixsock::deletesocket\": true, \"collectd::plugin::cpu::reportbycpu\": true, \"collectd::plugin::cpu::reportbystate\": true, \"collectd::plugin::cpu::reportnumcpu\": false, \"collectd::plugin::cpu::valuespercentage\": true, \"collectd::plugin::df::ignoreselected\": true, \"collectd::plugin::df::reportbydevice\": true, \"collectd::plugin::df::fstypes\": [\"xfs\"], \"collectd::plugin::load::reportrelative\": true, \"collectd::plugin::virt::connection\": \"qemu:///system\", \"collectd::plugin::virt::extra_stats\": {\"list_join\": [\" \", [\"pcpu\", \"cpu_util\", \"vcpu\", \"memory\", \"disk\", \"disk_err\", \"disk_allocation\", \"disk_capacity\", \"disk_physical\", \"domain_state\", \"job_stats_background\", \"perf\"]]}, \"collectd::plugin::virt::hostname_format\": \"hostname\", \"tripleo.collectd.plugins.collectd\": {\"yaql\": {\"data\": {\"default_plugins\": {\"get_param\": \"CollectdDefaultPlugins\"}, \"stf_plugins\": {\"if\": [\"enable_stf\", [\"cpu\", \"df\", \"load\", \"connectivity\", \"intel_rdt\", \"procevent\"], []]}, \"extra_plugins\": {\"get_param\": \"CollectdExtraPlugins\"}}, \"expression\": \"($.data.default_plugins + $.data.stf_plugins + $.data.extra_plugins) .flatten().distinct()\\n\"}}}, {\"if\": [\"amqp_connection\", {\"map_merge\": [{\"tripleo::profile::base::metrics::collectd::amqp_transport_name\": {\"get_param\": \"CollectdAmqpTransportName\"}, \"tripleo::profile::base::metrics::collectd::amqp_address\": {\"get_param\": \"CollectdAmqpAddress\"}, \"tripleo::profile::base::metrics::collectd::amqp_instances\": {\"get_param\": \"CollectdAmqpInstances\"}, \"tripleo::profile::base::metrics::collectd::amqp_retry_delay\": {\"get_param\": \"CollectdAmqpRetryDelay\"}}, {\"if\": [\"amqp_default_interval\", {}, {\"tripleo::profile::base::metrics::collectd::amqp_interval\": {\"get_param\": \"CollectdAmqpInterval\"}}]}, {\"if\": [\"amqp_default_send_queue_limit\", {}, {\"tripleo::profile::base::metrics::collectd::amqp_send_queue_limit\": {\"get_param\": \"CollectdAmqpSendQueueLimit\"}}]}, {\"if\": [\"amqp_default_connection\", {\"tripleo::profile::base::metrics::collectd::amqp_host\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", {\"str_replace\": {\"template\": \"ROLENAMEMetricsQdrNetwork\", \"params\": {\"ROLENAME\": {\"get_param\": \"RoleName\"}}}}]}}}}, \"tripleo::profile::base::metrics::collectd::amqp_port\": {\"get_param\": \"MetricsQdrPort\"}, \"tripleo::profile::base::metrics::collectd::amqp_user\": {\"get_param\": \"MetricsQdrUsername\"}, \"tripleo::profile::base::metrics::collectd::amqp_password\": {\"get_param\": \"MetricsQdrPassword\"}}, {\"tripleo::profile::base::metrics::collectd::amqp_host\": {\"get_param\": \"CollectdAmqpHost\"}, \"tripleo::profile::base::metrics::collectd::amqp_port\": {\"get_param\": \"CollectdAmqpPort\"}, \"tripleo::profile::base::metrics::collectd::amqp_user\": {\"get_param\": \"CollectdAmqpUser\"}, \"tripleo::profile::base::metrics::collectd::amqp_password\": {\"get_param\": \"CollectdAmqpPassword\"}}]}]}, {}]}, {\"if\": [\"collectd_connection\", {\"tripleo::profile::base::metrics::collectd::collectd_server\": {\"get_param\": \"CollectdServer\"}, \"tripleo::profile::base::metrics::collectd::collectd_port\": {\"get_param\": \"CollectdServerPort\"}, \"tripleo::profile::base::metrics::collectd::collectd_username\": {\"get_param\": \"CollectdUsername\"}, \"tripleo::profile::base::metrics::collectd::collectd_password\": {\"get_param\": \"CollectdPassword\"}, \"tripleo::profile::base::metrics::collectd::collectd_securitylevel\": {\"get_param\": \"CollectdSecurityLevel\"}}, {}]}, {\"if\": [\"enable_sqlalchemy_collectd\", {\"map_merge\": [{\"tripleo::profile::base::metrics::collectd::enable_sqlalchemy_collectd\": true}, {\"tripleo::profile::base::metrics::collectd::sqlalchemy_collectd_bind_host\": {\"get_param\": \"CollectdSQLAlchemyBindHost\"}}, {\"tripleo::profile::base::metrics::collectd::sqlalchemy_collectd_log_messages\": {\"get_param\": \"CollectdSQLAlchemyLogMessages\"}}]}, {}]}, {\"if\": [\"enable_sensubility\", {\"map_merge\": [{\"if\": [\"sensubility_needs_sudo\", {\"tripleo::profile::base::metrics::collectd::sensubility::exec_sudo_rule\": {\"get_param\": \"CollectdSensubilityExecSudoRule\"}}, {}]}, {\"tripleo::profile::base::metrics::collectd::enable_sensubility\": {\"get_param\": \"CollectdEnableSensubility\"}, \"tripleo::profile::base::metrics::collectd::sensubility::connection\": {\"get_param\": \"CollectdSensubilityConnection\"}, \"tripleo::profile::base::metrics::collectd::sensubility::log_level\": {\"get_param\": \"CollectdSensubilityLogLevel\"}, \"tripleo::profile::base::metrics::collectd::sensubility::client_name\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_NETWORK\')}\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", {\"str_replace\": {\"template\": \"ROLENAMEMetricsQdrNetwork\", \"params\": {\"ROLENAME\": {\"get_param\": \"RoleName\"}}}}]}}}}, \"tripleo::profile::base::metrics::collectd::sensubility::client_address\": {\"str_replace\": {\"template\": \"%{hiera(\'NETWORK\')}\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", {\"str_replace\": {\"template\": \"ROLENAMEMetricsQdrNetwork\", \"params\": {\"ROLENAME\": {\"get_param\": \"RoleName\"}}}}]}}}}, \"tripleo::profile::base::metrics::collectd::sensubility::keepalive_interval\": {\"get_param\": \"CollectdSensubilityKeepaliveInterval\"}, \"tripleo::profile::base::metrics::collectd::sensubility::tmp_base_dir\": {\"get_param\": \"CollectdSensubilityTmpDir\"}, \"tripleo::profile::base::metrics::collectd::sensubility::shell_path\": {\"get_param\": \"CollectdSensubilityShellPath\"}, \"tripleo::profile::base::metrics::collectd::sensubility::worker_count\": {\"get_param\": \"CollectdSensubilityWorkerCount\"}, \"tripleo::profile::base::metrics::collectd::sensubility::checks\": {\"map_merge\": [{\"get_param\": \"CollectdSensubilityChecks\"}, {\"if\": [{\"get_param\": \"CollectdEnableContainerHealthCheck\"}, {\"check-container-health\": {\"standalone\": true, \"command\": {\"get_param\": \"CollectdContainerHealthCheckCommand\"}, \"interval\": {\"get_param\": \"CollectdContainerHealthCheckInterval\"}, \"handlers\": {\"get_param\": \"CollectdContainerHealthCheckHandlers\"}, \"occurrences\": {\"get_param\": \"CollectdContainerHealthCheckOccurrences\"}, \"refresh\": {\"get_param\": \"CollectdContainerHealthCheckRefresh\"}}}, {}]}]}, \"tripleo::profile::base::metrics::collectd::sensubility::results_channel\": {\"get_param\": \"CollectdSensubilityResultsChannel\"}, \"tripleo::profile::base::metrics::collectd::sensubility::transport\": {\"get_param\": \"CollectdSensubilityTransport\"}, \"tripleo::profile::base::metrics::collectd::sensubility::amqp_port\": {\"get_param\": \"CollectdAmqpPort\"}}]}, {}]}, {\"if\": [\"enable_libpodstats\", {\"tripleo::profile::base::metrics::collectd::enable_libpodstats\": {\"get_param\": \"CollectdEnableLibpodstats\"}}, {}]}, {\"if\": [{\"get_param\": \"DeployedCeph\"}, {\"collectd::plugin::ceph::ceph_fsid\": {\"get_param\": \"CephClusterFSID\"}}]}]}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_collectd\": [{\"get_param\": \"CollectdLoggingSource\"}]}}, \"puppet_config\": {\"config_volume\": \"collectd\", \"puppet_tags\": \"collectd_client_config,exec\", \"step_config\": \"include tripleo::profile::base::metrics::collectd\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCollectdConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/collectd.json\": {\"command\": \"/usr/sbin/collectd -f\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/etc/collectd.d\", \"dest\": \"/etc/\", \"merge\": false, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/collectd\", \"owner\": \"collectd:collectd\", \"recurse\": true}, {\"path\": \"/scripts\", \"owner\": \"collectd:collectd\", \"recurse\": true}, {\"path\": \"/config-scripts\", \"owner\": \"collectd:collectd\", \"recurse\": true}]}}, \"container_config_scripts\": {\"map_merge\": [{\"get_attr\": [\"ContainersCommon\", \"container_config_scripts\"]}, {\"collectd_check_health.py\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/monitoring/collectd_check_health.py\"}}}]}, \"docker_config\": {\"step_2\": {\"if\": [{\"get_param\": \"CollectdEnableSensubility\"}, {\"collectd_init_perm\": {\"image\": {\"get_param\": \"ContainerCollectdImage\"}, \"net\": \"none\", \"user\": \"root\", \"volumes\": [\"/var/lib/tripleo-podman/collectd:/tmp/run:rw,z\"], \"command\": [\"setfacl\", \"-R\", \"-m\", \"u:collectd:rwx\", \"/tmp/run\"]}}]}, \"step_3\": {\"collectd\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCollectdImage\"]}, \"net\": \"host\", \"pid\": \"host\", \"user\": \"root\", \"restart\": \"always\", \"memory\": \"512m\", \"device\": {\"if\": [\"ipmi_monitor\", {\"get_param\": [\"RoleParameters\", \"IpmiMonitor\"]}]}, \"cap_add\": {\"list_concat\": [{\"get_param\": \"CollectdContainerAdditionalCapAdd\"}, [\"IPC_LOCK\"]]}, \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/collectd.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/containers/storage/overlay-containers:/var/lib/containers/storage/overlay-containers:ro\", \"/var/lib/config-data/puppet-generated/collectd:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/collectd:/var/log/collectd:rw,z\", \"/var/lib/container-config-scripts:/config-scripts:ro\", \"/var/lib/container-user-scripts:/scripts:z\", \"/run:/run:rw\", \"/sys/fs/cgroup:/sys/fs/cgroup:ro\"], {\"if\": [{\"get_param\": \"CollectdEnableSensubility\"}, [\"/var/lib/tripleo-podman/collectd:/run/podman:z\"]]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"host_prep_tasks\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/collectd\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/container-user-scripts/\", \"setype\": \"container_file_t\", \"mode\": \"0755\"}]}, {\"name\": \"import provision_mcelog\", \"include_role\": {\"name\": \"tripleo_provision_mcelog\"}, \"when\": {\"get_param\": \"CollectdEnableMcelog\"}}], \"deploy_steps_tasks\": [{\"name\": \"set enable_sensubility fact\", \"set_fact\": {\"enable_sensubility\": {\"get_param\": \"CollectdEnableSensubility\"}}}, {\"name\": \"create podman socket for sensubility purposes\", \"block\": [{\"name\": \"create podman socket and appropriate systemd service\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_service\"}, \"vars\": {\"tripleo_podman_socket_path\": \"/var/lib/tripleo-podman/collectd/podman.sock\"}}, {\"name\": \"create systemd service for ensuring socket file ACL contains collectd\", \"become\": true, \"ansible.builtin.copy\": {\"content\": \"[Unit]\\nDescription=ACL setting for /var/lib/tripleo-podman/collectd/podman.sock\\nRequires=tripleo_collectd.service\\nAfter=tripleo_podman.service\\nAfter=tripleo_collectd.service\\n\\n[Service]\\nType=oneshot\\nExecStart=/usr/bin/podman exec -it collectd setfacl -m m:rwx /run/podman/podman.sock\\nExecStart=/usr/bin/podman exec -it collectd setfacl -R -m u:collectd:rwx /run/podman\\nExecStart=/usr/bin/podman exec -it collectd setfacl -d -m u:collectd:rwx /run/podman\\n\\n[Install]\\nWantedBy=multi-user.target\\n\", \"dest\": \"/etc/systemd/system/tripleo_podman_collectd_acl.service\", \"mode\": 420}}, {\"name\": \"enable podman.sock ACL service\", \"ansible.builtin.service\": {\"name\": \"tripleo_podman_collectd_acl.service\", \"enabled\": true}}, {\"name\": \"create directory for downloads of users\' scripts\", \"file\": {\"path\": \"/var/lib/container-user-scripts\", \"state\": \"directory\", \"setype\": \"container_file_t\", \"mode\": \"0755\"}}, {\"name\": \"download exec scripts\", \"ansible.builtin.get_url\": {\"url\": \"{{ item.source }}\", \"checksum\": \"{{ item.checksum }}\", \"dest\": \"/var/lib/container-user-scripts/{{ item.name }}\", \"mode\": \"0755\"}, \"with_items\": {\"get_param\": \"CollectdSensubilityScripts\"}}], \"when\": [\"enable_sensubility|bool\", \"step|int == 1\"]}], \"update_tasks\": [{\"name\": \"remove rsyslog configuration for podman healthcheck log\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_rsyslog_cleanup\"}}], \"upgrade_tasks\": [{\"name\": \"remove rsyslog configuration for podman healthcheck log\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_rsyslog_cleanup\"}}, {\"name\": \"Force pull image collectd\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\"], \"when\": [\"step|int == 3\"], \"containers.podman.podman_image\": {\"name\": {\"get_param\": \"ContainerCollectdImage\"}, \"force\": true}}, {\"name\": \"UBI8 to UBI9 switch of collectd\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\"], \"when\": [\"step|int == 5\"], \"block\": [{\"name\": \"Update collectd to UBI9\", \"tripleo_container_manage\": {\"config_dir\": \"/var/lib/tripleo-config/container-startup-config/step_3\", \"config_patterns\": \"collectd.json\", \"config_id\": [\"tripleo_step3\"], \"log_base_path\": \"{{ container_log_stdout_path }}\", \"debug\": \"{{ enable_debug | bool }}\", \"config_overrides\": {\"collectd\": {\"image\": {\"get_param\": \"ContainerCollectdImage\"}}}}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(103,'2026-06-10 07:46:58',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Heat API service\\n\", \"parameters\": {\"ContainerHeatApiImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\"}, \"ContainerHeatApiConfigImage\": {\"description\": \"The container image to use for the heat_api config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\"}, \"HeatApiLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.heat.api\", \"file\": \"/var/log/containers/heat/heat_api.log\"}}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"HeatApiOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\"}, \"HeatApiOptEnvVars\": {\"default\": {}, \"description\": \"hash of optional environment variables\", \"type\": \"json\"}, \"HeatWorkers\": {\"default\": 1, \"description\": \"Number of workers for Heat service.\", \"type\": \"number\"}, \"HeatPassword\": {\"description\": \"The password for the Heat service and db account, used by the Heat services.\", \"type\": \"string\", \"hidden\": true, \"default\": \"bFBTZhN5CyNCch5KSkr70C02s\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"MonitoringSubscriptionHeatApi\": {\"default\": \"overcloud-heat-api\", \"type\": \"string\"}, \"HeatStackDomainAdminPassword\": {\"description\": \"Password for heat_stack_domain_admin user.\", \"type\": \"string\", \"hidden\": true, \"default\": \"UVdJtbPbJkihrvjY5nov69TzB\"}}, \"conditions\": {\"heat_workers_set\": {\"not\": {\"equals\": [{\"get_param\": \"HeatWorkers\"}, 0]}}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"ApacheServiceBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}, \"EnableInternalTLS\": {\"get_param\": \"EnableInternalTLS\"}}}, \"HeatBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-base-puppet.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"HeatApiLogging\": {\"type\": \"OS::TripleO::Services::Logging::HeatApi\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerHeatApiImage\": \"ContainerHeatApiImage\", \"ContainerHeatApiConfigImage\": \"ContainerHeatApiConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerHeatApiImage\": {\"get_param\": \"ContainerHeatApiImage\"}, \"ContainerHeatApiConfigImage\": {\"get_param\": \"ContainerHeatApiConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Heat API role.\", \"value\": {\"service_name\": \"heat_api\", \"firewall_rules\": {\"125 heat_api\": {\"dport\": [8004]}}, \"firewall_frontend_rules\": {\"100 heat_api_haproxy_frontend\": {\"dport\": [8004]}}, \"firewall_ssl_frontend_rules\": {\"100 heat_api_haproxy_frontend_ssl\": {\"dport\": [13004]}}, \"keystone_resources\": {\"heat\": {\"endpoints\": {\"public\": {\"get_param\": [\"EndpointMap\", \"HeatPublic\", \"uri\"]}, \"internal\": {\"get_param\": [\"EndpointMap\", \"HeatInternal\", \"uri\"]}, \"admin\": {\"get_param\": [\"EndpointMap\", \"HeatAdmin\", \"uri\"]}}, \"users\": {\"heat\": {\"password\": {\"get_param\": \"HeatPassword\"}}, \"heat_stack_domain_admin\": {\"password\": {\"get_param\": \"HeatStackDomainAdminPassword\"}, \"roles\": [\"admin\"], \"domain\": \"heat_stack\"}}, \"region\": {\"get_param\": \"KeystoneRegion\"}, \"service\": \"orchestration\", \"roles\": [\"heat_stack_user\"], \"domains\": [\"heat_stack\"]}}, \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionHeatApi\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"HeatBase\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"HeatApiLogging\", \"config_settings\"]}, {\"get_attr\": [\"ApacheServiceBase\", \"role_data\", \"config_settings\"]}, {\"apache::default_vhost\": false, \"heat::api::bind_host\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}}}, \"heat::wsgi::apache_api::ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"heat::wsgi::apache_api::vhost_custom_fragment\": \"Timeout 600\", \"heat::api::service_name\": \"httpd\", \"heat::wsgi::apache_api::bind_host\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}}}, \"heat::wsgi::apache_api::servername\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}}}}, {\"if\": [\"heat_workers_set\", {\"heat::wsgi::apache_api::workers\": {\"get_param\": \"HeatWorkers\"}}]}]}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_heat_api\": [{\"get_param\": \"HeatApiLoggingSource\"}]}}, \"puppet_config\": {\"config_volume\": \"heat_api\", \"puppet_tags\": \"heat_config,file,concat,file_line,heat_api_paste_ini\", \"step_config\": \"include tripleo::profile::base::heat::api\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHeatApiConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/heat_api.json\": {\"command\": \"/usr/sbin/httpd -DFOREGROUND\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.d\", \"dest\": \"/etc/httpd/conf.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.modules.d\", \"dest\": \"/etc/httpd/conf.modules.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/heat\", \"owner\": \"heat:heat\", \"recurse\": true}]}, \"/var/lib/kolla/config_files/heat_api_cron.json\": {\"command\": \"/usr/sbin/crond -n\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/heat\", \"owner\": \"heat:heat\", \"recurse\": true}]}}, \"docker_config\": {\"step_2\": {\"get_attr\": [\"HeatApiLogging\", \"docker_config\", \"step_2\"]}, \"step_4\": {\"heat_api\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHeatApiImage\"]}, \"net\": \"host\", \"privileged\": false, \"restart\": \"always\", \"user\": \"root\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"HeatApiLogging\", \"volumes\"]}, {\"get_param\": \"HeatApiOptVolumes\"}, [\"/var/lib/kolla/config_files/heat_api.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/heat_api:/var/lib/kolla/config_files/src:ro\"], {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [\"/etc/pki/tls/certs/httpd:/etc/pki/tls/certs/httpd:ro\", \"/etc/pki/tls/private/httpd:/etc/pki/tls/private/httpd:ro\"]]}]}, \"environment\": {\"map_merge\": [{\"get_param\": \"HeatApiOptEnvVars\"}, {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}]}}, \"heat_api_cron\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHeatApiImage\"]}, \"net\": \"host\", \"user\": \"root\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/usr/share/openstack-tripleo-common/healthcheck/cron heat\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"HeatApiLogging\", \"volumes\"]}, [\"/var/lib/kolla/config_files/heat_api_cron.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/heat_api:/var/lib/kolla/config_files/src:ro\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"host_prep_tasks\": {\"get_attr\": [\"HeatApiLogging\", \"host_prep_tasks\"]}, \"upgrade_tasks\": [], \"metadata_settings\": {\"get_attr\": [\"ApacheServiceBase\", \"role_data\", \"metadata_settings\"]}, \"deploy_steps_tasks\": {\"get_attr\": [\"ApacheServiceBase\", \"role_data\", \"deploy_steps_tasks\"]}, \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop heat api container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"heat_api\", \"heat_api_cron\"], \"tripleo_delegate_to\": \"{{ groups[\'heat_api\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(104,'2026-06-10 07:46:58',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(105,'2026-06-10 07:46:58',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Heat API service\\n\", \"outputs\": {\"config_settings\": {\"description\": \"Extra hieradata needed to log to files in the host.\", \"value\": null}, \"docker_config\": {\"description\": \"Extra containers needed for logging to files in the host.\", \"value\": {\"step_2\": {}}}, \"volumes\": {\"description\": \"The volumes needed to log to files in the host.\", \"value\": [\"/var/log/containers/heat:/var/log/heat:z\", \"/var/log/containers/httpd/heat-api:/var/log/httpd:z\"]}, \"host_prep_tasks\": {\"description\": \"Extra ansible tasks needed for logging to files in the host.\", \"value\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/heat\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/log/containers/httpd/heat-api\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}]}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (106,'2026-06-10 07:46:59',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(107,'2026-06-10 07:46:59',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(108,'2026-06-10 07:46:59',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(109,'2026-06-10 07:47:00',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Provides the list of common container volumes and environment used by various cinder services.\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"CinderVolumeOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\"}, \"CinderBackupOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\"}, \"CinderVolumeOptEnvVars\": {\"default\": {}, \"description\": \"hash of optional environment variables\", \"type\": \"json\"}, \"CinderEnableIscsiBackend\": {\"default\": true, \"description\": \"Whether to enable or not the Iscsi backend for Cinder\", \"type\": \"boolean\"}, \"CinderEnableNVMeOFBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NVMeOF backend for Cinder\", \"type\": \"boolean\"}, \"CinderLVMConfigureVG\": {\"default\": true, \"description\": \"Whether to configure the \'cinder-volumes\' VG used by the LVM driver. When disabled (set to False), the LVM driver will work as long as the \'cinder-volumes\' VG has been created through some other means.\\n\", \"type\": \"boolean\"}, \"CinderLVMLoopDeviceSize\": {\"default\": 20480, \"description\": \"The size of the loopback file used by the cinder LVM driver.\", \"type\": \"number\"}, \"MultipathdEnable\": {\"default\": false, \"description\": \"Whether to enable the multipath daemon\", \"type\": \"boolean\"}, \"CinderVolumeCluster\": {\"default\": \"\", \"description\": \"The cluster name used for deploying the cinder-volume service in an active-active (A/A) configuration. This configuration requires the Cinder backend drivers support A/A, and the cinder-volume service not be managed by pacemaker. If these criteria are not met then the cluster name must be left blank.\\n\", \"type\": \"string\"}, \"CinderImageConversionNfsShare\": {\"default\": \"\", \"description\": \"When set, the NFS share to be used for Cinder\'s image conversion directory.\", \"type\": \"string\"}, \"CinderImageConversionNfsOptions\": {\"default\": \"_netdev,bg,intr,context=system_u:object_r:container_file_t:s0\", \"description\": \"NFS mount options when using an NFS share for Cinder\'s image conversion directory.\", \"type\": \"string\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"EnableEtcdInternalTLS\": {\"description\": \"Controls whether etcd and the cinder-volume service use TLS for cinder\'s lock manager, even when the rest of the internal API network is using TLS.\", \"type\": \"boolean\", \"default\": true}, \"CephConfigPath\": {\"type\": \"string\", \"default\": \"/var/lib/tripleo-config/ceph\", \"description\": \"The path where the Ceph Cluster config files are stored on the host.\\n\"}, \"CephClientUserName\": {\"default\": \"openstack\", \"type\": \"string\"}, \"CephClusterName\": {\"type\": \"string\", \"default\": \"ceph\", \"description\": \"The Ceph cluster name.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9]+\", \"description\": \"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\n\"}]}, \"CephExternalMultiConfig\": {\"type\": \"json\", \"hidden\": true, \"description\": \"List of maps describing extra overrides which will be applied when configuring\\nextra external Ceph clusters. If this list is non-empty, ceph-ansible will run\\nan extra count(list) times using the same parameters as the first run except\\neach parameter within each map will override the defaults. If the following\\nwere used, the second run would configure the overcloud to also use the ceph2\\ncluster with all the previous parameters except /etc/ceph/ceph2.conf would have\\na mon_host entry containing the value of external_cluster_mon_ips below, and\\nnot the default CephExternalMonHost. Subsequent ceph-ansible runs are restricted\\nto just ceph clients. CephExternalMultiConfig may not be used to deploy additional\\ninternal Ceph clusters within one Heat stack. The map for each list should contain\\nnot tripleo-heat-template parameters but ceph-ansible parameters.\\n  - cluster: \'ceph2\'\\n    fsid: \'e2cba068-5f14-4b0f-b047-acf375c0004a\'\\n    external_cluster_mon_ips: \'172.18.0.5,172.18.0.6,172.18.0.7\'\\n    keys:\\n      - name: \\\"client.openstack\\\"\\n        caps:\\n          mgr: \\\"allow *\\\"\\n          mon: \\\"profile rbd\\\"\\n          osd: \\\"osd: profile rbd pool=volumes, profile rbd pool=backups, profile rbd pool=vms, profile rbd pool=images\\\"\\n        key: \\\"AQCwmeRcAAAAABAA6SQU/bGqFjlfLro5KxrB1Q==\\\"\\n        mode: \\\"0600\\\"\\n    dashboard_enabled: false\\n\", \"default\": []}}, \"conditions\": {\"cvol_active_active_tls_enabled\": {\"and\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderVolumeCluster\"}, \"\"]}}, {\"get_param\": \"EnableInternalTLS\"}, {\"get_param\": \"EnableEtcdInternalTLS\"}]}, \"cinder_nfs_conversion_dir_enabled\": {\"not\": {\"equals\": [{\"get_param\": \"CinderImageConversionNfsShare\"}, \"\"]}}, \"cinder_configure_lvm\": {\"and\": [{\"get_param\": \"CinderLVMConfigureVG\"}, {\"or\": [{\"get_param\": \"CinderEnableIscsiBackend\"}, {\"get_param\": \"CinderEnableNVMeOFBackend\"}]}]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml\"}, \"CinderNVMeOF\": {\"type\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml\"}}, \"outputs\": {\"cinder_image_conversion_nfs_dir\": {\"description\": \"The directory where cinder does its image conversion when the directory is backed by an NFS share.\", \"value\": \"/var/lib/cinder_image_conversion\"}, \"cinder_common_host_prep_tasks\": {\"description\": \"Common host prep tasks for cinder-volume and cinder-backup services\", \"value\": {\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}}, \"cinder_common_volumes\": {\"description\": \"Common volumes for all cinder services\", \"value\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}}, \"cinder_common_kolla_config_files\": {\"description\": \"Common kolla config_files for cinder-volume and cinder-backup services\", \"value\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-ceph/\", \"dest\": \"/etc/ceph/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-iscsid/*\", \"dest\": \"/etc/iscsi/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true, \"optional\": true}]}, \"cinder_common_kolla_permissions\": {\"description\": \"Common kolla permissions for cinder-volume and cinder-backup services\", \"value\": {\"list_concat\": [[{\"path\": \"/var/log/cinder\", \"owner\": \"cinder:cinder\", \"recurse\": true}, {\"path\": {\"str_replace\": {\"template\": \"/etc/ceph/CLUSTER.client.USER.keyring\", \"params\": {\"CLUSTER\": {\"get_param\": \"CephClusterName\"}, \"USER\": {\"get_param\": \"CephClientUserName\"}}}}, \"owner\": \"cinder:cinder\", \"perm\": \"0600\"}, {\"path\": \"/etc/pki/tls/certs/etcd.crt\", \"owner\": \"cinder:cinder\"}, {\"path\": \"/etc/pki/tls/private/etcd.key\", \"owner\": \"cinder:cinder\"}], {\"repeat\": {\"template\": {\"path\": \"/etc/ceph/<%cluster%>.client.*.keyring\", \"owner\": \"cinder:cinder\", \"perm\": \"0600\"}, \"for_each\": {\"<%cluster%>\": {\"yaql\": {\"expression\": \"$.data.multiconfig.select($.cluster)\", \"data\": {\"multiconfig\": {\"get_param\": \"CephExternalMultiConfig\"}}}}}}}]}}, \"cinder_volume_host_prep_and_system_upgrade_post_tasks\": {\"description\": \"Common host_prep and system_upgrade post tasks for cinder-volume\", \"value\": [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}]}, \"cinder_volume_host_prep_tasks\": {\"description\": \"Host prep tasks for the cinder-volume service (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}, [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}], [{\"name\": \"cinder_configure_lvm fact\", \"set_fact\": {\"cinder_configure_lvm\": {\"if\": [\"cinder_configure_lvm\", true, false]}}}, {\"when\": \"cinder_configure_lvm|bool\", \"block\": [{\"name\": \"ensure LVM rpm dependencies are installed\", \"package\": {\"name\": \"lvm2\", \"state\": \"latest\"}}, {\"name\": \"cinder create LVM volume group dd\", \"command\": {\"list_join\": [\"\", [\"dd if=/dev/zero of=/var/lib/cinder/cinder-volumes bs=1 count=0 seek=\", {\"str_replace\": {\"template\": \"VALUE\", \"params\": {\"VALUE\": {\"get_param\": \"CinderLVMLoopDeviceSize\"}}}}, \"M\"]]}, \"args\": {\"creates\": \"/var/lib/cinder/cinder-volumes\"}}, {\"name\": \"Get or create LVM loopback device\", \"shell\": \"exit_code=0\\nexisting_device=$(losetup -j /var/lib/cinder/cinder-volumes -l -n -O NAME)\\nif [[ -z \\\"${existing_device}\\\" ]]; then\\n    losetup -f /var/lib/cinder/cinder-volumes --show\\n    exit_code=2\\nelse\\n    echo ${existing_device%$\'\\\\n\'*}\\nfi\\nexit ${exit_code}\", \"args\": {\"executable\": \"/bin/bash\"}, \"register\": \"_loopback_device\", \"changed_when\": \"_loopback_device.rc == 2\", \"failed_when\": \"_loopback_device.rc not in [0,2]\"}, {\"name\": \"Create LVM volume group\", \"community.general.lvg\": {\"vg\": \"cinder-volumes\", \"pvs\": \"{{ _loopback_device.stdout }}\", \"state\": \"present\"}, \"when\": [\"not (ansible_check_mode | bool)\"]}, {\"name\": \"cinder create service to run losetup for LVM on startup\", \"copy\": {\"dest\": \"/etc/systemd/system/cinder-lvm-losetup.service\", \"content\": \"[Unit]\\nDescription=Cinder LVM losetup\\nDefaultDependencies=no\\nConflicts=umount.target\\nRequires=lvm2-monitor.service systemd-udev-settle.service\\nBefore=local-fs.target umount.target\\nAfter=var.mount lvm2-monitor.service systemd-udev-settle.service\\n\\n[Service]\\nType=oneshot\\nExecStart=/sbin/losetup {{ _loopback_device.stdout }} /var/lib/cinder/cinder-volumes\\nExecStop=/sbin/losetup -d {{ _loopback_device.stdout }}\\nRemainAfterExit=yes\\n\\n[Install]\\nWantedBy=local-fs-pre.target\\n\"}, \"when\": [\"not (ansible_check_mode | bool)\"]}, {\"name\": \"cinder enable the LVM losetup service\", \"systemd\": {\"name\": \"cinder-lvm-losetup\", \"enabled\": true, \"daemon_reload\": true}}]}]]}}, \"cinder_volume_upgrade_tasks\": {\"description\": \"Upgrade tasks for the cinder-volume service (HA or non-HA)\", \"value\": [{\"name\": \"cinder-volume pre system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 3\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Unmount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}, \"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": \"image_conversion_nfs_enabled|bool\", \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"absent\", \"fstype\": \"nfs4\"}}]}, {\"name\": \"cinder-volume post system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 5\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}]}]}, \"cinder_volume_config_settings\": {\"description\": \"Config settings for the cinder-volume container (HA or non-HA)\", \"value\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", {\"cinder::image_conversion_dir\": \"/var/lib/cinder_image_conversion\"}, {}]}}, \"cinder_volume_volumes\": {\"description\": \"Volumes for the cinder-volume container (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}, {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}, {\"get_param\": \"CinderVolumeOptVolumes\"}, [\"/var/lib/kolla/config_files/cinder_volume.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/lib/modules:/lib/modules:ro\", \"/dev:/dev\", \"/run:/run\", \"/sys:/sys\", \"/var/lib/cinder:/var/lib/cinder:z\", \"/var/lib/iscsi:/var/lib/iscsi:z\"], {\"if\": [{\"get_param\": \"CinderEnableIscsiBackend\"}, [\"/etc/target:/etc/target:z\"]]}, {\"if\": [{\"get_param\": \"MultipathdEnable\"}, [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}, {\"if\": [\"cinder_nfs_conversion_dir_enabled\", [{\"str_replace\": {\"template\": \"DIR:DIR:slave\", \"params\": {\"DIR\": \"/var/lib/cinder_image_conversion\"}}}]]}]}}, \"cinder_volume_environment\": {\"description\": \"Docker environment for the cinder-volume container (HA or non-HA)\", \"value\": {\"map_merge\": [{\"get_param\": \"CinderVolumeOptEnvVars\"}, {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}]}}, \"cinder_backup_host_prep_tasks\": {\"description\": \"Host prep tasks for the cinder-backup service (HA or non-HA)\", \"value\": {\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}}, \"cinder_backup_volumes\": {\"description\": \"Volumes for the cinder-backup container (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}, {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}, {\"get_param\": \"CinderBackupOptVolumes\"}, [\"/var/lib/kolla/config_files/cinder_backup.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/dev:/dev\", \"/run:/run\", \"/sys:/sys\", \"/lib/modules:/lib/modules:ro\", \"/var/lib/cinder:/var/lib/cinder:z\", \"/var/lib/iscsi:/var/lib/iscsi:z\"], {\"if\": [{\"get_param\": \"MultipathdEnable\"}, [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}]}}, \"cinder_backup_environment\": {\"description\": \"Docker environment for the cinder-backup container (HA or non-HA)\", \"value\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(110,'2026-06-10 07:47:00',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Openstack Cinder NVMeOF backend\\n\", \"parameters\": {\"CinderEnableNVMeOFBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NVMeOF backend for Cinder\", \"type\": \"boolean\"}, \"CinderNVMeOFBackendName\": {\"type\": \"string\", \"default\": \"tripleo_nvmeof\"}, \"CinderNVMeOFAvailabilityZone\": {\"default\": \"\", \"description\": \"The availability zone of the NVMeOF Cinder backend. When set, it overrides the default CinderStorageAvailabilityZone.\\n\", \"type\": \"string\"}, \"CinderNVMeOFTargetPort\": {\"type\": \"number\", \"default\": 4420}, \"CinderNVMeOFTargetHelper\": {\"type\": \"string\", \"default\": \"nvmet\"}, \"CinderNVMeOFTargetProtocol\": {\"type\": \"string\", \"default\": \"nvmet_rdma\", \"description\": \"The target protocol, supported values are nvmet_rdma and nvmet_tcp.\\n\", \"constraints\": [{\"allowed_values\": [\"nvmet_rdma\", \"nvmet_tcp\"]}]}, \"CinderNVMeOFTargetPrefix\": {\"type\": \"string\", \"default\": \"nvme-subsystem\"}, \"CinderNVMeOFTargetPortId\": {\"type\": \"number\", \"default\": 1}, \"CinderNVMeOFTargetNameSpaceId\": {\"type\": \"number\", \"default\": 10}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"type\": \"json\", \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\"}}, \"outputs\": {\"cinder_nvmeof_host_prep_tasks\": {\"description\": \"Host prep tasks related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [{\"name\": \"ensure /etc/nvme exists\", \"file\": {\"path\": \"/etc/nvme\", \"state\": \"directory\", \"setype\": \"container_file_t\"}}]]}}, \"cinder_nvmeof_volumes\": {\"description\": \"Volumes related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [\"/etc/nvme:/etc/nvme:z\"]]}}, \"role_data\": {\"description\": \"Role data for the Cinder NVMeOF backend.\", \"value\": {\"service_name\": \"cinder_backend_nvmeof\", \"firewall_rules\": {\"120 LVM nvmet target\": {\"dport\": {\"get_param\": \"CinderNVMeOFTargetPort\"}}}, \"config_settings\": {\"map_merge\": [{\"tripleo::profile::base::cinder::volume::cinder_enable_nvmeof_backend\": {\"get_param\": \"CinderEnableNVMeOFBackend\"}, \"tripleo::profile::base::cinder::volume::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_port\": {\"get_param\": \"CinderNVMeOFTargetPort\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_helper\": {\"get_param\": \"CinderNVMeOFTargetHelper\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_protocol\": {\"get_param\": \"CinderNVMeOFTargetProtocol\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_prefix\": {\"get_param\": \"CinderNVMeOFTargetPrefix\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_port_id\": {\"get_param\": \"CinderNVMeOFTargetPortId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_ns_id\": {\"get_param\": \"CinderNVMeOFTargetNameSpaceId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_ip_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderIscsiNetwork\"]}}}}, \"cinder::backend::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}}, {\"if\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderNVMeOFAvailabilityZone\"}, \"\"]}}, {\"tripleo::profile::base::cinder::volume::nvmeof::backend_availability_zone\": {\"get_param\": \"CinderNVMeOFAvailabilityZone\"}}]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(111,'2026-06-10 07:47:00',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized HAproxy service for pacemaker\\n\", \"parameters\": {\"ContainerHAProxyImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\"}, \"ContainerHAProxyConfigImage\": {\"description\": \"The container image to use for the haproxy config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\"}, \"ClusterCommonTag\": {\"default\": false, \"description\": \"When set to false, a pacemaker service is configured to use a floating tag for its container image name, e.g. \'REGISTRY/NAMESPACE/IMAGENAME:pcmklatest\'. When set to true, the service uses a floating prefix as well, e.g. \'cluster.common.tag/IMAGENAME:pcmklatest\'.\", \"type\": \"boolean\"}, \"ClusterFullTag\": {\"default\": true, \"description\": \"When set to true, the pacemaker service uses a fully constant tag for its container image name, e.g. \'cluster.common.tag/SERVICENAME:pcmklatest\'.\", \"type\": \"boolean\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"SSLCertificate\": {\"default\": \"\", \"description\": \"The content of the SSL certificate (without Key) in PEM format.\\n\", \"type\": \"string\"}, \"PublicSSLCertificateAutogenerated\": {\"default\": false, \"description\": \"Whether the public SSL certificate was autogenerated or not.\\n\", \"type\": \"boolean\"}, \"EnablePublicTLS\": {\"default\": true, \"description\": \"Whether to enable TLS on the public interface or not.\\n\", \"type\": \"boolean\"}, \"DeployedSSLCertificatePath\": {\"default\": \"/etc/pki/tls/private/overcloud_endpoint.pem\", \"description\": \"The filepath of the certificate as it will be stored in the controller.\\n\", \"type\": \"string\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"HAProxyInternalTLSCertsDirectory\": {\"default\": \"/etc/pki/tls/certs/haproxy\", \"type\": \"string\"}, \"HAProxyInternalTLSKeysDirectory\": {\"default\": \"/etc/pki/tls/private/haproxy\", \"type\": \"string\"}, \"HAProxyLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.haproxy\", \"file\": \"/var/log/containers/haproxy/haproxy.log\", \"startmsg.regex\": \"^[a-zA-Z]{3} [ 123][0-9] [:0-9]{8}\"}}, \"HAProxySyslogAddress\": {\"default\": \"/dev/log\", \"description\": \"Syslog address where HAproxy will send its log\", \"type\": \"string\"}, \"HAProxySyslogFacility\": {\"default\": \"local0\", \"description\": \"Syslog facility HAProxy will use for its logs\", \"type\": \"string\"}, \"ConfigDebug\": {\"default\": false, \"description\": \"Whether to run config management (e.g. Puppet) in debug mode.\", \"type\": \"boolean\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}, \"DeployIdentifier\": {\"default\": 1781077560, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}}, \"conditions\": {\"public_tls_enabled\": {\"and\": [{\"get_param\": \"EnablePublicTLS\"}, {\"or\": [{\"not\": {\"equals\": [{\"get_param\": \"SSLCertificate\"}, \"\"]}}, {\"get_param\": \"PublicSSLCertificateAutogenerated\"}]}]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml\"}, \"HAProxyBase\": {\"type\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-container-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"HAProxyPublicTLS\": {\"type\": \"OS::TripleO::Services::HAProxyPublicTLS\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"HAProxyInternalTLS\": {\"type\": \"OS::TripleO::Services::HAProxyInternalTLS\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerHAProxyImage\": \"ContainerHAProxyImage\", \"ContainerHAProxyConfigImage\": \"ContainerHAProxyConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerHAProxyImage\": {\"get_param\": \"ContainerHAProxyImage\"}, \"ContainerHAProxyConfigImage\": {\"get_param\": \"ContainerHAProxyConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the HAproxy role.\", \"value\": {\"service_name\": \"haproxy\", \"firewall_rules\": {\"get_attr\": [\"HAProxyBase\", \"role_data\", \"firewall_rules\"]}, \"monitoring_subscription\": {\"get_attr\": [\"HAProxyBase\", \"role_data\", \"monitoring_subscription\"]}, \"ansible_group_vars\": {\"get_attr\": [\"HAProxyBase\", \"role_data\", \"ansible_group_vars\"]}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"HAProxyBase\", \"role_data\", \"config_settings\"]}, {\"tripleo::haproxy::haproxy_service_manage\": false, \"tripleo::haproxy::mysql_clustercheck\": true, \"tripleo::haproxy::haproxy_log_address\": {\"get_param\": \"HAProxySyslogAddress\"}, \"tripleo::haproxy::haproxy_log_facility\": {\"get_param\": \"HAProxySyslogFacility\"}}, {\"haproxy_docker\": true, \"tripleo::profile::pacemaker::haproxy_bundle::container_backend\": {\"get_param\": \"ContainerCli\"}, \"tripleo::profile::pacemaker::haproxy_bundle::tls_mapping\": {\"list_concat\": [{\"if\": [\"public_tls_enabled\", [{\"get_param\": \"DeployedSSLCertificatePath\"}]]}, {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"HAProxyInternalTLSKeysDirectory\"}, {\"get_param\": \"HAProxyInternalTLSCertsDirectory\"}]]}]}, \"tripleo::profile::pacemaker::haproxy_bundle::tls_mapping_init_bundle\": {\"list_concat\": [{\"if\": [\"public_tls_enabled\", [{\"get_param\": \"DeployedSSLCertificatePath\"}]]}, {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [{\"get_param\": \"HAProxyInternalTLSKeysDirectory\"}, {\"get_param\": \"HAProxyInternalTLSCertsDirectory\"}]]}]}, \"tripleo::profile::pacemaker::haproxy_bundle::internal_certs_directory\": {\"get_param\": \"HAProxyInternalTLSCertsDirectory\"}, \"tripleo::profile::pacemaker::haproxy_bundle::internal_keys_directory\": {\"get_param\": \"HAProxyInternalTLSKeysDirectory\"}, \"tripleo::profile::pacemaker::haproxy_bundle::haproxy_docker_image\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/haproxy:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}}]}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_haproxy\": [{\"get_param\": \"HAProxyLoggingSource\"}]}}, \"puppet_config\": {\"config_volume\": \"haproxy\", \"puppet_tags\": \"haproxy_config\", \"step_config\": {\"list_join\": [\"\\n\", [\"exec {\'wait-for-settle\': command => \'/bin/true\' }\", \"class tripleo::firewall(){}; define tripleo::firewall::rule( $port = undef, $dport = undef, $sport = undef, $proto = undef, $action = undef, $state = undef, $source = undef, $iniface = undef, $chain = undef, $destination = undef, $extras = undef){}\", \"[\'pcmk_bundle\', \'pcmk_resource\', \'pcmk_property\', \'pcmk_constraint\', \'pcmk_resource_default\'].each |String $val| { noop_resource($val) }\", \"include tripleo::profile::pacemaker::haproxy_bundle\"]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyConfigImage\"]}, \"volumes\": {\"yaql\": {\"expression\": \"$.data.select($+\\\":\\\"+$+\\\":ro\\\")\", \"data\": {\"list_concat\": [{\"if\": [\"public_tls_enabled\", [{\"get_param\": \"DeployedSSLCertificatePath\"}]]}, {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"HAProxyInternalTLSKeysDirectory\"}, {\"get_param\": \"HAProxyInternalTLSCertsDirectory\"}]]}]}}}}, \"kolla_config\": {\"/var/lib/kolla/config_files/haproxy.json\": {\"command\": \"bash -c $* -- eval if [ -f /usr/sbin/haproxy-systemd-wrapper ]; then exec /usr/sbin/haproxy-systemd-wrapper -f /etc/haproxy/haproxy.cfg; else exec /usr/sbin/haproxy -f /etc/haproxy/haproxy.cfg -Ws; fi\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true, \"optional\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"optional\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/lib/haproxy\", \"owner\": \"haproxy:haproxy\", \"recurse\": true}, {\"path\": {\"list_join\": [\"\", [{\"get_param\": \"HAProxyInternalTLSCertsDirectory\"}, \"/*\"]]}, \"owner\": \"haproxy:haproxy\", \"perm\": \"0600\", \"optional\": true}, {\"path\": {\"list_join\": [\"\", [{\"get_param\": \"HAProxyInternalTLSKeysDirectory\"}, \"/*\"]]}, \"owner\": \"haproxy:haproxy\", \"perm\": \"0600\", \"optional\": true}]}}, \"container_config_scripts\": {\"get_attr\": [\"ContainersCommon\", \"container_config_scripts\"]}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"HAProxyBase\", \"role_data\", \"host_prep_tasks\"]}, [{\"name\": \"Run puppet on the host to apply IPtables rules\", \"no_log\": true, \"shell\": \"puppet apply {{ (puppet_debug|bool) | ternary(\'--debug --verbose\', \'\') }} --detailed-exitcodes --summarize --color=false \\\\\\n    --modulepath \'{{ puppet_modulepath }}\' --tags \'{{ puppet_tags }}\' -e \'{{ puppet_execute }}\'\\n\", \"register\": \"puppet_host_outputs\", \"changed_when\": \"puppet_host_outputs.rc == 2\", \"failed_when\": false, \"vars\": {\"puppet_execute\": \"if hiera(\'enable_load_balancer\', true) { class {\'::tripleo::haproxy\': use_internal_certificates => false, manage_firewall => hiera(\'tripleo::firewall::manage_firewall\', true), }}\", \"puppet_tags\": \"tripleo::firewall::rule\", \"puppet_modulepath\": \"/etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules\", \"puppet_debug\": {\"get_param\": \"ConfigDebug\"}}}, {\"name\": \"Debug output for task: Run puppet on the host to apply IPtables rules\", \"debug\": {\"var\": \"puppet_host_outputs.stdout_lines | default([]) | union(puppet_host_outputs.stderr_lines | default([]))\"}, \"when\": [\"not (ansible_check_mode | bool)\", \"puppet_host_outputs.rc is defined\"], \"failed_when\": \"puppet_host_outputs.rc not in [0, 2]\"}]]}, \"metadata_settings\": {\"get_attr\": [\"HAProxyBase\", \"role_data\", \"metadata_settings\"]}, \"deploy_steps_tasks\": {\"list_concat\": [[{\"name\": \"Configure rsyslog for HAproxy container managed by Pacemaker\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"Check if rsyslog exists\", \"shell\": \"systemctl is-active rsyslog\", \"register\": \"rsyslog_config\"}, {\"when\": [\"rsyslog_config is changed\", \"rsyslog_config.rc == 0\"], \"block\": [{\"name\": \"Forward logging to haproxy.log file\", \"blockinfile\": {\"content\": \"if $syslogfacility-text == \'{{facility}}\' and $programname == \'haproxy\' then -/var/log/containers/haproxy/haproxy.log\\n& stop\\n\", \"create\": true, \"path\": \"/etc/rsyslog.d/openstack-haproxy.conf\"}, \"vars\": {\"facility\": {\"get_param\": \"HAProxySyslogFacility\"}}, \"register\": \"logconfig\"}, {\"name\": \"restart rsyslog service after logging conf change\", \"service\": {\"name\": \"rsyslog\", \"state\": \"restarted\"}, \"when\": \"logconfig is changed\"}]}]}, {\"name\": \"HAproxy tag container image for pacemaker\", \"when\": \"step|int == 1\", \"import_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}, \"container_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/haproxy:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}}}, {\"name\": \"HAproxy HA Wrappers Step\", \"when\": \"step|int == 2\", \"block\": [{\"name\": \"HAproxy puppet bundle\", \"import_role\": {\"name\": \"tripleo_ha_wrapper\"}, \"vars\": {\"tripleo_ha_wrapper_service_name\": \"haproxy\", \"tripleo_ha_wrapper_resource_name\": \"haproxy-bundle\", \"tripleo_ha_wrapper_bundle_name\": \"haproxy-bundle\", \"tripleo_ha_wrapper_resource_state\": \"Started\", \"tripleo_ha_wrapper_puppet_config_volume\": \"haproxy\", \"tripleo_ha_wrapper_puppet_execute\": \"include ::tripleo::profile::base::pacemaker; include ::tripleo::profile::pacemaker::haproxy_bundle\", \"tripleo_ha_wrapper_puppet_tags\": \"pacemaker::resource::bundle,pacemaker::property,pacemaker::resource::ip,pacemaker::resource::ocf,pacemaker::constraint::order,pacemaker::constraint::colocation\", \"tripleo_ha_wrapper_puppet_debug\": {\"get_param\": \"ConfigDebug\"}, \"tripleo_ha_wrapper_config_suffix\": \".previous_run\"}}]}], {\"if\": [\"public_tls_enabled\", {\"get_attr\": [\"HAProxyPublicTLS\", \"role_data\", \"deploy_steps_tasks\"]}, []]}, {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"get_attr\": [\"HAProxyInternalTLS\", \"role_data\", \"deploy_steps_tasks\"]}]}]}, \"external_update_tasks\": [{\"when\": \"step|int == 1\", \"tags\": \"ha_image_update\", \"block\": [{\"block\": [{\"name\": \"Get haproxy image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_haproxy_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'haproxy-bundle\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container haproxy image\", \"set_fact\": {\"haproxy_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}, \"haproxy_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/haproxy:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"pcmk_haproxy_image\": \"{{xmllint_pcmk_haproxy_image.stdout}}\"}}], \"delegate_to\": \"{{ (groups[\\\"haproxy\\\"] | difference(groups[\\\"excluded_overcloud\\\"]))[0] }}\"}, {\"name\": \"haproxy temporary pacemaker container tag in case of image switch\", \"become\": true, \"import_role\": {\"name\": \"tripleo_ha_image_update\"}, \"vars\": {\"tripleo_ha_image_update_node_names\": \"{{ groups[\\\"haproxy\\\"] | difference(groups[\\\"excluded_overcloud\\\"]) }}\", \"tripleo_ha_image_update_bundle\": \"haproxy-bundle\", \"tripleo_ha_image_update_new_image\": \"{{haproxy_image_latest}}\", \"tripleo_ha_image_update_old_image\": \"{{pcmk_haproxy_image}}\"}, \"when\": [\"(pcmk_haproxy_image != \\\"\\\")\", \"(pcmk_haproxy_image != haproxy_image_latest)\"]}]}], \"update_tasks\": [{\"block\": [{\"name\": \"Get haproxy image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_haproxy_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'haproxy-bundle\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container haproxy image\", \"set_fact\": {\"haproxy_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}, \"haproxy_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/haproxy:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"pcmk_haproxy_image\": \"{{xmllint_pcmk_haproxy_image.stdout}}\"}}], \"when\": \"(step|int == 0 or step|int == 2)\"}, {\"name\": \"Check for update of haproxy container image name\", \"when\": \"step|int == 0\", \"assert\": {\"that\": \"pcmk_haproxy_image == haproxy_image_latest\", \"fail_msg\": \"haproxy image change detected, run overcloud external-update --tags ha_image_update first\"}}, {\"name\": \"Tear-down non-HA haproxy container\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"Remove non-HA haproxy container\", \"include_role\": {\"name\": \"tripleo_container_rm\"}, \"vars\": {\"tripleo_container_cli\": \"{{ container_cli }}\", \"tripleo_containers_to_rm\": [\"haproxy\"]}}]}, {\"name\": \"Set HAProxy upgrade facts\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"set is_haproxy_bootstrap_node fact\", \"tags\": \"common\", \"set_fact\": \"is_haproxy_bootstrap_node={{haproxy_short_bootstrap_node_name|lower == ansible_facts[\'hostname\']|lower}}\", \"when\": [\"haproxy_short_bootstrap_node_name|default(false)\"]}]}, {\"name\": \"Mount TLS cert if needed\", \"when\": [\"step|int == 1\", \"is_haproxy_bootstrap_node\"], \"block\": [{\"name\": \"Check haproxy public certificate configuration in pacemaker\", \"command\": \"cibadmin --query --xpath \\\"//storage-mapping[@id=\'haproxy-cert\']\\\"\", \"failed_when\": false, \"register\": \"haproxy_cert_mounted\"}, {\"name\": \"Disable the haproxy cluster resource\", \"pacemaker_resource\": {\"resource\": \"haproxy-bundle\", \"state\": \"disable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\", \"when\": \"haproxy_cert_mounted.rc == 6\"}, {\"name\": \"Set HAProxy public cert volume mount fact\", \"set_fact\": {\"haproxy_public_cert_path\": {\"get_param\": \"DeployedSSLCertificatePath\"}, \"haproxy_public_tls_enabled\": {\"if\": [\"public_tls_enabled\", true, false]}}}, {\"name\": \"Add a bind mount for public certificate in the haproxy bundle\", \"command\": \"pcs resource bundle update haproxy-bundle storage-map add id=haproxy-cert source-dir={{ haproxy_public_cert_path }} target-dir=/var/lib/kolla/config_files/src-tls/{{ haproxy_public_cert_path }} options=ro\", \"when\": \"haproxy_cert_mounted.rc == 6 and haproxy_public_tls_enabled|bool\"}, {\"name\": \"Enable the haproxy cluster resource\", \"pacemaker_resource\": {\"resource\": \"haproxy-bundle\", \"state\": \"enable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\", \"when\": \"haproxy_cert_mounted.rc == 6\"}]}, {\"name\": \"Haproxy fetch and retag container image for pacemaker\", \"tags\": \"haproxy_syn_block\", \"when\": [\"step|int == 2\"], \"block\": [{\"name\": \"Retag pcmklatest to latest haproxy image\", \"include_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{haproxy_image}}\", \"container_image_latest\": \"{{haproxy_image_latest}}\"}}]}, {\"name\": \"Move virtual IPs to another node before stopping pacemaker\", \"when\": [\"step|int == 1\", \"hostvars[inventory_hostname][\\\"haproxy_node_names\\\"]|default([])|length > 1\"], \"shell\": \"CLUSTER_NODE=$(crm_node -n)\\necho \\\"Retrieving all the VIPs which are hosted on this node\\\"\\nVIPS_TO_MOVE=$(crm_mon --as-xml | xmllint --xpath \'//resource[@resource_agent=\\\"ocf:heartbeat:IPaddr2\\\" and @role = \\\"Started\\\" and @managed = \\\"true\\\" and ./node[@name = \\\"\'${CLUSTER_NODE}\'\\\"]]/@id\' - | sed -e \'s/id=//g\' -e \'s/\\\"//g\')\\nfor v in ${VIPS_TO_MOVE}; do\\n    echo \\\"Moving VIP $v on another node\\\"\\n    pcs resource ban $v ${CLUSTER_NODE} --wait=300\\ndone\\necho \\\"Removing the location constraints that were created to move the VIPs\\\"\\nfor v in ${VIPS_TO_MOVE}; do\\n    echo \\\"Removing location ban for VIP $v\\\"\\n    ban_id=$(cibadmin --query | xmllint --xpath \'string(//rsc_location[@rsc=\\\"\'${v}\'\\\" and @node=\\\"\'${CLUSTER_NODE}\'\\\" and @score=\\\"-INFINITY\\\"]/@id)\' -)\\n    if [ -n \\\"$ban_id\\\" ]; then\\n        pcs constraint remove ${ban_id}\\n    else\\n        echo \\\"Could not retrieve and clear location constraint for VIP $v\\\" 2>&1\\n    fi\\ndone\\n\"}, {\"name\": \"Wait for 10s to settle connections on new VIPs\", \"wait_for\": {\"timeout\": 10}, \"when\": [\"step|int == 1\", \"hostvars[inventory_hostname][\\\"haproxy_node_names\\\"]|default([])|length > 1\"]}, {\"name\": \"Block local INPUT SYN packets on the backends except mysql\", \"tags\": \"haproxy_syn_block\", \"when\": [\"step|int == 1\"], \"shell\": \"# server controller-0.storage.redhat.local 172.17.3.93:8080 check fall 5 inter 2000 rise 2\\n# server controller-0.internalapi.redhat.local fd00:fd00:fd00:2000::176:9292 check fall 5 inter 2000 rise 2\\nset -o pipefail\\nsource /etc/os-release; test  \\\"${VERSION_ID%*}\\\" = \\\"9.0\\\" && exit 0\\ngrep {{ ansible_facts[\\\"hostname\\\"]|lower }} /var/lib/config-data/puppet-generated/haproxy/etc/haproxy/haproxy.cfg  | grep -v \\\":3306 \\\" | \\\\\\nawk \'{print $3}\' | \\\\\\nwhile read BACKEND; do\\n    IP=${BACKEND%:*}\\n    PORT=${BACKEND#\\\"$IP:\\\"}\\n    if [[ $IP =~ .*:.* ]]\\n      then PROTOCOL=\\\"ip6\\\"\\n      else PROTOCOL=\\\"ip\\\"\\n    fi\\necho \\\"insert rule $PROTOCOL filter INPUT $PROTOCOL daddr $IP tcp dport $PORT tcp flags syn / fin,syn,rst,ack meta time\\\"\\ndone | xargs -i nft {} $(date +%s)-$(date -d\'+20 minutes\' +%s) counter drop comment \\\"{{ ansible_facts[\\\"hostname\\\"]|lower }}_haproxy_drop\\\"\\n\"}, {\"name\": \"Generate block for other nodes OUTPUT SYN packets on the backends except mysql\", \"tags\": \"haproxy_syn_block\", \"when\": [\"step|int == 1\"], \"shell\": \"set -o pipefail\\nsource /etc/os-release; test  \\\"${VERSION_ID%*}\\\" = \\\"9.0\\\" && exit 0\\ngrep {{ ansible_facts[\\\"hostname\\\"]|lower }} /var/lib/config-data/puppet-generated/haproxy/etc/haproxy/haproxy.cfg  | grep -v \\\":3306 \\\" | \\\\\\nawk \'{print $3}\' | \\\\\\nwhile read BACKEND; do\\n    IP=${BACKEND%:*}\\n    PORT=${BACKEND#\\\"$IP:\\\"}\\n    if [[ $IP =~ .*:.* ]]\\n      then PROTOCOL=\\\"ip6\\\"\\n      else PROTOCOL=\\\"ip\\\"\\n    fi\\n echo \\\"nft insert rule $PROTOCOL \\\\$TABLE OUTPUT $PROTOCOL daddr $IP tcp dport $PORT tcp flags syn / fin,syn,rst,ack meta time $(date +%s)-$(date -d\'+20 minutes\' +%s) counter drop comment \\\\\\\"{{ ansible_facts[\\\"hostname\\\"]|lower }}_haproxy_drop\\\\\\\" \\\"\\ndone\\n\", \"register\": \"haproxy_iptables_block\"}, {\"name\": \"Block OUTPUT SYN packets to this node on other haproxy nodes\", \"tags\": \"haproxy_syn_block\", \"delegate_to\": \"{{ item }}\", \"when\": [\"step|int == 1\"], \"shell\": \"set -o pipefail\\ngrep {{ ansible_facts[\\\"hostname\\\"]|lower }} /var/lib/config-data/puppet-generated/haproxy/etc/haproxy/haproxy.cfg | head -n 1 \\\\\\nawk \'{print $3}\' | while read BACKEND; do\\n    IP=${BACKEND%:*}\\n    if [[ $IP =~ .*:.* ]]\\n      then PROTOCOL=\\\"ip6\\\"\\n      else PROTOCOL=\\\"ip\\\"\\n    fi\\ndone\\nTABLE=$(nft list tables | grep -q \\\"$PROTOCOL raw\\\" && echo raw || echo filter )\\necho \\\"{{ haproxy_iptables_block.stdout}}\\\" | while read i; do bash -c \\\"$i\\\"; done\\n\", \"loop\": \"{{ groups[\\\"haproxy\\\"] | difference(groups[\\\"excluded_overcloud\\\"]) | difference(ansible_facts[\\\"hostname\\\"]|lower) }}\"}], \"post_update_tasks\": [{\"name\": \"HAProxy bundle post update\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"HAproxy puppet bundle\", \"import_role\": {\"name\": \"tripleo_ha_wrapper\"}, \"vars\": {\"tripleo_ha_wrapper_service_name\": \"haproxy\", \"tripleo_ha_wrapper_resource_name\": \"haproxy-bundle\", \"tripleo_ha_wrapper_bundle_name\": \"haproxy-bundle\", \"tripleo_ha_wrapper_resource_state\": \"Started\", \"tripleo_ha_wrapper_puppet_config_volume\": \"haproxy\", \"tripleo_ha_wrapper_puppet_execute\": \"include ::tripleo::profile::base::pacemaker; include ::tripleo::profile::pacemaker::haproxy_bundle\", \"tripleo_ha_wrapper_puppet_tags\": \"pacemaker::resource::bundle,pacemaker::property,pacemaker::resource::ip,pacemaker::resource::ocf,pacemaker::constraint::order,pacemaker::constraint::colocation\", \"tripleo_ha_wrapper_puppet_debug\": {\"get_param\": \"ConfigDebug\"}, \"tripleo_ha_wrapper_config_suffix\": \".previous_run\"}}], \"vars\": {\"tripleo_ha_wrapper_minor_update\": true}}, {\"name\": \"Cleanup local SYN DROP rules\", \"tags\": \"haproxy_syn_block\", \"when\": \"step|int == 1\", \"shell\": \"nft -a list chain filter INPUT | grep {{ ansible_facts[\\\"hostname\\\"]|lower }} | grep haproxy_drop | \\\\\\nawk -F# \'{print \\\"nft delete rule filter INPUT \\\"$2}\' | \\\\\\nwhile read i; do bash -c \\\"$i\\\"; done\\n\"}, {\"name\": \"Cleanup SYN DROP rules from other haproxy nodes\", \"tags\": \"haproxy_syn_block\", \"when\": \"step|int == 1\", \"delegate_to\": \"{{ item }}\", \"loop\": \"{{ groups[\\\"haproxy\\\"] | difference(groups[\\\"excluded_overcloud\\\"]) | difference(ansible_facts[\\\"hostname\\\"]|lower) }}\", \"shell\": \"nft -a list chain raw OUTPUT | grep {{ ansible_facts[\\\"hostname\\\"]|lower }} | grep haproxy_drop | \\\\\\nawk -F# \'{print \\\"nft delete rule raw OUTPUT \\\"$2}\' | \\\\\\nwhile read i; do bash -c \\\"$i\\\"; done\\n\"}], \"upgrade_tasks\": [{\"name\": \"Tear-down non-HA haproxy container\", \"when\": [\"step|int == 0\"], \"block\": [{\"name\": \"Remove non-HA haproxy container\", \"include_role\": {\"name\": \"tripleo_container_rm\"}, \"vars\": {\"tripleo_container_cli\": \"{{ container_cli }}\", \"tripleo_containers_to_rm\": [\"haproxy\"]}}]}, {\"name\": \"Prepare switch of haproxy image name\", \"when\": [\"step|int == 0\"], \"block\": [{\"name\": \"Get haproxy image id currently used by pacemaker\", \"shell\": \"pcs resource config haproxy-bundle | grep -Eo \'image=[^ ]+\' | awk -F= \'{print $2;}\'\", \"register\": \"haproxy_image_current_res\", \"failed_when\": false}, {\"name\": \"Image facts for haproxy\", \"set_fact\": {\"haproxy_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/haproxy:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"haproxy_image_current\": \"{{haproxy_image_current_res.stdout}}\"}}, {\"name\": \"Temporarily tag the current haproxy image id with the upgraded image name\", \"import_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{haproxy_image_current}}\", \"container_image_latest\": \"{{haproxy_image_latest}}\", \"pull_image\": false}, \"when\": [\"haproxy_image_current != \'\'\", \"haproxy_image_current != haproxy_image_latest\"]}, {\"name\": \"Create haproxy retag statefile\", \"file\": {\"path\": \"/var/lib/tripleo/haproxy_needs_retag\", \"state\": \"touch\"}, \"when\": [\"haproxy_image_current != \'\'\", \"haproxy_image_current != haproxy_image_latest\"]}]}, {\"name\": \"Update haproxy pcs resource bundle for new container image\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"Set upgrade haproxy facts\", \"set_fact\": {\"is_haproxy_bootstrap_node\": \"{{haproxy_short_bootstrap_node_name|lower == ansible_facts[\'hostname\']|lower}}\"}}, {\"name\": \"Check for haproxy retag statefile\", \"stat\": {\"path\": \"/var/lib/tripleo/haproxy_needs_retag\"}, \"register\": \"haproxy_retag_state_file\"}]}, {\"name\": \"Update haproxy pcs resource bundle for new container image\", \"when\": [\"step|int == 1\", \"is_haproxy_bootstrap_node|bool\", \"haproxy_retag_state_file.stat.exists|bool\"], \"block\": [{\"name\": \"Disable the haproxy cluster resource before container upgrade\", \"pacemaker_resource\": {\"resource\": \"haproxy-bundle\", \"state\": \"disable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}, {\"name\": \"Expose HAProxy stats socket on the host and mount TLS cert if needed\", \"block\": [{\"name\": \"Check haproxy stats socket configuration in pacemaker\", \"command\": \"cibadmin --query --xpath \\\"//storage-mapping[@id=\'haproxy-var-lib\']\\\"\", \"failed_when\": false, \"register\": \"haproxy_stats_exposed\"}, {\"name\": \"Check haproxy public certificate configuration in pacemaker\", \"command\": \"cibadmin --query --xpath \\\"//storage-mapping[@id=\'haproxy-cert\']\\\"\", \"failed_when\": false, \"register\": \"haproxy_cert_mounted\"}, {\"name\": \"Add a bind mount for stats socket in the haproxy bundle\", \"command\": \"pcs resource bundle update haproxy-bundle storage-map add id=haproxy-var-lib source-dir=/var/lib/haproxy target-dir=/var/lib/haproxy options=rw\", \"when\": \"haproxy_stats_exposed.rc == 6\"}, {\"name\": \"Set HAProxy public cert volume mount fact\", \"set_fact\": {\"haproxy_public_cert_path\": {\"get_param\": \"DeployedSSLCertificatePath\"}, \"haproxy_public_tls_enabled\": {\"if\": [\"public_tls_enabled\", true, false]}}}, {\"name\": \"Add a bind mount for public certificate in the haproxy bundle\", \"command\": \"pcs resource bundle update haproxy-bundle storage-map add id=haproxy-cert source-dir={{ haproxy_public_cert_path }} target-dir=/var/lib/kolla/config_files/src-tls/{{ haproxy_public_cert_path }} options=ro\", \"when\": [\"haproxy_cert_mounted.rc == 6\", \"haproxy_public_tls_enabled|bool\"]}]}, {\"name\": \"Update the haproxy bundle to use the new container image name\", \"command\": \"pcs resource bundle update haproxy-bundle container image={{haproxy_image_latest}}\"}, {\"name\": \"Enable the haproxy cluster resource\", \"pacemaker_resource\": {\"resource\": \"haproxy-bundle\", \"state\": \"enable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}, {\"name\": \"Remove haproxy retag statefile\", \"file\": {\"path\": \"/var/lib/tripleo/haproxy_needs_retag\", \"state\": \"absent\"}}]}, {\"name\": \"Retag the pacemaker image if containerized\", \"when\": [\"step|int == 3\"], \"block\": [{\"block\": [{\"name\": \"Get haproxy image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_haproxy_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'haproxy-bundle\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container haproxy image\", \"set_fact\": {\"haproxy_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}, \"haproxy_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/haproxy:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"pcmk_haproxy_image\": \"{{xmllint_pcmk_haproxy_image.stdout}}\"}}]}, {\"block\": [{\"name\": \"Retag pcmklatest to latest haproxy image\", \"include_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{haproxy_image}}\", \"container_image_latest\": \"{{haproxy_image_latest}}\"}}]}, {\"name\": \"Ensure config works for the new config\", \"shell\": \"set -o pipefail\\nawk -i inplace -v INPLACE_SUFFIX=.bak \'/  rsprep/ {print \\\"  http-response replace-header Location \\\" $3\\\" \\\"$5; next;}; {print} \' /var/lib/config-data/puppet-generated/haproxy/etc/haproxy/haproxy.cfg\"}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(112,'2026-06-10 07:47:01',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(113,'2026-06-10 07:47:01',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Apache service configured with Puppet. Note this is typically included automatically via other services which run via Apache.\\n\", \"parameters\": {\"ApacheMaxRequestWorkers\": {\"default\": 100, \"description\": \"Maximum number of simultaneously processed requests.\", \"type\": \"number\"}, \"ApacheServerLimit\": {\"default\": 100, \"description\": \"Maximum number of Apache processes.\", \"type\": \"number\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"ApacheCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}, \"ApacheTimeout\": {\"type\": \"number\", \"default\": 90, \"description\": \"The timeout in seconds for Apache, which defines duration Apache waits for I/O operations\"}}, \"conditions\": {\"key_size_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"ApacheCertificateKeySize\"}, \"\"]}}}, \"resources\": {\"ApacheNetworks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"Controller\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"CellController\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"CellControllerCompute\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"Compute\": [\"ctlplane\", \"storage\", \"internal_api\"], \"BlockStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"ObjectStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"CephStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\"], \"Networker\": [\"ctlplane\", \"internal_api\"]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Apache role.\", \"value\": {\"service_name\": \"apache\", \"config_settings\": {\"map_merge\": [{\"apache::ip\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ApacheNetwork\"]}}}}, \"apache::default_vhost\": false, \"apache::trace_enable\": \"Off\", \"apache::server_signature\": \"Off\", \"apache::server_tokens\": \"Prod\", \"apache::timeout\": {\"get_param\": \"ApacheTimeout\"}, \"apache::default_mods\": false, \"apache::mod::prefork::maxrequestworkers\": {\"get_param\": \"ApacheMaxRequestWorkers\"}, \"apache::mod::prefork::serverlimit\": {\"get_param\": \"ApacheServerLimit\"}, \"apache::mod::remoteip::proxy_ips\": {\"get_param\": [\"ServiceData\", \"net_cidr_map\", {\"get_param\": [\"ServiceNetMap\", \"ApacheNetwork\"]}]}, \"apache::mod::alias::icons_options\": \"None\"}, {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"apache::mod::ssl::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}, \"apache::mod::ssl::ssl_protocol\": [\"all\", \"-SSLv2\", \"-SSLv3\", \"-TLSv1\"], \"apache_certificates_specs\": {\"map_merge\": {\"repeat\": {\"template\": {\"httpd-NETWORK\": {\"service_certificate\": \"/etc/pki/tls/certs/httpd/httpd-NETWORK.crt\", \"service_key\": \"/etc/pki/tls/private/httpd/httpd-NETWORK.key\"}}, \"for_each\": {\"NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}}}]}]}, \"metadata_settings\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"repeat\": {\"template\": [{\"service\": \"HTTP\", \"network\": \"$NETWORK\", \"type\": \"node\"}], \"for_each\": {\"$NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}]}, \"upgrade_tasks\": [], \"deploy_steps_tasks\": [{\"name\": \"Certificate generation\", \"when\": [\"step|int == 1\", \"enable_internal_tls\"], \"block\": [{\"name\": \"Create dirs for certificates and keys\", \"file\": {\"path\": \"{{ item }}\", \"state\": \"directory\", \"serole\": \"object_r\", \"setype\": \"cert_t\", \"seuser\": \"system_u\"}, \"with_items\": [\"/etc/pki/tls/certs/httpd\", \"/etc/pki/tls/private/httpd\"]}, {\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": {\"repeat\": {\"template\": {\"name\": \"httpd-NETWORK\", \"dns\": \"{{ fqdn_NETWORK }}\", \"principal\": \"HTTP/{{ fqdn_NETWORK }}@{{ idm_realm }}\", \"run_after\": \"cp /etc/pki/tls/certs/httpd-NETWORK.crt /etc/pki/tls/certs/httpd/httpd-NETWORK.crt\\ncp /etc/pki/tls/private/httpd-NETWORK.key /etc/pki/tls/private/httpd/httpd-NETWORK.key\\npkill -USR1 httpd\\n\", \"key_size\": {\"if\": [\"key_size_override_set\", {\"get_param\": \"ApacheCertificateKeySize\"}, {\"get_param\": \"CertificateKeySize\"}]}, \"ca\": \"ipa\"}, \"for_each\": {\"NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"EnableInternalTLS\": false}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(114,'2026-06-10 07:47:02',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized HAproxy service\\n\", \"parameters\": {\"ContainerHAProxyImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\"}, \"ContainerHAProxyConfigImage\": {\"description\": \"The container image to use for the haproxy config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"HAProxyStatsPassword\": {\"description\": \"Password for HAProxy stats endpoint\", \"hidden\": true, \"type\": \"string\", \"default\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\"}, \"HAProxyStatsUser\": {\"description\": \"User for HAProxy stats endpoint\", \"default\": \"admin\", \"type\": \"string\"}, \"HAProxyLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.haproxy\", \"file\": \"/var/log/containers/haproxy/haproxy.log\", \"startmsg.regex\": \"^[a-zA-Z]{3} [ 123][0-9] [:0-9]{8}\"}}, \"HAProxySyslogAddress\": {\"default\": \"/dev/log\", \"description\": \"Syslog address where HAproxy will send its log\", \"type\": \"string\"}, \"HAProxySyslogFacility\": {\"default\": \"local0\", \"description\": \"Syslog facility HAProxy will use for its logs\", \"type\": \"string\"}, \"SSLCertificate\": {\"default\": \"\", \"description\": \"The content of the SSL certificate (without Key) in PEM format.\\n\", \"type\": \"string\"}, \"PublicSSLCertificateAutogenerated\": {\"default\": false, \"description\": \"Whether the public SSL certificate was autogenerated or not.\\n\", \"type\": \"boolean\"}, \"EnablePublicTLS\": {\"default\": true, \"description\": \"Whether to enable TLS on the public interface or not.\\n\", \"type\": \"boolean\"}, \"DeployedSSLCertificatePath\": {\"default\": \"/etc/pki/tls/private/overcloud_endpoint.pem\", \"description\": \"The filepath of the certificate as it will be stored in the controller.\\n\", \"type\": \"string\"}, \"RedisPassword\": {\"description\": \"The password for the redis service account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"PeixZYMWlure0PQXGfRipmgn4\"}, \"MonitoringSubscriptionHaproxy\": {\"default\": \"overcloud-haproxy\", \"type\": \"string\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"ConfigDebug\": {\"default\": false, \"description\": \"Whether to run config management (e.g. Puppet) in debug mode.\", \"type\": \"boolean\"}, \"EnableLoadBalancer\": {\"default\": true, \"description\": \"Whether to deploy a LoadBalancer, set to false when an external load balancer is used.\", \"type\": \"boolean\"}, \"HAProxyStatsEnabled\": {\"default\": true, \"description\": \"Whether or not to enable the HAProxy stats interface.\", \"type\": \"boolean\"}, \"InternalTLSCRLPEMFile\": {\"default\": \"/etc/pki/CA/crl/overcloud-crl.pem\", \"type\": \"string\", \"description\": \"Specifies the default CRL PEM file to use for revocation if TLS is used for services in the internal network.\"}, \"InternalTLSCRLPEMDir\": {\"default\": \"/etc/pki/CA/crl/\", \"type\": \"string\", \"description\": \"The directory of the CRL PEM file to be mounted.\"}}, \"conditions\": {\"public_tls_enabled\": {\"and\": [{\"get_param\": \"EnablePublicTLS\"}, {\"or\": [{\"not\": {\"equals\": [{\"get_param\": \"SSLCertificate\"}, \"\"]}}, {\"get_param\": \"PublicSSLCertificateAutogenerated\"}]}]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml\"}, \"HAProxyLogging\": {\"type\": \"OS::TripleO::Services::Logging::HAProxy\"}, \"HAProxyPublicTLS\": {\"type\": \"OS::TripleO::Services::HAProxyPublicTLS\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"HAProxyInternalTLS\": {\"type\": \"OS::TripleO::Services::HAProxyInternalTLS\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerHAProxyImage\": \"ContainerHAProxyImage\", \"ContainerHAProxyConfigImage\": \"ContainerHAProxyConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerHAProxyImage\": {\"get_param\": \"ContainerHAProxyImage\"}, \"ContainerHAProxyConfigImage\": {\"get_param\": \"ContainerHAProxyConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the HAproxy role.\", \"value\": {\"service_name\": \"haproxy\", \"firewall_rules\": {\"107 haproxy stats\": {\"dport\": 1993}}, \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionHaproxy\"}, \"ansible_group_vars\": {\"tripleo_firewall_frontend_enabled\": true, \"tripleo_firewall_ssl_frontend_enabled\": {\"if\": [\"public_tls_enabled\", true]}}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"HAProxyLogging\", \"config_settings\"]}, {\"tripleo::haproxy::haproxy_service_manage\": false, \"tripleo::haproxy::haproxy_log_address\": {\"get_param\": \"HAProxySyslogAddress\"}, \"tripleo::haproxy::haproxy_log_facility\": {\"get_param\": \"HAProxySyslogFacility\"}, \"tripleo::haproxy::haproxy_stats_user\": {\"get_param\": \"HAProxyStatsUser\"}, \"tripleo::haproxy::haproxy_stats_password\": {\"get_param\": \"HAProxyStatsPassword\"}, \"tripleo::haproxy::haproxy_stats_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HaproxyNetwork\"]}}}}, \"tripleo::haproxy::redis_password\": {\"get_param\": \"RedisPassword\"}, \"tripleo::haproxy::crl_file\": null, \"tripleo::haproxy::haproxy_stats\": {\"get_param\": \"HAProxyStatsEnabled\"}, \"enable_load_balancer\": {\"get_param\": \"EnableLoadBalancer\"}, \"tripleo::profile::base::haproxy::certificates_specs\": {\"map_merge\": [{\"get_attr\": [\"HAProxyPublicTLS\", \"role_data\", \"certificates_specs\"]}, {\"get_attr\": [\"HAProxyInternalTLS\", \"role_data\", \"certificates_specs\"]}]}, \"tripleo::haproxy::service_certificate\": {\"if\": [\"public_tls_enabled\", {\"get_param\": \"DeployedSSLCertificatePath\"}]}, \"tripleo::haproxy::ca_bundle\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"get_param\": \"InternalTLSCAFile\"}]}}, {\"get_attr\": [\"HAProxyPublicTLS\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"HAProxyInternalTLS\", \"role_data\", \"config_settings\"]}]}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_haproxy\": [{\"get_param\": \"HAProxyLoggingSource\"}]}}, \"puppet_config\": {\"config_volume\": \"haproxy\", \"puppet_tags\": \"haproxy_config\", \"step_config\": \"class {\'tripleo::profile::base::haproxy\': manage_firewall => false}\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyConfigImage\"]}, \"volumes\": {\"list_concat\": [{\"if\": [\"public_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"DeployedSSLCertificatePath\"}, {\"get_param\": \"DeployedSSLCertificatePath\"}, \"ro,shared\"]]}]]}, {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [\"/etc/pki/tls/certs/haproxy:/etc/pki/tls/certs/haproxy:ro,shared\", \"/etc/pki/tls/private/haproxy:/etc/pki/tls/private/haproxy:ro,shared\", {\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro,shared\"]]}, {\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCRLPEMDir\"}, {\"get_param\": \"InternalTLSCRLPEMDir\"}, \"ro,shared\"]]}]]}]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/haproxy.json\": {\"command\": \"bash -c $* -- eval if [ -f /usr/sbin/haproxy-systemd-wrapper ]; then exec /usr/sbin/haproxy-systemd-wrapper -f /etc/haproxy/haproxy.cfg; else exec /usr/sbin/haproxy -f /etc/haproxy/haproxy.cfg -Ws; fi\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true, \"optional\": true}], \"permissions\": [{\"path\": \"/var/lib/haproxy\", \"owner\": \"haproxy:haproxy\", \"recurse\": true}, {\"path\": \"/etc/pki/tls/certs/haproxy\", \"owner\": \"haproxy:haproxy\", \"recurse\": true, \"optional\": true}]}}, \"container_config_scripts\": {\"get_attr\": [\"ContainersCommon\", \"container_config_scripts\"]}, \"docker_config\": {\"step_1\": {\"map_merge\": [{\"get_attr\": [\"HAProxyLogging\", \"docker_config\", \"step_1\"]}, {\"haproxy\": {\"start_order\": 1, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}, \"net\": \"host\", \"restart\": \"always\", \"security_opt\": [\"label=disable\"], \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"HAProxyLogging\", \"volumes\"]}, [\"/var/lib/kolla/config_files/haproxy.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/haproxy:/var/lib/kolla/config_files/src:ro\", \"/var/lib/haproxy:/var/lib/haproxy:rw,z\"], {\"if\": [\"public_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"DeployedSSLCertificatePath\"}, {\"list_join\": [\"\", [\"/var/lib/kolla/config_files/src-tls\", {\"get_param\": \"DeployedSSLCertificatePath\"}]]}, \"ro,shared\"]]}]]}, {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [\"/etc/pki/tls/certs/haproxy:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/haproxy:ro,shared\", \"/etc/pki/tls/private/haproxy:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/haproxy:ro,shared\", {\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCRLPEMDir\"}, {\"get_param\": \"InternalTLSCRLPEMDir\"}, \"ro\"]]}]]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}]}}, \"deploy_steps_tasks\": {\"list_concat\": [[{\"name\": \"Configure rsyslog for HAproxy container\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"Check if rsyslog exists\", \"shell\": \"systemctl is-active rsyslog\", \"register\": \"rsyslog_config\"}, {\"when\": [\"rsyslog_config is changed\", \"rsyslog_config.rc == 0\"], \"block\": [{\"name\": \"Forward logging to haproxy.log file\", \"blockinfile\": {\"content\": \"if $syslogfacility-text == \'{{facility}}\' and $programname == \'haproxy\' then -/var/log/containers/haproxy/haproxy.log\\n& stop\\n\", \"create\": true, \"path\": \"/etc/rsyslog.d/openstack-haproxy.conf\"}, \"vars\": {\"facility\": {\"get_param\": \"HAProxySyslogFacility\"}}, \"register\": \"logconfig\"}, {\"name\": \"restart rsyslog service after logging conf change\", \"service\": {\"name\": \"rsyslog\", \"state\": \"restarted\"}, \"when\": \"logconfig is changed\"}]}]}, {\"name\": \"Run puppet on the host to apply IPtables rules\", \"no_log\": true, \"when\": \"step|int == 1\", \"register\": \"puppet_host_outputs\", \"shell\": \"puppet apply {{ (puppet_debug|bool) | ternary(\'--debug --verbose\', \'\') }} --detailed-exitcodes --summarize --color=false \\\\\\n    --modulepath \'{{ puppet_modulepath }}\' --tags \'{{ puppet_tags }}\' -e \'{{ puppet_execute }}\'\\n\", \"changed_when\": \"puppet_host_outputs.rc == 2\", \"failed_when\": false, \"vars\": {\"puppet_execute\": \"include tripleo::profile::base::haproxy\", \"puppet_tags\": \"tripleo::firewall::rule\", \"puppet_modulepath\": \"/etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules\", \"puppet_debug\": {\"get_param\": \"ConfigDebug\"}}}, {\"name\": \"Debug output for task: Run puppet on the host to apply IPtables rules\", \"debug\": {\"var\": \"puppet_host_outputs.stdout_lines | default([]) | union(puppet_host_outputs.stderr_lines | default([]))\"}, \"when\": [\"not (ansible_check_mode | bool)\", \"puppet_host_outputs.rc is defined\"], \"failed_when\": \"puppet_host_outputs.rc not in [0, 2]\"}], {\"if\": [\"public_tls_enabled\", {\"get_attr\": [\"HAProxyPublicTLS\", \"role_data\", \"deploy_steps_tasks\"]}]}, {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"get_attr\": [\"HAProxyInternalTLS\", \"role_data\", \"deploy_steps_tasks\"]}]}]}, \"upgrade_tasks\": [{\"name\": \"ensure we have haproxy log dir with the correct setype\", \"file\": {\"path\": \"/var/log/containers/haproxy\", \"state\": \"directory\", \"setype\": \"var_log_t\", \"recurse\": true}, \"when\": \"step|int == 1\"}], \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop haproxy container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"haproxy\"], \"tripleo_delegate_to\": \"{{ groups[\'haproxy\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}], \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"HAProxyPublicTLS\", \"role_data\", \"host_prep_tasks\"]}, [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/haproxy\", \"setype\": \"var_log_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/haproxy\", \"setype\": \"container_file_t\"}]}]]}, \"metadata_settings\": {\"list_concat\": [{\"get_attr\": [\"HAProxyPublicTLS\", \"role_data\", \"metadata_settings\"]}, {\"get_attr\": [\"HAProxyInternalTLS\", \"role_data\", \"metadata_settings\"]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(115,'2026-06-10 07:47:02',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Glance internal service configured with Puppet\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"GlanceApiInternalLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.glance.api\", \"file\": \"/var/log/containers/glance/api_internal.log\"}}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"GlanceNetappNfsEnabled\": {\"default\": false, \"description\": \"When using GlanceBackend \'file\', Netapp mount NFS share for image storage.\\n\", \"type\": \"boolean\"}, \"ContainerGlanceApiImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\"}, \"ContainerGlanceApiInternalConfigImage\": {\"description\": \"The container image to use for the glance_api_internal config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\"}}, \"resources\": {\"GlanceApi\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}, \"EnableInternalTLS\": {\"get_param\": \"EnableInternalTLS\"}}}, \"MySQLClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\"}, \"GlanceLogging\": {\"type\": \"OS::TripleO::Services::Logging::GlanceApi\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerGlanceApiImage\": \"ContainerGlanceApiImage\", \"ContainerGlanceApiInternalConfigImage\": \"ContainerGlanceApiInternalConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerGlanceApiImage\": {\"get_param\": \"ContainerGlanceApiImage\"}, \"ContainerGlanceApiInternalConfigImage\": {\"get_param\": \"ContainerGlanceApiInternalConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the internal Glance API.\", \"value\": {\"map_merge\": [{\"get_attr\": [\"GlanceApi\", \"role_data\"]}, {\"service_name\": \"glance_api_internal\", \"firewall_rules\": {\"112 glance_api_internal\": {\"dport\": [{\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"port\"]}]}}, \"firewall_frontend_rules\": {\"100 glance_api_internal_haproxy_frontend\": {\"dport\": [{\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"port\"]}]}}, \"keystone_resources\": {}, \"config_settings\": {\"get_attr\": [\"GlanceApi\", \"role_data\", \"config_settings\"]}, \"service_config_settings\": {\"map_merge\": [{\"get_attr\": [\"GlanceApi\", \"role_data\", \"service_config_settings\"]}, {\"rsyslog\": {\"tripleo_logging_sources_glance_api_internal\": [{\"get_param\": \"GlanceApiInternalLoggingSource\"}]}}]}, \"puppet_config\": {\"config_volume\": \"glance_api_internal\", \"puppet_tags\": \"glance_api_config,glance_api_paste_ini,glance_swift_config,glance_cache_config,glance_image_import_config\", \"step_config\": {\"list_join\": [\"\\n\", [{\"str_replace\": {\"template\": \"class { \'tripleo::profile::base::glance::api\':\\n  bind_port => PORT,\\n  tls_proxy_port => PORT,\\n  log_file => \'/var/log/glance/api_internal.log\',\\n  show_image_direct_url => true,\\n  show_multiple_locations => true,\\n}\\n\", \"params\": {\"PORT\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"port\"]}}}}, {\"if\": [{\"get_param\": \"GlanceNetappNfsEnabled\"}, \"include tripleo::profile::base::glance::netapp\"]}, {\"get_attr\": [\"MySQLClient\", \"role_data\", \"step_config\"]}]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerGlanceApiInternalConfigImage\"]}}, \"docker_config\": {\"step_2\": {\"get_attr\": [\"GlanceLogging\", \"docker_config\", \"step_2\"]}, \"step_4\": {\"glance_api_internal\": {\"map_merge\": [{\"get_attr\": [\"GlanceApi\", \"role_data\", \"docker_config\", \"step_4\", \"glance_api\"]}, {\"volumes\": {\"yaql\": {\"expression\": \"$.data.vols.select($.replace(\'puppet-generated/glance_api\', \'puppet-generated/glance_api_internal\'))\", \"data\": {\"vols\": {\"get_attr\": [\"GlanceApi\", \"role_data\", \"docker_config\", \"step_4\", \"glance_api\", \"volumes\"]}}}}}]}, \"glance_api_internal_tls_proxy\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"map_merge\": [{\"get_attr\": [\"GlanceApi\", \"role_data\", \"docker_config\", \"step_4\", \"glance_api_tls_proxy\"]}, {\"volumes\": {\"yaql\": {\"expression\": \"$.data.vols.select($.replace(\'puppet-generated/glance_api\', \'puppet-generated/glance_api_internal\'))\", \"data\": {\"vols\": {\"get_attr\": [\"GlanceApi\", \"role_data\", \"docker_config\", \"step_4\", \"glance_api_tls_proxy\", \"volumes\"]}}}}}]}]}}}, \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop glance api internal container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"glance_api_internal\"], \"tripleo_delegate_to\": \"{{ groups[\'glance_api_internal\'] | default([]) }}\"}}]}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (116,'2026-06-10 07:47:02',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Openstack Heat base service. Shared for all Heat services.\\n\", \"parameters\": {\"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"HeatDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Heat services.\", \"type\": \"boolean\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"HeatPassword\": {\"description\": \"The password for the Heat service and db account, used by the Heat services.\", \"type\": \"string\", \"hidden\": true, \"default\": \"bFBTZhN5CyNCch5KSkr70C02s\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableCache\": {\"description\": \"Enable caching with memcached\", \"type\": \"boolean\", \"default\": true}, \"HeatCronPurgeDeletedEnsure\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Ensure\\n\", \"default\": \"present\"}, \"HeatCronPurgeDeletedMinute\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Minute\\n\", \"default\": \"1\"}, \"HeatCronPurgeDeletedHour\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Hour\\n\", \"default\": \"0\"}, \"HeatCronPurgeDeletedMonthday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month Day\\n\", \"default\": \"*\"}, \"HeatCronPurgeDeletedMonth\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month\\n\", \"default\": \"*\"}, \"HeatCronPurgeDeletedWeekday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Week Day\\n\", \"default\": \"*\"}, \"HeatCronPurgeDeletedMaxDelay\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Max Delay\\n\", \"default\": \"3600\"}, \"HeatCronPurgeDeletedUser\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - User\\n\", \"default\": \"heat\"}, \"HeatCronPurgeDeletedAge\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Age\\n\", \"default\": \"30\"}, \"HeatCronPurgeDeletedAgeType\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Age type\\n\", \"default\": \"days\"}, \"HeatCronPurgeDeletedDestination\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Log destination\\n\", \"default\": \"/dev/null\"}, \"HeatYaqlLimitIterators\": {\"type\": \"number\", \"description\": \"The maximum number of elements in collection yaql expressions can take for its evaluation.\\n\", \"default\": 1000}, \"HeatYaqlMemoryQuota\": {\"type\": \"number\", \"description\": \"The maximum size of memory in bytes that yaql exrpessions can take for its evaluation.\\n\", \"default\": 100000}, \"HeatMaxJsonBodySize\": {\"default\": 4194304, \"description\": \"Maximum raw byte size of the Heat API JSON request body.\", \"type\": \"number\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"noop\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"HeatCorsAllowedOrigin\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Indicate whether this resource may be shared with the domain received in the request \\\"origin\\\" header.\"}, \"MemcachedTLS\": {\"default\": false, \"description\": \"Set to True to enable TLS on Memcached service. Because not all services support Memcached TLS, during the migration period, Memcached will listen on 2 ports - on the port set with MemcachedPort parameter (above) and on 11211, without TLS.\", \"type\": \"boolean\"}, \"MemcacheUseAdvancedPool\": {\"type\": \"boolean\", \"description\": \"Use the advanced (eventlet safe) memcached client pool.\\n\", \"default\": true}, \"HeatApiPolicies\": {\"description\": \"A hash of policies to configure for Heat API.\\ne.g. { heat-context_is_admin: { key: context_is_admin, value: \'role:admin\' } }\\n\", \"default\": {}, \"type\": \"json\"}, \"EnforceSecureRbac\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Setting this option to True will configure each OpenStack service to enforce Secure RBAC by setting `[oslo_policy] enforce_new_defaults` and `[oslo_policy] enforce_scope` to True. This introduces a consistent set of RBAC personas across OpenStack services that include support for system and project scope, as well as keystone\'s default roles, admin, member, and reader. Do not enable this functionality until all services in your deployment actually support secure RBAC.\"}}, \"conditions\": {\"tls_cache_enabled\": {\"and\": [{\"get_param\": \"EnableCache\"}, {\"get_param\": \"MemcachedTLS\"}]}, \"cors_allowed_origin_set\": {\"not\": {\"equals\": [{\"get_param\": \"HeatCorsAllowedOrigin\"}, \"\"]}}}, \"outputs\": {\"role_data\": {\"description\": \"Shared role data for the Heat services.\", \"value\": {\"service_name\": \"heat_base\", \"config_settings\": {\"map_merge\": [{\"if\": [{\"get_param\": \"EnforceSecureRbac\"}, {\"heat::policy::enforce_scope\": true, \"heat::policy::enforce_new_defaults\": true}]}, {\"if\": [\"cors_allowed_origin_set\", {\"heat::cors::allowed_origin\": {\"get_param\": \"HeatCorsAllowedOrigin\"}}]}, {\"heat::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"heat::logging::debug\": {\"if\": [{\"get_param\": \"HeatDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"heat::policy::policies\": {\"get_param\": \"HeatApiPolicies\"}, \"heat::enable_proxy_headers_parsing\": true, \"heat::rpc_response_timeout\": 600, \"heat::rabbit_heartbeat_timeout_threshold\": 60, \"heat::rabbit_heartbeat_in_pthread\": false, \"heat::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"heat::keystone::authtoken::project_name\": \"service\", \"heat::keystone::authtoken::user_domain_name\": \"Default\", \"heat::keystone::authtoken::project_domain_name\": \"Default\", \"heat::keystone::authtoken::www_authenticate_uri\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"uri_no_suffix\"]}, \"heat::keystone::authtoken::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"heat::keystone::authtoken::password\": {\"get_param\": \"HeatPassword\"}, \"heat::keystone::authtoken::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"heat::keystone::authtoken::interface\": \"internal\", \"heat::keystone::authtoken::memcache_use_advanced_pool\": {\"get_param\": \"MemcacheUseAdvancedPool\"}, \"heat::keystone::domain::domain_name\": \"heat_stack\", \"heat::keystone::domain::domain_admin\": \"heat_stack_domain_admin\", \"heat::keystone::domain::domain_admin_email\": \"heat_stack_domain_admin@localhost\", \"heat::db::database_db_max_retries\": -1, \"heat::db::database_max_retries\": -1, \"heat::yaql_memory_quota\": {\"get_param\": \"HeatYaqlMemoryQuota\"}, \"heat::yaql_limit_iterators\": {\"get_param\": \"HeatYaqlLimitIterators\"}, \"heat::cors::max_age\": 3600, \"heat::cors::allow_headers\": \"Content-Type,Cache-Control,Content-Language,Expires,Last-Modified,Pragma,X-Auth-Token\", \"heat::cors::expose_headers\": \"Content-Type,Cache-Control,Content-Language,Expires,Last-Modified,Pragma\", \"heat::cron::purge_deleted::ensure\": {\"get_param\": \"HeatCronPurgeDeletedEnsure\"}, \"heat::cron::purge_deleted::minute\": {\"get_param\": \"HeatCronPurgeDeletedMinute\"}, \"heat::cron::purge_deleted::hour\": {\"get_param\": \"HeatCronPurgeDeletedHour\"}, \"heat::cron::purge_deleted::monthday\": {\"get_param\": \"HeatCronPurgeDeletedMonthday\"}, \"heat::cron::purge_deleted::month\": {\"get_param\": \"HeatCronPurgeDeletedMonth\"}, \"heat::cron::purge_deleted::weekday\": {\"get_param\": \"HeatCronPurgeDeletedWeekday\"}, \"heat::cron::purge_deleted::maxdelay\": {\"get_param\": \"HeatCronPurgeDeletedMaxDelay\"}, \"heat::cron::purge_deleted::user\": {\"get_param\": \"HeatCronPurgeDeletedUser\"}, \"heat::cron::purge_deleted::age\": {\"get_param\": \"HeatCronPurgeDeletedAge\"}, \"heat::cron::purge_deleted::age_type\": {\"get_param\": \"HeatCronPurgeDeletedAgeType\"}, \"heat::cron::purge_deleted::destination\": {\"get_param\": \"HeatCronPurgeDeletedDestination\"}, \"heat::max_json_body_size\": {\"get_param\": \"HeatMaxJsonBodySize\"}}, {\"heat::cache::enabled\": {\"get_param\": \"EnableCache\"}, \"heat::cache::tls_enabled\": {\"get_param\": \"MemcachedTLS\"}, \"heat::cache::resource_finder_caching\": false}, {\"if\": [\"tls_cache_enabled\", {\"heat::cache::backend\": \"dogpile.cache.pymemcache\"}, {\"heat::cache::backend\": \"dogpile.cache.memcached\"}]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(117,'2026-06-10 07:47:03',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"HAProxy deployment with TLS enabled, with an injected certificate\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"SSLCertificate\": {\"default\": \"\", \"description\": \"The content of the SSL certificate (without Key) in PEM format.\\n\", \"type\": \"string\"}, \"SSLIntermediateCertificate\": {\"default\": \"\", \"description\": \"The content of an SSL intermediate CA certificate in PEM format.\\n\", \"type\": \"string\"}, \"SSLKey\": {\"default\": \"\", \"description\": \"The content of the SSL Key in PEM format.\\n\", \"type\": \"string\", \"hidden\": true}, \"DeployedSSLCertificatePath\": {\"default\": \"/etc/pki/tls/private/overcloud_endpoint.pem\", \"description\": \"The filepath of the certificate as it will be stored in the controller.\\n\", \"type\": \"string\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the HAProxy public TLS injection.\", \"value\": {\"service_name\": \"haproxy_public_tls_inject\", \"config_settings\": {}, \"certificates_specs\": {}, \"metadata_settings\": null, \"host_prep_tasks\": [{\"name\": \"get parameters\", \"set_fact\": {\"cert_path\": {\"get_param\": \"DeployedSSLCertificatePath\"}, \"cert_content\": {\"get_param\": \"SSLCertificate\"}, \"chain_content\": {\"get_param\": \"SSLIntermediateCertificate\"}, \"key_content\": {\"get_param\": \"SSLKey\"}}, \"no_log\": \"{{ hide_sensitive_logs | bool }}\"}, {\"name\": \"manage certificate\", \"when\": [\"cert_content is defined\", \"cert_content != \'\'\"], \"block\": [{\"name\": \"get DeployedSSLCertificatePath attributes\", \"register\": \"attr_cert_path\", \"stat\": {\"path\": \"{{cert_path}}\"}}, {\"name\": \"set is_haproxy_bootstrap_node fact\", \"set_fact\": \"is_haproxy_bootstrap_node={{haproxy_short_bootstrap_node_name | lower == ansible_facts[\'hostname\'] | lower}}\", \"when\": [\"haproxy_short_bootstrap_node_name|default(false)\"]}, {\"name\": \"get haproxy status\", \"register\": \"haproxy_state\", \"systemd\": {\"name\": \"haproxy\"}}, {\"name\": \"get pacemaker status\", \"register\": \"pacemaker_state\", \"systemd\": {\"name\": \"pacemaker\"}}, {\"name\": \"get docker status\", \"register\": \"docker_state\", \"systemd\": {\"name\": \"docker\"}}, {\"name\": \"get container_id\", \"when\": [\"docker_state.status.ActiveState == \'active\' or container_cli == \'podman\'\", \"attr_cert_path.stat.exists\", \"attr_cert_path.stat.isdir == False\"], \"command\": \"{{ container_cli }} ps -q -f name=\'^haproxy(-bundle)?\'\", \"register\": \"container_id\"}, {\"name\": \"get pcs resource name for haproxy container\", \"when\": [\"bootstrap_node is defined\", \"is_haproxy_bootstrap_node\", \"pacemaker_state.status.ActiveState == \'active\'\", \"attr_cert_path.stat.exists\", \"attr_cert_path.stat.isdir\"], \"shell\": \"pcs status resources | sed -n \'s/^.*container.*: \\\\(haproxy.*\\\\) .*/\\\\1/p\'\\n\", \"register\": \"pacemaker_resource\"}, {\"name\": \"remove DeployedSSLCertificatePath if is dir\", \"when\": \"attr_cert_path.stat.isdir is defined and attr_cert_path.stat.isdir\", \"file\": {\"path\": \"{{cert_path}}\", \"state\": \"absent\"}}, {\"name\": \"push certificate content\", \"no_log\": \"{{ hide_sensitive_logs | bool }}\", \"copy\": {\"dest\": \"{{cert_path}}\", \"mode\": 288, \"owner\": \"root\", \"content\": \"{{cert_content}}\\n{{chain_content}}\\n{{key_content}}\\n\"}}, {\"name\": \"BM haproxy non-pacemaker context\", \"when\": \"haproxy_state.status.ActiveState == \'active\'\", \"block\": [{\"name\": \"set certificate ownership\", \"file\": {\"path\": \"{{cert_path}}\", \"group\": \"haproxy\"}}, {\"name\": \"reload haproxy if enabled\", \"service\": {\"name\": \"haproxy\", \"state\": \"reloaded\"}}]}, {\"name\": \"restart pacemaker resource for haproxy\", \"when\": [\"pacemaker_resource is defined\", \"pacemaker_resource.stdout is defined\", \"pacemaker_resource.stdout != \'\'\"], \"command\": \"pcs resource restart \\\"{{pacemaker_resource.stdout}}\\\"\"}, {\"name\": \"dedicated part for containers\", \"when\": [\"container_id is defined\", \"container_id.stdout is defined\", \"container_id.stdout != \'\'\"], \"block\": [{\"name\": \"copy certificate, chgrp, restart haproxy\", \"shell\": \"set -e\\nif {{ container_cli }} ps -f \\\"id={{ item }}\\\" --format \\\"{{ \'{{\' }}.Names{{ \'}}\' }}\\\" | grep -q \\\"^haproxy-bundle\\\"; then\\n  tar -c {{ cert_path }} | {{container_cli}} exec -i {{ item }} tar -C / -xv\\nelse\\n  {{ container_cli }} cp {{ cert_path }} {{ item }}:{{ cert_path }}\\nfi\\n{{ container_cli }} exec --user root {{ item }} chgrp haproxy {{ cert_path }}\\n{{ container_cli }} kill --signal=HUP {{ item }}\\n\", \"register\": \"container_kill_result\", \"failed_when\": [\"container_kill_result.rc != 0\", \"(\\\"no such container\\\" not in container_kill_result.stderr)\", \"(\\\"container state improper\\\" not in container_kill_result.stderr)\"], \"with_items\": \"{{ container_id.stdout.split(\'\\n\') }}\"}]}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(118,'2026-06-10 07:47:03',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Glance API service\\n\", \"parameters\": {\"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ContainerGlanceApiImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\"}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerGlanceApiImage\": \"ContainerGlanceApiImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerGlanceApiImage\": {\"get_param\": \"ContainerGlanceApiImage\"}}}]}}}}, \"outputs\": {\"config_settings\": {\"description\": \"Extra hieradata needed to log to files in the host.\", \"value\": null}, \"volumes\": {\"description\": \"The volumes needed to log to files in the host.\", \"value\": [\"/var/log/containers/glance:/var/log/glance:z\", \"/var/log/containers/httpd/glance:/var/log/httpd:z\"]}, \"docker_config\": {\"description\": \"Extra containers needed for logging to files in the host.\", \"value\": {\"step_2\": {\"glance_init_logs\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerGlanceApiImage\"]}, \"net\": \"none\", \"privileged\": false, \"user\": \"root\", \"volumes\": [\"/var/log/containers/glance:/var/log/glance:z\", \"/var/log/containers/httpd/glance:/var/log/httpd:z\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R glance:glance /var/log/glance\"]}}}}, \"host_prep_tasks\": {\"description\": \"Extra ansible tasks needed for logging to files in the host.\", \"value\": [{\"name\": \"create persistent logs directory\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/glance\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/log/containers/httpd/glance\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}]}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(119,'2026-06-10 07:47:04',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(120,'2026-06-10 07:47:04',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized HAProxy API service\\n\", \"outputs\": {\"config_settings\": {\"description\": \"Extra hieradata needed to log to files in the host.\", \"value\": null}, \"volumes\": {\"description\": \"The volumes needed to log to files in the host.\", \"value\": null}, \"docker_config\": {\"description\": \"Extra containers needed for logging to files in the host.\", \"value\": {\"step_1\": {}}}, \"host_prep_tasks\": {\"description\": \"Extra ansible tasks needed for logging to files in the host.\", \"value\": null}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(121,'2026-06-10 07:47:04',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Glance service configured with Puppet\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"DeployIdentifier\": {\"default\": 1781077560, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}, \"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"GlanceDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Glance service.\", \"type\": \"boolean\"}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}, \"GlancePassword\": {\"description\": \"The password for the glance service and db account, used by the glance services.\", \"type\": \"string\", \"hidden\": true, \"default\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\"}, \"GlanceWorkers\": {\"default\": 1, \"description\": \"Number of API worker processes for Glance. If left unset (empty string), the\\ndefault value will result in the configuration being left unset and a\\nsystem-dependent default value will be chosen (e.g.: number of\\nprocessors). Please note that this will create a large number of\\nprocesses on systems with a large number of CPUs resulting in excess\\nmemory consumption. It is recommended that a suitable non-default value\\nbe selected on such systems.\\n\", \"type\": \"string\"}, \"MonitoringSubscriptionGlanceApi\": {\"default\": \"overcloud-glance-api\", \"type\": \"string\"}, \"GlanceApiLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.glance.api\", \"file\": \"/var/log/containers/glance/api.log\"}}, \"GlanceImageMemberQuota\": {\"default\": 128, \"description\": \"Maximum number of image members per image.\\nNegative values evaluate to unlimited.\\n\", \"type\": \"number\"}, \"GlanceNfsEnabled\": {\"default\": false, \"description\": \"When using GlanceBackend \'file\', mount NFS share for image storage.\\n\", \"type\": \"boolean\"}, \"GlanceCacheEnabled\": {\"description\": \"Enable Glance Image Cache\", \"type\": \"boolean\", \"default\": false}, \"GlanceImageCacheDir\": {\"description\": \"Base directory that the Image Cache uses\", \"type\": \"string\", \"default\": \"/var/lib/glance/image-cache\"}, \"GlanceImageCacheMaxSize\": {\"description\": \"The upper limit on cache size, in bytes, after which the cache-pruner cleans up the image cache.\\n\", \"type\": \"number\", \"default\": 10737418240}, \"GlanceImageCacheStallTime\": {\"description\": \"The amount of time, in seconds, to let an image remain in the cache without being accessed.\\n\", \"type\": \"number\", \"default\": 86400}, \"GlanceImagePrefetcherInterval\": {\"description\": \"The interval in seconds to run periodic job cache_images.\\n\", \"type\": \"number\", \"default\": 300}, \"GlanceNfsShare\": {\"default\": \"\", \"description\": \"NFS share to mount for image storage (when GlanceNfsEnabled is true)\\n\", \"type\": \"string\"}, \"GlanceNetappNfsEnabled\": {\"default\": false, \"description\": \"When using GlanceBackend \'file\', Netapp mount NFS share for image storage.\\n\", \"type\": \"boolean\"}, \"NetappShareLocation\": {\"default\": \"\", \"description\": \"Netapp share to mount for image storage (when GlanceNetappNfsEnabled is true)\\n\", \"type\": \"string\"}, \"GlanceNfsOptions\": {\"default\": \"_netdev,bg,intr,context=system_u:object_r:container_file_t:s0\", \"description\": \"NFS mount options for image storage (when GlanceNfsEnabled is true)\\n\", \"type\": \"string\"}, \"GlanceRbdPoolName\": {\"default\": \"images\", \"type\": \"string\"}, \"NovaEnableRbdBackend\": {\"default\": false, \"description\": \"Whether to enable the Rbd backend for Nova ephemeral storage.\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"GlanceImageImportPlugins\": {\"default\": [\"no_op\"], \"description\": \"List of enabled Image Import Plugins. Valid values in the list are \'image_conversion\', \'inject_metadata\', \'no_op\'.\\n\", \"type\": \"comma_delimited_list\"}, \"GlanceDiskFormats\": {\"default\": \"\", \"description\": \"List of allowed disk formats in Glance; all formats are allowed when left unset.\\n\", \"type\": \"comma_delimited_list\"}, \"GlanceImageConversionOutputFormat\": {\"default\": \"raw\", \"description\": \"Desired output format for image conversion plugin.\", \"type\": \"string\"}, \"GlanceInjectMetadataProperties\": {\"default\": \"\", \"description\": \"Metadata properties to be injected in image.\", \"type\": \"comma_delimited_list\"}, \"GlanceIgnoreUserRoles\": {\"default\": \"admin\", \"description\": \"List of user roles to be ignored for injecting image metadata properties.\", \"type\": \"comma_delimited_list\"}, \"GlanceEnabledImportMethods\": {\"default\": \"web-download\", \"description\": \"List of enabled Image Import Methods. Valid values in the list are \'glance-direct\', \'web-download\', or \'copy-image\'\\n\", \"type\": \"comma_delimited_list\"}, \"GlanceStagingNfsShare\": {\"default\": \"\", \"description\": \"NFS share to mount for image import staging\\n\", \"type\": \"string\"}, \"GlanceNodeStagingUri\": {\"default\": \"file:///var/lib/glance/staging\", \"description\": \"URI that specifies the staging location to use when importing images\\n\", \"type\": \"string\"}, \"GlanceStagingNfsOptions\": {\"default\": \"_netdev,bg,intr,context=system_u:object_r:container_file_t:s0\", \"description\": \"NFS mount options for NFS image import staging\\n\", \"type\": \"string\"}, \"GlanceSparseUploadEnabled\": {\"default\": false, \"description\": \"When using GlanceBackend \'file\' and \'rbd\' to enable or not sparse upload.\\n\", \"type\": \"boolean\"}, \"EnforceSecureRbac\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Setting this option to True will configure each OpenStack service to enforce Secure RBAC by setting `[oslo_policy] enforce_new_defaults` and `[oslo_policy] enforce_scope` to True. This introduces a consistent set of RBAC personas across OpenStack services that include support for system and project scope, as well as keystone\'s default roles, admin, member, and reader. Do not enable this functionality until all services in your deployment actually support secure RBAC.\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"GlanceApiPolicies\": {\"description\": \"A hash of policies to configure for Glance API.\\ne.g. { glance-context_is_admin: { key: context_is_admin, value: \'role:admin\' } }\\n\", \"default\": {}, \"type\": \"json\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"noop\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"GlanceNotifierStrategy\": {\"description\": \"Strategy to use for Glance notification queue\", \"type\": \"string\", \"default\": \"noop\"}, \"GlanceLogFile\": {\"description\": \"The filepath of the file to use for logging messages from Glance.\", \"type\": \"string\", \"default\": \"\"}, \"GlanceBackend\": {\"default\": \"swift\", \"description\": \"The short name of the Glance backend to use. Should be one of swift, rbd, cinder, or file\", \"type\": \"string\", \"constraints\": [{\"allowed_values\": [\"swift\", \"file\", \"rbd\", \"cinder\"]}]}, \"GlanceBackendID\": {\"type\": \"string\", \"default\": \"default_backend\", \"description\": \"The default backend\'s identifier.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9_-]+\"}]}, \"GlanceStoreDescription\": {\"type\": \"string\", \"default\": \"Default glance store backend.\", \"description\": \"User facing description for the Glance backend.\"}, \"GlanceMultistoreConfig\": {\"type\": \"json\", \"default\": {}, \"description\": \"Dictionary of settings when configuring additional glance backends. The\\nhash key is the backend ID, and the value is a dictionary of parameter\\nvalues unique to that backend. Multiple rbd and cinder backends are allowed, but\\nfile and swift backends are limited to one each. Example:\\n  # Default glance store is rbd.\\n  GlanceBackend: rbd\\n  GlanceStoreDescription: \'Default rbd store\'\\n  # GlanceMultistoreConfig specifies a second rbd backend, plus a cinder\\n  # backend.\\n  GlanceMultistoreConfig:\\n    rbd2_store:\\n      GlanceBackend: rbd\\n      GlanceStoreDescription: \'Second rbd store\'\\n      CephClusterName: ceph2\\n      # Override CephClientUserName if this cluster uses a different\\n      # client name.\\n      CephClientUserName: client2\\n    cinder1_store:\\n      GlanceBackend: cinder\\n      GlanceCinderVolumeType: \'volume-type-1\'\\n      GlanceStoreDescription: \'First cinder store\'\\n    cinder2_store:\\n      GlanceBackend: cinder\\n      GlanceCinderVolumeType: \'volume-type-2\'\\n      GlanceStoreDescription: \'Seconde cinder store\'\\n\"}, \"GlanceCinderMountPointBase\": {\"default\": \"/var/lib/glance/mnt\", \"type\": \"string\", \"description\": \"The mount point base when glance is using cinder as store and cinder backend\\nis NFS. This mount point is where the NFS volume is mounted on the glance node.\\n\"}, \"GlanceCinderVolumeType\": {\"default\": \"\", \"type\": \"string\", \"description\": \"A unique volume type required for each cinder store while configuring multiple cinder\\nstores as glance backends. The same volume types must be configured in Cinder as well.\\nThe volume type must exist in cinder prior to any attempt to add an image in the associated\\ncinder store. If no volume type is specified then cinder\'s default volume type will be used.\\n\"}, \"GlanceCinderLockPath\": {\"default\": \"/var/lib/cinder/tmp\", \"type\": \"string\", \"description\": \"The oslo.coordination lock_path to use when glance is using cinder as a store. Using\\ncinder\'s lock_path ensures os-brick operations are synchronized across both services.\\n\"}, \"CephClientUserName\": {\"default\": \"openstack\", \"type\": \"string\"}, \"CephClusterName\": {\"type\": \"string\", \"default\": \"ceph\", \"description\": \"The Ceph cluster name.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9]+\", \"description\": \"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\n\"}]}, \"CephConfigPath\": {\"type\": \"string\", \"default\": \"/var/lib/tripleo-config/ceph\", \"description\": \"The path where the Ceph Cluster config files are stored on the host.\\n\"}, \"MultipathdEnable\": {\"default\": false, \"description\": \"Whether to enable the multipath daemon\", \"type\": \"boolean\"}, \"GlanceApiOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\"}, \"ContainerGlanceApiImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\"}, \"ContainerGlanceApiConfigImage\": {\"description\": \"The container image to use for the glance_api config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\"}, \"GlanceCronDbPurgeMinute\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Minute\\n\", \"default\": \"1\"}, \"GlanceCronDbPurgeHour\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Hour\\n\", \"default\": \"0\"}, \"GlanceCronDbPurgeMonthday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month Day\\n\", \"default\": \"*\"}, \"GlanceCronDbPurgeMonth\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month\\n\", \"default\": \"*\"}, \"GlanceCronDbPurgeWeekday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Week Day\\n\", \"default\": \"*\"}, \"GlanceCronDbPurgeUser\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - User\\n\", \"default\": \"glance\"}, \"GlanceCronDbPurgeAge\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Age\\n\", \"default\": \"30\"}, \"GlanceCronDbPurgeMaxRows\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Max Rows\\n\", \"default\": \"100\"}, \"GlanceCronDbPurgeDestination\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Log destination\\n\", \"default\": \"/var/log/glance/glance-rowsflush.log\"}, \"GlanceCronDbPurgeMaxDelay\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Max Delay\\n\", \"default\": \"3600\"}, \"MemcacheUseAdvancedPool\": {\"type\": \"boolean\", \"description\": \"Use the advanced (eventlet safe) memcached client pool.\\n\", \"default\": true}, \"GlanceShowMultipleLocations\": {\"default\": false, \"description\": \"Whether to show multiple image locations e.g for copy-on-write support on\\nRBD or Netapp backends. Potential security risk, see glance.conf for more information.\\n\", \"type\": \"boolean\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"The following parameters are deprecated and will be removed. They should not\\nbe relied on for new deployments.\\n\", \"parameters\": [\"GlanceShowMultipleLocations\"]}], \"conditions\": {\"cinder_backend_enabled\": {\"or\": [{\"equals\": [{\"get_param\": \"GlanceBackend\"}, \"cinder\"]}, {\"yaql\": {\"expression\": \"$.data.values().any($.get(\\\"GlanceBackend\\\", \\\"\\\") = \\\"cinder\\\")\", \"data\": {\"get_param\": \"GlanceMultistoreConfig\"}}}]}, \"cinder_multipathd_enabled\": {\"and\": [\"cinder_backend_enabled\", {\"get_param\": \"MultipathdEnable\"}]}, \"rbd_backend_enabled\": {\"or\": [{\"equals\": [{\"get_param\": \"GlanceBackend\"}, \"rbd\"]}, {\"yaql\": {\"expression\": \"$.data.values().any($.get(\\\"GlanceBackend\\\", \\\"\\\") = \\\"rbd\\\")\", \"data\": {\"get_param\": \"GlanceMultistoreConfig\"}}}]}, \"force_image_conversion_plugin\": {\"or\": [{\"and\": [\"rbd_backend_enabled\", {\"equals\": [{\"get_param\": \"GlanceImageImportPlugins\"}, [\"no_op\"]]}, {\"get_param\": \"NovaEnableRbdBackend\"}]}, {\"get_param\": \"GlanceSparseUploadEnabled\"}]}, \"glance_workers_set\": {\"not\": {\"equals\": [{\"get_param\": \"GlanceWorkers\"}, \"\"]}}, \"glance_multiple_locations\": {\"or\": [{\"get_param\": \"GlanceShowMultipleLocations\"}, {\"get_param\": \"GlanceNetappNfsEnabled\"}, {\"and\": [\"rbd_backend_enabled\", {\"get_param\": \"NovaEnableRbdBackend\"}]}]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MySQLClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\"}, \"GlanceLogging\": {\"type\": \"OS::TripleO::Services::Logging::GlanceApi\"}, \"CinderNVMeOF\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml\"}, \"TLSProxyBase\": {\"type\": \"OS::TripleO::Services::TLSProxyBase\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}, \"EnableInternalTLS\": {\"get_param\": \"EnableInternalTLS\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerGlanceApiImage\": \"ContainerGlanceApiImage\", \"ContainerGlanceApiConfigImage\": \"ContainerGlanceApiConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerGlanceApiImage\": {\"get_param\": \"ContainerGlanceApiImage\"}, \"ContainerGlanceApiConfigImage\": {\"get_param\": \"ContainerGlanceApiConfigImage\"}}}]}}}}, \"outputs\": {\"glance_api_host_prep_and_system_upgrade_post_tasks\": {\"description\": \"Common host_prep and system_upgrade post tasks for glance_api\", \"value\": [{\"name\": \"Mount NFS on host\", \"vars\": {\"nfs_backend_enabled\": {\"get_param\": \"GlanceNfsEnabled\"}, \"glance_netapp_nfs_enabled\": {\"get_param\": \"GlanceNetappNfsEnabled\"}, \"glance_nfs_share\": {\"get_param\": \"GlanceNfsShare\"}, \"netapp_share_location\": {\"get_param\": \"NetappShareLocation\"}, \"nfs_share\": \"{{ glance_nfs_share if (glance_nfs_share) else netapp_share_location }}\", \"nfs_options\": {\"get_param\": \"GlanceNfsOptions\"}}, \"mount\": {\"name\": \"/var/lib/glance/images\", \"state\": \"mounted\", \"fstype\": \"nfs\", \"src\": \"{{nfs_share}}\", \"opts\": \"{{nfs_options}}\"}, \"when\": \"nfs_backend_enabled or glance_netapp_nfs_enabled\"}, {\"name\": \"Mount Node Staging Location\", \"vars\": {\"glance_node_staging_uri\": {\"get_param\": \"GlanceNodeStagingUri\"}, \"glance_staging_nfs_share\": {\"get_param\": \"GlanceStagingNfsShare\"}, \"glance_nfs_options\": {\"get_param\": \"GlanceStagingNfsOptions\"}}, \"mount\": {\"name\": \"{{glance_node_staging_uri[7:]}}\", \"state\": \"mounted\", \"fstype\": \"nfs\", \"src\": \"{{glance_staging_nfs_share}}\", \"opts\": \"{{glance_nfs_options}}\"}, \"when\": \"glance_staging_nfs_share != \'\'\"}]}, \"role_data\": {\"description\": \"Role data for the Glance API role.\", \"value\": {\"service_name\": \"glance_api\", \"firewall_rules\": {\"112 glance_api\": {\"dport\": [9292]}}, \"firewall_frontend_rules\": {\"100 glance_api_haproxy_frontend\": {\"dport\": [9292]}}, \"firewall_ssl_frontend_rules\": {\"100 glance_api_haproxy_frontend_ssl\": {\"dport\": [13292]}}, \"keystone_resources\": {\"glance\": {\"endpoints\": {\"public\": {\"get_param\": [\"EndpointMap\", \"GlancePublic\", \"uri\"]}, \"internal\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"uri\"]}, \"admin\": {\"get_param\": [\"EndpointMap\", \"GlanceAdmin\", \"uri\"]}}, \"users\": {\"glance\": {\"password\": {\"get_param\": \"GlancePassword\"}}}, \"region\": {\"get_param\": \"KeystoneRegion\"}, \"service\": \"image\"}}, \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionGlanceApi\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"TLSProxyBase\", \"role_data\", \"config_settings\"]}, {\"glance::api::db::database_connection\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"protocol\"]}, \"username\": \"glance\", \"password\": {\"get_param\": \"GlancePassword\"}, \"host\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"host\"]}, \"path\": \"/glance\", \"query\": {\"if\": [{\"get_param\": \"EnableSQLAlchemyCollectd\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\", \"plugin\": \"collectd\", \"collectd_program_name\": \"glance\", \"collectd_host\": \"localhost\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\"}]}}}, \"glance::api::authtoken::www_authenticate_uri\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"uri_no_suffix\"]}, \"glance::api::authtoken::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"glance::api::enable_v1_api\": false, \"glance::api::enable_v2_api\": true, \"glance::api::authtoken::password\": {\"get_param\": \"GlancePassword\"}, \"glance::api::enable_proxy_headers_parsing\": true, \"glance::api::logging::debug\": {\"if\": [{\"get_param\": \"GlanceDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"glance::policy::policies\": {\"get_param\": \"GlanceApiPolicies\"}, \"glance::api::authtoken::project_name\": \"service\", \"glance::api::authtoken::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"glance::api::authtoken::user_domain_name\": \"Default\", \"glance::api::authtoken::project_domain_name\": \"Default\", \"glance::api::authtoken::interface\": \"internal\", \"glance::api::authtoken::memcache_use_advanced_pool\": {\"get_param\": \"MemcacheUseAdvancedPool\"}, \"glance::api::pipeline\": {\"if\": [{\"get_param\": \"GlanceCacheEnabled\"}, \"keystone+cachemanagement\", \"keystone\"]}, \"glance::api::os_region_name\": {\"get_param\": \"KeystoneRegion\"}, \"glance::api::image_member_quota\": {\"get_param\": \"GlanceImageMemberQuota\"}, \"glance::api::enabled_import_methods\": {\"get_param\": \"GlanceEnabledImportMethods\"}, \"glance::api::node_staging_uri\": {\"get_param\": \"GlanceNodeStagingUri\"}, \"glance::api::image_import_plugins\": {\"if\": [\"force_image_conversion_plugin\", {\"list_concat_unique\": [{\"get_param\": \"GlanceImageImportPlugins\"}, [\"image_conversion\"]]}, {\"get_param\": \"GlanceImageImportPlugins\"}]}, \"glance::api::image_conversion_output_format\": {\"get_param\": \"GlanceImageConversionOutputFormat\"}, \"glance::api::inject_metadata_properties\": {\"get_param\": \"GlanceInjectMetadataProperties\"}, \"glance::api::ignore_user_roles\": {\"get_param\": \"GlanceIgnoreUserRoles\"}, \"tripleo::profile::base::glance::api::tls_proxy_bind_ip\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}}}}, \"tripleo::profile::base::glance::api::tls_proxy_fqdn\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}}}}, \"tripleo::profile::base::glance::api::tls_proxy_port\": 9292, \"glance::api::bind_host\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, \"%{hiera(\'localhost_address\')}\", {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}}}}]}, \"glance_notifier_strategy\": {\"get_param\": \"GlanceNotifierStrategy\"}, \"glance_log_file\": {\"get_param\": \"GlanceLogFile\"}, \"glance::backend::rbd::rbd_thin_provisioning\": {\"get_param\": \"GlanceSparseUploadEnabled\"}, \"glance::backend::file::filesystem_thin_provisioning\": {\"get_param\": \"GlanceSparseUploadEnabled\"}, \"glance::backend::swift::swift_store_auth_address\": {\"get_param\": [\"EndpointMap\", \"KeystoneV3Internal\", \"uri\"]}, \"glance::backend::swift::swift_store_user\": \"service:glance\", \"glance::backend::swift::swift_store_key\": {\"get_param\": \"GlancePassword\"}, \"glance::backend::swift::swift_store_create_container_on_put\": true, \"glance::backend::swift::swift_store_auth_version\": 3, \"glance::backend::rbd::rbd_store_ceph_conf\": {\"list_join\": [\"\", [\"/etc/ceph/\", {\"get_param\": \"CephClusterName\"}, \".conf\"]]}, \"glance::backend::rbd::rbd_store_pool\": {\"get_param\": \"GlanceRbdPoolName\"}, \"glance::backend::rbd::rbd_store_user\": {\"get_param\": \"CephClientUserName\"}, \"glance_backend\": {\"get_param\": \"GlanceBackend\"}, \"tripleo::profile::base::glance::api::glance_backend_id\": {\"get_param\": \"GlanceBackendID\"}, \"tripleo::profile::base::glance::api::glance_store_description\": {\"get_param\": \"GlanceStoreDescription\"}, \"tripleo::profile::base::glance::api::multistore_config\": {\"get_param\": \"GlanceMultistoreConfig\"}, \"tripleo::profile::base::glance::backend::rbd::glance_rbd_ceph_conf_path\": {\"get_param\": \"CephConfigPath\"}, \"glance::notify::rabbitmq::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"glance::notify::rabbitmq::rabbit_heartbeat_in_pthread\": false, \"glance::cron::db_purge::minute\": {\"get_param\": \"GlanceCronDbPurgeMinute\"}, \"glance::cron::db_purge::hour\": {\"get_param\": \"GlanceCronDbPurgeHour\"}, \"glance::cron::db_purge::monthday\": {\"get_param\": \"GlanceCronDbPurgeMonthday\"}, \"glance::cron::db_purge::month\": {\"get_param\": \"GlanceCronDbPurgeMonth\"}, \"glance::cron::db_purge::weekday\": {\"get_param\": \"GlanceCronDbPurgeWeekday\"}, \"glance::cron::db_purge::user\": {\"get_param\": \"GlanceCronDbPurgeUser\"}, \"glance::cron::db_purge::age\": {\"get_param\": \"GlanceCronDbPurgeAge\"}, \"glance::cron::db_purge::max_rows\": {\"get_param\": \"GlanceCronDbPurgeMaxRows\"}, \"glance::cron::db_purge::destination\": {\"get_param\": \"GlanceCronDbPurgeDestination\"}, \"glance::cron::db_purge::maxdelay\": {\"get_param\": \"GlanceCronDbPurgeMaxDelay\"}}, {\"if\": [\"glance_workers_set\", {\"glance::api::workers\": {\"get_param\": \"GlanceWorkers\"}}]}, {\"if\": [{\"get_param\": \"EnforceSecureRbac\"}, {\"glance::api::enforce_secure_rbac\": true, \"glance::policy::enforce_new_defaults\": true}]}, {\"if\": [\"cinder_backend_enabled\", {\"glance::backend::cinder::cinder_store_auth_address\": {\"get_param\": [\"EndpointMap\", \"KeystoneV3Internal\", \"uri\"]}, \"glance::backend::cinder::cinder_store_project_name\": \"service\", \"glance::backend::cinder::cinder_store_user_name\": \"glance\", \"glance::backend::cinder::cinder_store_password\": {\"get_param\": \"GlancePassword\"}, \"glance::api::lock_path\": {\"get_param\": \"GlanceCinderLockPath\"}, \"tripleo::profile::base::glance::backend::cinder::cinder_mount_point_base\": {\"get_param\": \"GlanceCinderMountPointBase\"}, \"tripleo::profile::base::glance::backend::cinder::cinder_volume_type\": {\"get_param\": \"GlanceCinderVolumeType\"}}]}, {\"if\": [\"cinder_multipathd_enabled\", {\"glance::backend::cinder::cinder_use_multipath\": true}]}, {\"if\": [{\"get_param\": \"GlanceCacheEnabled\"}, {\"tripleo::profile::base::glance::api::glance_enable_cache\": true, \"glance::api::image_cache_dir\": {\"get_param\": \"GlanceImageCacheDir\"}, \"glance::api::image_cache_max_size\": {\"get_param\": \"GlanceImageCacheMaxSize\"}, \"glance::api::image_cache_stall_time\": {\"get_param\": \"GlanceImageCacheStallTime\"}, \"glance::api::cache_prefetcher_interval\": {\"get_param\": \"GlanceImagePrefetcherInterval\"}}]}, {\"if\": [{\"get_param\": \"GlanceNetappNfsEnabled\"}, {\"tripleo::profile::base::glance::netapp::netapp_share\": {\"get_param\": \"NetappShareLocation\"}, \"glance::api::filesystem_store_metadata_file\": \"/etc/glance/glance-metadata-file.json\", \"glance::api::filesystem_store_file_perm\": \"0644\"}]}, {\"if\": [{\"contains\": [\"glance-direct\", {\"get_param\": \"GlanceEnabledImportMethods\"}]}, {\"glance::api::worker_self_reference_url\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"str_replace\": {\"template\": \"https://%{hiera(\'fqdn_NETWORK\')}:PORT\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}, \"PORT\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"port\"]}}}}, {\"str_replace\": {\"template\": \"http://%{hiera(\'NETWORK_uri\')}:PORT\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}, \"PORT\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"port\"]}}}}]}}]}, {\"if\": [{\"not\": {\"equals\": [{\"get_param\": \"GlanceDiskFormats\"}, []]}}, {\"glance::api::disk_formats\": {\"get_param\": \"GlanceDiskFormats\"}}]}]}, \"service_config_settings\": {\"mysql\": {\"glance::db::mysql::password\": {\"get_param\": \"GlancePassword\"}, \"glance::db::mysql::user\": \"glance\", \"glance::db::mysql::host\": \"%\", \"glance::db::mysql::dbname\": \"glance\"}, \"rsyslog\": {\"tripleo_logging_sources_glance_api\": [{\"get_param\": \"GlanceApiLoggingSource\"}]}}, \"puppet_config\": {\"config_volume\": \"glance_api\", \"puppet_tags\": \"glance_api_config,glance_api_paste_ini,glance_swift_config,glance_cache_config,glance_image_import_config\", \"step_config\": {\"list_join\": [\"\\n\", [\"include tripleo::profile::base::glance::api\", {\"if\": [{\"get_param\": \"GlanceNetappNfsEnabled\"}, \"include tripleo::profile::base::glance::netapp\"]}, {\"get_attr\": [\"MySQLClient\", \"role_data\", \"step_config\"]}]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerGlanceApiConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/glance_api.json\": {\"command\": \"/usr/bin/glance-api --config-file /usr/share/glance/glance-api-dist.conf --config-file /etc/glance/glance-api.conf --config-file /etc/glance/glance-image-import.conf\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-ceph/\", \"dest\": \"/etc/ceph/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-iscsid/*\", \"dest\": \"/etc/iscsi/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": {\"list_concat\": [[{\"path\": \"/var/lib/glance\", \"owner\": \"glance:glance\", \"recurse\": true}, {\"path\": {\"str_replace\": {\"template\": \"/etc/ceph/CLUSTER.client.USER.keyring\", \"params\": {\"CLUSTER\": {\"get_param\": \"CephClusterName\"}, \"USER\": {\"get_param\": \"CephClientUserName\"}}}}, \"owner\": \"glance:glance\", \"perm\": \"0600\"}], {\"repeat\": {\"template\": {\"path\": \"/etc/ceph/<%keyring%>\", \"owner\": \"glance:glance\", \"perm\": \"0600\"}, \"for_each\": {\"<%keyring%>\": {\"yaql\": {\"expression\": \"let(u => $.data.user) -> $.data.multistore.values().where($.get(\\\"CephClusterName\\\")).select($.CephClusterName + \\\".client.\\\" + $.get(\\\"CephClientUserName\\\", $u) +\\\".keyring\\\")\", \"data\": {\"user\": {\"get_param\": \"CephClientUserName\"}, \"multistore\": {\"get_param\": \"GlanceMultistoreConfig\"}}}}}}}]}}, \"/var/lib/kolla/config_files/glance_api_tls_proxy.json\": {\"command\": \"/usr/sbin/httpd -DFOREGROUND\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.d\", \"dest\": \"/etc/httpd/conf.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.modules.d\", \"dest\": \"/etc/httpd/conf.modules.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]}, \"/var/lib/kolla/config_files/glance_api_cron.json\": {\"command\": \"/usr/sbin/crond -n\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/glance\", \"owner\": \"glance:glance\", \"recurse\": true}]}}, \"docker_config\": {\"step_2\": {\"get_attr\": [\"GlanceLogging\", \"docker_config\", \"step_2\"]}, \"step_3\": {\"glance_api_db_sync\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerGlanceApiImage\"]}, \"cap_add\": [\"AUDIT_WRITE\"], \"net\": \"host\", \"privileged\": false, \"detach\": false, \"user\": \"root\", \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"GlanceLogging\", \"volumes\"]}, {\"get_param\": \"GlanceApiOptVolumes\"}, [\"/var/lib/kolla/config_files/glance_api.json:/var/lib/kolla/config_files/config.json\", \"/var/lib/config-data/puppet-generated/glance_api:/var/lib/kolla/config_files/src:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", \"/var/lib/glance:/var/lib/glance:shared\"], {\"if\": [\"cinder_backend_enabled\", {\"list_concat\": [[\"/dev:/dev\", \"/var/lib/iscsi:/var/lib/iscsi:z\", {\"list_join\": [\":\", [{\"get_param\": \"GlanceCinderLockPath\"}, {\"get_param\": \"GlanceCinderLockPath\"}, \"z\"]]}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}]}]}, {\"if\": [\"cinder_multipathd_enabled\", [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}]}, \"environment\": {\"KOLLA_BOOTSTRAP\": true, \"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\", \"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}}, \"command\": \"/usr/bin/bootstrap_host_exec glance_api su glance -s /bin/bash -c \'/usr/local/bin/kolla_start\'\"}}, \"step_4\": {\"glance_api\": {\"start_order\": 2, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerGlanceApiImage\"]}, \"net\": \"host\", \"privileged\": {\"if\": [\"cinder_backend_enabled\", true, false]}, \"restart\": \"always\", \"depends_on\": {\"if\": [{\"or\": [{\"get_param\": \"GlanceNfsEnabled\"}, {\"get_param\": \"GlanceNetappNfsEnabled\"}]}, \"var-lib-glance-images.mount\"]}, \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"GlanceLogging\", \"volumes\"]}, {\"get_param\": \"GlanceApiOptVolumes\"}, [\"/var/lib/kolla/config_files/glance_api.json:/var/lib/kolla/config_files/config.json\", \"/var/lib/config-data/puppet-generated/glance_api:/var/lib/kolla/config_files/src:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", \"/var/lib/glance:/var/lib/glance:shared\"], {\"if\": [\"cinder_backend_enabled\", {\"list_concat\": [[\"/dev:/dev\", \"/var/lib/iscsi:/var/lib/iscsi:z\", {\"list_join\": [\":\", [{\"get_param\": \"GlanceCinderLockPath\"}, {\"get_param\": \"GlanceCinderLockPath\"}, \"z\"]]}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}]}]}, {\"if\": [\"cinder_multipathd_enabled\", [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}, \"glance_api_tls_proxy\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"start_order\": 3, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerGlanceApiImage\"]}, \"net\": \"host\", \"user\": \"root\", \"restart\": \"always\", \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"GlanceLogging\", \"volumes\"]}, [\"/var/lib/kolla/config_files/glance_api_tls_proxy.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/glance_api:/var/lib/kolla/config_files/src:ro\", \"/etc/pki/tls/certs/httpd:/etc/pki/tls/certs/httpd:ro\", \"/etc/pki/tls/private/httpd:/etc/pki/tls/private/httpd:ro\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}]}, \"glance_api_cron\": {\"start_order\": 2, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerGlanceApiImage\"]}, \"net\": \"host\", \"user\": \"root\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/usr/share/openstack-tripleo-common/healthcheck/cron glance\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"GlanceLogging\", \"volumes\"]}, [\"/var/lib/kolla/config_files/glance_api_cron.json:/var/lib/kolla/config_files/config.json\", \"/var/lib/config-data/puppet-generated/glance_api:/var/lib/kolla/config_files/src:ro\", \"/var/lib/glance:/var/lib/glance:shared\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"GlanceLogging\", \"host_prep_tasks\"]}, [{\"name\": \"Mount NFS on host\", \"vars\": {\"nfs_backend_enabled\": {\"get_param\": \"GlanceNfsEnabled\"}, \"glance_netapp_nfs_enabled\": {\"get_param\": \"GlanceNetappNfsEnabled\"}, \"glance_nfs_share\": {\"get_param\": \"GlanceNfsShare\"}, \"netapp_share_location\": {\"get_param\": \"NetappShareLocation\"}, \"nfs_share\": \"{{ glance_nfs_share if (glance_nfs_share) else netapp_share_location }}\", \"nfs_options\": {\"get_param\": \"GlanceNfsOptions\"}}, \"mount\": {\"name\": \"/var/lib/glance/images\", \"state\": \"mounted\", \"fstype\": \"nfs\", \"src\": \"{{nfs_share}}\", \"opts\": \"{{nfs_options}}\"}, \"when\": \"nfs_backend_enabled or glance_netapp_nfs_enabled\"}, {\"name\": \"Mount Node Staging Location\", \"vars\": {\"glance_node_staging_uri\": {\"get_param\": \"GlanceNodeStagingUri\"}, \"glance_staging_nfs_share\": {\"get_param\": \"GlanceStagingNfsShare\"}, \"glance_nfs_options\": {\"get_param\": \"GlanceStagingNfsOptions\"}}, \"mount\": {\"name\": \"{{glance_node_staging_uri[7:]}}\", \"state\": \"mounted\", \"fstype\": \"nfs\", \"src\": \"{{glance_staging_nfs_share}}\", \"opts\": \"{{glance_nfs_options}}\"}, \"when\": \"glance_staging_nfs_share != \'\'\"}], [{\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}, {\"name\": \"ensure /var/lib/glance exists\", \"file\": {\"path\": \"/var/lib/glance\", \"state\": \"directory\", \"setype\": \"container_file_t\"}}], {\"if\": [\"cinder_backend_enabled\", [{\"name\": \"Allow glance to use cinder\'s lock_path\", \"file\": {\"path\": {\"get_param\": \"GlanceCinderLockPath\"}, \"state\": \"directory\", \"setype\": \"container_file_t\", \"mode\": 504, \"group\": 42400}}, {\"name\": \"Identify dynamic os-brick lock files used by glance\", \"vars\": {\"lock_path\": {\"get_param\": \"GlanceCinderLockPath\"}}, \"ansible.builtin.find\": {\"paths\": \"{{ lock_path }}\", \"patterns\": \"os-brick-connect_to_iscsi_portal-*\"}, \"register\": \"find_dynamic_locks\"}, {\"name\": \"Prepare the os-brick lock files used by glance\", \"vars\": {\"lock_path\": {\"get_param\": \"GlanceCinderLockPath\"}, \"static_brick_locks\": [\"{{ lock_path }}/os-brick-connect_volume\", \"{{ lock_path }}/os-brick-extend_volume\", \"{{ lock_path }}/scaleio-scaleio\"], \"dynamic_brick_locks\": \"{{ find_dynamic_locks.files | map(attribute=\'path\') }}\"}, \"file\": {\"path\": \"{{ item }}\", \"state\": \"touch\", \"setype\": \"container_file_t\", \"mode\": 432, \"group\": 42400}, \"loop\": \"{{ (static_brick_locks + dynamic_brick_locks) | flatten}}\"}]]}, {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}, \"upgrade_tasks\": [{\"name\": \"glance-api pre system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 3\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Unmount and remove NFS glance entry\", \"vars\": {\"nfs_backend_enabled\": {\"get_param\": \"GlanceNfsEnabled\"}, \"glance_netapp_nfs_enabled\": {\"get_param\": \"GlanceNetappNfsEnabled\"}}, \"mount\": {\"name\": \"/var/lib/glance/images\", \"fstype\": \"nfs\", \"state\": \"absent\"}, \"when\": \"nfs_backend_enabled or glance_netapp_nfs_enabled\"}, {\"name\": \"Unmount and remove NFS glance-staging entry\", \"vars\": {\"glance_node_staging_uri\": {\"get_param\": \"GlanceNodeStagingUri\"}, \"glance_staging_nfs_share\": {\"get_param\": \"GlanceStagingNfsShare\"}}, \"mount\": {\"name\": \"{{glance_node_staging_uri[7:]}}\", \"fstype\": \"nfs\", \"state\": \"absent\"}, \"when\": \"glance_staging_nfs_share != \'\'\"}]}, {\"name\": \"glance-api post system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 5\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Mount NFS on host\", \"vars\": {\"nfs_backend_enabled\": {\"get_param\": \"GlanceNfsEnabled\"}, \"glance_netapp_nfs_enabled\": {\"get_param\": \"GlanceNetappNfsEnabled\"}, \"glance_nfs_share\": {\"get_param\": \"GlanceNfsShare\"}, \"netapp_share_location\": {\"get_param\": \"NetappShareLocation\"}, \"nfs_share\": \"{{ glance_nfs_share if (glance_nfs_share) else netapp_share_location }}\", \"nfs_options\": {\"get_param\": \"GlanceNfsOptions\"}}, \"mount\": {\"name\": \"/var/lib/glance/images\", \"state\": \"mounted\", \"fstype\": \"nfs\", \"src\": \"{{nfs_share}}\", \"opts\": \"{{nfs_options}}\"}, \"when\": \"nfs_backend_enabled or glance_netapp_nfs_enabled\"}, {\"name\": \"Mount Node Staging Location\", \"vars\": {\"glance_node_staging_uri\": {\"get_param\": \"GlanceNodeStagingUri\"}, \"glance_staging_nfs_share\": {\"get_param\": \"GlanceStagingNfsShare\"}, \"glance_nfs_options\": {\"get_param\": \"GlanceStagingNfsOptions\"}}, \"mount\": {\"name\": \"{{glance_node_staging_uri[7:]}}\", \"state\": \"mounted\", \"fstype\": \"nfs\", \"src\": \"{{glance_staging_nfs_share}}\", \"opts\": \"{{glance_nfs_options}}\"}, \"when\": \"glance_staging_nfs_share != \'\'\"}]}], \"metadata_settings\": {\"get_attr\": [\"TLSProxyBase\", \"role_data\", \"metadata_settings\"]}, \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop glance api container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"glance_api\", \"glance_api_cron\"], \"tripleo_delegate_to\": \"{{ groups[\'glance_api\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}], \"deploy_steps_tasks\": {\"get_attr\": [\"TLSProxyBase\", \"role_data\", \"deploy_steps_tasks\"]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"EnableInternalTLS\": false}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(122,'2026-06-10 07:47:05',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Openstack Cinder NVMeOF backend\\n\", \"parameters\": {\"CinderEnableNVMeOFBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NVMeOF backend for Cinder\", \"type\": \"boolean\"}, \"CinderNVMeOFBackendName\": {\"type\": \"string\", \"default\": \"tripleo_nvmeof\"}, \"CinderNVMeOFAvailabilityZone\": {\"default\": \"\", \"description\": \"The availability zone of the NVMeOF Cinder backend. When set, it overrides the default CinderStorageAvailabilityZone.\\n\", \"type\": \"string\"}, \"CinderNVMeOFTargetPort\": {\"type\": \"number\", \"default\": 4420}, \"CinderNVMeOFTargetHelper\": {\"type\": \"string\", \"default\": \"nvmet\"}, \"CinderNVMeOFTargetProtocol\": {\"type\": \"string\", \"default\": \"nvmet_rdma\", \"description\": \"The target protocol, supported values are nvmet_rdma and nvmet_tcp.\\n\", \"constraints\": [{\"allowed_values\": [\"nvmet_rdma\", \"nvmet_tcp\"]}]}, \"CinderNVMeOFTargetPrefix\": {\"type\": \"string\", \"default\": \"nvme-subsystem\"}, \"CinderNVMeOFTargetPortId\": {\"type\": \"number\", \"default\": 1}, \"CinderNVMeOFTargetNameSpaceId\": {\"type\": \"number\", \"default\": 10}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"type\": \"json\", \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\"}}, \"outputs\": {\"cinder_nvmeof_host_prep_tasks\": {\"description\": \"Host prep tasks related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [{\"name\": \"ensure /etc/nvme exists\", \"file\": {\"path\": \"/etc/nvme\", \"state\": \"directory\", \"setype\": \"container_file_t\"}}]]}}, \"cinder_nvmeof_volumes\": {\"description\": \"Volumes related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [\"/etc/nvme:/etc/nvme:z\"]]}}, \"role_data\": {\"description\": \"Role data for the Cinder NVMeOF backend.\", \"value\": {\"service_name\": \"cinder_backend_nvmeof\", \"firewall_rules\": {\"120 LVM nvmet target\": {\"dport\": {\"get_param\": \"CinderNVMeOFTargetPort\"}}}, \"config_settings\": {\"map_merge\": [{\"tripleo::profile::base::cinder::volume::cinder_enable_nvmeof_backend\": {\"get_param\": \"CinderEnableNVMeOFBackend\"}, \"tripleo::profile::base::cinder::volume::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_port\": {\"get_param\": \"CinderNVMeOFTargetPort\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_helper\": {\"get_param\": \"CinderNVMeOFTargetHelper\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_protocol\": {\"get_param\": \"CinderNVMeOFTargetProtocol\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_prefix\": {\"get_param\": \"CinderNVMeOFTargetPrefix\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_port_id\": {\"get_param\": \"CinderNVMeOFTargetPortId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_ns_id\": {\"get_param\": \"CinderNVMeOFTargetNameSpaceId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_ip_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderIscsiNetwork\"]}}}}, \"cinder::backend::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}}, {\"if\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderNVMeOFAvailabilityZone\"}, \"\"]}}, {\"tripleo::profile::base::cinder::volume::nvmeof::backend_availability_zone\": {\"get_param\": \"CinderNVMeOFAvailabilityZone\"}}]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(123,'2026-06-10 07:47:05',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Horizon service\\n\", \"parameters\": {\"ContainerHorizonImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\"}, \"ContainerHorizonConfigImage\": {\"description\": \"The container image to use for the horizon config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"HorizonDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Horizon service.\", \"type\": \"boolean\"}, \"HorizonAllowedHosts\": {\"default\": \"*\", \"description\": \"A list of IP/Hostname for the server Horizon is running on. Used for header checks.\", \"type\": \"comma_delimited_list\"}, \"HorizonPasswordValidator\": {\"description\": \"Regex for password validation\", \"type\": \"string\", \"default\": \"\"}, \"HorizonPasswordValidatorHelp\": {\"description\": \"Help text for password validation\", \"type\": \"string\", \"default\": \"\"}, \"HorizonSecret\": {\"description\": \"Secret key for Django\", \"type\": \"string\", \"hidden\": true, \"default\": \"qFqrstvXVq\"}, \"HorizonSecureCookies\": {\"description\": \"Set CSRF_COOKIE_SECURE / SESSION_COOKIE_SECURE in Horizon\", \"type\": \"boolean\", \"default\": false}, \"HorizonSessionTimeout\": {\"description\": \"Set session timeout for horizon in seconds\", \"type\": \"number\", \"default\": 1800}, \"MemcachedIPv6\": {\"default\": false, \"description\": \"Enable IPv6 features in Memcached.\", \"type\": \"boolean\"}, \"MonitoringSubscriptionHorizon\": {\"default\": \"overcloud-horizon\", \"type\": \"string\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"HorizonVhostExtraParams\": {\"default\": {\"add_listen\": true, \"priority\": 10, \"access_log_format\": \"%a %l %u %t \\\\\\\"%r\\\\\\\" %>s %b \\\\\\\"%%{}{Referer}i\\\\\\\" \\\\\\\"%%{}{User-Agent}i\\\\\\\"\", \"options\": [\"FollowSymLinks\", \"MultiViews\"]}, \"description\": \"Extra parameters for Horizon vhost configuration\", \"type\": \"json\"}, \"HorizonCustomizationModule\": {\"default\": \"\", \"description\": \"Horizon has a global overrides mechanism available to perform customizations\", \"type\": \"string\"}, \"HorizonHelpURL\": {\"default\": \"http://docs.openstack.org\", \"description\": \"On top of dashboard there is a Help button. This button could be used to re-direct user to vendor documentation or dedicated help portal.\", \"type\": \"string\"}, \"TimeZone\": {\"default\": \"UTC\", \"description\": \"The timezone to be set on the overcloud.\", \"type\": \"string\"}, \"WebSSOEnable\": {\"default\": false, \"type\": \"boolean\", \"description\": \"Enable support for Web Single Sign-On\"}, \"WebSSOInitialChoice\": {\"default\": \"OIDC\", \"type\": \"string\", \"description\": \"The initial authentication choice to select by default\"}, \"WebSSOChoicesHideKeystone\": {\"default\": false, \"type\": \"boolean\", \"description\": \"Hide Keystone crednetials login when WebSSO is enabled.\"}, \"WebSSOChoices\": {\"default\": [[\"OIDC\", \"OpenID Connect\"]], \"type\": \"json\", \"description\": \"Specifies the list of SSO authentication choices to present. Each item is a list of an SSO choice identifier and a display message.\"}, \"WebSSOIDPMapping\": {\"default\": {\"OIDC\": [\"myidp\", \"openid\"]}, \"type\": \"json\", \"description\": \"Specifies a mapping from SSO authentication choice to identity provider and protocol.  The identity provider and protocol names must match the resources defined in keystone.\"}, \"HorizonDomainChoices\": {\"default\": [], \"type\": \"json\", \"description\": \"Specifies available domains to choose from. We expect an array of hashes, and the hashes should have two items each (name, display) containing Keystone domain name and a human-readable description of the domain respectively.\"}, \"HorizonLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.horizon\", \"file\": \"/var/log/containers/horizon/horizon.log\"}}, \"HorizonHstsHeaderValue\": {\"default\": [], \"description\": \"Enables HTTP Strict-Transport-Security header in response.\", \"type\": \"comma_delimited_list\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"The following parameters are deprecated and will be removed. They should not\\nbe relied on for new deployments. If you have concerns regarding deprecated\\nparameters, please contact the TripleO development team on IRC or the\\nOpenStack mailing list.\\n\", \"parameters\": [\"MemcachedIPv6\"]}], \"conditions\": {\"horizon_domain_choices_set\": {\"not\": {\"equals\": [{\"get_param\": \"HorizonDomainChoices\"}, []]}}, \"is_ipv6\": {\"equals\": [{\"get_param\": [\"ServiceData\", \"net_ip_version_map\", {\"get_param\": [\"ServiceNetMap\", \"HorizonNetwork\"]}]}, 6]}, \"horizon_logger_debug\": {\"or\": [{\"get_param\": \"Debug\"}, {\"get_param\": \"HorizonDebug\"}]}, \"horizon_hsts_header_value_set\": {\"not\": {\"equals\": [{\"get_param\": \"HorizonHstsHeaderValue\"}, []]}}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerHorizonImage\": \"ContainerHorizonImage\", \"ContainerHorizonConfigImage\": \"ContainerHorizonConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerHorizonImage\": {\"get_param\": \"ContainerHorizonImage\"}, \"ContainerHorizonConfigImage\": {\"get_param\": \"ContainerHorizonConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Horizon API role.\", \"value\": {\"service_name\": \"horizon\", \"firewall_rules\": {\"126 horizon\": {\"dport\": [{\"if\": [{\"get_param\": \"EnableInternalTLS\"}, 443, 80]}]}}, \"firewall_frontend_rules\": {\"100 horizon_haproxy_frontend\": {\"dport\": [80]}}, \"firewall_ssl_frontend_rules\": {\"100 horizon_haproxy_frontend_ssl\": {\"dport\": [443]}}, \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionHorizon\"}, \"config_settings\": {\"map_merge\": [{\"horizon::allowed_hosts\": {\"get_param\": \"HorizonAllowedHosts\"}, \"horizon::enable_secure_proxy_ssl_header\": true, \"horizon::secure_proxy_addr_header\": \"HTTP_X_FORWARDED_FOR\", \"horizon::disable_password_reveal\": true, \"horizon::enforce_password_check\": true, \"horizon::disallow_iframe_embed\": true, \"horizon::cache_backend\": \"django.core.cache.backends.memcached.MemcachedCache\", \"horizon::django_session_engine\": \"django.contrib.sessions.backends.cache\", \"horizon::vhost_extra_params\": {\"get_param\": \"HorizonVhostExtraParams\"}, \"horizon::bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HorizonNetwork\"]}}}}, \"horizon::keystone_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneV3Public\", \"uri\"]}, \"horizon::password_validator\": {\"get_param\": [\"HorizonPasswordValidator\"]}, \"horizon::password_validator_help\": {\"get_param\": [\"HorizonPasswordValidatorHelp\"]}, \"horizon::secret_key\": {\"get_param\": \"HorizonSecret\"}, \"horizon::secure_cookies\": {\"get_param\": [\"HorizonSecureCookies\"]}, \"horizon::session_timeout\": {\"get_param\": \"HorizonSessionTimeout\"}, \"memcached_ipv6\": {\"if\": [\"is_ipv6\", true, false]}, \"horizon::servername\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HorizonNetwork\"]}}}}, \"horizon::listen_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"horizon::customization_module\": {\"get_param\": \"HorizonCustomizationModule\"}, \"horizon::timezone\": {\"get_param\": \"TimeZone\"}, \"horizon::file_upload_temp_dir\": \"/var/tmp\", \"horizon::help_url\": {\"get_param\": \"HorizonHelpURL\"}, \"horizon::enable_user_pass\": \"UNSET\"}, {\"if\": [{\"get_param\": \"WebSSOEnable\"}, {\"horizon::websso_enabled\": {\"get_param\": \"WebSSOEnable\"}, \"horizon::websso_initial_choice\": {\"get_param\": \"WebSSOInitialChoice\"}, \"horizon::websso_choices\": {\"get_param\": \"WebSSOChoices\"}, \"horizon::websso_idp_mapping\": {\"get_param\": \"WebSSOIDPMapping\"}, \"horizon::websso_choices_hide_keystone\": {\"get_param\": \"WebSSOChoicesHideKeystone\"}}]}, {\"if\": [{\"get_param\": \"HorizonDebug\"}, {\"horizon::django_debug\": true}, {\"horizon::django_debug\": {\"get_param\": \"Debug\"}}]}, {\"if\": [\"horizon_logger_debug\", {\"horizon::log_level\": \"DEBUG\"}]}, {\"if\": [\"horizon_domain_choices_set\", {\"horizon::keystone_domain_choices\": {\"get_param\": \"HorizonDomainChoices\"}}]}]}, \"ansible_group_vars\": {\"keystone_enable_member\": true}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_horizon\": {\"yaql\": {\"expression\": \"$.data.sources.flatten()\", \"data\": {\"sources\": [{\"get_param\": \"HorizonLoggingSource\"}]}}}}, \"haproxy\": {\"if\": [\"horizon_hsts_header_value_set\", {\"tripleo::profile::base::horizon::hsts_header_value\": {\"get_param\": \"HorizonHstsHeaderValue\"}}]}}, \"puppet_config\": {\"config_volume\": \"horizon\", \"puppet_tags\": \"horizon_config\", \"step_config\": \"include tripleo::profile::base::horizon\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHorizonConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/horizon.json\": {\"command\": \"/usr/sbin/httpd -DFOREGROUND\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.d\", \"dest\": \"/etc/httpd/conf.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.modules.d\", \"dest\": \"/etc/httpd/conf.modules.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/horizon/\", \"owner\": \"apache:apache\", \"recurse\": true}, {\"path\": \"/etc/openstack-dashboard/\", \"owner\": \"apache:apache\", \"recurse\": true}, {\"path\": \"/usr/share/openstack-dashboard/openstack_dashboard/local/\", \"owner\": \"apache:apache\", \"recurse\": false}, {\"path\": \"/usr/share/openstack-dashboard/openstack_dashboard/local/local_settings.d/\", \"owner\": \"apache:apache\", \"recurse\": false}]}}, \"docker_config\": {\"step_2\": {\"horizon_fix_perms\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHorizonImage\"]}, \"net\": \"none\", \"user\": \"root\", \"command\": [\"/bin/bash\", \"-c\", \"touch /var/log/horizon/horizon.log ; chown -R apache:apache /var/log/horizon && chmod -R a+rx /etc/openstack-dashboard\"], \"volumes\": [\"/var/log/containers/horizon:/var/log/horizon:z\", \"/var/log/containers/httpd/horizon:/var/log/httpd:z\", \"/var/lib/config-data/puppet-generated/horizon/etc/openstack-dashboard:/etc/openstack-dashboard\"]}}, \"step_3\": {\"horizon\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHorizonImage\"]}, \"net\": \"host\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/horizon.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/horizon:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/horizon:/var/log/horizon:z\", \"/var/log/containers/httpd/horizon:/var/log/httpd:z\", \"/var/tmp/horizon:/var/tmp:z\", \"/var/www:/var/www:ro\"], {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [\"/etc/pki/tls/certs/httpd:/etc/pki/tls/certs/httpd:ro\", \"/etc/pki/tls/private/httpd:/etc/pki/tls/private/httpd:ro\"]]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\", \"ENABLE_DESIGNATE\": \"yes\", \"ENABLE_HEAT\": \"yes\", \"ENABLE_IRONIC\": \"yes\", \"ENABLE_MANILA\": \"yes\", \"ENABLE_OCTAVIA\": \"yes\"}}}}, \"host_prep_tasks\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/horizon\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/log/containers/httpd/horizon\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/www\", \"setype\": \"container_file_t\"}, {\"path\": \"/var/tmp/horizon\", \"setype\": \"container_file_t\", \"mode\": \"01777\"}]}, {\"name\": \"ensure /var/tmp/horizon exists on boot\", \"copy\": {\"dest\": \"/etc/tmpfiles.d/var-tmp-horizon.conf\", \"content\": \"d /var/tmp/horizon 01777 root root - -\\n\"}}], \"upgrade_tasks\": [{\"name\": \"Anchor for upgrade and update tasks\", \"when\": \"step|int == 0\", \"block\": [{\"name\": \"Reset selinux label on /var/tmp\", \"file\": {\"path\": \"/var/tmp\", \"state\": \"directory\", \"setype\": \"tmp_t\", \"mode\": 1023}}]}], \"update_tasks\": [{\"name\": \"Anchor for upgrade and update tasks\", \"when\": \"step|int == 0\", \"block\": [{\"name\": \"Reset selinux label on /var/tmp\", \"file\": {\"path\": \"/var/tmp\", \"state\": \"directory\", \"setype\": \"tmp_t\", \"mode\": 1023}}]}], \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop horizon container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"horizon\"], \"tripleo_delegate_to\": \"{{ groups[\'horizon\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(124,'2026-06-10 07:47:05',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Glance service configured with Puppet\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"DeployIdentifier\": {\"default\": 1781077560, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}, \"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"GlanceDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Glance service.\", \"type\": \"boolean\"}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}, \"GlancePassword\": {\"description\": \"The password for the glance service and db account, used by the glance services.\", \"type\": \"string\", \"hidden\": true, \"default\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\"}, \"GlanceWorkers\": {\"default\": 1, \"description\": \"Number of API worker processes for Glance. If left unset (empty string), the\\ndefault value will result in the configuration being left unset and a\\nsystem-dependent default value will be chosen (e.g.: number of\\nprocessors). Please note that this will create a large number of\\nprocesses on systems with a large number of CPUs resulting in excess\\nmemory consumption. It is recommended that a suitable non-default value\\nbe selected on such systems.\\n\", \"type\": \"string\"}, \"MonitoringSubscriptionGlanceApi\": {\"default\": \"overcloud-glance-api\", \"type\": \"string\"}, \"GlanceApiLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.glance.api\", \"file\": \"/var/log/containers/glance/api.log\"}}, \"GlanceImageMemberQuota\": {\"default\": 128, \"description\": \"Maximum number of image members per image.\\nNegative values evaluate to unlimited.\\n\", \"type\": \"number\"}, \"GlanceNfsEnabled\": {\"default\": false, \"description\": \"When using GlanceBackend \'file\', mount NFS share for image storage.\\n\", \"type\": \"boolean\"}, \"GlanceCacheEnabled\": {\"description\": \"Enable Glance Image Cache\", \"type\": \"boolean\", \"default\": false}, \"GlanceImageCacheDir\": {\"description\": \"Base directory that the Image Cache uses\", \"type\": \"string\", \"default\": \"/var/lib/glance/image-cache\"}, \"GlanceImageCacheMaxSize\": {\"description\": \"The upper limit on cache size, in bytes, after which the cache-pruner cleans up the image cache.\\n\", \"type\": \"number\", \"default\": 10737418240}, \"GlanceImageCacheStallTime\": {\"description\": \"The amount of time, in seconds, to let an image remain in the cache without being accessed.\\n\", \"type\": \"number\", \"default\": 86400}, \"GlanceImagePrefetcherInterval\": {\"description\": \"The interval in seconds to run periodic job cache_images.\\n\", \"type\": \"number\", \"default\": 300}, \"GlanceNfsShare\": {\"default\": \"\", \"description\": \"NFS share to mount for image storage (when GlanceNfsEnabled is true)\\n\", \"type\": \"string\"}, \"GlanceNetappNfsEnabled\": {\"default\": false, \"description\": \"When using GlanceBackend \'file\', Netapp mount NFS share for image storage.\\n\", \"type\": \"boolean\"}, \"NetappShareLocation\": {\"default\": \"\", \"description\": \"Netapp share to mount for image storage (when GlanceNetappNfsEnabled is true)\\n\", \"type\": \"string\"}, \"GlanceNfsOptions\": {\"default\": \"_netdev,bg,intr,context=system_u:object_r:container_file_t:s0\", \"description\": \"NFS mount options for image storage (when GlanceNfsEnabled is true)\\n\", \"type\": \"string\"}, \"GlanceRbdPoolName\": {\"default\": \"images\", \"type\": \"string\"}, \"NovaEnableRbdBackend\": {\"default\": false, \"description\": \"Whether to enable the Rbd backend for Nova ephemeral storage.\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"GlanceImageImportPlugins\": {\"default\": [\"no_op\"], \"description\": \"List of enabled Image Import Plugins. Valid values in the list are \'image_conversion\', \'inject_metadata\', \'no_op\'.\\n\", \"type\": \"comma_delimited_list\"}, \"GlanceDiskFormats\": {\"default\": \"\", \"description\": \"List of allowed disk formats in Glance; all formats are allowed when left unset.\\n\", \"type\": \"comma_delimited_list\"}, \"GlanceImageConversionOutputFormat\": {\"default\": \"raw\", \"description\": \"Desired output format for image conversion plugin.\", \"type\": \"string\"}, \"GlanceInjectMetadataProperties\": {\"default\": \"\", \"description\": \"Metadata properties to be injected in image.\", \"type\": \"comma_delimited_list\"}, \"GlanceIgnoreUserRoles\": {\"default\": \"admin\", \"description\": \"List of user roles to be ignored for injecting image metadata properties.\", \"type\": \"comma_delimited_list\"}, \"GlanceEnabledImportMethods\": {\"default\": \"web-download\", \"description\": \"List of enabled Image Import Methods. Valid values in the list are \'glance-direct\', \'web-download\', or \'copy-image\'\\n\", \"type\": \"comma_delimited_list\"}, \"GlanceStagingNfsShare\": {\"default\": \"\", \"description\": \"NFS share to mount for image import staging\\n\", \"type\": \"string\"}, \"GlanceNodeStagingUri\": {\"default\": \"file:///var/lib/glance/staging\", \"description\": \"URI that specifies the staging location to use when importing images\\n\", \"type\": \"string\"}, \"GlanceStagingNfsOptions\": {\"default\": \"_netdev,bg,intr,context=system_u:object_r:container_file_t:s0\", \"description\": \"NFS mount options for NFS image import staging\\n\", \"type\": \"string\"}, \"GlanceSparseUploadEnabled\": {\"default\": false, \"description\": \"When using GlanceBackend \'file\' and \'rbd\' to enable or not sparse upload.\\n\", \"type\": \"boolean\"}, \"EnforceSecureRbac\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Setting this option to True will configure each OpenStack service to enforce Secure RBAC by setting `[oslo_policy] enforce_new_defaults` and `[oslo_policy] enforce_scope` to True. This introduces a consistent set of RBAC personas across OpenStack services that include support for system and project scope, as well as keystone\'s default roles, admin, member, and reader. Do not enable this functionality until all services in your deployment actually support secure RBAC.\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"GlanceApiPolicies\": {\"description\": \"A hash of policies to configure for Glance API.\\ne.g. { glance-context_is_admin: { key: context_is_admin, value: \'role:admin\' } }\\n\", \"default\": {}, \"type\": \"json\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"noop\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"GlanceNotifierStrategy\": {\"description\": \"Strategy to use for Glance notification queue\", \"type\": \"string\", \"default\": \"noop\"}, \"GlanceLogFile\": {\"description\": \"The filepath of the file to use for logging messages from Glance.\", \"type\": \"string\", \"default\": \"\"}, \"GlanceBackend\": {\"default\": \"swift\", \"description\": \"The short name of the Glance backend to use. Should be one of swift, rbd, cinder, or file\", \"type\": \"string\", \"constraints\": [{\"allowed_values\": [\"swift\", \"file\", \"rbd\", \"cinder\"]}]}, \"GlanceBackendID\": {\"type\": \"string\", \"default\": \"default_backend\", \"description\": \"The default backend\'s identifier.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9_-]+\"}]}, \"GlanceStoreDescription\": {\"type\": \"string\", \"default\": \"Default glance store backend.\", \"description\": \"User facing description for the Glance backend.\"}, \"GlanceMultistoreConfig\": {\"type\": \"json\", \"default\": {}, \"description\": \"Dictionary of settings when configuring additional glance backends. The\\nhash key is the backend ID, and the value is a dictionary of parameter\\nvalues unique to that backend. Multiple rbd and cinder backends are allowed, but\\nfile and swift backends are limited to one each. Example:\\n  # Default glance store is rbd.\\n  GlanceBackend: rbd\\n  GlanceStoreDescription: \'Default rbd store\'\\n  # GlanceMultistoreConfig specifies a second rbd backend, plus a cinder\\n  # backend.\\n  GlanceMultistoreConfig:\\n    rbd2_store:\\n      GlanceBackend: rbd\\n      GlanceStoreDescription: \'Second rbd store\'\\n      CephClusterName: ceph2\\n      # Override CephClientUserName if this cluster uses a different\\n      # client name.\\n      CephClientUserName: client2\\n    cinder1_store:\\n      GlanceBackend: cinder\\n      GlanceCinderVolumeType: \'volume-type-1\'\\n      GlanceStoreDescription: \'First cinder store\'\\n    cinder2_store:\\n      GlanceBackend: cinder\\n      GlanceCinderVolumeType: \'volume-type-2\'\\n      GlanceStoreDescription: \'Seconde cinder store\'\\n\"}, \"GlanceCinderMountPointBase\": {\"default\": \"/var/lib/glance/mnt\", \"type\": \"string\", \"description\": \"The mount point base when glance is using cinder as store and cinder backend\\nis NFS. This mount point is where the NFS volume is mounted on the glance node.\\n\"}, \"GlanceCinderVolumeType\": {\"default\": \"\", \"type\": \"string\", \"description\": \"A unique volume type required for each cinder store while configuring multiple cinder\\nstores as glance backends. The same volume types must be configured in Cinder as well.\\nThe volume type must exist in cinder prior to any attempt to add an image in the associated\\ncinder store. If no volume type is specified then cinder\'s default volume type will be used.\\n\"}, \"GlanceCinderLockPath\": {\"default\": \"/var/lib/cinder/tmp\", \"type\": \"string\", \"description\": \"The oslo.coordination lock_path to use when glance is using cinder as a store. Using\\ncinder\'s lock_path ensures os-brick operations are synchronized across both services.\\n\"}, \"CephClientUserName\": {\"default\": \"openstack\", \"type\": \"string\"}, \"CephClusterName\": {\"type\": \"string\", \"default\": \"ceph\", \"description\": \"The Ceph cluster name.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9]+\", \"description\": \"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\n\"}]}, \"CephConfigPath\": {\"type\": \"string\", \"default\": \"/var/lib/tripleo-config/ceph\", \"description\": \"The path where the Ceph Cluster config files are stored on the host.\\n\"}, \"MultipathdEnable\": {\"default\": false, \"description\": \"Whether to enable the multipath daemon\", \"type\": \"boolean\"}, \"GlanceApiOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\"}, \"ContainerGlanceApiImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\"}, \"ContainerGlanceApiConfigImage\": {\"description\": \"The container image to use for the glance_api config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\"}, \"GlanceCronDbPurgeMinute\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Minute\\n\", \"default\": \"1\"}, \"GlanceCronDbPurgeHour\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Hour\\n\", \"default\": \"0\"}, \"GlanceCronDbPurgeMonthday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month Day\\n\", \"default\": \"*\"}, \"GlanceCronDbPurgeMonth\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month\\n\", \"default\": \"*\"}, \"GlanceCronDbPurgeWeekday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Week Day\\n\", \"default\": \"*\"}, \"GlanceCronDbPurgeUser\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - User\\n\", \"default\": \"glance\"}, \"GlanceCronDbPurgeAge\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Age\\n\", \"default\": \"30\"}, \"GlanceCronDbPurgeMaxRows\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Max Rows\\n\", \"default\": \"100\"}, \"GlanceCronDbPurgeDestination\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Log destination\\n\", \"default\": \"/var/log/glance/glance-rowsflush.log\"}, \"GlanceCronDbPurgeMaxDelay\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Max Delay\\n\", \"default\": \"3600\"}, \"MemcacheUseAdvancedPool\": {\"type\": \"boolean\", \"description\": \"Use the advanced (eventlet safe) memcached client pool.\\n\", \"default\": true}, \"GlanceShowMultipleLocations\": {\"default\": false, \"description\": \"Whether to show multiple image locations e.g for copy-on-write support on\\nRBD or Netapp backends. Potential security risk, see glance.conf for more information.\\n\", \"type\": \"boolean\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"The following parameters are deprecated and will be removed. They should not\\nbe relied on for new deployments.\\n\", \"parameters\": [\"GlanceShowMultipleLocations\"]}], \"conditions\": {\"cinder_backend_enabled\": {\"or\": [{\"equals\": [{\"get_param\": \"GlanceBackend\"}, \"cinder\"]}, {\"yaql\": {\"expression\": \"$.data.values().any($.get(\\\"GlanceBackend\\\", \\\"\\\") = \\\"cinder\\\")\", \"data\": {\"get_param\": \"GlanceMultistoreConfig\"}}}]}, \"cinder_multipathd_enabled\": {\"and\": [\"cinder_backend_enabled\", {\"get_param\": \"MultipathdEnable\"}]}, \"rbd_backend_enabled\": {\"or\": [{\"equals\": [{\"get_param\": \"GlanceBackend\"}, \"rbd\"]}, {\"yaql\": {\"expression\": \"$.data.values().any($.get(\\\"GlanceBackend\\\", \\\"\\\") = \\\"rbd\\\")\", \"data\": {\"get_param\": \"GlanceMultistoreConfig\"}}}]}, \"force_image_conversion_plugin\": {\"or\": [{\"and\": [\"rbd_backend_enabled\", {\"equals\": [{\"get_param\": \"GlanceImageImportPlugins\"}, [\"no_op\"]]}, {\"get_param\": \"NovaEnableRbdBackend\"}]}, {\"get_param\": \"GlanceSparseUploadEnabled\"}]}, \"glance_workers_set\": {\"not\": {\"equals\": [{\"get_param\": \"GlanceWorkers\"}, \"\"]}}, \"glance_multiple_locations\": {\"or\": [{\"get_param\": \"GlanceShowMultipleLocations\"}, {\"get_param\": \"GlanceNetappNfsEnabled\"}, {\"and\": [\"rbd_backend_enabled\", {\"get_param\": \"NovaEnableRbdBackend\"}]}]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MySQLClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\"}, \"GlanceLogging\": {\"type\": \"OS::TripleO::Services::Logging::GlanceApi\"}, \"CinderNVMeOF\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml\"}, \"TLSProxyBase\": {\"type\": \"OS::TripleO::Services::TLSProxyBase\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}, \"EnableInternalTLS\": {\"get_param\": \"EnableInternalTLS\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerGlanceApiImage\": \"ContainerGlanceApiImage\", \"ContainerGlanceApiConfigImage\": \"ContainerGlanceApiConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerGlanceApiImage\": {\"get_param\": \"ContainerGlanceApiImage\"}, \"ContainerGlanceApiConfigImage\": {\"get_param\": \"ContainerGlanceApiConfigImage\"}}}]}}}}, \"outputs\": {\"glance_api_host_prep_and_system_upgrade_post_tasks\": {\"description\": \"Common host_prep and system_upgrade post tasks for glance_api\", \"value\": [{\"name\": \"Mount NFS on host\", \"vars\": {\"nfs_backend_enabled\": {\"get_param\": \"GlanceNfsEnabled\"}, \"glance_netapp_nfs_enabled\": {\"get_param\": \"GlanceNetappNfsEnabled\"}, \"glance_nfs_share\": {\"get_param\": \"GlanceNfsShare\"}, \"netapp_share_location\": {\"get_param\": \"NetappShareLocation\"}, \"nfs_share\": \"{{ glance_nfs_share if (glance_nfs_share) else netapp_share_location }}\", \"nfs_options\": {\"get_param\": \"GlanceNfsOptions\"}}, \"mount\": {\"name\": \"/var/lib/glance/images\", \"state\": \"mounted\", \"fstype\": \"nfs\", \"src\": \"{{nfs_share}}\", \"opts\": \"{{nfs_options}}\"}, \"when\": \"nfs_backend_enabled or glance_netapp_nfs_enabled\"}, {\"name\": \"Mount Node Staging Location\", \"vars\": {\"glance_node_staging_uri\": {\"get_param\": \"GlanceNodeStagingUri\"}, \"glance_staging_nfs_share\": {\"get_param\": \"GlanceStagingNfsShare\"}, \"glance_nfs_options\": {\"get_param\": \"GlanceStagingNfsOptions\"}}, \"mount\": {\"name\": \"{{glance_node_staging_uri[7:]}}\", \"state\": \"mounted\", \"fstype\": \"nfs\", \"src\": \"{{glance_staging_nfs_share}}\", \"opts\": \"{{glance_nfs_options}}\"}, \"when\": \"glance_staging_nfs_share != \'\'\"}]}, \"role_data\": {\"description\": \"Role data for the Glance API role.\", \"value\": {\"service_name\": \"glance_api\", \"firewall_rules\": {\"112 glance_api\": {\"dport\": [9292]}}, \"firewall_frontend_rules\": {\"100 glance_api_haproxy_frontend\": {\"dport\": [9292]}}, \"firewall_ssl_frontend_rules\": {\"100 glance_api_haproxy_frontend_ssl\": {\"dport\": [13292]}}, \"keystone_resources\": {\"glance\": {\"endpoints\": {\"public\": {\"get_param\": [\"EndpointMap\", \"GlancePublic\", \"uri\"]}, \"internal\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"uri\"]}, \"admin\": {\"get_param\": [\"EndpointMap\", \"GlanceAdmin\", \"uri\"]}}, \"users\": {\"glance\": {\"password\": {\"get_param\": \"GlancePassword\"}}}, \"region\": {\"get_param\": \"KeystoneRegion\"}, \"service\": \"image\"}}, \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionGlanceApi\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"TLSProxyBase\", \"role_data\", \"config_settings\"]}, {\"glance::api::db::database_connection\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"protocol\"]}, \"username\": \"glance\", \"password\": {\"get_param\": \"GlancePassword\"}, \"host\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"host\"]}, \"path\": \"/glance\", \"query\": {\"if\": [{\"get_param\": \"EnableSQLAlchemyCollectd\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\", \"plugin\": \"collectd\", \"collectd_program_name\": \"glance\", \"collectd_host\": \"localhost\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\"}]}}}, \"glance::api::authtoken::www_authenticate_uri\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"uri_no_suffix\"]}, \"glance::api::authtoken::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"glance::api::enable_v1_api\": false, \"glance::api::enable_v2_api\": true, \"glance::api::authtoken::password\": {\"get_param\": \"GlancePassword\"}, \"glance::api::enable_proxy_headers_parsing\": true, \"glance::api::logging::debug\": {\"if\": [{\"get_param\": \"GlanceDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"glance::policy::policies\": {\"get_param\": \"GlanceApiPolicies\"}, \"glance::api::authtoken::project_name\": \"service\", \"glance::api::authtoken::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"glance::api::authtoken::user_domain_name\": \"Default\", \"glance::api::authtoken::project_domain_name\": \"Default\", \"glance::api::authtoken::interface\": \"internal\", \"glance::api::authtoken::memcache_use_advanced_pool\": {\"get_param\": \"MemcacheUseAdvancedPool\"}, \"glance::api::pipeline\": {\"if\": [{\"get_param\": \"GlanceCacheEnabled\"}, \"keystone+cachemanagement\", \"keystone\"]}, \"glance::api::os_region_name\": {\"get_param\": \"KeystoneRegion\"}, \"glance::api::image_member_quota\": {\"get_param\": \"GlanceImageMemberQuota\"}, \"glance::api::enabled_import_methods\": {\"get_param\": \"GlanceEnabledImportMethods\"}, \"glance::api::node_staging_uri\": {\"get_param\": \"GlanceNodeStagingUri\"}, \"glance::api::image_import_plugins\": {\"if\": [\"force_image_conversion_plugin\", {\"list_concat_unique\": [{\"get_param\": \"GlanceImageImportPlugins\"}, [\"image_conversion\"]]}, {\"get_param\": \"GlanceImageImportPlugins\"}]}, \"glance::api::image_conversion_output_format\": {\"get_param\": \"GlanceImageConversionOutputFormat\"}, \"glance::api::inject_metadata_properties\": {\"get_param\": \"GlanceInjectMetadataProperties\"}, \"glance::api::ignore_user_roles\": {\"get_param\": \"GlanceIgnoreUserRoles\"}, \"tripleo::profile::base::glance::api::tls_proxy_bind_ip\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}}}}, \"tripleo::profile::base::glance::api::tls_proxy_fqdn\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}}}}, \"tripleo::profile::base::glance::api::tls_proxy_port\": 9292, \"glance::api::bind_host\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, \"%{hiera(\'localhost_address\')}\", {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}}}}]}, \"glance_notifier_strategy\": {\"get_param\": \"GlanceNotifierStrategy\"}, \"glance_log_file\": {\"get_param\": \"GlanceLogFile\"}, \"glance::backend::rbd::rbd_thin_provisioning\": {\"get_param\": \"GlanceSparseUploadEnabled\"}, \"glance::backend::file::filesystem_thin_provisioning\": {\"get_param\": \"GlanceSparseUploadEnabled\"}, \"glance::backend::swift::swift_store_auth_address\": {\"get_param\": [\"EndpointMap\", \"KeystoneV3Internal\", \"uri\"]}, \"glance::backend::swift::swift_store_user\": \"service:glance\", \"glance::backend::swift::swift_store_key\": {\"get_param\": \"GlancePassword\"}, \"glance::backend::swift::swift_store_create_container_on_put\": true, \"glance::backend::swift::swift_store_auth_version\": 3, \"glance::backend::rbd::rbd_store_ceph_conf\": {\"list_join\": [\"\", [\"/etc/ceph/\", {\"get_param\": \"CephClusterName\"}, \".conf\"]]}, \"glance::backend::rbd::rbd_store_pool\": {\"get_param\": \"GlanceRbdPoolName\"}, \"glance::backend::rbd::rbd_store_user\": {\"get_param\": \"CephClientUserName\"}, \"glance_backend\": {\"get_param\": \"GlanceBackend\"}, \"tripleo::profile::base::glance::api::glance_backend_id\": {\"get_param\": \"GlanceBackendID\"}, \"tripleo::profile::base::glance::api::glance_store_description\": {\"get_param\": \"GlanceStoreDescription\"}, \"tripleo::profile::base::glance::api::multistore_config\": {\"get_param\": \"GlanceMultistoreConfig\"}, \"tripleo::profile::base::glance::backend::rbd::glance_rbd_ceph_conf_path\": {\"get_param\": \"CephConfigPath\"}, \"glance::notify::rabbitmq::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"glance::notify::rabbitmq::rabbit_heartbeat_in_pthread\": false, \"glance::cron::db_purge::minute\": {\"get_param\": \"GlanceCronDbPurgeMinute\"}, \"glance::cron::db_purge::hour\": {\"get_param\": \"GlanceCronDbPurgeHour\"}, \"glance::cron::db_purge::monthday\": {\"get_param\": \"GlanceCronDbPurgeMonthday\"}, \"glance::cron::db_purge::month\": {\"get_param\": \"GlanceCronDbPurgeMonth\"}, \"glance::cron::db_purge::weekday\": {\"get_param\": \"GlanceCronDbPurgeWeekday\"}, \"glance::cron::db_purge::user\": {\"get_param\": \"GlanceCronDbPurgeUser\"}, \"glance::cron::db_purge::age\": {\"get_param\": \"GlanceCronDbPurgeAge\"}, \"glance::cron::db_purge::max_rows\": {\"get_param\": \"GlanceCronDbPurgeMaxRows\"}, \"glance::cron::db_purge::destination\": {\"get_param\": \"GlanceCronDbPurgeDestination\"}, \"glance::cron::db_purge::maxdelay\": {\"get_param\": \"GlanceCronDbPurgeMaxDelay\"}}, {\"if\": [\"glance_workers_set\", {\"glance::api::workers\": {\"get_param\": \"GlanceWorkers\"}}]}, {\"if\": [{\"get_param\": \"EnforceSecureRbac\"}, {\"glance::api::enforce_secure_rbac\": true, \"glance::policy::enforce_new_defaults\": true}]}, {\"if\": [\"cinder_backend_enabled\", {\"glance::backend::cinder::cinder_store_auth_address\": {\"get_param\": [\"EndpointMap\", \"KeystoneV3Internal\", \"uri\"]}, \"glance::backend::cinder::cinder_store_project_name\": \"service\", \"glance::backend::cinder::cinder_store_user_name\": \"glance\", \"glance::backend::cinder::cinder_store_password\": {\"get_param\": \"GlancePassword\"}, \"glance::api::lock_path\": {\"get_param\": \"GlanceCinderLockPath\"}, \"tripleo::profile::base::glance::backend::cinder::cinder_mount_point_base\": {\"get_param\": \"GlanceCinderMountPointBase\"}, \"tripleo::profile::base::glance::backend::cinder::cinder_volume_type\": {\"get_param\": \"GlanceCinderVolumeType\"}}]}, {\"if\": [\"cinder_multipathd_enabled\", {\"glance::backend::cinder::cinder_use_multipath\": true}]}, {\"if\": [{\"get_param\": \"GlanceCacheEnabled\"}, {\"tripleo::profile::base::glance::api::glance_enable_cache\": true, \"glance::api::image_cache_dir\": {\"get_param\": \"GlanceImageCacheDir\"}, \"glance::api::image_cache_max_size\": {\"get_param\": \"GlanceImageCacheMaxSize\"}, \"glance::api::image_cache_stall_time\": {\"get_param\": \"GlanceImageCacheStallTime\"}, \"glance::api::cache_prefetcher_interval\": {\"get_param\": \"GlanceImagePrefetcherInterval\"}}]}, {\"if\": [{\"get_param\": \"GlanceNetappNfsEnabled\"}, {\"tripleo::profile::base::glance::netapp::netapp_share\": {\"get_param\": \"NetappShareLocation\"}, \"glance::api::filesystem_store_metadata_file\": \"/etc/glance/glance-metadata-file.json\", \"glance::api::filesystem_store_file_perm\": \"0644\"}]}, {\"if\": [{\"contains\": [\"glance-direct\", {\"get_param\": \"GlanceEnabledImportMethods\"}]}, {\"glance::api::worker_self_reference_url\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"str_replace\": {\"template\": \"https://%{hiera(\'fqdn_NETWORK\')}:PORT\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}, \"PORT\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"port\"]}}}}, {\"str_replace\": {\"template\": \"http://%{hiera(\'NETWORK_uri\')}:PORT\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}, \"PORT\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"port\"]}}}}]}}]}, {\"if\": [{\"not\": {\"equals\": [{\"get_param\": \"GlanceDiskFormats\"}, []]}}, {\"glance::api::disk_formats\": {\"get_param\": \"GlanceDiskFormats\"}}]}]}, \"service_config_settings\": {\"mysql\": {\"glance::db::mysql::password\": {\"get_param\": \"GlancePassword\"}, \"glance::db::mysql::user\": \"glance\", \"glance::db::mysql::host\": \"%\", \"glance::db::mysql::dbname\": \"glance\"}, \"rsyslog\": {\"tripleo_logging_sources_glance_api\": [{\"get_param\": \"GlanceApiLoggingSource\"}]}}, \"puppet_config\": {\"config_volume\": \"glance_api\", \"puppet_tags\": \"glance_api_config,glance_api_paste_ini,glance_swift_config,glance_cache_config,glance_image_import_config\", \"step_config\": {\"list_join\": [\"\\n\", [\"include tripleo::profile::base::glance::api\", {\"if\": [{\"get_param\": \"GlanceNetappNfsEnabled\"}, \"include tripleo::profile::base::glance::netapp\"]}, {\"get_attr\": [\"MySQLClient\", \"role_data\", \"step_config\"]}]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerGlanceApiConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/glance_api.json\": {\"command\": \"/usr/bin/glance-api --config-file /usr/share/glance/glance-api-dist.conf --config-file /etc/glance/glance-api.conf --config-file /etc/glance/glance-image-import.conf\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-ceph/\", \"dest\": \"/etc/ceph/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-iscsid/*\", \"dest\": \"/etc/iscsi/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": {\"list_concat\": [[{\"path\": \"/var/lib/glance\", \"owner\": \"glance:glance\", \"recurse\": true}, {\"path\": {\"str_replace\": {\"template\": \"/etc/ceph/CLUSTER.client.USER.keyring\", \"params\": {\"CLUSTER\": {\"get_param\": \"CephClusterName\"}, \"USER\": {\"get_param\": \"CephClientUserName\"}}}}, \"owner\": \"glance:glance\", \"perm\": \"0600\"}], {\"repeat\": {\"template\": {\"path\": \"/etc/ceph/<%keyring%>\", \"owner\": \"glance:glance\", \"perm\": \"0600\"}, \"for_each\": {\"<%keyring%>\": {\"yaql\": {\"expression\": \"let(u => $.data.user) -> $.data.multistore.values().where($.get(\\\"CephClusterName\\\")).select($.CephClusterName + \\\".client.\\\" + $.get(\\\"CephClientUserName\\\", $u) +\\\".keyring\\\")\", \"data\": {\"user\": {\"get_param\": \"CephClientUserName\"}, \"multistore\": {\"get_param\": \"GlanceMultistoreConfig\"}}}}}}}]}}, \"/var/lib/kolla/config_files/glance_api_tls_proxy.json\": {\"command\": \"/usr/sbin/httpd -DFOREGROUND\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.d\", \"dest\": \"/etc/httpd/conf.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.modules.d\", \"dest\": \"/etc/httpd/conf.modules.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]}, \"/var/lib/kolla/config_files/glance_api_cron.json\": {\"command\": \"/usr/sbin/crond -n\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/glance\", \"owner\": \"glance:glance\", \"recurse\": true}]}}, \"docker_config\": {\"step_2\": {\"get_attr\": [\"GlanceLogging\", \"docker_config\", \"step_2\"]}, \"step_3\": {\"glance_api_db_sync\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerGlanceApiImage\"]}, \"cap_add\": [\"AUDIT_WRITE\"], \"net\": \"host\", \"privileged\": false, \"detach\": false, \"user\": \"root\", \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"GlanceLogging\", \"volumes\"]}, {\"get_param\": \"GlanceApiOptVolumes\"}, [\"/var/lib/kolla/config_files/glance_api.json:/var/lib/kolla/config_files/config.json\", \"/var/lib/config-data/puppet-generated/glance_api:/var/lib/kolla/config_files/src:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", \"/var/lib/glance:/var/lib/glance:shared\"], {\"if\": [\"cinder_backend_enabled\", {\"list_concat\": [[\"/dev:/dev\", \"/var/lib/iscsi:/var/lib/iscsi:z\", {\"list_join\": [\":\", [{\"get_param\": \"GlanceCinderLockPath\"}, {\"get_param\": \"GlanceCinderLockPath\"}, \"z\"]]}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}]}]}, {\"if\": [\"cinder_multipathd_enabled\", [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}]}, \"environment\": {\"KOLLA_BOOTSTRAP\": true, \"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\", \"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}}, \"command\": \"/usr/bin/bootstrap_host_exec glance_api su glance -s /bin/bash -c \'/usr/local/bin/kolla_start\'\"}}, \"step_4\": {\"glance_api\": {\"start_order\": 2, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerGlanceApiImage\"]}, \"net\": \"host\", \"privileged\": {\"if\": [\"cinder_backend_enabled\", true, false]}, \"restart\": \"always\", \"depends_on\": {\"if\": [{\"or\": [{\"get_param\": \"GlanceNfsEnabled\"}, {\"get_param\": \"GlanceNetappNfsEnabled\"}]}, \"var-lib-glance-images.mount\"]}, \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"GlanceLogging\", \"volumes\"]}, {\"get_param\": \"GlanceApiOptVolumes\"}, [\"/var/lib/kolla/config_files/glance_api.json:/var/lib/kolla/config_files/config.json\", \"/var/lib/config-data/puppet-generated/glance_api:/var/lib/kolla/config_files/src:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", \"/var/lib/glance:/var/lib/glance:shared\"], {\"if\": [\"cinder_backend_enabled\", {\"list_concat\": [[\"/dev:/dev\", \"/var/lib/iscsi:/var/lib/iscsi:z\", {\"list_join\": [\":\", [{\"get_param\": \"GlanceCinderLockPath\"}, {\"get_param\": \"GlanceCinderLockPath\"}, \"z\"]]}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}]}]}, {\"if\": [\"cinder_multipathd_enabled\", [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}, \"glance_api_tls_proxy\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"start_order\": 3, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerGlanceApiImage\"]}, \"net\": \"host\", \"user\": \"root\", \"restart\": \"always\", \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"GlanceLogging\", \"volumes\"]}, [\"/var/lib/kolla/config_files/glance_api_tls_proxy.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/glance_api:/var/lib/kolla/config_files/src:ro\", \"/etc/pki/tls/certs/httpd:/etc/pki/tls/certs/httpd:ro\", \"/etc/pki/tls/private/httpd:/etc/pki/tls/private/httpd:ro\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}]}, \"glance_api_cron\": {\"start_order\": 2, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerGlanceApiImage\"]}, \"net\": \"host\", \"user\": \"root\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/usr/share/openstack-tripleo-common/healthcheck/cron glance\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"GlanceLogging\", \"volumes\"]}, [\"/var/lib/kolla/config_files/glance_api_cron.json:/var/lib/kolla/config_files/config.json\", \"/var/lib/config-data/puppet-generated/glance_api:/var/lib/kolla/config_files/src:ro\", \"/var/lib/glance:/var/lib/glance:shared\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"GlanceLogging\", \"host_prep_tasks\"]}, [{\"name\": \"Mount NFS on host\", \"vars\": {\"nfs_backend_enabled\": {\"get_param\": \"GlanceNfsEnabled\"}, \"glance_netapp_nfs_enabled\": {\"get_param\": \"GlanceNetappNfsEnabled\"}, \"glance_nfs_share\": {\"get_param\": \"GlanceNfsShare\"}, \"netapp_share_location\": {\"get_param\": \"NetappShareLocation\"}, \"nfs_share\": \"{{ glance_nfs_share if (glance_nfs_share) else netapp_share_location }}\", \"nfs_options\": {\"get_param\": \"GlanceNfsOptions\"}}, \"mount\": {\"name\": \"/var/lib/glance/images\", \"state\": \"mounted\", \"fstype\": \"nfs\", \"src\": \"{{nfs_share}}\", \"opts\": \"{{nfs_options}}\"}, \"when\": \"nfs_backend_enabled or glance_netapp_nfs_enabled\"}, {\"name\": \"Mount Node Staging Location\", \"vars\": {\"glance_node_staging_uri\": {\"get_param\": \"GlanceNodeStagingUri\"}, \"glance_staging_nfs_share\": {\"get_param\": \"GlanceStagingNfsShare\"}, \"glance_nfs_options\": {\"get_param\": \"GlanceStagingNfsOptions\"}}, \"mount\": {\"name\": \"{{glance_node_staging_uri[7:]}}\", \"state\": \"mounted\", \"fstype\": \"nfs\", \"src\": \"{{glance_staging_nfs_share}}\", \"opts\": \"{{glance_nfs_options}}\"}, \"when\": \"glance_staging_nfs_share != \'\'\"}], [{\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}, {\"name\": \"ensure /var/lib/glance exists\", \"file\": {\"path\": \"/var/lib/glance\", \"state\": \"directory\", \"setype\": \"container_file_t\"}}], {\"if\": [\"cinder_backend_enabled\", [{\"name\": \"Allow glance to use cinder\'s lock_path\", \"file\": {\"path\": {\"get_param\": \"GlanceCinderLockPath\"}, \"state\": \"directory\", \"setype\": \"container_file_t\", \"mode\": 504, \"group\": 42400}}, {\"name\": \"Identify dynamic os-brick lock files used by glance\", \"vars\": {\"lock_path\": {\"get_param\": \"GlanceCinderLockPath\"}}, \"ansible.builtin.find\": {\"paths\": \"{{ lock_path }}\", \"patterns\": \"os-brick-connect_to_iscsi_portal-*\"}, \"register\": \"find_dynamic_locks\"}, {\"name\": \"Prepare the os-brick lock files used by glance\", \"vars\": {\"lock_path\": {\"get_param\": \"GlanceCinderLockPath\"}, \"static_brick_locks\": [\"{{ lock_path }}/os-brick-connect_volume\", \"{{ lock_path }}/os-brick-extend_volume\", \"{{ lock_path }}/scaleio-scaleio\"], \"dynamic_brick_locks\": \"{{ find_dynamic_locks.files | map(attribute=\'path\') }}\"}, \"file\": {\"path\": \"{{ item }}\", \"state\": \"touch\", \"setype\": \"container_file_t\", \"mode\": 432, \"group\": 42400}, \"loop\": \"{{ (static_brick_locks + dynamic_brick_locks) | flatten}}\"}]]}, {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}, \"upgrade_tasks\": [{\"name\": \"glance-api pre system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 3\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Unmount and remove NFS glance entry\", \"vars\": {\"nfs_backend_enabled\": {\"get_param\": \"GlanceNfsEnabled\"}, \"glance_netapp_nfs_enabled\": {\"get_param\": \"GlanceNetappNfsEnabled\"}}, \"mount\": {\"name\": \"/var/lib/glance/images\", \"fstype\": \"nfs\", \"state\": \"absent\"}, \"when\": \"nfs_backend_enabled or glance_netapp_nfs_enabled\"}, {\"name\": \"Unmount and remove NFS glance-staging entry\", \"vars\": {\"glance_node_staging_uri\": {\"get_param\": \"GlanceNodeStagingUri\"}, \"glance_staging_nfs_share\": {\"get_param\": \"GlanceStagingNfsShare\"}}, \"mount\": {\"name\": \"{{glance_node_staging_uri[7:]}}\", \"fstype\": \"nfs\", \"state\": \"absent\"}, \"when\": \"glance_staging_nfs_share != \'\'\"}]}, {\"name\": \"glance-api post system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 5\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Mount NFS on host\", \"vars\": {\"nfs_backend_enabled\": {\"get_param\": \"GlanceNfsEnabled\"}, \"glance_netapp_nfs_enabled\": {\"get_param\": \"GlanceNetappNfsEnabled\"}, \"glance_nfs_share\": {\"get_param\": \"GlanceNfsShare\"}, \"netapp_share_location\": {\"get_param\": \"NetappShareLocation\"}, \"nfs_share\": \"{{ glance_nfs_share if (glance_nfs_share) else netapp_share_location }}\", \"nfs_options\": {\"get_param\": \"GlanceNfsOptions\"}}, \"mount\": {\"name\": \"/var/lib/glance/images\", \"state\": \"mounted\", \"fstype\": \"nfs\", \"src\": \"{{nfs_share}}\", \"opts\": \"{{nfs_options}}\"}, \"when\": \"nfs_backend_enabled or glance_netapp_nfs_enabled\"}, {\"name\": \"Mount Node Staging Location\", \"vars\": {\"glance_node_staging_uri\": {\"get_param\": \"GlanceNodeStagingUri\"}, \"glance_staging_nfs_share\": {\"get_param\": \"GlanceStagingNfsShare\"}, \"glance_nfs_options\": {\"get_param\": \"GlanceStagingNfsOptions\"}}, \"mount\": {\"name\": \"{{glance_node_staging_uri[7:]}}\", \"state\": \"mounted\", \"fstype\": \"nfs\", \"src\": \"{{glance_staging_nfs_share}}\", \"opts\": \"{{glance_nfs_options}}\"}, \"when\": \"glance_staging_nfs_share != \'\'\"}]}], \"metadata_settings\": {\"get_attr\": [\"TLSProxyBase\", \"role_data\", \"metadata_settings\"]}, \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop glance api container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"glance_api\", \"glance_api_cron\"], \"tripleo_delegate_to\": \"{{ groups[\'glance_api\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}], \"deploy_steps_tasks\": {\"get_attr\": [\"TLSProxyBase\", \"role_data\", \"deploy_steps_tasks\"]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (125,'2026-06-10 07:47:05',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(126,'2026-06-10 07:47:05',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mysql client settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role for setting mysql client parameters\", \"value\": {\"service_name\": \"mysql_client\", \"config_settings\": {\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"tripleo::profile::base::database::mysql::client::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}}, \"step_config\": \"include tripleo::profile::base::database::mysql::client\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(127,'2026-06-10 07:47:06',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(128,'2026-06-10 07:47:06',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mysql client settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role for setting mysql client parameters\", \"value\": {\"service_name\": \"mysql_client\", \"config_settings\": {\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"tripleo::profile::base::database::mysql::client::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}}, \"step_config\": \"include tripleo::profile::base::database::mysql::client\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(129,'2026-06-10 07:47:06',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(130,'2026-06-10 07:47:06',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"HAProxy deployment with TLS enabled, with an injected certificate\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"SSLCertificate\": {\"default\": \"\", \"description\": \"The content of the SSL certificate (without Key) in PEM format.\\n\", \"type\": \"string\"}, \"SSLIntermediateCertificate\": {\"default\": \"\", \"description\": \"The content of an SSL intermediate CA certificate in PEM format.\\n\", \"type\": \"string\"}, \"SSLKey\": {\"default\": \"\", \"description\": \"The content of the SSL Key in PEM format.\\n\", \"type\": \"string\", \"hidden\": true}, \"DeployedSSLCertificatePath\": {\"default\": \"/etc/pki/tls/private/overcloud_endpoint.pem\", \"description\": \"The filepath of the certificate as it will be stored in the controller.\\n\", \"type\": \"string\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the HAProxy public TLS injection.\", \"value\": {\"service_name\": \"haproxy_public_tls_inject\", \"config_settings\": {}, \"certificates_specs\": {}, \"metadata_settings\": null, \"host_prep_tasks\": [{\"name\": \"get parameters\", \"set_fact\": {\"cert_path\": {\"get_param\": \"DeployedSSLCertificatePath\"}, \"cert_content\": {\"get_param\": \"SSLCertificate\"}, \"chain_content\": {\"get_param\": \"SSLIntermediateCertificate\"}, \"key_content\": {\"get_param\": \"SSLKey\"}}, \"no_log\": \"{{ hide_sensitive_logs | bool }}\"}, {\"name\": \"manage certificate\", \"when\": [\"cert_content is defined\", \"cert_content != \'\'\"], \"block\": [{\"name\": \"get DeployedSSLCertificatePath attributes\", \"register\": \"attr_cert_path\", \"stat\": {\"path\": \"{{cert_path}}\"}}, {\"name\": \"set is_haproxy_bootstrap_node fact\", \"set_fact\": \"is_haproxy_bootstrap_node={{haproxy_short_bootstrap_node_name | lower == ansible_facts[\'hostname\'] | lower}}\", \"when\": [\"haproxy_short_bootstrap_node_name|default(false)\"]}, {\"name\": \"get haproxy status\", \"register\": \"haproxy_state\", \"systemd\": {\"name\": \"haproxy\"}}, {\"name\": \"get pacemaker status\", \"register\": \"pacemaker_state\", \"systemd\": {\"name\": \"pacemaker\"}}, {\"name\": \"get docker status\", \"register\": \"docker_state\", \"systemd\": {\"name\": \"docker\"}}, {\"name\": \"get container_id\", \"when\": [\"docker_state.status.ActiveState == \'active\' or container_cli == \'podman\'\", \"attr_cert_path.stat.exists\", \"attr_cert_path.stat.isdir == False\"], \"command\": \"{{ container_cli }} ps -q -f name=\'^haproxy(-bundle)?\'\", \"register\": \"container_id\"}, {\"name\": \"get pcs resource name for haproxy container\", \"when\": [\"bootstrap_node is defined\", \"is_haproxy_bootstrap_node\", \"pacemaker_state.status.ActiveState == \'active\'\", \"attr_cert_path.stat.exists\", \"attr_cert_path.stat.isdir\"], \"shell\": \"pcs status resources | sed -n \'s/^.*container.*: \\\\(haproxy.*\\\\) .*/\\\\1/p\'\\n\", \"register\": \"pacemaker_resource\"}, {\"name\": \"remove DeployedSSLCertificatePath if is dir\", \"when\": \"attr_cert_path.stat.isdir is defined and attr_cert_path.stat.isdir\", \"file\": {\"path\": \"{{cert_path}}\", \"state\": \"absent\"}}, {\"name\": \"push certificate content\", \"no_log\": \"{{ hide_sensitive_logs | bool }}\", \"copy\": {\"dest\": \"{{cert_path}}\", \"mode\": 288, \"owner\": \"root\", \"content\": \"{{cert_content}}\\n{{chain_content}}\\n{{key_content}}\\n\"}}, {\"name\": \"BM haproxy non-pacemaker context\", \"when\": \"haproxy_state.status.ActiveState == \'active\'\", \"block\": [{\"name\": \"set certificate ownership\", \"file\": {\"path\": \"{{cert_path}}\", \"group\": \"haproxy\"}}, {\"name\": \"reload haproxy if enabled\", \"service\": {\"name\": \"haproxy\", \"state\": \"reloaded\"}}]}, {\"name\": \"restart pacemaker resource for haproxy\", \"when\": [\"pacemaker_resource is defined\", \"pacemaker_resource.stdout is defined\", \"pacemaker_resource.stdout != \'\'\"], \"command\": \"pcs resource restart \\\"{{pacemaker_resource.stdout}}\\\"\"}, {\"name\": \"dedicated part for containers\", \"when\": [\"container_id is defined\", \"container_id.stdout is defined\", \"container_id.stdout != \'\'\"], \"block\": [{\"name\": \"copy certificate, chgrp, restart haproxy\", \"shell\": \"set -e\\nif {{ container_cli }} ps -f \\\"id={{ item }}\\\" --format \\\"{{ \'{{\' }}.Names{{ \'}}\' }}\\\" | grep -q \\\"^haproxy-bundle\\\"; then\\n  tar -c {{ cert_path }} | {{container_cli}} exec -i {{ item }} tar -C / -xv\\nelse\\n  {{ container_cli }} cp {{ cert_path }} {{ item }}:{{ cert_path }}\\nfi\\n{{ container_cli }} exec --user root {{ item }} chgrp haproxy {{ cert_path }}\\n{{ container_cli }} kill --signal=HUP {{ item }}\\n\", \"register\": \"container_kill_result\", \"failed_when\": [\"container_kill_result.rc != 0\", \"(\\\"no such container\\\" not in container_kill_result.stderr)\", \"(\\\"container state improper\\\" not in container_kill_result.stderr)\"], \"with_items\": \"{{ container_id.stdout.split(\'\\n\') }}\"}]}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(131,'2026-06-10 07:47:07',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Glance API service\\n\", \"parameters\": {\"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ContainerGlanceApiImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\"}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerGlanceApiImage\": \"ContainerGlanceApiImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerGlanceApiImage\": {\"get_param\": \"ContainerGlanceApiImage\"}}}]}}}}, \"outputs\": {\"config_settings\": {\"description\": \"Extra hieradata needed to log to files in the host.\", \"value\": null}, \"volumes\": {\"description\": \"The volumes needed to log to files in the host.\", \"value\": [\"/var/log/containers/glance:/var/log/glance:z\", \"/var/log/containers/httpd/glance:/var/log/httpd:z\"]}, \"docker_config\": {\"description\": \"Extra containers needed for logging to files in the host.\", \"value\": {\"step_2\": {\"glance_init_logs\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerGlanceApiImage\"]}, \"net\": \"none\", \"privileged\": false, \"user\": \"root\", \"volumes\": [\"/var/log/containers/glance:/var/log/glance:z\", \"/var/log/containers/httpd/glance:/var/log/httpd:z\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R glance:glance /var/log/glance\"]}}}}, \"host_prep_tasks\": {\"description\": \"Extra ansible tasks needed for logging to files in the host.\", \"value\": [{\"name\": \"create persistent logs directory\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/glance\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/log/containers/httpd/glance\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}]}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(132,'2026-06-10 07:47:08',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(133,'2026-06-10 07:47:08',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Manila API service\\n\", \"parameters\": {\"ContainerManilaApiImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\"}, \"ContainerManilaConfigImage\": {\"description\": \"The container image to use for the manila config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"ManilaWorkers\": {\"type\": \"string\", \"description\": \"Set the number of workers for manila::wsgi::apache\", \"default\": \"%{::os_workers}\"}, \"ManilaPassword\": {\"description\": \"The password for the manila service account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"KqSyIJe4bogoBLLwnLhZJDRFk\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"ManilaApiPolicies\": {\"description\": \"A hash of policies to configure for Manila API.\\ne.g. { manila-context_is_admin: { key: context_is_admin, value: \'role:admin\' } }\\n\", \"default\": {}, \"type\": \"json\"}, \"MonitoringSubscriptionManilaApi\": {\"default\": \"overcloud-manila-api\", \"type\": \"string\"}, \"ManilaEnabledShareProtocols\": {\"default\": \"\", \"description\": \"List of protocols to be allowed for share creation in manila. When not set, the list is inferred via the storage back end/s enabled.\", \"type\": \"comma_delimited_list\"}, \"ManilaCronDbPurgeMinute\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Minute\\n\", \"default\": \"1\"}, \"ManilaCronDbPurgeHour\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Hour\\n\", \"default\": \"0\"}, \"ManilaCronDbPurgeMonthday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month Day\\n\", \"default\": \"*\"}, \"ManilaCronDbPurgeMonth\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month\\n\", \"default\": \"*\"}, \"ManilaCronDbPurgeWeekday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Week Day\\n\", \"default\": \"*\"}, \"ManilaCronDbPurgeUser\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - User\\n\", \"default\": \"manila\"}, \"ManilaCronDbPurgeAge\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Age\\n\", \"default\": \"30\"}, \"ManilaCronDbPurgeDestination\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Log destination\\n\", \"default\": \"/var/log/manila/manila-rowsflush.log\"}, \"ManilaCronDbPurgeMaxDelay\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Max Delay\\n\", \"default\": \"3600\"}, \"MemcacheUseAdvancedPool\": {\"type\": \"boolean\", \"description\": \"Use the advanced (eventlet safe) memcached client pool.\\n\", \"default\": true}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MySQLClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\"}, \"ManilaBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-base.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"ApacheServiceBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}, \"EnableInternalTLS\": {\"get_param\": \"EnableInternalTLS\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerManilaApiImage\": \"ContainerManilaApiImage\", \"ContainerManilaConfigImage\": \"ContainerManilaConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerManilaApiImage\": {\"get_param\": \"ContainerManilaApiImage\"}, \"ContainerManilaConfigImage\": {\"get_param\": \"ContainerManilaConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Manila API role.\", \"value\": {\"service_name\": \"manila_api\", \"firewall_rules\": {\"150 manila\": {\"dport\": [8786]}}, \"firewall_frontend_rules\": {\"100 manila_haproxy_frontend\": {\"dport\": [8786]}}, \"firewall_ssl_frontend_rules\": {\"100 manila_haproxy_frontend_ssl\": {\"dport\": [13786]}}, \"keystone_resources\": {\"manila\": {\"endpoints\": {\"public\": {\"get_param\": [\"EndpointMap\", \"ManilaV1Public\", \"uri\"]}, \"internal\": {\"get_param\": [\"EndpointMap\", \"ManilaV1Internal\", \"uri\"]}, \"admin\": {\"get_param\": [\"EndpointMap\", \"ManilaV1Admin\", \"uri\"]}}, \"users\": {\"manila\": {\"password\": {\"get_param\": \"ManilaPassword\"}}}, \"region\": {\"get_param\": \"KeystoneRegion\"}, \"service\": \"share\"}, \"manilav2\": {\"endpoints\": {\"public\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"uri\"]}, \"internal\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"uri\"]}, \"admin\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"uri\"]}}, \"users\": {\"manilav2\": {\"password\": {\"get_param\": \"ManilaPassword\"}}}, \"region\": {\"get_param\": \"KeystoneRegion\"}, \"service\": \"sharev2\"}}, \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionManilaApi\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"ManilaBase\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"ApacheServiceBase\", \"role_data\", \"config_settings\"]}, {\"manila::keystone::authtoken::password\": {\"get_param\": \"ManilaPassword\"}, \"manila::keystone::authtoken::www_authenticate_uri\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"uri_no_suffix\"]}, \"manila::keystone::authtoken::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"manila::keystone::authtoken::project_name\": \"service\", \"manila::keystone::authtoken::user_domain_name\": \"Default\", \"manila::keystone::authtoken::project_domain_name\": \"Default\", \"manila::keystone::authtoken::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"manila::keystone::authtoken::interface\": \"internal\", \"manila::keystone::authtoken::memcache_use_advanced_pool\": {\"get_param\": \"MemcacheUseAdvancedPool\"}, \"manila::api::bind_host\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}}}}, \"manila::wsgi::apache::bind_host\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}}}}, \"manila::wsgi::apache::ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"manila::api::service_name\": \"httpd\", \"manila::api::enable_proxy_headers_parsing\": true, \"manila::api::default_share_type\": \"default\", \"manila_enabled_share_protocols\": {\"get_param\": \"ManilaEnabledShareProtocols\"}, \"manila::policy::policies\": {\"get_param\": \"ManilaApiPolicies\"}, \"manila::cron::db_purge::minute\": {\"get_param\": \"ManilaCronDbPurgeMinute\"}, \"manila::cron::db_purge::hour\": {\"get_param\": \"ManilaCronDbPurgeHour\"}, \"manila::cron::db_purge::monthday\": {\"get_param\": \"ManilaCronDbPurgeMonthday\"}, \"manila::cron::db_purge::month\": {\"get_param\": \"ManilaCronDbPurgeMonth\"}, \"manila::cron::db_purge::weekday\": {\"get_param\": \"ManilaCronDbPurgeWeekday\"}, \"manila::cron::db_purge::user\": {\"get_param\": \"ManilaCronDbPurgeUser\"}, \"manila::cron::db_purge::age\": {\"get_param\": \"ManilaCronDbPurgeAge\"}, \"manila::cron::db_purge::destination\": {\"get_param\": \"ManilaCronDbPurgeDestination\"}, \"manila::cron::db_purge::maxdelay\": {\"get_param\": \"ManilaCronDbPurgeMaxDelay\"}, \"manila::wsgi::apache::servername\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}}}}, \"manila::wsgi::apache::workers\": {\"get_param\": \"ManilaWorkers\"}}]}, \"service_config_settings\": {\"get_attr\": [\"ManilaBase\", \"role_data\", \"service_config_settings\"]}, \"puppet_config\": {\"config_volume\": \"manila\", \"puppet_tags\": \"manila_config,manila_api_paste_ini\", \"step_config\": {\"list_join\": [\"\\n\", [\"include tripleo::profile::base::manila::api\", {\"get_attr\": [\"MySQLClient\", \"role_data\", \"step_config\"]}]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerManilaConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/manila_api.json\": {\"command\": \"/usr/sbin/httpd -DFOREGROUND\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.d\", \"dest\": \"/etc/httpd/conf.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.modules.d\", \"dest\": \"/etc/httpd/conf.modules.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/manila\", \"owner\": \"manila:manila\", \"recurse\": true}]}, \"/var/lib/kolla/config_files/manila_api_db_sync.json\": {\"command\": \"/usr/bin/bootstrap_host_exec manila_api su manila -s /bin/bash -c \'/usr/bin/manila-manage db sync\'\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.d\", \"dest\": \"/etc/httpd/conf.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.modules.d\", \"dest\": \"/etc/httpd/conf.modules.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/manila\", \"owner\": \"manila:manila\", \"recurse\": true}]}, \"/var/lib/kolla/config_files/manila_api_cron.json\": {\"command\": \"/usr/sbin/crond -n\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/manila\", \"owner\": \"manila:manila\", \"recurse\": true}]}}, \"docker_config\": {\"step_2\": {\"manila_init_logs\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerManilaApiImage\"]}, \"net\": \"none\", \"user\": \"root\", \"volumes\": [\"/var/log/containers/manila:/var/log/manila:z\", \"/var/log/containers/httpd/manila-api:/var/log/httpd:z\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R manila:manila /var/log/manila\"]}}, \"step_3\": {\"manila_api_db_sync\": {\"user\": \"root\", \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerManilaApiImage\"]}, \"cap_add\": [\"AUDIT_WRITE\"], \"net\": \"host\", \"detach\": false, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/manila_api_db_sync.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/manila:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/manila:/var/log/manila:z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}, \"step_4\": {\"manila_api\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerManilaApiImage\"]}, \"net\": \"host\", \"restart\": \"always\", \"user\": \"root\", \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/manila_api.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/manila:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/manila:/var/log/manila:z\", \"/var/log/containers/httpd/manila-api:/var/log/httpd:z\"], {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [\"/etc/pki/tls/certs/httpd:/etc/pki/tls/certs/httpd:ro\", \"/etc/pki/tls/private/httpd:/etc/pki/tls/private/httpd:ro\"]]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}, \"manila_api_cron\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerManilaApiImage\"]}, \"net\": \"host\", \"user\": \"root\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/usr/share/openstack-tripleo-common/healthcheck/cron manila\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/manila_api_cron.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/manila:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/manila:/var/log/manila:z\", \"/var/log/containers/httpd/manila-api:/var/log/httpd:z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"metadata_settings\": {\"get_attr\": [\"ApacheServiceBase\", \"role_data\", \"metadata_settings\"]}, \"deploy_steps_tasks\": {\"get_attr\": [\"ApacheServiceBase\", \"role_data\", \"deploy_steps_tasks\"]}, \"host_prep_tasks\": [{\"name\": \"Create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/manila\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/log/containers/httpd/manila-api\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}], \"upgrade_tasks\": [], \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop manila api container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"manila_api\"], \"tripleo_delegate_to\": \"{{ groups[\'manila_api\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(134,'2026-06-10 07:47:09',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mysql client settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role for setting mysql client parameters\", \"value\": {\"service_name\": \"mysql_client\", \"config_settings\": {\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"tripleo::profile::base::database::mysql::client::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}}, \"step_config\": \"include tripleo::profile::base::database::mysql::client\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(135,'2026-06-10 07:47:09',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Glance API service\\n\", \"parameters\": {\"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ContainerGlanceApiImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\"}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerGlanceApiImage\": \"ContainerGlanceApiImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerGlanceApiImage\": {\"get_param\": \"ContainerGlanceApiImage\"}}}]}}}}, \"outputs\": {\"config_settings\": {\"description\": \"Extra hieradata needed to log to files in the host.\", \"value\": null}, \"volumes\": {\"description\": \"The volumes needed to log to files in the host.\", \"value\": [\"/var/log/containers/glance:/var/log/glance:z\", \"/var/log/containers/httpd/glance:/var/log/httpd:z\"]}, \"docker_config\": {\"description\": \"Extra containers needed for logging to files in the host.\", \"value\": {\"step_2\": {\"glance_init_logs\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerGlanceApiImage\"]}, \"net\": \"none\", \"privileged\": false, \"user\": \"root\", \"volumes\": [\"/var/log/containers/glance:/var/log/glance:z\", \"/var/log/containers/httpd/glance:/var/log/httpd:z\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R glance:glance /var/log/glance\"]}}}}, \"host_prep_tasks\": {\"description\": \"Extra ansible tasks needed for logging to files in the host.\", \"value\": [{\"name\": \"create persistent logs directory\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/glance\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/log/containers/httpd/glance\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}]}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (136,'2026-06-10 07:47:09',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Heat Engine service\\n\", \"parameters\": {\"ContainerHeatEngineImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\"}, \"ContainerHeatConfigImage\": {\"description\": \"The container image to use for the heat config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\"}, \"HeatEngineLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.heat.engine\", \"file\": \"/var/log/containers/heat/heat-engine.log\"}}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"DeployIdentifier\": {\"default\": 1781077560, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}, \"HeatEngineOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\"}, \"HeatEngineOptEnvVars\": {\"default\": {}, \"description\": \"hash of optional environment variables\", \"type\": \"json\"}, \"HeatEnableDBPurge\": {\"type\": \"boolean\", \"default\": true, \"description\": \"Whether to create cron job for purging soft deleted rows in the Heat database.\\n\"}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}, \"HeatWorkers\": {\"default\": 1, \"description\": \"Number of workers for Heat service.\", \"type\": \"number\"}, \"HeatMaxNestedStackDepth\": {\"default\": 6, \"description\": \"Maximum number of nested stack depth.\", \"type\": \"number\"}, \"HeatReauthenticationAuthMethod\": {\"description\": \"Allow reauthentication on token expiry, such that long-running tasks may complete. Note this defeats the expiry of any provided user tokens.\", \"type\": \"string\", \"default\": \"\", \"constraints\": [{\"allowed_values\": [\"\", \"trusts\"]}]}, \"HeatPassword\": {\"description\": \"The password for the Heat service and db account, used by the Heat services.\", \"type\": \"string\", \"hidden\": true, \"default\": \"bFBTZhN5CyNCch5KSkr70C02s\"}, \"HeatStackDomainAdminPassword\": {\"description\": \"Password for heat_stack_domain_admin user.\", \"type\": \"string\", \"hidden\": true, \"default\": \"UVdJtbPbJkihrvjY5nov69TzB\"}, \"HeatAuthEncryptionKey\": {\"description\": \"Auth encryption key for heat-engine\", \"type\": \"string\", \"hidden\": true, \"default\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\"}, \"MonitoringSubscriptionHeatEngine\": {\"default\": \"overcloud-heat-engine\", \"type\": \"string\"}, \"HeatConvergenceEngine\": {\"type\": \"boolean\", \"default\": true, \"description\": \"Enables the heat engine with the convergence architecture.\"}, \"HeatMaxResourcesPerStack\": {\"type\": \"number\", \"default\": 1000, \"description\": \"Maximum resources allowed per top-level stack. -1 stands for unlimited.\"}, \"HeatEnginePluginDirs\": {\"type\": \"comma_delimited_list\", \"default\": [], \"description\": \"An array of directories to search for plug-ins.\"}, \"HeatConfigureDelegatedRoles\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Create delegated roles\"}, \"ClientRetryLimit\": {\"type\": \"number\", \"default\": 2, \"description\": \"Client retries for transient errors.\"}}, \"conditions\": {\"heat_workers_set\": {\"not\": {\"equals\": [{\"get_param\": \"HeatWorkers\"}, 0]}}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MySQLClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\"}, \"HeatBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-base-puppet.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"HeatEngineLogging\": {\"type\": \"OS::TripleO::Services::Logging::HeatEngine\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerHeatEngineImage\": \"ContainerHeatEngineImage\", \"ContainerHeatConfigImage\": \"ContainerHeatConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerHeatEngineImage\": {\"get_param\": \"ContainerHeatEngineImage\"}, \"ContainerHeatConfigImage\": {\"get_param\": \"ContainerHeatConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Heat Engine role.\", \"value\": {\"service_name\": \"heat_engine\", \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionHeatEngine\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"HeatBase\", \"role_data\", \"config_settings\"]}, {\"apache::default_vhost\": false, \"heat::engine::configure_delegated_roles\": {\"get_param\": \"HeatConfigureDelegatedRoles\"}, \"heat::engine::trusts_delegated_roles\": [], \"heat::engine::max_nested_stack_depth\": {\"get_param\": \"HeatMaxNestedStackDepth\"}, \"heat::engine::max_resources_per_stack\": {\"get_param\": \"HeatMaxResourcesPerStack\"}, \"heat::engine::reauthentication_auth_method\": {\"get_param\": \"HeatReauthenticationAuthMethod\"}, \"heat::engine::heat_metadata_server_url\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"protocol\"]}, \"host\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"host\"]}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"port\"]}}}, \"heat::engine::heat_waitcondition_server_url\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"protocol\"]}, \"host\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"host\"]}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"port\"]}, \"path\": \"/v1/waitcondition\"}}, \"heat::engine::convergence_engine\": {\"get_param\": \"HeatConvergenceEngine\"}, \"heat::engine::client_retry_limit\": {\"get_param\": \"ClientRetryLimit\"}, \"tripleo::profile::base::heat::manage_db_purge\": {\"get_param\": \"HeatEnableDBPurge\"}, \"heat::database_connection\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"protocol\"]}, \"username\": \"heat\", \"password\": {\"get_param\": \"HeatPassword\"}, \"host\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"host\"]}, \"path\": \"/heat\", \"query\": {\"if\": [{\"get_param\": \"EnableSQLAlchemyCollectd\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\", \"plugin\": \"collectd\", \"collectd_program_name\": \"heat\", \"collectd_host\": \"localhost\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\"}]}}}, \"heat::keystone_ec2_uri\": {\"list_join\": [\"\", [{\"get_param\": [\"EndpointMap\", \"KeystoneV3Internal\", \"uri\"]}, \"/ec2tokens\"]]}, \"heat::keystone::domain::domain_password\": {\"get_param\": \"HeatStackDomainAdminPassword\"}, \"heat::engine::auth_encryption_key\": {\"get_param\": \"HeatAuthEncryptionKey\"}, \"heat::engine::plugin_dirs\": {\"get_param\": \"HeatEnginePluginDirs\"}}, {\"if\": [\"heat_workers_set\", {\"heat::engine::num_engine_workers\": {\"get_param\": \"HeatWorkers\"}}]}]}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_heat_engine\": [{\"get_param\": \"HeatEngineLoggingSource\"}]}, \"mysql\": {\"heat::db::mysql::password\": {\"get_param\": \"HeatPassword\"}, \"heat::db::mysql::user\": \"heat\", \"heat::db::mysql::host\": \"%\", \"heat::db::mysql::dbname\": \"heat\"}}, \"puppet_config\": {\"config_volume\": \"heat\", \"puppet_tags\": \"heat_config,file,concat,file_line\", \"step_config\": {\"list_join\": [\"\\n\", [\"include tripleo::profile::base::heat::engine\", {\"get_attr\": [\"MySQLClient\", \"role_data\", \"step_config\"]}]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHeatConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/heat_engine.json\": {\"command\": {\"list_join\": [\" \", [\"/usr/bin/heat-engine --config-file /usr/share/heat/heat-dist.conf --config-file /etc/heat/heat.conf\", {\"get_attr\": [\"HeatEngineLogging\", \"cmd_extra_args\"]}]]}, \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/heat\", \"owner\": \"heat:heat\", \"recurse\": true}]}, \"/var/lib/kolla/config_files/heat_engine_db_sync.json\": {\"command\": \"/usr/bin/bootstrap_host_exec heat_engine su heat -s /bin/bash -c \'heat-manage db_sync\'\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/heat\", \"owner\": \"heat:heat\", \"recurse\": true}]}}, \"docker_config\": {\"step_2\": {\"get_attr\": [\"HeatEngineLogging\", \"docker_config\", \"step_2\"]}, \"step_3\": {\"heat_engine_db_sync\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHeatEngineImage\"]}, \"cap_add\": [\"AUDIT_WRITE\"], \"net\": \"host\", \"privileged\": false, \"detach\": false, \"user\": \"root\", \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"HeatEngineLogging\", \"volumes\"]}, {\"get_param\": \"HeatEngineOptVolumes\"}, [\"/var/lib/kolla/config_files/heat_engine_db_sync.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/heat:/var/lib/kolla/config_files/src:ro\"]]}, \"environment\": {\"map_merge\": [{\"get_param\": \"HeatEngineOptEnvVars\"}, {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\", \"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}}]}}}, \"step_4\": {\"heat_engine\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHeatEngineImage\"]}, \"net\": \"host\", \"privileged\": false, \"stop_grace_period\": 60, \"restart\": \"always\", \"healthcheck\": {\"get_attr\": [\"ContainersCommon\", \"healthcheck_rpc_port\"]}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"HeatEngineLogging\", \"volumes\"]}, {\"get_param\": \"HeatEngineOptVolumes\"}, [\"/var/lib/kolla/config_files/heat_engine.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/heat:/var/lib/kolla/config_files/src:ro\"]]}, \"environment\": {\"map_merge\": [{\"get_param\": \"HeatEngineOptEnvVars\"}, {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}]}}}}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"HeatEngineLogging\", \"host_prep_tasks\"]}, [{\"name\": \"enable virt_sandbox_use_netlink for healthcheck\", \"seboolean\": {\"name\": \"virt_sandbox_use_netlink\", \"persistent\": true, \"state\": true}, \"when\": [\"ansible_facts.selinux is defined\", \"ansible_facts.selinux.status == \\\"enabled\\\"\"]}]]}, \"upgrade_tasks\": [], \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop heat engine container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"heat_engine\"], \"tripleo_delegate_to\": \"{{ groups[\'heat_engine\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(137,'2026-06-10 07:47:10',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Openstack Cinder NVMeOF backend\\n\", \"parameters\": {\"CinderEnableNVMeOFBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NVMeOF backend for Cinder\", \"type\": \"boolean\"}, \"CinderNVMeOFBackendName\": {\"type\": \"string\", \"default\": \"tripleo_nvmeof\"}, \"CinderNVMeOFAvailabilityZone\": {\"default\": \"\", \"description\": \"The availability zone of the NVMeOF Cinder backend. When set, it overrides the default CinderStorageAvailabilityZone.\\n\", \"type\": \"string\"}, \"CinderNVMeOFTargetPort\": {\"type\": \"number\", \"default\": 4420}, \"CinderNVMeOFTargetHelper\": {\"type\": \"string\", \"default\": \"nvmet\"}, \"CinderNVMeOFTargetProtocol\": {\"type\": \"string\", \"default\": \"nvmet_rdma\", \"description\": \"The target protocol, supported values are nvmet_rdma and nvmet_tcp.\\n\", \"constraints\": [{\"allowed_values\": [\"nvmet_rdma\", \"nvmet_tcp\"]}]}, \"CinderNVMeOFTargetPrefix\": {\"type\": \"string\", \"default\": \"nvme-subsystem\"}, \"CinderNVMeOFTargetPortId\": {\"type\": \"number\", \"default\": 1}, \"CinderNVMeOFTargetNameSpaceId\": {\"type\": \"number\", \"default\": 10}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"type\": \"json\", \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\"}}, \"outputs\": {\"cinder_nvmeof_host_prep_tasks\": {\"description\": \"Host prep tasks related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [{\"name\": \"ensure /etc/nvme exists\", \"file\": {\"path\": \"/etc/nvme\", \"state\": \"directory\", \"setype\": \"container_file_t\"}}]]}}, \"cinder_nvmeof_volumes\": {\"description\": \"Volumes related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [\"/etc/nvme:/etc/nvme:z\"]]}}, \"role_data\": {\"description\": \"Role data for the Cinder NVMeOF backend.\", \"value\": {\"service_name\": \"cinder_backend_nvmeof\", \"firewall_rules\": {\"120 LVM nvmet target\": {\"dport\": {\"get_param\": \"CinderNVMeOFTargetPort\"}}}, \"config_settings\": {\"map_merge\": [{\"tripleo::profile::base::cinder::volume::cinder_enable_nvmeof_backend\": {\"get_param\": \"CinderEnableNVMeOFBackend\"}, \"tripleo::profile::base::cinder::volume::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_port\": {\"get_param\": \"CinderNVMeOFTargetPort\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_helper\": {\"get_param\": \"CinderNVMeOFTargetHelper\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_protocol\": {\"get_param\": \"CinderNVMeOFTargetProtocol\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_prefix\": {\"get_param\": \"CinderNVMeOFTargetPrefix\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_port_id\": {\"get_param\": \"CinderNVMeOFTargetPortId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_ns_id\": {\"get_param\": \"CinderNVMeOFTargetNameSpaceId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_ip_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderIscsiNetwork\"]}}}}, \"cinder::backend::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}}, {\"if\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderNVMeOFAvailabilityZone\"}, \"\"]}}, {\"tripleo::profile::base::cinder::volume::nvmeof::backend_availability_zone\": {\"get_param\": \"CinderNVMeOFAvailabilityZone\"}}]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(138,'2026-06-10 07:47:10',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Openstack Manila base service. Shared by manila-api/scheduler/share services\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ManilaIPv6\": {\"default\": false, \"description\": \"Set to True to enable IPv6 access in manila.\", \"type\": \"boolean\"}, \"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"ManilaDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Manila services.\", \"type\": \"boolean\"}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}, \"ManilaPassword\": {\"description\": \"The password for the manila service account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"KqSyIJe4bogoBLLwnLhZJDRFk\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"noop\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"ManilaStorageAvailabilityZone\": {\"default\": \"nova\", \"description\": \"The Manila service\'s storage availability zone.\", \"type\": \"string\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Manila Base service.\", \"value\": {\"service_name\": \"manila_base\", \"config_settings\": {\"manila::storage_availability_zone\": {\"get_param\": \"ManilaStorageAvailabilityZone\"}, \"manila::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"manila::logging::debug\": {\"if\": [{\"get_param\": \"ManilaDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"manila::db::database_db_max_retries\": -1, \"manila::db::database_max_retries\": -1, \"manila::sql_connection\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"protocol\"]}, \"username\": \"manila\", \"password\": {\"get_param\": \"ManilaPassword\"}, \"host\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"host\"]}, \"path\": \"/manila\", \"query\": {\"if\": [{\"get_param\": \"EnableSQLAlchemyCollectd\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\", \"plugin\": \"collectd\", \"collectd_program_name\": \"manila\", \"collectd_host\": \"localhost\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\"}]}}}, \"manila::network::neutron::network_plugin_ipv6_enabled\": {\"get_param\": \"ManilaIPv6\"}, \"manila::network::neutron::network_plugin_ipv4_enabled\": {\"if\": [{\"get_param\": \"ManilaIPv6\"}, false, true]}, \"manila::rabbit_heartbeat_in_pthread\": false}, \"service_config_settings\": {\"mysql\": {\"manila::db::mysql::password\": {\"get_param\": \"ManilaPassword\"}, \"manila::db::mysql::user\": \"manila\", \"manila::db::mysql::host\": \"%\", \"manila::db::mysql::dbname\": \"manila\"}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(139,'2026-06-10 07:47:10',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(140,'2026-06-10 07:47:11',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Apache service configured with Puppet. Note this is typically included automatically via other services which run via Apache.\\n\", \"parameters\": {\"ApacheMaxRequestWorkers\": {\"default\": 100, \"description\": \"Maximum number of simultaneously processed requests.\", \"type\": \"number\"}, \"ApacheServerLimit\": {\"default\": 100, \"description\": \"Maximum number of Apache processes.\", \"type\": \"number\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"ApacheCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}, \"ApacheTimeout\": {\"type\": \"number\", \"default\": 90, \"description\": \"The timeout in seconds for Apache, which defines duration Apache waits for I/O operations\"}}, \"conditions\": {\"key_size_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"ApacheCertificateKeySize\"}, \"\"]}}}, \"resources\": {\"ApacheNetworks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"Controller\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"CellController\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"CellControllerCompute\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"Compute\": [\"ctlplane\", \"storage\", \"internal_api\"], \"BlockStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"ObjectStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"CephStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\"], \"Networker\": [\"ctlplane\", \"internal_api\"]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Apache role.\", \"value\": {\"service_name\": \"apache\", \"config_settings\": {\"map_merge\": [{\"apache::ip\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ApacheNetwork\"]}}}}, \"apache::default_vhost\": false, \"apache::trace_enable\": \"Off\", \"apache::server_signature\": \"Off\", \"apache::server_tokens\": \"Prod\", \"apache::timeout\": {\"get_param\": \"ApacheTimeout\"}, \"apache::default_mods\": false, \"apache::mod::prefork::maxrequestworkers\": {\"get_param\": \"ApacheMaxRequestWorkers\"}, \"apache::mod::prefork::serverlimit\": {\"get_param\": \"ApacheServerLimit\"}, \"apache::mod::remoteip::proxy_ips\": {\"get_param\": [\"ServiceData\", \"net_cidr_map\", {\"get_param\": [\"ServiceNetMap\", \"ApacheNetwork\"]}]}, \"apache::mod::alias::icons_options\": \"None\"}, {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"apache::mod::ssl::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}, \"apache::mod::ssl::ssl_protocol\": [\"all\", \"-SSLv2\", \"-SSLv3\", \"-TLSv1\"], \"apache_certificates_specs\": {\"map_merge\": {\"repeat\": {\"template\": {\"httpd-NETWORK\": {\"service_certificate\": \"/etc/pki/tls/certs/httpd/httpd-NETWORK.crt\", \"service_key\": \"/etc/pki/tls/private/httpd/httpd-NETWORK.key\"}}, \"for_each\": {\"NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}}}]}]}, \"metadata_settings\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"repeat\": {\"template\": [{\"service\": \"HTTP\", \"network\": \"$NETWORK\", \"type\": \"node\"}], \"for_each\": {\"$NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}]}, \"upgrade_tasks\": [], \"deploy_steps_tasks\": [{\"name\": \"Certificate generation\", \"when\": [\"step|int == 1\", \"enable_internal_tls\"], \"block\": [{\"name\": \"Create dirs for certificates and keys\", \"file\": {\"path\": \"{{ item }}\", \"state\": \"directory\", \"serole\": \"object_r\", \"setype\": \"cert_t\", \"seuser\": \"system_u\"}, \"with_items\": [\"/etc/pki/tls/certs/httpd\", \"/etc/pki/tls/private/httpd\"]}, {\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": {\"repeat\": {\"template\": {\"name\": \"httpd-NETWORK\", \"dns\": \"{{ fqdn_NETWORK }}\", \"principal\": \"HTTP/{{ fqdn_NETWORK }}@{{ idm_realm }}\", \"run_after\": \"cp /etc/pki/tls/certs/httpd-NETWORK.crt /etc/pki/tls/certs/httpd/httpd-NETWORK.crt\\ncp /etc/pki/tls/private/httpd-NETWORK.key /etc/pki/tls/private/httpd/httpd-NETWORK.key\\npkill -USR1 httpd\\n\", \"key_size\": {\"if\": [\"key_size_override_set\", {\"get_param\": \"ApacheCertificateKeySize\"}, {\"get_param\": \"CertificateKeySize\"}]}, \"ca\": \"ipa\"}, \"for_each\": {\"NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"EnableInternalTLS\": false}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(141,'2026-06-10 07:47:11',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mysql client settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role for setting mysql client parameters\", \"value\": {\"service_name\": \"mysql_client\", \"config_settings\": {\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"tripleo::profile::base::database::mysql::client::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}}, \"step_config\": \"include tripleo::profile::base::database::mysql::client\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(142,'2026-06-10 07:47:11',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Openstack Heat base service. Shared for all Heat services.\\n\", \"parameters\": {\"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"HeatDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Heat services.\", \"type\": \"boolean\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"HeatPassword\": {\"description\": \"The password for the Heat service and db account, used by the Heat services.\", \"type\": \"string\", \"hidden\": true, \"default\": \"bFBTZhN5CyNCch5KSkr70C02s\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableCache\": {\"description\": \"Enable caching with memcached\", \"type\": \"boolean\", \"default\": true}, \"HeatCronPurgeDeletedEnsure\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Ensure\\n\", \"default\": \"present\"}, \"HeatCronPurgeDeletedMinute\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Minute\\n\", \"default\": \"1\"}, \"HeatCronPurgeDeletedHour\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Hour\\n\", \"default\": \"0\"}, \"HeatCronPurgeDeletedMonthday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month Day\\n\", \"default\": \"*\"}, \"HeatCronPurgeDeletedMonth\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month\\n\", \"default\": \"*\"}, \"HeatCronPurgeDeletedWeekday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Week Day\\n\", \"default\": \"*\"}, \"HeatCronPurgeDeletedMaxDelay\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Max Delay\\n\", \"default\": \"3600\"}, \"HeatCronPurgeDeletedUser\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - User\\n\", \"default\": \"heat\"}, \"HeatCronPurgeDeletedAge\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Age\\n\", \"default\": \"30\"}, \"HeatCronPurgeDeletedAgeType\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Age type\\n\", \"default\": \"days\"}, \"HeatCronPurgeDeletedDestination\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Log destination\\n\", \"default\": \"/dev/null\"}, \"HeatYaqlLimitIterators\": {\"type\": \"number\", \"description\": \"The maximum number of elements in collection yaql expressions can take for its evaluation.\\n\", \"default\": 1000}, \"HeatYaqlMemoryQuota\": {\"type\": \"number\", \"description\": \"The maximum size of memory in bytes that yaql exrpessions can take for its evaluation.\\n\", \"default\": 100000}, \"HeatMaxJsonBodySize\": {\"default\": 4194304, \"description\": \"Maximum raw byte size of the Heat API JSON request body.\", \"type\": \"number\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"noop\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"HeatCorsAllowedOrigin\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Indicate whether this resource may be shared with the domain received in the request \\\"origin\\\" header.\"}, \"MemcachedTLS\": {\"default\": false, \"description\": \"Set to True to enable TLS on Memcached service. Because not all services support Memcached TLS, during the migration period, Memcached will listen on 2 ports - on the port set with MemcachedPort parameter (above) and on 11211, without TLS.\", \"type\": \"boolean\"}, \"MemcacheUseAdvancedPool\": {\"type\": \"boolean\", \"description\": \"Use the advanced (eventlet safe) memcached client pool.\\n\", \"default\": true}, \"HeatApiPolicies\": {\"description\": \"A hash of policies to configure for Heat API.\\ne.g. { heat-context_is_admin: { key: context_is_admin, value: \'role:admin\' } }\\n\", \"default\": {}, \"type\": \"json\"}, \"EnforceSecureRbac\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Setting this option to True will configure each OpenStack service to enforce Secure RBAC by setting `[oslo_policy] enforce_new_defaults` and `[oslo_policy] enforce_scope` to True. This introduces a consistent set of RBAC personas across OpenStack services that include support for system and project scope, as well as keystone\'s default roles, admin, member, and reader. Do not enable this functionality until all services in your deployment actually support secure RBAC.\"}}, \"conditions\": {\"tls_cache_enabled\": {\"and\": [{\"get_param\": \"EnableCache\"}, {\"get_param\": \"MemcachedTLS\"}]}, \"cors_allowed_origin_set\": {\"not\": {\"equals\": [{\"get_param\": \"HeatCorsAllowedOrigin\"}, \"\"]}}}, \"outputs\": {\"role_data\": {\"description\": \"Shared role data for the Heat services.\", \"value\": {\"service_name\": \"heat_base\", \"config_settings\": {\"map_merge\": [{\"if\": [{\"get_param\": \"EnforceSecureRbac\"}, {\"heat::policy::enforce_scope\": true, \"heat::policy::enforce_new_defaults\": true}]}, {\"if\": [\"cors_allowed_origin_set\", {\"heat::cors::allowed_origin\": {\"get_param\": \"HeatCorsAllowedOrigin\"}}]}, {\"heat::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"heat::logging::debug\": {\"if\": [{\"get_param\": \"HeatDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"heat::policy::policies\": {\"get_param\": \"HeatApiPolicies\"}, \"heat::enable_proxy_headers_parsing\": true, \"heat::rpc_response_timeout\": 600, \"heat::rabbit_heartbeat_timeout_threshold\": 60, \"heat::rabbit_heartbeat_in_pthread\": false, \"heat::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"heat::keystone::authtoken::project_name\": \"service\", \"heat::keystone::authtoken::user_domain_name\": \"Default\", \"heat::keystone::authtoken::project_domain_name\": \"Default\", \"heat::keystone::authtoken::www_authenticate_uri\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"uri_no_suffix\"]}, \"heat::keystone::authtoken::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"heat::keystone::authtoken::password\": {\"get_param\": \"HeatPassword\"}, \"heat::keystone::authtoken::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"heat::keystone::authtoken::interface\": \"internal\", \"heat::keystone::authtoken::memcache_use_advanced_pool\": {\"get_param\": \"MemcacheUseAdvancedPool\"}, \"heat::keystone::domain::domain_name\": \"heat_stack\", \"heat::keystone::domain::domain_admin\": \"heat_stack_domain_admin\", \"heat::keystone::domain::domain_admin_email\": \"heat_stack_domain_admin@localhost\", \"heat::db::database_db_max_retries\": -1, \"heat::db::database_max_retries\": -1, \"heat::yaql_memory_quota\": {\"get_param\": \"HeatYaqlMemoryQuota\"}, \"heat::yaql_limit_iterators\": {\"get_param\": \"HeatYaqlLimitIterators\"}, \"heat::cors::max_age\": 3600, \"heat::cors::allow_headers\": \"Content-Type,Cache-Control,Content-Language,Expires,Last-Modified,Pragma,X-Auth-Token\", \"heat::cors::expose_headers\": \"Content-Type,Cache-Control,Content-Language,Expires,Last-Modified,Pragma\", \"heat::cron::purge_deleted::ensure\": {\"get_param\": \"HeatCronPurgeDeletedEnsure\"}, \"heat::cron::purge_deleted::minute\": {\"get_param\": \"HeatCronPurgeDeletedMinute\"}, \"heat::cron::purge_deleted::hour\": {\"get_param\": \"HeatCronPurgeDeletedHour\"}, \"heat::cron::purge_deleted::monthday\": {\"get_param\": \"HeatCronPurgeDeletedMonthday\"}, \"heat::cron::purge_deleted::month\": {\"get_param\": \"HeatCronPurgeDeletedMonth\"}, \"heat::cron::purge_deleted::weekday\": {\"get_param\": \"HeatCronPurgeDeletedWeekday\"}, \"heat::cron::purge_deleted::maxdelay\": {\"get_param\": \"HeatCronPurgeDeletedMaxDelay\"}, \"heat::cron::purge_deleted::user\": {\"get_param\": \"HeatCronPurgeDeletedUser\"}, \"heat::cron::purge_deleted::age\": {\"get_param\": \"HeatCronPurgeDeletedAge\"}, \"heat::cron::purge_deleted::age_type\": {\"get_param\": \"HeatCronPurgeDeletedAgeType\"}, \"heat::cron::purge_deleted::destination\": {\"get_param\": \"HeatCronPurgeDeletedDestination\"}, \"heat::max_json_body_size\": {\"get_param\": \"HeatMaxJsonBodySize\"}}, {\"heat::cache::enabled\": {\"get_param\": \"EnableCache\"}, \"heat::cache::tls_enabled\": {\"get_param\": \"MemcachedTLS\"}, \"heat::cache::resource_finder_caching\": false}, {\"if\": [\"tls_cache_enabled\", {\"heat::cache::backend\": \"dogpile.cache.pymemcache\"}, {\"heat::cache::backend\": \"dogpile.cache.memcached\"}]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(143,'2026-06-10 07:47:12',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(144,'2026-06-10 07:47:12',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mysql client settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role for setting mysql client parameters\", \"value\": {\"service_name\": \"mysql_client\", \"config_settings\": {\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"tripleo::profile::base::database::mysql::client::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}}, \"step_config\": \"include tripleo::profile::base::database::mysql::client\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(145,'2026-06-10 07:47:12',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Heat API CFN service\\n\", \"parameters\": {\"ContainerHeatApiCfnImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\"}, \"ContainerHeatApiCfnConfigImage\": {\"description\": \"The container image to use for the heat_api_cfn config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\"}, \"HeatApiCfnLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.heat.api.cfn\", \"file\": \"/var/log/containers/heat/heat_api_cfn.log\"}}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"HeatWorkers\": {\"default\": 1, \"description\": \"Number of workers for Heat service.\", \"type\": \"number\"}, \"HeatPassword\": {\"description\": \"The password for the Heat service and db account, used by the Heat services.\", \"type\": \"string\", \"hidden\": true, \"default\": \"bFBTZhN5CyNCch5KSkr70C02s\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"MonitoringSubscriptionHeatApiCnf\": {\"default\": \"overcloud-heat-api-cfn\", \"type\": \"string\"}}, \"conditions\": {\"heat_workers_set\": {\"not\": {\"equals\": [{\"get_param\": \"HeatWorkers\"}, 0]}}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"ApacheServiceBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}, \"EnableInternalTLS\": {\"get_param\": \"EnableInternalTLS\"}}}, \"HeatBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-base-puppet.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"HeatApiCfnLogging\": {\"type\": \"OS::TripleO::Services::Logging::HeatApiCfn\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerHeatApiCfnImage\": \"ContainerHeatApiCfnImage\", \"ContainerHeatApiCfnConfigImage\": \"ContainerHeatApiCfnConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerHeatApiCfnImage\": {\"get_param\": \"ContainerHeatApiCfnImage\"}, \"ContainerHeatApiCfnConfigImage\": {\"get_param\": \"ContainerHeatApiCfnConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Heat API CFN role.\", \"value\": {\"service_name\": \"heat_api_cfn\", \"firewall_rules\": {\"125 heat_cfn\": {\"dport\": [8000]}}, \"firewall_frontend_rules\": {\"100 heat_api_cfn_haproxy_frontend\": {\"dport\": [8000]}}, \"firewall_ssl_frontend_rules\": {\"100 heat_api_cfn_haproxy_frontend_ssl\": {\"dport\": [13005]}}, \"keystone_resources\": {\"heat-cfn\": {\"endpoints\": {\"public\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"uri\"]}, \"internal\": {\"get_param\": [\"EndpointMap\", \"HeatCfnInternal\", \"uri\"]}, \"admin\": {\"get_param\": [\"EndpointMap\", \"HeatCfnAdmin\", \"uri\"]}}, \"users\": {\"heat-cfn\": {\"password\": {\"get_param\": \"HeatPassword\"}}}, \"region\": {\"get_param\": \"KeystoneRegion\"}, \"service\": \"cloudformation\"}}, \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionHeatApiCnf\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"HeatBase\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"HeatApiCfnLogging\", \"config_settings\"]}, {\"apache::default_vhost\": false, \"heat::api_cfn::bind_host\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiCfnNetwork\"]}}}}, \"heat::wsgi::apache_api_cfn::ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"heat::api_cfn::service_name\": \"httpd\", \"heat::wsgi::apache_api_cfn::bind_host\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiCfnNetwork\"]}}}}, \"heat::wsgi::apache_api_cfn::servername\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiCfnNetwork\"]}}}}}, {\"if\": [\"heat_workers_set\", {\"heat::wsgi::apache_api_cfn::workers\": {\"get_param\": \"HeatWorkers\"}}]}]}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_heat_api_cfn\": [{\"get_param\": \"HeatApiCfnLoggingSource\"}]}}, \"puppet_config\": {\"config_volume\": \"heat_api_cfn\", \"puppet_tags\": \"heat_config,file,concat,file_line\", \"step_config\": \"include tripleo::profile::base::heat::api_cfn\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHeatApiCfnConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/heat_api_cfn.json\": {\"command\": \"/usr/sbin/httpd -DFOREGROUND\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.d\", \"dest\": \"/etc/httpd/conf.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.modules.d\", \"dest\": \"/etc/httpd/conf.modules.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/heat\", \"owner\": \"heat:heat\", \"recurse\": true}]}}, \"docker_config\": {\"step_2\": {\"get_attr\": [\"HeatApiCfnLogging\", \"docker_config\", \"step_2\"]}, \"step_4\": {\"heat_api_cfn\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHeatApiCfnImage\"]}, \"net\": \"host\", \"privileged\": false, \"restart\": \"always\", \"user\": \"root\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"HeatApiCfnLogging\", \"volumes\"]}, [\"/var/lib/kolla/config_files/heat_api_cfn.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/heat_api_cfn:/var/lib/kolla/config_files/src:ro\"], {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [\"/etc/pki/tls/certs/httpd:/etc/pki/tls/certs/httpd:ro\", \"/etc/pki/tls/private/httpd:/etc/pki/tls/private/httpd:ro\"]]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"host_prep_tasks\": {\"get_attr\": [\"HeatApiCfnLogging\", \"host_prep_tasks\"]}, \"upgrade_tasks\": [], \"metadata_settings\": {\"get_attr\": [\"ApacheServiceBase\", \"role_data\", \"metadata_settings\"]}, \"deploy_steps_tasks\": {\"get_attr\": [\"ApacheServiceBase\", \"role_data\", \"deploy_steps_tasks\"]}, \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop heat cfn container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"heat_api_cfn\"], \"tripleo_delegate_to\": \"{{ groups[\'heat_api_cfn\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (146,'2026-06-10 07:47:12',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Apache service configured with Puppet. Note this is typically included automatically via other services which run via Apache.\\n\", \"parameters\": {\"ApacheMaxRequestWorkers\": {\"default\": 100, \"description\": \"Maximum number of simultaneously processed requests.\", \"type\": \"number\"}, \"ApacheServerLimit\": {\"default\": 100, \"description\": \"Maximum number of Apache processes.\", \"type\": \"number\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"ApacheCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}, \"ApacheTimeout\": {\"type\": \"number\", \"default\": 90, \"description\": \"The timeout in seconds for Apache, which defines duration Apache waits for I/O operations\"}}, \"conditions\": {\"key_size_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"ApacheCertificateKeySize\"}, \"\"]}}}, \"resources\": {\"ApacheNetworks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"Controller\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"CellController\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"CellControllerCompute\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"Compute\": [\"ctlplane\", \"storage\", \"internal_api\"], \"BlockStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"ObjectStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"CephStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\"], \"Networker\": [\"ctlplane\", \"internal_api\"]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Apache role.\", \"value\": {\"service_name\": \"apache\", \"config_settings\": {\"map_merge\": [{\"apache::ip\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ApacheNetwork\"]}}}}, \"apache::default_vhost\": false, \"apache::trace_enable\": \"Off\", \"apache::server_signature\": \"Off\", \"apache::server_tokens\": \"Prod\", \"apache::timeout\": {\"get_param\": \"ApacheTimeout\"}, \"apache::default_mods\": false, \"apache::mod::prefork::maxrequestworkers\": {\"get_param\": \"ApacheMaxRequestWorkers\"}, \"apache::mod::prefork::serverlimit\": {\"get_param\": \"ApacheServerLimit\"}, \"apache::mod::remoteip::proxy_ips\": {\"get_param\": [\"ServiceData\", \"net_cidr_map\", {\"get_param\": [\"ServiceNetMap\", \"ApacheNetwork\"]}]}, \"apache::mod::alias::icons_options\": \"None\"}, {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"apache::mod::ssl::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}, \"apache::mod::ssl::ssl_protocol\": [\"all\", \"-SSLv2\", \"-SSLv3\", \"-TLSv1\"], \"apache_certificates_specs\": {\"map_merge\": {\"repeat\": {\"template\": {\"httpd-NETWORK\": {\"service_certificate\": \"/etc/pki/tls/certs/httpd/httpd-NETWORK.crt\", \"service_key\": \"/etc/pki/tls/private/httpd/httpd-NETWORK.key\"}}, \"for_each\": {\"NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}}}]}]}, \"metadata_settings\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"repeat\": {\"template\": [{\"service\": \"HTTP\", \"network\": \"$NETWORK\", \"type\": \"node\"}], \"for_each\": {\"$NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}]}, \"upgrade_tasks\": [], \"deploy_steps_tasks\": [{\"name\": \"Certificate generation\", \"when\": [\"step|int == 1\", \"enable_internal_tls\"], \"block\": [{\"name\": \"Create dirs for certificates and keys\", \"file\": {\"path\": \"{{ item }}\", \"state\": \"directory\", \"serole\": \"object_r\", \"setype\": \"cert_t\", \"seuser\": \"system_u\"}, \"with_items\": [\"/etc/pki/tls/certs/httpd\", \"/etc/pki/tls/private/httpd\"]}, {\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": {\"repeat\": {\"template\": {\"name\": \"httpd-NETWORK\", \"dns\": \"{{ fqdn_NETWORK }}\", \"principal\": \"HTTP/{{ fqdn_NETWORK }}@{{ idm_realm }}\", \"run_after\": \"cp /etc/pki/tls/certs/httpd-NETWORK.crt /etc/pki/tls/certs/httpd/httpd-NETWORK.crt\\ncp /etc/pki/tls/private/httpd-NETWORK.key /etc/pki/tls/private/httpd/httpd-NETWORK.key\\npkill -USR1 httpd\\n\", \"key_size\": {\"if\": [\"key_size_override_set\", {\"get_param\": \"ApacheCertificateKeySize\"}, {\"get_param\": \"CertificateKeySize\"}]}, \"ca\": \"ipa\"}, \"for_each\": {\"NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"EnableInternalTLS\": false}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(147,'2026-06-10 07:47:13',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Glance API service\\n\", \"parameters\": {\"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ContainerHeatEngineImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\"}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerHeatEngineImage\": \"ContainerHeatEngineImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerHeatEngineImage\": {\"get_param\": \"ContainerHeatEngineImage\"}}}]}}}}, \"outputs\": {\"cmd_extra_args\": {\"description\": \"Extra command line arguments for running the service in the container.\", \"value\": \"\"}, \"config_settings\": {\"description\": \"Extra hieradata needed to log to files in the host.\", \"value\": null}, \"docker_config\": {\"description\": \"Extra containers needed for logging to files in the host.\", \"value\": {\"step_2\": {\"heat_init_log\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHeatEngineImage\"]}, \"net\": \"none\", \"user\": \"root\", \"volumes\": [\"/var/log/containers/heat:/var/log/heat:z\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R heat:heat /var/log/heat\"]}}}}, \"volumes\": {\"description\": \"The volumes needed to log to files in the host.\", \"value\": [\"/var/log/containers/heat:/var/log/heat:z\"]}, \"host_prep_tasks\": {\"description\": \"Extra ansible tasks needed for logging to files in the host.\", \"value\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/heat\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}]}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(148,'2026-06-10 07:47:13',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Openstack Heat CloudWatch API service, disabled by default since Pike\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the disabled Heat CloudWatch API\", \"value\": {\"service_name\": \"heat_api_cloudwatch_disabled\", \"upgrade_tasks\": []}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(149,'2026-06-10 07:47:13',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Iscsid service\\n\", \"parameters\": {\"ContainerIscsidImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\"}, \"ContainerIscsidConfigImage\": {\"description\": \"The container image to use for the iscsid config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"LVMFilterEnabled\": {\"default\": false, \"description\": \"Enables configuration of LVM2 with a filter so that devices not in use on the host or explicitly allowed are ignored by LVM2. Can be configured per-role. When disabled, the proposed lvm.conf file will be created regardless and left in /tmp/tripleo_lvmfilter.conf for debugging purposes.\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"LVMFilterAllowlist\": {\"default\": [], \"description\": \"A list of block devices which should be allowed in the LVM2 `global_filter`. Supports regular expressions, like `/dev/sd.*` and can be configured per-role. Any block device in use at boot time will be automatically allowed.\", \"type\": \"comma_delimited_list\", \"tags\": [\"role_specific\"]}, \"LVMFilterDenylist\": {\"default\": [\".*\"], \"description\": \"A list of block devices which should be disallowed in the LVM2 `global_filter`. Supports regular expressions, like `/dev/sd.*` and can be configured per-role.\", \"type\": \"comma_delimited_list\", \"tags\": [\"role_specific\"]}, \"IscsidCHAPAlgorithms\": {\"default\": \"SHA3-256,SHA256,SHA1,MD5\", \"description\": \"A comma separated list of algorithms to be used for the CHAP algorithm.\", \"type\": \"string\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"tripleo_tripleo_lvmfilter_enabled\": \"LVMFilterEnabled\", \"tripleo_tripleo_lvmfilter_devices_allowlist\": \"LVMFilterAllowlist\", \"tripleo_tripleo_lvmfilter_devices_denylist\": \"LVMFilterDenylist\", \"ContainerIscsidImage\": \"ContainerIscsidImage\", \"ContainerIscsidConfigImage\": \"ContainerIscsidConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"LVMFilterEnabled\": {\"get_param\": \"LVMFilterEnabled\"}, \"LVMFilterAllowlist\": {\"get_param\": \"LVMFilterAllowlist\"}, \"LVMFilterDenylist\": {\"get_param\": \"LVMFilterDenylist\"}, \"ContainerIscsidImage\": {\"get_param\": \"ContainerIscsidImage\"}, \"ContainerIscsidConfigImage\": {\"get_param\": \"ContainerIscsidConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Iscsid role.\", \"value\": {\"service_name\": \"iscsid\", \"config_settings\": {\"tripleo::profile::base::iscsid::chap_algs\": {\"get_param\": \"IscsidCHAPAlgorithms\"}}, \"service_config_settings\": {}, \"deploy_steps_tasks\": [{\"name\": \"Run lvmfilter role\", \"include_role\": {\"name\": \"tripleo_lvmfilter\"}, \"when\": [\"step|int == 1\"]}], \"ansible_group_vars\": {\"get_attr\": [\"RoleParametersValue\", \"value\"]}, \"puppet_config\": {\"config_volume\": \"iscsid\", \"puppet_tags\": \"iscsid_config\", \"step_config\": \"include tripleo::profile::base::iscsid\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerIscsidConfigImage\"]}, \"volumes\": [\"/etc/iscsi:/tmp/iscsi.host:z\"]}, \"kolla_config\": {\"/var/lib/kolla/config_files/iscsid.json\": {\"command\": \"/usr/sbin/iscsid -f\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src-iscsid/\", \"dest\": \"/etc/iscsi/\", \"merge\": true, \"preserve_properties\": true}]}}, \"docker_config\": {\"step_3\": {\"iscsid\": {\"start_order\": 2, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerIscsidImage\"]}, \"net\": \"host\", \"privileged\": true, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/iscsid.json:/var/lib/kolla/config_files/config.json:ro\", \"/dev:/dev\", \"/run:/run\", \"/sys:/sys\", \"/lib/modules:/lib/modules:ro\", \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", \"/etc/target:/etc/target:z\", \"/var/lib/iscsi:/var/lib/iscsi:z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"host_prep_tasks\": [{\"name\": \"create fcontext entry for iscsi\", \"community.general.sefcontext\": {\"target\": \"{{ item.path }}(/.*)?\", \"setype\": \"{{ item.setype }}\", \"state\": \"present\"}, \"with_items\": [{\"path\": \"/etc/iscsi\", \"setype\": \"container_file_t\"}, {\"path\": \"/etc/target\", \"setype\": \"container_file_t\"}, {\"path\": \"/var/lib/iscsi\", \"setype\": \"container_file_t\"}]}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\"}, \"with_items\": [{\"path\": \"/etc/iscsi\", \"setype\": \"container_file_t\"}, {\"path\": \"/etc/target\", \"setype\": \"container_file_t\"}, {\"path\": \"/var/lib/iscsi\", \"setype\": \"container_file_t\"}]}, {\"name\": \"stat /lib/systemd/system/iscsid.socket\", \"stat\": \"path=/lib/systemd/system/iscsid.socket\", \"register\": \"stat_iscsid_socket\"}, {\"name\": \"Stop and disable iscsid.socket service\", \"service\": \"name=iscsid.socket state=stopped enabled=no\", \"when\": \"stat_iscsid_socket.stat.exists\"}, {\"name\": \"Check if iscsi.service is enabled\", \"command\": \"systemctl is-enabled --quiet iscsi.service\", \"failed_when\": false, \"register\": \"iscsi_service_enabled_result\"}, {\"name\": \"Stop iscsi.service\", \"service\": \"name=iscsi.service state=stopped enabled=no\", \"when\": [\"iscsi_service_enabled_result is changed\", \"iscsi_service_enabled_result.rc == 0\"]}], \"upgrade_tasks\": []}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(150,'2026-06-10 07:47:14',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Heat API CFN service\\n\", \"outputs\": {\"config_settings\": {\"description\": \"Extra hieradata needed to log to files in the host.\", \"value\": null}, \"docker_config\": {\"description\": \"Extra containers needed for logging to files in the host.\", \"value\": {\"step_2\": {}}}, \"volumes\": {\"description\": \"The volumes needed to log to files in the host.\", \"value\": [\"/var/log/containers/heat:/var/log/heat:z\", \"/var/log/containers/httpd/heat-api-cfn:/var/log/httpd:z\"]}, \"host_prep_tasks\": {\"description\": \"Extra ansible tasks needed for logging to files in the host.\", \"value\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/heat\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/log/containers/httpd/heat-api-cfn\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}]}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(151,'2026-06-10 07:47:14',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Memcached services\\n\", \"parameters\": {\"ContainerMemcachedImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\"}, \"ContainerMemcachedConfigImage\": {\"description\": \"The container image to use for the memcached config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"MemcachedMaxMemory\": {\"default\": \"50%\", \"description\": \"The maximum amount of memory for memcached to be configured to use when installed. This can be either a percentage (\'50%\') or a fixed value (\'2048\').\", \"type\": \"string\"}, \"MemcachedMaxConnections\": {\"default\": 8192, \"description\": \"The maximum number of connections to be accepted by memcached\", \"type\": \"number\"}, \"MonitoringSubscriptionMemcached\": {\"default\": \"overcloud-memcached\", \"type\": \"string\"}, \"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"MemcachedDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Memcached service.\", \"type\": \"boolean\"}, \"MemcachedIpSubnet\": {\"default\": \"\", \"description\": \"IP address/subnet on the memcached network. If empty (default), MemcachedNetwork will be taken. Useful in the case where an operator wants to open Memcached outside of the internal network. Use this parameter with caution and be aware of opening memcached to external network can be dangerous.\", \"type\": \"string\"}, \"MemcachedPort\": {\"default\": 11211, \"description\": \"Port to have Memcached listening at. When using MemcachedTLS, this has to be set to a different port then the default - see below.\", \"type\": \"number\"}, \"MemcachedTLS\": {\"default\": false, \"description\": \"Set to True to enable TLS on Memcached service. Because not all services support Memcached TLS, during the migration period, Memcached will listen on 2 ports - on the port set with MemcachedPort parameter (above) and on 11211, without TLS.\", \"type\": \"boolean\"}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"MemcachedCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}}, \"conditions\": {\"enable_non_tls_port\": {\"and\": [{\"get_param\": \"MemcachedTLS\"}, {\"not\": {\"equals\": [{\"get_param\": \"MemcachedPort\"}, 11211]}}]}, \"memcached_network_set\": {\"not\": {\"equals\": [{\"get_param\": \"MemcachedIpSubnet\"}, \"\"]}}, \"memcached_debug\": {\"or\": [{\"get_param\": \"Debug\"}, {\"get_param\": \"MemcachedDebug\"}]}, \"is_ipv6\": {\"equals\": [{\"get_param\": [\"ServiceData\", \"net_ip_version_map\", {\"get_param\": [\"ServiceNetMap\", \"MemcachedNetwork\"]}]}, 6]}, \"key_size_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"MemcachedCertificateKeySize\"}, \"\"]}}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerMemcachedImage\": \"ContainerMemcachedImage\", \"ContainerMemcachedConfigImage\": \"ContainerMemcachedConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerMemcachedImage\": {\"get_param\": \"ContainerMemcachedImage\"}, \"ContainerMemcachedConfigImage\": {\"get_param\": \"ContainerMemcachedConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Memcached API role.\", \"value\": {\"service_name\": \"memcached\", \"firewall_rules\": {\"if\": [\"memcached_network_set\", {\"121 memcached\": {\"dport\": {\"list_concat\": [[{\"get_param\": \"MemcachedPort\"}], {\"if\": [\"enable_non_tls_port\", [11211]]}]}, \"proto\": \"tcp\", \"source\": {\"get_param\": \"MemcachedIpSubnet\"}}}, {\"map_merge\": {\"repeat\": {\"for_each\": {\"<%net_cidr%>\": {\"get_param\": [\"ServiceData\", \"net_cidr_map\", {\"get_param\": [\"ServiceNetMap\", \"MemcachedNetwork\"]}]}}, \"template\": {\"121 memcached <%net_cidr%>\": {\"dport\": {\"list_concat\": [[{\"get_param\": \"MemcachedPort\"}], {\"if\": [\"enable_non_tls_port\", [11211]]}]}, \"proto\": \"tcp\", \"source\": \"<%net_cidr%>\"}}}}}]}, \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionMemcached\"}, \"config_settings\": {\"map_merge\": [{\"memcached::listen\": {\"list_concat\": [[{\"if\": [\"is_ipv6\", \"::1\", \"127.0.0.1\"]}, {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MemcachedNetwork\"]}}}}], {\"if\": [\"enable_non_tls_port\", [{\"str_replace\": {\"template\": \"notls:%{hiera(\'$NETWORK_uri\')}:11211\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MemcachedNetwork\"]}}}}, {\"if\": [\"is_ipv6\", \"notls:[::1]:11211\", \"notls:127.0.0.1:11211\"]}]]}]}, \"memcached::listen_ip\": [{\"if\": [\"is_ipv6\", \"::1\", \"127.0.0.1\"]}, {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MemcachedNetwork\"]}}}}], \"memcached::listen_ip_uri\": [{\"if\": [\"is_ipv6\", \"::1\", \"127.0.0.1\"]}, {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK_uri\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MemcachedNetwork\"]}}}}], \"memcached::tcp_port\": {\"get_param\": \"MemcachedPort\"}, \"memcached::max_connections\": {\"get_param\": \"MemcachedMaxConnections\"}, \"memcached::max_memory\": {\"get_param\": \"MemcachedMaxMemory\"}, \"memcached::udp_port\": 0, \"memcached::verbosity\": {\"list_join\": [\"\", [\"v\", {\"if\": [\"memcached_debug\", \"v\", \"\"]}]]}, \"memcached::disable_cachedump\": true, \"memcached::logstdout\": true, \"tripleo::profile::base::memcached::enable_internal_memcached_tls\": {\"get_param\": \"MemcachedTLS\"}}, {\"if\": [{\"get_param\": \"MemcachedTLS\"}, {\"tripleo::memcached::service_certificate\": \"/etc/pki/tls/certs/memcached.crt\", \"tripleo::profile::base::memcached::certificate_specs\": {\"service_certificate\": \"/etc/pki/tls/certs/memcached.crt\", \"service_key\": \"/etc/pki/tls/private/memcached.key\"}}]}]}, \"service_config_settings\": {\"collectd\": {\"tripleo.collectd.plugins.memcached\": [\"memcached\"], \"collectd::plugin::memcached::instances\": {\"local\": {\"host\": \"%{hiera(\'memcached::listen_ip_uri\')}\", \"port\": [{\"if\": [\"enable_non_tls_port\", 11211, {\"get_param\": \"MemcachedPort\"}]}]}}}}, \"global_config_settings\": {\"map_merge\": [{\"if\": [\"enable_non_tls_port\", {\"memcached_port\": {\"get_param\": \"MemcachedPort\"}, \"memcached_authtoken_port\": 11211}, {\"memcached_port\": {\"get_param\": \"MemcachedPort\"}, \"memcached_authtoken_port\": {\"get_param\": \"MemcachedPort\"}}]}, {\"if\": [\"is_ipv6\", {\"memcached_ipv6\": true}]}]}, \"puppet_config\": {\"config_volume\": \"memcached\", \"puppet_tags\": \"file\", \"step_config\": \"include tripleo::profile::base::memcached\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMemcachedConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/memcached.json\": {\"command\": \"bash -c $* -- eval source /etc/sysconfig/memcached; exec /usr/bin/memcached -p ${PORT} -u ${USER} -m ${CACHESIZE} -c ${MAXCONN} $OPTIONS >> /var/log/memcached/memcached.log 2>&1\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true, \"optional\": true}], \"permissions\": [{\"path\": \"/var/log/memcached\", \"owner\": \"memcached:memcached\", \"recurse\": true}, {\"path\": \"/etc/pki/tls/certs/memcached.crt\", \"owner\": \"memcached:memcached\", \"optional\": true}, {\"path\": \"/etc/pki/tls/private/memcached.key\", \"owner\": \"memcached:memcached\", \"optional\": true}]}}, \"docker_config\": {\"step_1\": {\"memcached\": {\"start_order\": 0, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMemcachedImage\"]}, \"net\": \"host\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/memcached.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/memcached:/var/lib/kolla/config_files/src:rw,z\", \"/var/log/containers/memcached:/var/log/memcached:rw\"], {\"if\": [{\"get_param\": \"MemcachedTLS\"}, [\"/etc/pki/tls/certs/memcached.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/memcached.crt:ro\", \"/etc/pki/tls/private/memcached.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/memcached.key:ro\"]]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"metadata_settings\": {\"if\": [{\"get_param\": \"MemcachedTLS\"}, [{\"service\": \"memcached\", \"network\": {\"get_param\": [\"ServiceNetMap\", \"MemcachedNetwork\"]}, \"type\": \"node\"}]]}, \"deploy_steps_tasks\": {\"if\": [{\"get_param\": \"MemcachedTLS\"}, [{\"name\": \"Certificate generation\", \"when\": \"step|int == 1\", \"block\": [{\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": [{\"name\": \"memcached\", \"dns\": {\"str_replace\": {\"template\": \"{{fqdn_$NETWORK}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MemcachedNetwork\"]}}}}, \"principal\": {\"str_replace\": {\"template\": \"memcached/{{fqdn_$NETWORK}}@{{idm_realm}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MemcachedNetwork\"]}}}}, \"run_after\": \"container_name=$({{container_cli}} ps --format=\\\\{\\\\{.Names\\\\}\\\\} | grep memcached)\\nservice_crt=\\\"/etc/pki/tls/certs/memcached.crt\\\"\\nservice_key=\\\"/etc/pki/tls/private/memcached.key\\\"\\n# Copy the new cert from the mount-point to the real path\\n{{container_cli}} exec -u root \\\"$container_name\\\" cp \\\"/var/lib/kolla/config_files/src-tls$service_crt\\\" \\\"$service_crt\\\"\\n# Copy the new key from the mount-point to the real path\\n{{container_cli}} exec -u root \\\"$container_name\\\" cp \\\"/var/lib/kolla/config_files/src-tls$service_key\\\" \\\"$service_key\\\"\\n# Set appropriate permissions\\n{{container_cli}} exec -u root \\\"$container_name\\\" chown memcached:memcached \\\"$service_crt\\\"\\n{{container_cli}} exec -u root \\\"$container_name\\\" chown memcached:memcached \\\"$service_key\\\"\\n# Send refresh_certs command to memcached to read the new certificate\\nmemcached_ip=\\\"$(hiera -c /etc/puppet/hiera.yaml memcached::listen_ip.0 127.0.0.1)\\\"\\nmemcached_port=\\\"$(hiera -c /etc/puppet/hiera.yaml memcached::tcp_port 11211)\\\"\\necho refresh_certs | openssl s_client -connect $memcached_ip:$memcached_port\\n\", \"key_size\": {\"if\": [\"key_size_override_set\", {\"get_param\": \"MemcachedCertificateKeySize\"}, {\"get_param\": \"CertificateKeySize\"}]}, \"ca\": \"ipa\"}]}}]}]]}, \"host_prep_tasks\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/memcached\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}], \"upgrade_tasks\": [], \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop memcached container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"memcached\"], \"tripleo_delegate_to\": \"{{ groups[\'memcached\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(152,'2026-06-10 07:47:14',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(153,'2026-06-10 07:47:15',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(154,'2026-06-10 07:47:15',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Keystone service\\n\", \"parameters\": {\"ContainerKeystoneImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\"}, \"ContainerKeystoneConfigImage\": {\"description\": \"The container image to use for the keystone config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"DeployIdentifier\": {\"default\": 1781077560, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}, \"AdminPassword\": {\"description\": \"The password for the keystone admin account, used for monitoring, querying neutron etc.\", \"type\": \"string\", \"hidden\": true, \"default\": \"5Inbz01FTud8Rr1i1p3QQo8TS\"}, \"KeystoneTokenProvider\": {\"description\": \"The keystone token format\", \"type\": \"string\", \"default\": \"fernet\", \"constraints\": [{\"allowed_values\": [\"fernet\"]}]}, \"SSLCertificate\": {\"default\": \"\", \"description\": \"The content of the SSL certificate (without Key) in PEM format.\\n\", \"type\": \"string\"}, \"PublicSSLCertificateAutogenerated\": {\"default\": false, \"description\": \"Whether the public SSL certificate was autogenerated or not.\\n\", \"type\": \"boolean\"}, \"EnablePublicTLS\": {\"default\": true, \"description\": \"Whether to enable TLS on the public interface or not.\\n\", \"type\": \"boolean\"}, \"PublicTLSCAFile\": {\"default\": \"\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the public network.\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"MemcachedTLS\": {\"default\": false, \"description\": \"Set to True to enable TLS on Memcached service. Because not all services support Memcached TLS, during the migration period, Memcached will listen on 2 ports - on the port set with MemcachedPort parameter (above) and on 11211, without TLS.\", \"type\": \"boolean\"}, \"KeystoneSSLCertificate\": {\"default\": \"\", \"description\": \"Keystone certificate for verifying token validity.\", \"type\": \"string\"}, \"KeystoneSSLCertificateKey\": {\"default\": \"\", \"description\": \"Keystone key for signing tokens.\", \"type\": \"string\", \"hidden\": true}, \"KeystoneNotificationFormat\": {\"description\": \"The Keystone notification format\", \"default\": \"basic\", \"type\": \"string\", \"constraints\": [{\"allowed_values\": [\"basic\", \"cadf\"]}]}, \"KeystoneNotificationTopics\": {\"description\": \"Keystone notification topics to enable\", \"default\": [], \"type\": \"comma_delimited_list\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"Debug\": {\"type\": \"boolean\", \"default\": true, \"description\": \"Set to True to enable debugging on all services.\"}, \"KeystoneDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Keystone service.\", \"type\": \"boolean\"}, \"EnableCache\": {\"description\": \"Enable caching with memcached\", \"type\": \"boolean\", \"default\": true}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}, \"AdminToken\": {\"description\": \"The keystone auth secret and db password.\", \"type\": \"string\", \"hidden\": true, \"default\": \"IYV82nvaxlUUniqVsGTpKZ1V1\"}, \"TokenExpiration\": {\"default\": 3600, \"description\": \"Set a token expiration time in seconds.\", \"type\": \"number\"}, \"KeystoneWorkers\": {\"type\": \"string\", \"description\": \"Set the number of workers for keystone::wsgi::apache\", \"default\": 1}, \"MonitoringSubscriptionKeystone\": {\"default\": \"overcloud-keystone\", \"type\": \"string\"}, \"KeystoneCredential0\": {\"type\": \"string\", \"description\": \"The first Keystone credential key. Must be a valid key.\", \"default\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\"}, \"KeystoneCredential1\": {\"type\": \"string\", \"description\": \"The second Keystone credential key. Must be a valid key.\", \"default\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\"}, \"KeystoneFernetKeys\": {\"type\": \"json\", \"description\": \"Mapping containing keystone\'s fernet keys and their paths.\", \"default\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}}, \"KeystoneFernetMaxActiveKeys\": {\"type\": \"number\", \"description\": \"The maximum active keys in the keystone fernet key repository.\", \"default\": 5}, \"ManageKeystoneFernetKeys\": {\"type\": \"boolean\", \"default\": true, \"description\": \"Whether TripleO should manage the keystone fernet keys or not. If set to true, the fernet keys will get the values from the saved keys repository in mistral (the KeystoneFernetKeys variable). If set to false, only the stack creation initializes the keys, but subsequent updates won\'t touch them.\"}, \"KeystoneLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.keystone\", \"file\": \"/var/log/containers/keystone/keystone.log\"}}, \"KeystonePolicies\": {\"description\": \"A hash of policies to configure for Keystone.\\ne.g. { keystone-context_is_admin: { key: context_is_admin, value: \'role:admin\' } }\\n\", \"default\": {}, \"type\": \"json\"}, \"KeystoneLDAPDomainEnable\": {\"description\": \"Trigger to call ldap_backend puppet keystone define.\", \"type\": \"boolean\", \"default\": false}, \"KeystoneLDAPBackendConfigs\": {\"description\": \"Hash containing the configurations for the LDAP backends configured in keystone.\", \"type\": \"json\", \"default\": {}, \"hidden\": true}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"noop\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"KeystoneNotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": [], \"description\": \"Driver or drivers to handle sending notifications. This parameter is\\nspecific to Keystone.\\n\"}, \"KeystoneEnableDBPurge\": {\"default\": true, \"description\": \"Whether to create cron job for purging soft deleted rows in Keystone database.\\n\", \"type\": \"boolean\"}, \"KeystoneCronTrustFlushEnsure\": {\"type\": \"string\", \"description\": \"Cron to purge expired or soft-deleted trusts - Ensure\\n\", \"default\": \"present\"}, \"KeystoneCronTrustFlushMinute\": {\"type\": \"string\", \"description\": \"Cron to purge expired or soft-deleted trusts - Minute\\n\", \"default\": \"1\"}, \"KeystoneCronTrustFlushHour\": {\"type\": \"string\", \"description\": \"Cron to purge expired or soft-deleted trusts - Hour\\n\", \"default\": \"*\"}, \"KeystoneCronTrustFlushMonthday\": {\"type\": \"string\", \"description\": \"Cron to purge expired or soft-deleted trusts - Month Day\\n\", \"default\": \"*\"}, \"KeystoneCronTrustFlushMonth\": {\"type\": \"string\", \"description\": \"Cron to purge expired or soft-deleted trusts - Month\\n\", \"default\": \"*\"}, \"KeystoneCronTrustFlushWeekday\": {\"type\": \"string\", \"description\": \"Cron to purge expired or soft-deleted trusts - Week Day\\n\", \"default\": \"*\"}, \"KeystoneCronTrustFlushMaxDelay\": {\"type\": \"number\", \"description\": \"Cron to purge expired or soft-deleted trusts - Max Delay\\n\", \"default\": 0}, \"KeystoneCronTrustFlushDestination\": {\"type\": \"string\", \"description\": \"Cron to purge expired or soft-deleted trusts - Log destination\\n\", \"default\": \"/var/log/keystone/keystone-trustflush.log\"}, \"KeystoneCronTrustFlushUser\": {\"type\": \"string\", \"description\": \"Cron to purge expired or soft-deleted trusts - User\\n\", \"default\": \"keystone\"}, \"KeystoneChangePasswordUponFirstUse\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Enabling this option requires users to change their password when the user is created, or upon administrative reset.\", \"constraints\": [{\"allowed_values\": [\"\", \"true\", \"True\", \"TRUE\", \"false\", \"False\", \"FALSE\"]}]}, \"KeystoneDisableUserAccountDaysInactive\": {\"type\": \"string\", \"default\": \"\", \"description\": \"The maximum number of days a user can go without authenticating before being considered \\\"inactive\\\" and automatically disabled (locked).\"}, \"KeystoneLockoutDuration\": {\"type\": \"string\", \"default\": \"\", \"description\": \"The number of seconds a user account will be locked when the maximum number of failed authentication attempts (as specified by KeystoneLockoutFailureAttempts) is exceeded.\"}, \"KeystoneLockoutFailureAttempts\": {\"type\": \"string\", \"default\": \"\", \"description\": \"The maximum number of times that a user can fail to authenticate before the user account is locked for the number of seconds specified by KeystoneLockoutDuration.\"}, \"KeystoneMinimumPasswordAge\": {\"type\": \"string\", \"default\": \"\", \"description\": \"The number of days that a password must be used before the user can change it. This prevents users from changing their passwords immediately in order to wipe out their password history and reuse an old password.\"}, \"KeystonePasswordExpiresDays\": {\"type\": \"string\", \"default\": \"\", \"description\": \"The number of days for which a password will be considered valid before requiring it to be changed.\"}, \"KeystonePasswordRegex\": {\"type\": \"string\", \"default\": \"\", \"description\": \"The regular expression used to validate password strength requirements.\"}, \"KeystonePasswordRegexDescription\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Describe your password regular expression here in language for humans.\"}, \"KeystoneUniqueLastPasswordCount\": {\"type\": \"string\", \"default\": \"\", \"description\": \"This controls the number of previous user password iterations to keep in history, in order to enforce that newly created passwords are unique.\"}, \"KeystoneCorsAllowedOrigin\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Indicate whether this resource may be shared with the domain received in the request \\\"origin\\\" header.\"}, \"KeystoneEnableMember\": {\"description\": \"Create the _member_ role, useful for undercloud deployment.\", \"type\": \"boolean\", \"default\": false}, \"KeystoneFederationEnable\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Enable support for federated authentication.\"}, \"KeystoneTrustedDashboards\": {\"type\": \"comma_delimited_list\", \"default\": [], \"description\": \"A list of dashboard URLs trusted for single sign-on.\"}, \"KeystoneAuthMethods\": {\"type\": \"comma_delimited_list\", \"default\": [], \"description\": \"A list of methods used for authentication.\"}, \"KeystoneOpenIdcEnable\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Enable support for OpenIDC federation.\"}, \"KeystoneOpenIdcIdpName\": {\"type\": \"string\", \"default\": \"\", \"description\": \"The name associated with the IdP in Keystone.\"}, \"KeystoneOpenIdcProviderMetadataUrl\": {\"type\": \"string\", \"default\": \"\", \"description\": \"The url that points to your OpenID Connect provider metadata\"}, \"KeystoneOpenIdcClientId\": {\"type\": \"string\", \"default\": \"\", \"description\": \"The client ID to use when handshaking with your OpenID Connect provider\"}, \"KeystoneOpenIdcClientSecret\": {\"type\": \"string\", \"default\": \"\", \"description\": \"The client secret to use when handshaking with your OpenID Connect provider\"}, \"KeystoneOpenIdcCryptoPassphrase\": {\"type\": \"string\", \"default\": \"openstack\", \"description\": \"Passphrase to use when encrypting data for OpenID Connect handshake.\"}, \"KeystoneOpenIdcOutgoingProxy\": {\"type\": \"string\", \"default\": \"\", \"description\": \"The outgoing proxy to use for OpenID connections.\"}, \"KeystoneOpenIdcResponseType\": {\"type\": \"string\", \"default\": \"id_token\", \"description\": \"Response type to be expected from the OpenID Connect provider.\"}, \"KeystoneOpenIdcRemoteIdAttribute\": {\"type\": \"string\", \"default\": \"OIDC-iss\", \"description\": \"Attribute to be used to obtain the entity ID of the Identity Provider from the environment.\"}, \"KeystoneOpenIdcEnableOAuth\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Enable OAuth 2.0 integration.\"}, \"KeystoneOpenIdcIntrospectionEndpoint\": {\"type\": \"string\", \"default\": \"\", \"description\": \"OAuth 2.0 introspection endpoint for mod_auth_openidc\"}, \"KeystoneOpenIdcClaimDelimiter\": {\"type\": \"string\", \"default\": \";\", \"description\": \"The delimiter to use when setting multi-valued claims.\"}, \"KeystoneOpenIdcPassUserInfoAs\": {\"type\": \"string\", \"default\": \"claims\", \"description\": \"Define the way(s) in which the claims resolved from the userinfo endpoint are passed to the application according to OIDCPassClaimsAs.\", \"constraints\": [{\"allowed_values\": [\"claims\", \"json\", \"jwt\"]}]}, \"KeystoneOpenIdcPassClaimsAs\": {\"type\": \"string\", \"default\": \"both\", \"description\": \"Define the way in which the claims and tokens are passed to the application environment: \\\"none\\\": no claims/tokens are passed \\\"environment\\\": claims/tokens are passed as environment variables \\\"headers\\\": claims/tokens are passed in headers (also useful in reverse proxy scenario\'s) \\\"both\\\": claims/tokens are passed as both headers as well as environment variables (default)\", \"constraints\": [{\"allowed_values\": [\"none\", \"environment\", \"headers\", \"both\"]}]}, \"RootStackName\": {\"description\": \"The name of the stack/plan.\", \"type\": \"string\", \"default\": \"overcloud\"}, \"EnforceSecureRbac\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Setting this option to True will configure each OpenStack service to enforce Secure RBAC by setting `[oslo_policy] enforce_new_defaults` and `[oslo_policy] enforce_scope` to True. This introduces a consistent set of RBAC personas across OpenStack services that include support for system and project scope, as well as keystone\'s default roles, admin, member, and reader. Do not enable this functionality until all services in your deployment actually support secure RBAC.\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MySQLClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\"}, \"ApacheServiceBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}, \"EnableInternalTLS\": {\"get_param\": \"EnableInternalTLS\"}}}, \"KeystoneLogging\": {\"type\": \"OS::TripleO::Services::Logging::Keystone\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerKeystoneImage\": \"ContainerKeystoneImage\", \"ContainerKeystoneConfigImage\": \"ContainerKeystoneConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerKeystoneImage\": {\"get_param\": \"ContainerKeystoneImage\"}, \"ContainerKeystoneConfigImage\": {\"get_param\": \"ContainerKeystoneConfigImage\"}}}]}}}}, \"conditions\": {\"public_tls_enabled\": {\"and\": [{\"get_param\": \"EnablePublicTLS\"}, {\"or\": [{\"not\": {\"equals\": [{\"get_param\": \"SSLCertificate\"}, \"\"]}}, {\"get_param\": \"PublicSSLCertificateAutogenerated\"}]}]}, \"keystone_fernet_tokens\": {\"equals\": [{\"get_param\": \"KeystoneTokenProvider\"}, \"fernet\"]}, \"nontls_cache_enabled\": {\"and\": [{\"get_param\": \"EnableCache\"}, {\"not\": {\"get_param\": \"MemcachedTLS\"}}]}, \"tls_cache_enabled\": {\"and\": [{\"get_param\": \"EnableCache\"}, {\"get_param\": \"MemcachedTLS\"}]}, \"keystone_outgoing_proxy\": {\"and\": [{\"not\": {\"equals\": [{\"get_param\": \"KeystoneOpenIdcOutgoingProxy\"}, \"\"]}}, {\"get_param\": \"KeystoneOpenIdcEnable\"}]}, \"change_password_upon_first_use_set\": {\"not\": {\"equals\": [{\"get_param\": \"KeystoneChangePasswordUponFirstUse\"}, \"\"]}}, \"disable_user_account_days_inactive_set\": {\"not\": {\"equals\": [{\"get_param\": \"KeystoneDisableUserAccountDaysInactive\"}, \"\"]}}, \"lockout_duration_set\": {\"not\": {\"equals\": [{\"get_param\": \"KeystoneLockoutDuration\"}, \"\"]}}, \"lockout_failure_attempts_set\": {\"not\": {\"equals\": [{\"get_param\": \"KeystoneLockoutFailureAttempts\"}, \"\"]}}, \"minimum_password_age_set\": {\"not\": {\"equals\": [{\"get_param\": \"KeystoneMinimumPasswordAge\"}, \"\"]}}, \"password_expires_days_set\": {\"not\": {\"equals\": [{\"get_param\": \"KeystonePasswordExpiresDays\"}, \"\"]}}, \"password_regex_set\": {\"not\": {\"equals\": [{\"get_param\": \"KeystonePasswordRegex\"}, \"\"]}}, \"password_regex_description_set\": {\"not\": {\"equals\": [{\"get_param\": \"KeystonePasswordRegexDescription\"}, \"\"]}}, \"unique_last_password_count_set\": {\"not\": {\"equals\": [{\"get_param\": \"KeystoneUniqueLastPasswordCount\"}, \"\"]}}, \"cors_allowed_origin_set\": {\"not\": {\"equals\": [{\"get_param\": \"KeystoneCorsAllowedOrigin\"}, \"\"]}}, \"keystone_notification_driver_set\": {\"not\": {\"equals\": [{\"get_param\": \"KeystoneNotificationDriver\"}, []]}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Keystone API role.\", \"value\": {\"service_name\": \"keystone\", \"firewall_rules\": {\"111 keystone\": {\"dport\": [5000, {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"port\"]}]}}, \"firewall_frontend_rules\": {\"100 keystone_public_haproxy_frontend\": {\"dport\": [5000]}, \"100 keystone_admin_haproxy_frontend\": {\"dport\": [{\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"port\"]}]}}, \"firewall_ssl_frontend_rules\": {\"100 keystone_public_haproxy_frontend_ssl\": {\"dport\": [13000]}}, \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionKeystone\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"ApacheServiceBase\", \"role_data\", \"config_settings\"]}, {\"if\": [\"cors_allowed_origin_set\", {\"keystone::cors::allowed_origin\": {\"get_param\": \"KeystoneCorsAllowedOrigin\"}}]}, {\"keystone::database_connection\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"protocol\"]}, \"username\": \"keystone\", \"password\": {\"get_param\": \"AdminToken\"}, \"host\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"host\"]}, \"path\": \"/keystone\", \"query\": {\"if\": [{\"get_param\": \"EnableSQLAlchemyCollectd\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\", \"plugin\": \"collectd\", \"collectd_program_name\": \"keystone\", \"collectd_host\": \"localhost\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\"}]}}}, \"keystone::token_expiration\": {\"get_param\": \"TokenExpiration\"}, \"keystone::policy::policies\": {\"get_param\": \"KeystonePolicies\"}, \"keystone_ssl_certificate\": {\"get_param\": \"KeystoneSSLCertificate\"}, \"keystone_ssl_certificate_key\": {\"get_param\": \"KeystoneSSLCertificateKey\"}, \"keystone::token_provider\": {\"get_param\": \"KeystoneTokenProvider\"}, \"keystone::enable_fernet_setup\": {\"if\": [\"keystone_fernet_tokens\", true, false]}, \"keystone::fernet_max_active_keys\": {\"get_param\": \"KeystoneFernetMaxActiveKeys\"}, \"keystone::enable_proxy_headers_parsing\": true, \"keystone::enable_credential_setup\": true, \"keystone::credential_keys\": {\"/etc/keystone/credential-keys/0\": {\"content\": {\"get_param\": \"KeystoneCredential0\"}}, \"/etc/keystone/credential-keys/1\": {\"content\": {\"get_param\": \"KeystoneCredential1\"}}}, \"keystone::fernet_keys\": {\"get_param\": \"KeystoneFernetKeys\"}, \"keystone::fernet_replace_keys\": {\"get_param\": \"ManageKeystoneFernetKeys\"}, \"keystone::logging::debug\": {\"if\": [{\"get_param\": \"KeystoneDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"keystone::notification_driver\": {\"if\": [\"keystone_notification_driver_set\", {\"get_param\": \"KeystoneNotificationDriver\"}, {\"get_param\": \"NotificationDriver\"}]}, \"keystone::notification_format\": {\"get_param\": \"KeystoneNotificationFormat\"}, \"tripleo::profile::base::keystone::extra_notification_topics\": {\"get_param\": \"KeystoneNotificationTopics\"}, \"keystone_enable_db_purge\": {\"get_param\": \"KeystoneEnableDBPurge\"}, \"keystone::cron::trust_flush::ensure\": {\"get_param\": \"KeystoneCronTrustFlushEnsure\"}, \"keystone::cron::trust_flush::minute\": {\"get_param\": \"KeystoneCronTrustFlushMinute\"}, \"keystone::cron::trust_flush::hour\": {\"get_param\": \"KeystoneCronTrustFlushHour\"}, \"keystone::cron::trust_flush::monthday\": {\"get_param\": \"KeystoneCronTrustFlushMonthday\"}, \"keystone::cron::trust_flush::month\": {\"get_param\": \"KeystoneCronTrustFlushMonth\"}, \"keystone::cron::trust_flush::weekday\": {\"get_param\": \"KeystoneCronTrustFlushWeekday\"}, \"keystone::cron::trust_flush::maxdelay\": {\"get_param\": \"KeystoneCronTrustFlushMaxDelay\"}, \"keystone::cron::trust_flush::destination\": {\"get_param\": \"KeystoneCronTrustFlushDestination\"}, \"keystone::cron::trust_flush::user\": {\"get_param\": \"KeystoneCronTrustFlushUser\"}, \"keystone::rabbit_heartbeat_timeout_threshold\": 60, \"keystone::rabbit_heartbeat_in_pthread\": false, \"keystone::service_name\": \"httpd\", \"keystone::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"keystone::wsgi::apache::api_port\": [5000, {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"port\"]}], \"keystone::wsgi::apache::ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"keystone::wsgi::apache::servername\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}}}}, \"keystone::wsgi::apache::workers\": {\"get_param\": \"KeystoneWorkers\"}, \"keystone::wsgi::apache::threads\": 1, \"keystone::db::database_db_max_retries\": -1, \"keystone::db::database_max_retries\": -1, \"keystone::wsgi::apache::bind_host\": [{\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}}}}, {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}}}}]}, {\"keystone::cache::enabled\": {\"get_param\": \"EnableCache\"}, \"keystone::cache::backend_argument\": [{\"str_replace\": {\"template\": \"memcached_expire_time: $EXPIRATION\", \"params\": {\"$EXPIRATION\": {\"get_param\": \"TokenExpiration\"}}}}], \"keystone::cache::tls_enabled\": {\"get_param\": \"MemcachedTLS\"}}, {\"if\": [\"tls_cache_enabled\", {\"keystone::cache::backend\": \"dogpile.cache.pymemcache\", \"keystone::token_caching\": true}, {\"keystone::cache::backend\": \"dogpile.cache.memcached\"}]}, {\"if\": [{\"get_param\": \"KeystoneFederationEnable\"}, {\"keystone_federation_enabled\": true, \"keystone::federation::trusted_dashboards\": {\"get_param\": \"KeystoneTrustedDashboards\"}}]}, {\"if\": [{\"get_param\": \"KeystoneOpenIdcEnable\"}, {\"keystone_openidc_enabled\": true, \"keystone::federation::openidc::methods\": {\"get_param\": \"KeystoneAuthMethods\"}, \"keystone::federation::openidc::keystone_url\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"uri_no_suffix\"]}, \"keystone::federation::openidc::idp_name\": {\"get_param\": \"KeystoneOpenIdcIdpName\"}, \"keystone::federation::openidc::openidc_provider_metadata_url\": {\"get_param\": \"KeystoneOpenIdcProviderMetadataUrl\"}, \"keystone::federation::openidc::openidc_client_id\": {\"get_param\": \"KeystoneOpenIdcClientId\"}, \"keystone::federation::openidc::openidc_client_secret\": {\"get_param\": \"KeystoneOpenIdcClientSecret\"}, \"keystone::federation::openidc::openidc_crypto_passphrase\": {\"get_param\": \"KeystoneOpenIdcCryptoPassphrase\"}, \"keystone::federation::openidc::openidc_response_type\": {\"get_param\": \"KeystoneOpenIdcResponseType\"}, \"keystone::federation::openidc::remote_id_attribute\": {\"get_param\": \"KeystoneOpenIdcRemoteIdAttribute\"}, \"keystone::federation::openidc::openidc_enable_oauth\": {\"get_param\": \"KeystoneOpenIdcEnableOAuth\"}, \"keystone::federation::openidc::openidc_introspection_endpoint\": {\"get_param\": \"KeystoneOpenIdcIntrospectionEndpoint\"}, \"keystone::federation::openidc::openidc_pass_userinfo_as\": {\"get_param\": \"KeystoneOpenIdcPassUserInfoAs\"}, \"keystone::federation::openidc::openidc_pass_claim_as\": {\"get_param\": \"KeystoneOpenIdcPassClaimsAs\"}, \"keystone::federation::openidc::openidc_claim_delimiter\": {\"get_param\": \"KeystoneOpenIdcClaimDelimiter\"}, \"keystone::federation::openidc::openidc_cache_type\": {\"if\": [\"nontls_cache_enabled\", \"memcache\"]}}]}, {\"if\": [\"keystone_outgoing_proxy\", {\"keystone::federation::openidc::openidc_outgoing_proxy\": {\"get_param\": \"KeystoneOpenIdcOutgoingProxy\"}}]}, {\"if\": [{\"get_param\": \"KeystoneLDAPDomainEnable\"}, {\"tripleo::profile::base::keystone::ldap_backend_enable\": true, \"keystone::using_domain_config\": true, \"tripleo::profile::base::keystone::ldap_backends_config\": {\"get_param\": \"KeystoneLDAPBackendConfigs\"}}]}, {\"if\": [\"change_password_upon_first_use_set\", {\"keystone::security_compliance::change_password_upon_first_use\": {\"get_param\": \"KeystoneChangePasswordUponFirstUse\"}}]}, {\"if\": [\"disable_user_account_days_inactive_set\", {\"keystone::security_compliance::disable_user_account_days_inactive\": {\"get_param\": \"KeystoneDisableUserAccountDaysInactive\"}}]}, {\"if\": [\"lockout_duration_set\", {\"keystone::security_compliance::lockout_duration\": {\"get_param\": \"KeystoneLockoutDuration\"}}]}, {\"if\": [\"lockout_failure_attempts_set\", {\"keystone::security_compliance::lockout_failure_attempts\": {\"get_param\": \"KeystoneLockoutFailureAttempts\"}}]}, {\"if\": [\"minimum_password_age_set\", {\"keystone::security_compliance::minimum_password_age\": {\"get_param\": \"KeystoneMinimumPasswordAge\"}}]}, {\"if\": [\"password_expires_days_set\", {\"keystone::security_compliance::password_expires_days\": {\"get_param\": \"KeystonePasswordExpiresDays\"}}]}, {\"if\": [\"password_regex_set\", {\"keystone::security_compliance::password_regex\": {\"get_param\": \"KeystonePasswordRegex\"}}]}, {\"if\": [\"password_regex_description_set\", {\"keystone::security_compliance::password_regex_description\": {\"get_param\": \"KeystonePasswordRegexDescription\"}}]}, {\"if\": [\"unique_last_password_count_set\", {\"keystone::security_compliance::unique_last_password_count\": {\"get_param\": \"KeystoneUniqueLastPasswordCount\"}}]}, {\"apache::default_vhost\": false}, {\"get_attr\": [\"KeystoneLogging\", \"config_settings\"]}]}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_keystone\": {\"get_param\": \"KeystoneLoggingSource\"}}, \"mysql\": {\"keystone::db::mysql::password\": {\"get_param\": \"AdminToken\"}, \"keystone::db::mysql::user\": \"keystone\", \"keystone::db::mysql::host\": \"%\", \"keystone::db::mysql::dbname\": \"keystone\"}, \"pacemaker\": {\"keystone::endpoint::public_url\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"uri_no_suffix\"]}, \"keystone::endpoint::internal_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"keystone::endpoint::admin_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"uri_no_suffix\"]}, \"keystone::endpoint::region\": {\"get_param\": \"KeystoneRegion\"}, \"keystone::admin_password\": {\"get_param\": \"AdminPassword\"}}, \"horizon\": {\"if\": [{\"get_param\": \"KeystoneLDAPDomainEnable\"}, {\"horizon::keystone_multidomain_support\": true, \"horizon::keystone_default_domain\": \"Default\"}]}}, \"puppet_config\": {\"config_volume\": \"keystone\", \"puppet_tags\": \"keystone_config,keystone_domain_config\", \"step_config\": {\"list_join\": [\"\\n\", [\"[\'Keystone_user\', \'Keystone_endpoint\', \'Keystone_domain\', \'Keystone_tenant\', \'Keystone_user_role\', \'Keystone_role\', \'Keystone_service\'].each |String $val| { noop_resource($val) }\", \"include tripleo::profile::base::keystone\\n\", {\"get_attr\": [\"MySQLClient\", \"role_data\", \"step_config\"]}]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerKeystoneConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/keystone.json\": {\"command\": \"/usr/sbin/httpd\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/etc/keystone/fernet-keys\", \"dest\": \"/etc/keystone/fernet-keys\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.d\", \"dest\": \"/etc/httpd/conf.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.modules.d\", \"dest\": \"/etc/httpd/conf.modules.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]}, \"/var/lib/kolla/config_files/keystone_cron.json\": {\"command\": \"/usr/sbin/crond -n\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]}}, \"docker_config\": {\"step_2\": {\"get_attr\": [\"KeystoneLogging\", \"docker_config\", \"step_2\"]}, \"step_3\": {\"keystone_db_sync\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerKeystoneImage\"]}, \"net\": \"host\", \"user\": \"root\", \"privileged\": false, \"detach\": false, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"KeystoneLogging\", \"volumes\"]}, [\"/etc/openldap:/etc/openldap:ro\", \"/var/lib/kolla/config_files/keystone.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/keystone:/var/lib/kolla/config_files/src:ro\"], {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [\"/etc/pki/tls/certs/httpd:/etc/pki/tls/certs/httpd:ro\", \"/etc/pki/tls/private/httpd:/etc/pki/tls/private/httpd:ro\"]]}]}, \"environment\": {\"map_merge\": [{\"get_attr\": [\"KeystoneLogging\", \"environment\"]}, {\"KOLLA_BOOTSTRAP\": true, \"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\", \"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}}]}, \"command\": [\"/usr/bin/bootstrap_host_exec\", \"keystone\", \"/usr/local/bin/kolla_start\"]}, \"keystone\": {\"start_order\": 2, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerKeystoneImage\"]}, \"net\": \"host\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"KeystoneLogging\", \"volumes\"]}, [\"/etc/openldap:/etc/openldap:ro\", \"/var/lib/kolla/config_files/keystone.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/keystone:/var/lib/kolla/config_files/src:ro\"], {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [\"/etc/pki/tls/certs/httpd:/etc/pki/tls/certs/httpd:ro\", \"/etc/pki/tls/private/httpd:/etc/pki/tls/private/httpd:ro\"]]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}, \"keystone_bootstrap\": {\"start_order\": 3, \"action\": \"exec\", \"user\": \"root\", \"command\": [\"keystone\", \"/usr/bin/bootstrap_host_exec\", \"keystone\", \"keystone-manage\", \"bootstrap\"], \"environment\": {\"KOLLA_BOOTSTRAP\": true, \"OS_BOOTSTRAP_PASSWORD\": {\"get_param\": \"AdminPassword\"}, \"OS_BOOTSTRAP_USERNAME\": \"admin\", \"OS_BOOTSTRAP_PROJECT_NAME\": \"admin\", \"OS_BOOTSTRAP_ROLE_NAME\": \"admin\", \"OS_BOOTSTRAP_SERVICE_NAME\": \"keystone\", \"OS_BOOTSTRAP_ADMIN_URL\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"uri_no_suffix\"]}, \"OS_BOOTSTRAP_PUBLIC_URL\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"uri_no_suffix\"]}, \"OS_BOOTSTRAP_INTERNAL_URL\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"OS_BOOTSTRAP_REGION_ID\": {\"get_param\": \"KeystoneRegion\"}}}, \"keystone_cron\": {\"start_order\": 4, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerKeystoneImage\"]}, \"user\": \"root\", \"net\": \"host\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/usr/share/openstack-tripleo-common/healthcheck/cron keystone\"}, \"command\": [\"/bin/bash\", \"-c\", \"/usr/local/bin/kolla_set_configs && /usr/sbin/crond -n\"], \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"KeystoneLogging\", \"volumes\"]}, [\"/var/lib/kolla/config_files/keystone_cron.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/keystone:/var/lib/kolla/config_files/src:ro\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}, \"step_4\": {\"keystone_refresh\": {\"start_order\": 1, \"action\": \"exec\", \"user\": \"root\", \"command\": [\"keystone\", \"pkill\", \"--signal\", \"USR1\", \"httpd\"]}}}, \"external_deploy_tasks\": [{\"name\": \"Manage clouds.yaml files\", \"when\": [\"step|int == 1\", \"not ansible_check_mode|bool\"], \"block\": [{\"name\": \"Create /etc/openstack directory if it does not exist\", \"become\": true, \"file\": {\"mode\": \"0755\", \"owner\": \"root\", \"path\": \"/etc/openstack\", \"state\": \"directory\"}}, {\"name\": \"Configure /etc/openstack/clouds.yaml\", \"include_role\": {\"name\": \"tripleo_keystone_resources\", \"tasks_from\": \"clouds\"}, \"vars\": {\"tripleo_keystone_resources_cloud_name\": {\"get_param\": \"RootStackName\"}, \"tripleo_keystone_resources_cloud_config\": {\"auth\": {\"auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"uri_no_suffix\"]}, \"password\": {\"get_param\": \"AdminPassword\"}, \"project_domain_name\": \"Default\", \"project_name\": \"admin\", \"user_domain_name\": \"Default\", \"username\": \"admin\"}, \"cacert\": {\"if\": [\"public_tls_enabled\", {\"get_param\": \"PublicTLSCAFile\"}, \"\"]}, \"identity_api_version\": \"3\", \"volume_api_version\": \"3\", \"region_name\": {\"get_param\": \"KeystoneRegion\"}}}}]}, {\"name\": \"Manage Keystone resources\", \"become\": true, \"when\": [\"step|int == 4\", \"not ansible_check_mode|bool\"], \"block\": [{\"name\": \"Manage Keystone resources for OpenStack services\", \"include_role\": {\"name\": \"tripleo_keystone_resources\"}, \"vars\": {\"tripleo_keystone_resources_catalog_config\": \"{{ keystone_resources }}\", \"tripleo_keystone_resources_service_project\": \"service\", \"tripleo_keystone_resources_cloud_name\": {\"get_param\": \"RootStackName\"}, \"tripleo_keystone_resources_region\": {\"get_param\": \"KeystoneRegion\"}, \"tripleo_keystone_resources_admin_endpoint\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"uri_no_suffix\"]}, \"tripleo_keystone_resources_public_endpoint\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"uri_no_suffix\"]}, \"tripleo_keystone_resources_internal_endpoint\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"tripleo_keystone_resources_admin_password\": {\"get_param\": \"AdminPassword\"}, \"tripleo_keystone_resources_member_role_enabled\": {\"get_param\": \"KeystoneEnableMember\"}}}, {\"name\": \"is Keystone LDAP enabled\", \"set_fact\": {\"keystone_ldap_domain_enabled\": {\"get_param\": \"KeystoneLDAPDomainEnable\"}}}, {\"name\": \"Set fact for tripleo_keystone_ldap_domains\", \"set_fact\": {\"tripleo_keystone_ldap_domains\": {\"get_param\": \"KeystoneLDAPBackendConfigs\"}}, \"when\": \"keystone_ldap_domain_enabled|bool\"}, {\"name\": \"Manage Keystone domains from LDAP config\", \"when\": \"keystone_ldap_domain_enabled|bool\", \"include_role\": {\"name\": \"tripleo_keystone_resources\", \"tasks_from\": \"domains\"}, \"vars\": {\"tripleo_keystone_resources_catalog_config\": \"{{ keystone_resources }}\", \"tripleo_keystone_resources_cloud_name\": {\"get_param\": \"RootStackName\"}, \"batched_tripleo_keystone_resources_domains\": \"{{ tripleo_keystone_ldap_domains | list }}\"}}]}], \"deploy_steps_tasks\": {\"list_concat\": [{\"get_attr\": [\"ApacheServiceBase\", \"role_data\", \"deploy_steps_tasks\"]}, [{\"name\": \"validate keystone container state\", \"containers.podman.podman_container_info\": {\"name\": \"keystone\"}, \"register\": \"keystone_infos\", \"failed_when\": [\"keystone_infos.containers.0.Healthcheck.Status is defined\", \"\'healthy\' not in keystone_infos.containers.0.Healthcheck.Status\"], \"retries\": 10, \"delay\": 30, \"tags\": [\"opendev-validation\", \"opendev-validation-keystone\"], \"when\": [\"container_cli == \'podman\'\", \"not container_healthcheck_disabled\", \"step|int == 4\"]}]]}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"KeystoneLogging\", \"host_prep_tasks\"]}, [{\"name\": \"Check if file certs_valid exist\", \"stat\": {\"path\": \"/etc/openldap/certs/certs_valid\"}, \"register\": \"certs_valid_stat\"}, {\"name\": \"Check if file cert9.db exist\", \"stat\": {\"path\": \"/etc/openldap/certs/cert9.db\"}, \"register\": \"cert9_stat\", \"when\": \"not certs_valid_stat.stat.exists\"}, {\"name\": \"Check if file key4.db exist\", \"stat\": {\"path\": \"/etc/openldap/certs/key4.db\"}, \"register\": \"key4_stat\", \"when\": \"not certs_valid_stat.stat.exists\"}, {\"fail\": {\"msg\": \"Keys and/or certificates were found in /etc/openldap/certs but these conflicts with keystone python LDAP calls.  If you know those certificates are valid and not causing any conflicts, you can touch /etc/openldap/certs/certs_valid in order to skip this failure and retry or you can delete the files located in /etc/openldap/certs and retry.\\n\"}, \"when\": \"( cert9_stat.stat.exists or key4_stat.stat.exists ) and not certs_valid_stat.stat.exists\"}]]}, \"metadata_settings\": {\"get_attr\": [\"ApacheServiceBase\", \"role_data\", \"metadata_settings\"]}, \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop keystone container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"keystone\", \"keystone_cron\"], \"tripleo_delegate_to\": \"{{ groups[\'keystone\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(155,'2026-06-10 07:47:15',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (156,'2026-06-10 07:47:15',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Apache service configured with Puppet. Note this is typically included automatically via other services which run via Apache.\\n\", \"parameters\": {\"ApacheMaxRequestWorkers\": {\"default\": 100, \"description\": \"Maximum number of simultaneously processed requests.\", \"type\": \"number\"}, \"ApacheServerLimit\": {\"default\": 100, \"description\": \"Maximum number of Apache processes.\", \"type\": \"number\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"ApacheCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}, \"ApacheTimeout\": {\"type\": \"number\", \"default\": 90, \"description\": \"The timeout in seconds for Apache, which defines duration Apache waits for I/O operations\"}}, \"conditions\": {\"key_size_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"ApacheCertificateKeySize\"}, \"\"]}}}, \"resources\": {\"ApacheNetworks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"Controller\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"CellController\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"CellControllerCompute\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"Compute\": [\"ctlplane\", \"storage\", \"internal_api\"], \"BlockStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"ObjectStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"CephStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\"], \"Networker\": [\"ctlplane\", \"internal_api\"]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Apache role.\", \"value\": {\"service_name\": \"apache\", \"config_settings\": {\"map_merge\": [{\"apache::ip\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ApacheNetwork\"]}}}}, \"apache::default_vhost\": false, \"apache::trace_enable\": \"Off\", \"apache::server_signature\": \"Off\", \"apache::server_tokens\": \"Prod\", \"apache::timeout\": {\"get_param\": \"ApacheTimeout\"}, \"apache::default_mods\": false, \"apache::mod::prefork::maxrequestworkers\": {\"get_param\": \"ApacheMaxRequestWorkers\"}, \"apache::mod::prefork::serverlimit\": {\"get_param\": \"ApacheServerLimit\"}, \"apache::mod::remoteip::proxy_ips\": {\"get_param\": [\"ServiceData\", \"net_cidr_map\", {\"get_param\": [\"ServiceNetMap\", \"ApacheNetwork\"]}]}, \"apache::mod::alias::icons_options\": \"None\"}, {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"apache::mod::ssl::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}, \"apache::mod::ssl::ssl_protocol\": [\"all\", \"-SSLv2\", \"-SSLv3\", \"-TLSv1\"], \"apache_certificates_specs\": {\"map_merge\": {\"repeat\": {\"template\": {\"httpd-NETWORK\": {\"service_certificate\": \"/etc/pki/tls/certs/httpd/httpd-NETWORK.crt\", \"service_key\": \"/etc/pki/tls/private/httpd/httpd-NETWORK.key\"}}, \"for_each\": {\"NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}}}]}]}, \"metadata_settings\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"repeat\": {\"template\": [{\"service\": \"HTTP\", \"network\": \"$NETWORK\", \"type\": \"node\"}], \"for_each\": {\"$NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}]}, \"upgrade_tasks\": [], \"deploy_steps_tasks\": [{\"name\": \"Certificate generation\", \"when\": [\"step|int == 1\", \"enable_internal_tls\"], \"block\": [{\"name\": \"Create dirs for certificates and keys\", \"file\": {\"path\": \"{{ item }}\", \"state\": \"directory\", \"serole\": \"object_r\", \"setype\": \"cert_t\", \"seuser\": \"system_u\"}, \"with_items\": [\"/etc/pki/tls/certs/httpd\", \"/etc/pki/tls/private/httpd\"]}, {\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": {\"repeat\": {\"template\": {\"name\": \"httpd-NETWORK\", \"dns\": \"{{ fqdn_NETWORK }}\", \"principal\": \"HTTP/{{ fqdn_NETWORK }}@{{ idm_realm }}\", \"run_after\": \"cp /etc/pki/tls/certs/httpd-NETWORK.crt /etc/pki/tls/certs/httpd/httpd-NETWORK.crt\\ncp /etc/pki/tls/private/httpd-NETWORK.key /etc/pki/tls/private/httpd/httpd-NETWORK.key\\npkill -USR1 httpd\\n\", \"key_size\": {\"if\": [\"key_size_override_set\", {\"get_param\": \"ApacheCertificateKeySize\"}, {\"get_param\": \"CertificateKeySize\"}]}, \"ca\": \"ipa\"}, \"for_each\": {\"NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"EnableInternalTLS\": false}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(157,'2026-06-10 07:47:15',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Openstack Heat base service. Shared for all Heat services.\\n\", \"parameters\": {\"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"HeatDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Heat services.\", \"type\": \"boolean\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"HeatPassword\": {\"description\": \"The password for the Heat service and db account, used by the Heat services.\", \"type\": \"string\", \"hidden\": true, \"default\": \"bFBTZhN5CyNCch5KSkr70C02s\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableCache\": {\"description\": \"Enable caching with memcached\", \"type\": \"boolean\", \"default\": true}, \"HeatCronPurgeDeletedEnsure\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Ensure\\n\", \"default\": \"present\"}, \"HeatCronPurgeDeletedMinute\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Minute\\n\", \"default\": \"1\"}, \"HeatCronPurgeDeletedHour\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Hour\\n\", \"default\": \"0\"}, \"HeatCronPurgeDeletedMonthday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month Day\\n\", \"default\": \"*\"}, \"HeatCronPurgeDeletedMonth\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month\\n\", \"default\": \"*\"}, \"HeatCronPurgeDeletedWeekday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Week Day\\n\", \"default\": \"*\"}, \"HeatCronPurgeDeletedMaxDelay\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Max Delay\\n\", \"default\": \"3600\"}, \"HeatCronPurgeDeletedUser\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - User\\n\", \"default\": \"heat\"}, \"HeatCronPurgeDeletedAge\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Age\\n\", \"default\": \"30\"}, \"HeatCronPurgeDeletedAgeType\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Age type\\n\", \"default\": \"days\"}, \"HeatCronPurgeDeletedDestination\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Log destination\\n\", \"default\": \"/dev/null\"}, \"HeatYaqlLimitIterators\": {\"type\": \"number\", \"description\": \"The maximum number of elements in collection yaql expressions can take for its evaluation.\\n\", \"default\": 1000}, \"HeatYaqlMemoryQuota\": {\"type\": \"number\", \"description\": \"The maximum size of memory in bytes that yaql exrpessions can take for its evaluation.\\n\", \"default\": 100000}, \"HeatMaxJsonBodySize\": {\"default\": 4194304, \"description\": \"Maximum raw byte size of the Heat API JSON request body.\", \"type\": \"number\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"noop\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"HeatCorsAllowedOrigin\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Indicate whether this resource may be shared with the domain received in the request \\\"origin\\\" header.\"}, \"MemcachedTLS\": {\"default\": false, \"description\": \"Set to True to enable TLS on Memcached service. Because not all services support Memcached TLS, during the migration period, Memcached will listen on 2 ports - on the port set with MemcachedPort parameter (above) and on 11211, without TLS.\", \"type\": \"boolean\"}, \"MemcacheUseAdvancedPool\": {\"type\": \"boolean\", \"description\": \"Use the advanced (eventlet safe) memcached client pool.\\n\", \"default\": true}, \"HeatApiPolicies\": {\"description\": \"A hash of policies to configure for Heat API.\\ne.g. { heat-context_is_admin: { key: context_is_admin, value: \'role:admin\' } }\\n\", \"default\": {}, \"type\": \"json\"}, \"EnforceSecureRbac\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Setting this option to True will configure each OpenStack service to enforce Secure RBAC by setting `[oslo_policy] enforce_new_defaults` and `[oslo_policy] enforce_scope` to True. This introduces a consistent set of RBAC personas across OpenStack services that include support for system and project scope, as well as keystone\'s default roles, admin, member, and reader. Do not enable this functionality until all services in your deployment actually support secure RBAC.\"}}, \"conditions\": {\"tls_cache_enabled\": {\"and\": [{\"get_param\": \"EnableCache\"}, {\"get_param\": \"MemcachedTLS\"}]}, \"cors_allowed_origin_set\": {\"not\": {\"equals\": [{\"get_param\": \"HeatCorsAllowedOrigin\"}, \"\"]}}}, \"outputs\": {\"role_data\": {\"description\": \"Shared role data for the Heat services.\", \"value\": {\"service_name\": \"heat_base\", \"config_settings\": {\"map_merge\": [{\"if\": [{\"get_param\": \"EnforceSecureRbac\"}, {\"heat::policy::enforce_scope\": true, \"heat::policy::enforce_new_defaults\": true}]}, {\"if\": [\"cors_allowed_origin_set\", {\"heat::cors::allowed_origin\": {\"get_param\": \"HeatCorsAllowedOrigin\"}}]}, {\"heat::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"heat::logging::debug\": {\"if\": [{\"get_param\": \"HeatDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"heat::policy::policies\": {\"get_param\": \"HeatApiPolicies\"}, \"heat::enable_proxy_headers_parsing\": true, \"heat::rpc_response_timeout\": 600, \"heat::rabbit_heartbeat_timeout_threshold\": 60, \"heat::rabbit_heartbeat_in_pthread\": false, \"heat::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"heat::keystone::authtoken::project_name\": \"service\", \"heat::keystone::authtoken::user_domain_name\": \"Default\", \"heat::keystone::authtoken::project_domain_name\": \"Default\", \"heat::keystone::authtoken::www_authenticate_uri\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"uri_no_suffix\"]}, \"heat::keystone::authtoken::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"heat::keystone::authtoken::password\": {\"get_param\": \"HeatPassword\"}, \"heat::keystone::authtoken::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"heat::keystone::authtoken::interface\": \"internal\", \"heat::keystone::authtoken::memcache_use_advanced_pool\": {\"get_param\": \"MemcacheUseAdvancedPool\"}, \"heat::keystone::domain::domain_name\": \"heat_stack\", \"heat::keystone::domain::domain_admin\": \"heat_stack_domain_admin\", \"heat::keystone::domain::domain_admin_email\": \"heat_stack_domain_admin@localhost\", \"heat::db::database_db_max_retries\": -1, \"heat::db::database_max_retries\": -1, \"heat::yaql_memory_quota\": {\"get_param\": \"HeatYaqlMemoryQuota\"}, \"heat::yaql_limit_iterators\": {\"get_param\": \"HeatYaqlLimitIterators\"}, \"heat::cors::max_age\": 3600, \"heat::cors::allow_headers\": \"Content-Type,Cache-Control,Content-Language,Expires,Last-Modified,Pragma,X-Auth-Token\", \"heat::cors::expose_headers\": \"Content-Type,Cache-Control,Content-Language,Expires,Last-Modified,Pragma\", \"heat::cron::purge_deleted::ensure\": {\"get_param\": \"HeatCronPurgeDeletedEnsure\"}, \"heat::cron::purge_deleted::minute\": {\"get_param\": \"HeatCronPurgeDeletedMinute\"}, \"heat::cron::purge_deleted::hour\": {\"get_param\": \"HeatCronPurgeDeletedHour\"}, \"heat::cron::purge_deleted::monthday\": {\"get_param\": \"HeatCronPurgeDeletedMonthday\"}, \"heat::cron::purge_deleted::month\": {\"get_param\": \"HeatCronPurgeDeletedMonth\"}, \"heat::cron::purge_deleted::weekday\": {\"get_param\": \"HeatCronPurgeDeletedWeekday\"}, \"heat::cron::purge_deleted::maxdelay\": {\"get_param\": \"HeatCronPurgeDeletedMaxDelay\"}, \"heat::cron::purge_deleted::user\": {\"get_param\": \"HeatCronPurgeDeletedUser\"}, \"heat::cron::purge_deleted::age\": {\"get_param\": \"HeatCronPurgeDeletedAge\"}, \"heat::cron::purge_deleted::age_type\": {\"get_param\": \"HeatCronPurgeDeletedAgeType\"}, \"heat::cron::purge_deleted::destination\": {\"get_param\": \"HeatCronPurgeDeletedDestination\"}, \"heat::max_json_body_size\": {\"get_param\": \"HeatMaxJsonBodySize\"}}, {\"heat::cache::enabled\": {\"get_param\": \"EnableCache\"}, \"heat::cache::tls_enabled\": {\"get_param\": \"MemcachedTLS\"}, \"heat::cache::resource_finder_caching\": false}, {\"if\": [\"tls_cache_enabled\", {\"heat::cache::backend\": \"dogpile.cache.pymemcache\"}, {\"heat::cache::backend\": \"dogpile.cache.memcached\"}]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(158,'2026-06-10 07:47:16',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(159,'2026-06-10 07:47:17',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Openstack Manila Cephfs backend\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"CephClusterName\": {\"type\": \"string\", \"default\": \"ceph\", \"description\": \"The Ceph cluster name.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9]+\", \"description\": \"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\n\"}]}, \"CephConfigPath\": {\"type\": \"string\", \"default\": \"/var/lib/tripleo-config/ceph\", \"description\": \"The path where the Ceph Cluster config files are stored on the host.\\n\"}, \"ManilaCephFSDataPoolName\": {\"default\": \"manila_data\", \"type\": \"string\"}, \"ManilaCephFSBackendName\": {\"type\": \"string\", \"default\": \"cephfs\"}, \"ManilaCephFSFileSystemName\": {\"type\": \"string\", \"default\": \"cephfs\"}, \"ManilaCephFSAvailabilityZone\": {\"default\": \"\", \"description\": \"The availability zone of the CephFS backend. When set, it overrides the default ManilaStorageAvailabilityZone.\\n\", \"type\": \"string\"}, \"ManilaCephFSDriverHandlesShareServers\": {\"type\": \"boolean\", \"default\": false}, \"ManilaCephFSShareBackendName\": {\"type\": \"string\", \"default\": \"cephfs\"}, \"ManilaCephFSCephFSAuthId\": {\"type\": \"string\", \"default\": \"manila\"}, \"ManilaCephFSCephVolumeMode\": {\"type\": \"string\", \"default\": \"0755\"}, \"ManilaCephFSCephFSProtocolHelperType\": {\"default\": \"CEPHFS\", \"description\": \"Protocol type (\'CEPHFS\' or \'NFS\') when cephfs back end is enabled.  Set via manila cephfs environment files.\", \"type\": \"string\", \"constraints\": [{\"allowed_values\": [\"CEPHFS\", \"NFS\"]}]}, \"ManilaCephFSCephFSEnableSnapshots\": {\"type\": \"boolean\", \"description\": \"Enable snapshot support in CephFS driver. Note that this parameter has\\nno effect now and snapshot support is always enabled.\\n\", \"default\": false}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"The following parameters are deprecated and will be removed. They should not\\nbe relied on for new deployments. If you have concerns regarding deprecated\\nparameters, please contact the TripleO development team on IRC or the\\nOpenStack mailing list.\\n\", \"parameters\": [\"ManilaCephFSCephFSEnableSnapshots\"]}], \"outputs\": {\"role_data\": {\"description\": \"Role data for the Manila Cephfs backend.\", \"value\": {\"service_name\": \"manila_backend_cephfs\", \"config_settings\": {\"map_merge\": [{\"manila::backend::cephfs::title\": {\"get_param\": \"ManilaCephFSBackendName\"}, \"manila::backend::cephfs::driver_handles_share_servers\": {\"get_param\": \"ManilaCephFSDriverHandlesShareServers\"}, \"manila::backend::cephfs::pool_name\": {\"get_param\": \"ManilaCephFSDataPoolName\"}, \"manila::backend::cephfs::share_backend_name\": {\"get_param\": \"ManilaCephFSShareBackendName\"}, \"manila::backend::cephfs::cephfs_filesystem_name\": {\"get_param\": \"ManilaCephFSFileSystemName\"}, \"manila_cephfs_ceph_conf_path\": {\"get_param\": \"CephConfigPath\"}, \"manila::backend::cephfs::cephfs_conf_path\": {\"list_join\": [\"\", [\"/etc/ceph/\", {\"get_param\": \"CephClusterName\"}, \".conf\"]]}, \"manila::backend::cephfs::cephfs_auth_id\": {\"get_param\": \"ManilaCephFSCephFSAuthId\"}, \"manila::backend::cephfs::cephfs_cluster_name\": {\"get_param\": \"CephClusterName\"}, \"manila::backend::cephfs::cephfs_volume_mode\": {\"get_param\": \"ManilaCephFSCephVolumeMode\"}, \"manila::backend::cephfs::cephfs_protocol_helper_type\": {\"get_param\": \"ManilaCephFSCephFSProtocolHelperType\"}}, {\"if\": [{\"equals\": [{\"get_param\": \"ManilaCephFSAvailabilityZone\"}, \"\"]}, {}, {\"manila::backend::cephfs::backend_availability_zone\": {\"get_param\": \"ManilaCephFSAvailabilityZone\"}}]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(160,'2026-06-10 07:47:17',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mysql client settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role for setting mysql client parameters\", \"value\": {\"service_name\": \"mysql_client\", \"config_settings\": {\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"tripleo::profile::base::database::mysql::client::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}}, \"step_config\": \"include tripleo::profile::base::database::mysql::client\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(161,'2026-06-10 07:47:17',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Neutron API service\\n\", \"parameters\": {\"ContainerNeutronApiImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\"}, \"ContainerNeutronConfigImage\": {\"description\": \"The container image to use for the neutron config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\"}, \"NeutronApiLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.neutron.api\", \"file\": \"/var/log/containers/neutron/server.log\"}}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"DeployIdentifier\": {\"default\": 1781077560, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"NeutronApiOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\"}, \"NeutronApiOptEnvVars\": {\"default\": {}, \"description\": \"hash of optional environment variables\", \"type\": \"json\"}, \"NeutronWorkers\": {\"default\": 1, \"description\": \"Sets the number of API workers for the Neutron service.\\nThe default value results in the configuration being left unset\\nand a system-dependent default will be chosen (usually the number\\nof processors). Please note that this can result in a large number\\nof processes and memory consumption on systems with a large core\\ncount. On such systems it is recommended that a non-default value\\nbe selected that matches the load requirements.\\n\", \"type\": \"string\"}, \"NeutronRpcWorkers\": {\"default\": \"\", \"description\": \"Sets the number of RPC workers for the Neutron service.\\nIf not specified, it\'ll take the value of NeutronWorkers and if this is\\nnot specified either, the default value results in the configuration\\nbeing left unset and a system-dependent default will be chosen\\n(usually 1).\\n\", \"type\": \"string\"}, \"NeutronPassword\": {\"description\": \"The password for the neutron service and db account, used by neutron agents.\", \"type\": \"string\", \"hidden\": true, \"default\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\"}, \"NeutronAllowL3AgentFailover\": {\"default\": \"True\", \"description\": \"Allow automatic l3-agent failover\", \"type\": \"string\"}, \"NovaPassword\": {\"description\": \"The password for the nova service and db account\", \"type\": \"string\", \"hidden\": true, \"default\": \"btE80AtSdL16lZ5QqRx6f9I9L\"}, \"NeutronEnableDVR\": {\"description\": \"Enable Neutron DVR.\", \"default\": \"\", \"type\": \"string\"}, \"NeutronEnableIgmpSnooping\": {\"description\": \"Enable IGMP Snooping.\", \"type\": \"boolean\", \"default\": false}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"MonitoringSubscriptionNeutronServer\": {\"default\": \"overcloud-neutron-server\", \"type\": \"string\"}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}, \"NeutronApiPolicies\": {\"description\": \"A hash of policies to configure for Neutron API.\\ne.g. { neutron-context_is_admin: { key: context_is_admin, value: \'role:admin\' } }\\n\", \"default\": {}, \"type\": \"json\"}, \"NeutronOvsIntegrationBridge\": {\"default\": \"\", \"type\": \"string\", \"description\": \"Name of Open vSwitch bridge to use\"}, \"NeutronPortQuota\": {\"default\": \"500\", \"type\": \"string\", \"description\": \"Number of ports allowed per tenant, and minus means unlimited.\"}, \"NeutronSecurityGroupQuota\": {\"default\": \"10\", \"type\": \"string\", \"description\": \"Number of security groups allowed per tenant, and minus means unlimited\"}, \"NeutronMechanismDrivers\": {\"default\": \"ovn\", \"description\": \"The mechanism drivers for the Neutron tenant network.\\n\", \"type\": \"comma_delimited_list\"}, \"NeutronDefaultAvailabilityZones\": {\"description\": \"Comma-separated list of default network availability zones to be used by Neutron if its resource is created without availability zone hints. If not set, no AZs will be configured for Neutron network services.\", \"default\": [], \"type\": \"comma_delimited_list\"}, \"NeutronNetworkSchedulerDriver\": {\"description\": \"The network schedule driver to use for avialability zones.\", \"default\": \"neutron.scheduler.dhcp_agent_scheduler.AZAwareWeightScheduler\", \"type\": \"string\"}, \"NeutronRouterSchedulerDriver\": {\"description\": \"The router schedule driver to use for avialability zones.\", \"default\": \"neutron.scheduler.l3_agent_scheduler.AZLeastRoutersScheduler\", \"type\": \"string\"}, \"NeutronDhcpLoadType\": {\"description\": \"Additional to the availability zones aware network scheduler.\", \"default\": \"networks\", \"type\": \"string\"}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"NeutronCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}, \"MemcacheUseAdvancedPool\": {\"type\": \"boolean\", \"description\": \"Use the advanced (eventlet safe) memcached client pool.\\n\", \"default\": true}, \"NeutronL3HA\": {\"default\": \"\", \"type\": \"string\", \"description\": \"Whether to enable HA for virtual routers. When not set, L3 HA will be\\nautomatically enabled if the number of nodes hosting controller\\nconfigurations and DVR is disabled. Valid values are \'true\' or \'false\'\\nThis parameter is being deprecated in Newton and is scheduled to be\\nremoved in Ocata.  Future releases will enable L3 HA by default if it is\\nappropriate for the deployment type. Alternate mechanisms will be\\navailable to override.\\n\"}, \"NeutronAgentDownTime\": {\"default\": 600, \"type\": \"number\", \"description\": \"Seconds to regard the agent as down; should be at least twice\\nNeutronGlobalReportInterval, to be sure the agent is down for good.\\n\"}, \"EnforceSecureRbac\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Setting this option to True will configure each OpenStack service to enforce Secure RBAC by setting `[oslo_policy] enforce_new_defaults` and `[oslo_policy] enforce_scope` to True. This introduces a consistent set of RBAC personas across OpenStack services that include support for system and project scope, as well as keystone\'s default roles, admin, member, and reader. Do not enable this functionality until all services in your deployment actually support secure RBAC.\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"The following parameters are deprecated and will be removed. They should not\\nbe relied on for new deployments. If you have concerns regarding deprecated\\nparameters, please contact the TripleO development team on IRC or the\\nOpenStack mailing list.\\n\", \"parameters\": [\"NeutronL3HA\"]}], \"conditions\": {\"use_tls_proxy\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"neutron_workers_unset\": {\"equals\": [{\"get_param\": \"NeutronWorkers\"}, \"\"]}, \"neutron_rpc_workers_unset\": {\"equals\": [{\"get_param\": \"NeutronRpcWorkers\"}, \"\"]}, \"neutron_ovs_int_br_unset\": {\"equals\": [{\"get_param\": \"NeutronOvsIntegrationBridge\"}, \"\"]}, \"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"neutron_dvr_unset\": {\"equals\": [{\"get_param\": \"NeutronEnableDVR\"}, \"\"]}, \"is_ovn_in_neutron_mechanism_driver\": {\"contains\": [\"ovn\", {\"get_param\": \"NeutronMechanismDrivers\"}]}, \"az_unset\": {\"equals\": [{\"get_param\": \"NeutronDefaultAvailabilityZones\"}, []]}, \"ovn_and_tls\": {\"and\": [\"is_ovn_in_neutron_mechanism_driver\", \"internal_tls_enabled\"]}, \"enable_sqlalchemy_collectd\": {\"equals\": [{\"get_param\": \"EnableSQLAlchemyCollectd\"}, true]}, \"key_size_override_unset\": {\"equals\": [{\"get_param\": \"NeutronCertificateKeySize\"}, \"\"]}}, \"resources\": {\"TLSProxyBase\": {\"type\": \"OS::TripleO::Services::TLSProxyBase\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}, \"EnableInternalTLS\": {\"get_param\": \"EnableInternalTLS\"}}}, \"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MySQLClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\"}, \"NeutronBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-base.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"NeutronLogging\": {\"type\": \"OS::TripleO::Services::Logging::NeutronApi\", \"properties\": {\"NeutronServiceName\": \"server\"}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerNeutronApiImage\": \"ContainerNeutronApiImage\", \"ContainerNeutronConfigImage\": \"ContainerNeutronConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerNeutronApiImage\": {\"get_param\": \"ContainerNeutronApiImage\"}, \"ContainerNeutronConfigImage\": {\"get_param\": \"ContainerNeutronConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Neutron API role.\", \"value\": {\"service_name\": \"neutron_api\", \"firewall_rules\": {\"114 neutron api\": {\"dport\": [9696]}}, \"firewall_frontend_rules\": {\"100 neutron_haproxy_frontend\": {\"dport\": [9696]}}, \"firewall_ssl_frontend_rules\": {\"100 neutron_haproxy_frontend_ssl\": {\"dport\": [13696]}}, \"keystone_resources\": {\"neutron\": {\"endpoints\": {\"public\": {\"get_param\": [\"EndpointMap\", \"NeutronPublic\", \"uri\"]}, \"internal\": {\"get_param\": [\"EndpointMap\", \"NeutronInternal\", \"uri\"]}, \"admin\": {\"get_param\": [\"EndpointMap\", \"NeutronAdmin\", \"uri\"]}}, \"users\": {\"neutron\": {\"password\": {\"get_param\": \"NeutronPassword\"}}}, \"region\": {\"get_param\": \"KeystoneRegion\"}, \"service\": \"network\"}}, \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionNeutronServer\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"NeutronBase\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"TLSProxyBase\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"NeutronLogging\", \"config_settings\"]}, {\"neutron::db::database_connection\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"protocol\"]}, \"username\": \"neutron\", \"password\": {\"get_param\": \"NeutronPassword\"}, \"host\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"host\"]}, \"path\": \"/ovs_neutron\", \"query\": {\"if\": [\"enable_sqlalchemy_collectd\", {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\", \"plugin\": \"collectd\", \"collectd_program_name\": \"ovs_neutron\", \"collectd_host\": \"localhost\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\"}]}}}, \"neutron::policy::policies\": {\"get_param\": \"NeutronApiPolicies\"}}, {\"if\": [{\"get_param\": \"EnforceSecureRbac\"}, {\"neutron::policy::enforce_scope\": true, \"neutron::policy::enforce_new_defaults\": true}], \"neutron::keystone::authtoken::www_authenticate_uri\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"uri_no_suffix\"]}, \"neutron::keystone::authtoken::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"neutron::server::agent_down_time\": {\"get_param\": \"NeutronAgentDownTime\"}, \"neutron::server::allow_automatic_l3agent_failover\": {\"get_param\": \"NeutronAllowL3AgentFailover\"}, \"neutron::server::enable_proxy_headers_parsing\": true, \"neutron::server::igmp_snooping_enable\": {\"get_param\": \"NeutronEnableIgmpSnooping\"}, \"neutron::keystone::authtoken::password\": {\"get_param\": \"NeutronPassword\"}, \"neutron::server::notifications::nova::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"neutron::server::notifications::nova::project_name\": \"service\", \"neutron::server::notifications::nova::user_domain_name\": \"Default\", \"neutron::server::notifications::nova::project_domain_name\": \"Default\", \"neutron::server::notifications::nova::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"neutron::server::notifications::nova::password\": {\"get_param\": \"NovaPassword\"}, \"neutron::server::notifications::nova::endpoint_type\": \"internal\", \"neutron::keystone::authtoken::project_name\": \"service\", \"neutron::keystone::authtoken::user_domain_name\": \"Default\", \"neutron::keystone::authtoken::project_domain_name\": \"Default\", \"neutron::keystone::authtoken::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"neutron::keystone::authtoken::interface\": \"internal\", \"neutron::keystone::authtoken::memcache_use_advanced_pool\": {\"get_param\": \"MemcacheUseAdvancedPool\"}, \"neutron::quota::quota_port\": {\"get_param\": \"NeutronPortQuota\"}, \"neutron::quota::quota_security_group\": {\"get_param\": \"NeutronSecurityGroupQuota\"}, \"neutron::server::placement::password\": {\"get_param\": \"NovaPassword\"}, \"neutron::server::placement::project_domain_name\": \"Default\", \"neutron::server::placement::project_name\": \"service\", \"neutron::server::placement::user_domain_name\": \"Default\", \"neutron::server::placement::username\": \"nova\", \"neutron::server::placement::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"neutron::server::placement::auth_type\": \"password\", \"neutron::server::placement::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"tripleo::profile::base::neutron::server::tls_proxy_bind_ip\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}}}}, \"tripleo::profile::base::neutron::server::tls_proxy_fqdn\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}}}}, \"tripleo::profile::base::neutron::server::tls_proxy_port\": {\"get_param\": [\"EndpointMap\", \"NeutronInternal\", \"port\"]}, \"neutron::bind_host\": {\"if\": [\"use_tls_proxy\", \"%{hiera(\'localhost_address\')}\", {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}}}}]}, \"tripleo::profile::base::neutron::server::l3_ha_override\": {\"get_param\": \"NeutronL3HA\"}}, {\"if\": [\"neutron_dvr_unset\", {}, {\"neutron::server::router_distributed\": {\"get_param\": \"NeutronEnableDVR\"}, \"neutron::server::enable_dvr\": {\"get_param\": \"NeutronEnableDVR\"}}]}, {\"if\": [\"neutron_workers_unset\", {}, {\"neutron::server::api_workers\": {\"get_param\": \"NeutronWorkers\"}}]}, {\"if\": [\"neutron_rpc_workers_unset\", {\"if\": [\"neutron_workers_unset\", {}, {\"neutron::server::rpc_workers\": {\"get_param\": \"NeutronWorkers\"}}]}, {\"neutron::server::rpc_workers\": {\"get_param\": \"NeutronRpcWorkers\"}}]}, {\"if\": [\"neutron_ovs_int_br_unset\", {}, {\"neutron::server::ovs_integration_bridge\": {\"get_param\": \"NeutronOvsIntegrationBridge\"}}]}, {\"if\": [\"az_unset\", {}, {\"neutron::server::dhcp_load_type\": {\"get_param\": \"NeutronDhcpLoadType\"}, \"neutron::server::network_scheduler_driver\": {\"get_param\": \"NeutronNetworkSchedulerDriver\"}, \"neutron::server::router_scheduler_driver\": {\"get_param\": \"NeutronRouterSchedulerDriver\"}, \"neutron::server::default_availability_zones\": {\"get_param\": \"NeutronDefaultAvailabilityZones\"}}]}, {\"if\": [\"ovn_and_tls\", {\"tripleo::profile::base::neutron::plugins::ml2::ovn::protocol\": \"ssl\", \"tripleo::profile::base::neutron::plugins::ml2::ovn::ovn_nb_private_key\": \"/etc/pki/tls/private/neutron_ovn.key\", \"tripleo::profile::base::neutron::plugins::ml2::ovn::ovn_nb_certificate\": \"/etc/pki/tls/certs/neutron_ovn.crt\", \"tripleo::profile::base::neutron::plugins::ml2::ovn::ovn_sb_private_key\": \"/etc/pki/tls/private/neutron_ovn.key\", \"tripleo::profile::base::neutron::plugins::ml2::ovn::ovn_sb_certificate\": \"/etc/pki/tls/certs/neutron_ovn.crt\", \"tripleo::profile::base::neutron::plugins::ml2::ovn::ovn_nb_ca_cert\": {\"get_param\": \"InternalTLSCAFile\"}, \"tripleo::profile::base::neutron::plugins::ml2::ovn::ovn_sb_ca_cert\": {\"get_param\": \"InternalTLSCAFile\"}}, {}]}]}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_neutron_api\": [{\"get_param\": \"NeutronApiLoggingSource\"}]}, \"mysql\": {\"neutron::db::mysql::password\": {\"get_param\": \"NeutronPassword\"}, \"neutron::db::mysql::user\": \"neutron\", \"neutron::db::mysql::host\": \"%\", \"neutron::db::mysql::dbname\": \"ovs_neutron\"}}, \"puppet_config\": {\"config_volume\": \"neutron\", \"puppet_tags\": \"neutron_config,neutron_api_paste_ini\", \"step_config\": {\"list_join\": [\"\\n\", [\"include tripleo::profile::base::neutron::server\", {\"get_attr\": [\"MySQLClient\", \"role_data\", \"step_config\"]}]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNeutronConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/neutron_api.json\": {\"command\": {\"list_join\": [\" \", [\"/usr/bin/neutron-server --config-file /usr/share/neutron/neutron-dist.conf --config-dir /usr/share/neutron/server --config-file /etc/neutron/neutron.conf --config-file /etc/neutron/plugin.ini --config-dir /etc/neutron/conf.d/common --config-dir /etc/neutron/conf.d/neutron-server\", {\"get_attr\": [\"NeutronLogging\", \"cmd_extra_args\"]}]]}, \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"optional\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/neutron\", \"owner\": \"neutron:neutron\", \"recurse\": true}, {\"path\": \"/etc/pki/tls/certs/neutron_ovn.crt\", \"owner\": \"neutron:neutron\", \"optional\": true, \"perm\": \"0644\"}, {\"path\": \"/etc/pki/tls/private/neutron_ovn.key\", \"owner\": \"neutron:neutron\", \"optional\": true, \"perm\": \"0644\"}]}, \"/var/lib/kolla/config_files/neutron_api_db_sync.json\": {\"command\": \"/usr/bin/bootstrap_host_exec neutron_api neutron-db-manage upgrade heads\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"optional\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/neutron\", \"owner\": \"neutron:neutron\", \"recurse\": true}, {\"path\": \"/etc/pki/tls/certs/neutron_ovn.crt\", \"owner\": \"neutron:neutron\", \"optional\": true, \"perm\": \"0644\"}, {\"path\": \"/etc/pki/tls/private/neutron_ovn.key\", \"owner\": \"neutron:neutron\", \"optional\": true, \"perm\": \"0644\"}]}, \"/var/lib/kolla/config_files/neutron_server_tls_proxy.json\": {\"command\": \"/usr/sbin/httpd -DFOREGROUND\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.d\", \"dest\": \"/etc/httpd/conf.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.modules.d\", \"dest\": \"/etc/httpd/conf.modules.d\", \"merge\": false, \"preserve_properties\": true}]}}, \"docker_config\": {\"step_2\": {\"get_attr\": [\"NeutronLogging\", \"docker_config\", \"step_2\"]}, \"step_3\": {\"neutron_db_sync\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNeutronApiImage\"]}, \"cap_add\": [\"AUDIT_WRITE\"], \"net\": \"host\", \"privileged\": false, \"detach\": false, \"user\": \"root\", \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"NeutronLogging\", \"volumes\"]}, {\"get_param\": \"NeutronApiOptVolumes\"}, [\"/var/lib/kolla/config_files/neutron_api_db_sync.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/neutron:/var/lib/kolla/config_files/src:ro\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\", \"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}}}}, \"step_4\": {\"map_merge\": [{\"neutron_api\": {\"start_order\": 0, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNeutronApiImage\"]}, \"net\": \"host\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"NeutronLogging\", \"volumes\"]}, {\"get_param\": \"NeutronApiOptVolumes\"}, [\"/var/lib/kolla/config_files/neutron_api.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/neutron:/var/lib/kolla/config_files/src:ro\"], {\"if\": [\"ovn_and_tls\", [\"/etc/pki/tls/certs/neutron_ovn.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/neutron_ovn.crt:ro\", \"/etc/pki/tls/private/neutron_ovn.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/neutron_ovn.key:ro\"], null]}]}, \"environment\": {\"map_merge\": [{\"get_param\": \"NeutronApiOptEnvVars\"}, {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}]}}}, {\"if\": [\"internal_tls_enabled\", {\"neutron_server_tls_proxy\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNeutronApiImage\"]}, \"net\": \"host\", \"user\": \"root\", \"restart\": \"always\", \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"NeutronLogging\", \"volumes\"]}, [\"/var/lib/kolla/config_files/neutron_server_tls_proxy.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/neutron:/var/lib/kolla/config_files/src:ro\", \"/etc/pki/tls/certs/httpd:/etc/pki/tls/certs/httpd:ro\", \"/etc/pki/tls/private/httpd:/etc/pki/tls/private/httpd:ro\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}, {}]}]}}, \"host_prep_tasks\": {\"get_attr\": [\"NeutronLogging\", \"host_prep_tasks\"]}, \"metadata_settings\": {\"list_concat\": [{\"get_attr\": [\"TLSProxyBase\", \"role_data\", \"metadata_settings\"]}, {\"if\": [\"ovn_and_tls\", [{\"service\": \"neutron_ovn\", \"network\": {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}, \"type\": \"node\"}], null]}]}, \"deploy_steps_tasks\": {\"if\": [\"ovn_and_tls\", [{\"name\": \"Certificate generation\", \"when\": \"step|int == 1\", \"block\": [{\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": [{\"name\": \"neutron_ovn\", \"dns\": {\"str_replace\": {\"template\": \"{{fqdn_$NETWORK}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}}}}, \"principal\": {\"str_replace\": {\"template\": \"neutron_ovn/{{fqdn_$NETWORK}}@{{idm_realm}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}}}}, \"key_size\": {\"if\": [\"key_size_override_unset\", {\"get_param\": \"CertificateKeySize\"}, {\"get_param\": \"NeutronCertificateKeySize\"}]}, \"ca\": \"ipa\"}]}}]}], null]}, \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop neutron api container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"neutron_api\"], \"tripleo_delegate_to\": \"{{ groups[\'neutron_api\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}], \"external_update_tasks\": [{\"name\": \"Check if python3-openvswitch3.1 workaround is needed\", \"delegate_to\": \"{{groups[\'neutron_api\'][0]}}\", \"become\": true, \"tags\": [\"ovn\", \"ovn_image\"], \"when\": \"step|int == 1\", \"shell\": \"podman exec neutron_api rpm -q python3-openvswitch3.1\\n\", \"register\": \"neutron_python_ovs_3_1\", \"failed_when\": false}, {\"name\": \"Update neutron_api first everywhere\", \"become\": true, \"tags\": [\"ovn\", \"ovn_image\"], \"when\": [\"step|int == 1\", \"neutron_python_ovs_3_1.rc == 0\"], \"block\": [{\"name\": \"Move virtual IPs to another node before stopping pacemaker\", \"delegate_to\": \"{{groups[\'neutron_api\'][0]}}\", \"when\": [\"hostvars[groups[\'neutron_api\'][0]][\\\"haproxy_node_names\\\"]|default([])|length > 1\"], \"shell\": \"CLUSTER_NODE=$(crm_node -n)\\necho \\\"Retrieving all the VIPs which are hosted on this node\\\"\\nVIPS_TO_MOVE=$(crm_mon --as-xml | xmllint --xpath \'//resource[@resource_agent=\\\"ocf:heartbeat:IPaddr2\\\" and @role = \\\"Started\\\" and @managed = \\\"true\\\" and ./node[@name = \\\"\'${CLUSTER_NODE}\'\\\"]]/@id\' - | sed -e \'s/id=//g\' -e \'s/\\\"//g\')\\nfor v in ${VIPS_TO_MOVE}; do\\n    echo \\\"Moving VIP $v on another node\\\"\\n    pcs resource ban $v ${CLUSTER_NODE} --wait=300\\ndone\\necho \\\"Removing the location constraints that were created to move the VIPs\\\"\\nfor v in ${VIPS_TO_MOVE}; do\\n    echo \\\"Removing location ban for VIP $v\\\"\\n    ban_id=$(cibadmin --query | xmllint --xpath \'string(//rsc_location[@rsc=\\\"\'${v}\'\\\" and @node=\\\"\'${CLUSTER_NODE}\'\\\" and @score=\\\"-INFINITY\\\"]/@id)\' -)\\n    if [ -n \\\"$ban_id\\\" ]; then\\n        pcs constraint remove ${ban_id}\\n    else\\n        echo \\\"Could not retrieve and clear location constraint for VIP $v\\\" 2>&1\\n    fi\\ndone\\n\"}, {\"name\": \"Create firewall nat prerouting and postrouting\", \"delegate_to\": \"{{groups[\'neutron_api\'][0]}}\", \"shell\": \"set -o pipefail\\nLOCAL_BACKEND=$(grep {{groups[\'neutron_api\'][0]}} /var/lib/config-data/puppet-generated/haproxy/etc/haproxy/haproxy.cfg | \\\\\\n  grep \\\":9696 \\\" | awk \'{print $3}\')\\nIP=${LOCAL_BACKEND%:*}\\nif [[ $IP =~ .*:.* ]]\\n  then\\n       PROTOCOL=\\\"ip6\\\"\\n       # we need to temporarly allow ipv6 forwarding, this will get reset by deployment run\\n       sysctl -w net.ipv6.conf.all.forwarding=1\\n  else PROTOCOL=\\\"ip\\\"\\nfi\\nnft add table $PROTOCOL nat\\nnft -- add chain $PROTOCOL nat prerouting { type nat hook prerouting priority -100 \\\\; }\\nnft add chain $PROTOCOL nat postrouting { type nat hook postrouting priority 100 \\\\; }\\n\"}, {\"name\": \"Redirect neutron backend traffic for 60s to other host\", \"delegate_to\": \"{{groups[\'neutron_api\'][0]}}\", \"shell\": \"set -o pipefail\\nsource /etc/os-release; test  \\\"${VERSION_ID%*}\\\" = \\\"9.0\\\" && exit 0\\nLOCAL_BACKEND=$(grep {{groups[\'neutron_api\'][0]}} /var/lib/config-data/puppet-generated/haproxy/etc/haproxy/haproxy.cfg | \\\\\\n  grep \\\":9696 \\\" | awk \'{print $3}\')\\nREMOTE_BACKEND=$(grep \\\":9696 \\\" /var/lib/config-data/puppet-generated/haproxy/etc/haproxy/haproxy.cfg | \\\\\\n  grep server | grep -v {{groups[\'neutron_api\'][0]}} | head -n1 | awk \'{print $3}\')\\nIP=${LOCAL_BACKEND%:*}\\nPORT=9696\\nif [[ $IP =~ .*:.* ]]\\n  then PROTOCOL=\\\"ip6\\\"\\n  else PROTOCOL=\\\"ip\\\"\\nfi\\nREMOTE_IP=${REMOTE_BACKEND%:*}\\nnft add rule $PROTOCOL nat postrouting $PROTOCOL daddr $REMOTE_IP tcp dport 9696 counter meta time $(date +%s)-$(date -d\'+60 seconds\' +%s) masquerade comment neutron_api\\nnft add rule $PROTOCOL nat prerouting $PROTOCOL daddr $IP tcp dport 9696 counter meta time $(date +%s)-$(date -d\'+60 seconds\' +%s) dnat to $REMOTE_IP comment neutron_api\\n\"}, {\"name\": \"Insanity neutron update first\", \"delegate_to\": \"{{groups[\'neutron_api\'][0]}}\", \"become\": true, \"tripleo_container_manage\": {\"config_dir\": \"/var/lib/tripleo-config/container-startup-config/step_4\", \"config_id\": [\"neutron_api\"], \"config_patterns\": \"*neutron_api.json\", \"config_overrides\": {\".*neutron_api\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNeutronApiImage\"]}, \"name\": \"neutron_api\"}}}}, {\"wait_for\": {\"timeout\": 50}}, {\"name\": \"Delete redirect rules\", \"delegate_to\": \"{{groups[\'neutron_api\'][0]}}\", \"shell\": \"set -o pipefail\\nLOCAL_BACKEND=$(grep {{groups[\'neutron_api\'][0]}} /var/lib/config-data/puppet-generated/haproxy/etc/haproxy/haproxy.cfg | \\\\\\n  grep \\\":9696 \\\" | awk \'{print $3}\')\\nIP=${LOCAL_BACKEND%:*}\\nif [[ $IP =~ .*:.* ]]\\n  then\\n       PROTOCOL=\\\"ip6\\\"\\n  else PROTOCOL=\\\"ip\\\"\\nfi\\nnft -a list chain $PROTOCOL nat postrouting | grep neutron_api | awk -F# \'{print \\\"nat postrouting \\\"$2}\' | \\\\\\nwhile read i; do bash -c \\\"nft delete rule $PROTOCOL $i\\\"; done\\nnft -a list chain $PROTOCOL nat prerouting | grep neutron_api | awk -F# \'{print \\\"nat prerouting \\\"$2}\' | \\\\\\nwhile read i; do bash -c \\\"nft delete rule $PROTOCOL $i\\\"; done\\n\"}, {\"name\": \"Move virtual IPs to another node before stopping pacemaker\", \"delegate_to\": \"{{groups[\'neutron_api\'][1]}}\", \"when\": [\"hostvars[groups[\'neutron_api\'][1]][\\\"haproxy_node_names\\\"]|default([])|length > 1\", \"groups[\'neutron_api\'] | default([]) | length > 1\"], \"shell\": \"CLUSTER_NODE=$(crm_node -n)\\necho \\\"Retrieving all the VIPs which are hosted on this node\\\"\\nVIPS_TO_MOVE=$(crm_mon --as-xml | xmllint --xpath \'//resource[@resource_agent=\\\"ocf:heartbeat:IPaddr2\\\" and @role = \\\"Started\\\" and @managed = \\\"true\\\" and ./node[@name = \\\"\'${CLUSTER_NODE}\'\\\"]]/@id\' - | sed -e \'s/id=//g\' -e \'s/\\\"//g\')\\nfor v in ${VIPS_TO_MOVE}; do\\n    echo \\\"Moving VIP $v on another node\\\"\\n    pcs resource ban $v ${CLUSTER_NODE} --wait=300\\ndone\\necho \\\"Removing the location constraints that were created to move the VIPs\\\"\\nfor v in ${VIPS_TO_MOVE}; do\\n    echo \\\"Removing location ban for VIP $v\\\"\\n    ban_id=$(cibadmin --query | xmllint --xpath \'string(//rsc_location[@rsc=\\\"\'${v}\'\\\" and @node=\\\"\'${CLUSTER_NODE}\'\\\" and @score=\\\"-INFINITY\\\"]/@id)\' -)\\n    if [ -n \\\"$ban_id\\\" ]; then\\n        pcs constraint remove ${ban_id}\\n    else\\n        echo \\\"Could not retrieve and clear location constraint for VIP $v\\\" 2>&1\\n    fi\\ndone\\n\"}, {\"name\": \"Create firewall nat prerouting and postrouting\", \"delegate_to\": \"{{groups[\'neutron_api\'][1]}}\", \"when\": [\"groups[\'neutron_api\'] | default([]) | length > 1\"], \"shell\": \"set -o pipefail\\nLOCAL_BACKEND=$(grep {{groups[\'neutron_api\'][1]}} /var/lib/config-data/puppet-generated/haproxy/etc/haproxy/haproxy.cfg | \\\\\\n  grep \\\":9696 \\\" | awk \'{print $3}\')\\nIP=${LOCAL_BACKEND%:*}\\nif [[ $IP =~ .*:.* ]]\\n  then\\n       PROTOCOL=\\\"ip6\\\"\\n       # we need to temporarly allow ipv6 forwarding, this will get reset by deployment run\\n       sysctl -w net.ipv6.conf.all.forwarding=1\\n  else PROTOCOL=\\\"ip\\\"\\nfi\\nnft add table $PROTOCOL nat\\nnft -- add chain $PROTOCOL nat prerouting { type nat hook prerouting priority -100 \\\\; }\\nnft add chain $PROTOCOL nat postrouting { type nat hook postrouting priority 100 \\\\; }\\n\"}, {\"name\": \"Redirect neutron backend traffic for 60s to other host\", \"delegate_to\": \"{{groups[\'neutron_api\'][1]}}\", \"when\": [\"groups[\'neutron_api\'] | default([]) | length > 1\"], \"shell\": \"set -o pipefail\\nsource /etc/os-release; test  \\\"${VERSION_ID%*}\\\" = \\\"9.0\\\" && exit 0\\nLOCAL_BACKEND=$(grep {{groups[\'neutron_api\'][1]}} /var/lib/config-data/puppet-generated/haproxy/etc/haproxy/haproxy.cfg | \\\\\\n  grep \\\":9696 \\\" | awk \'{print $3}\')\\nREMOTE_BACKEND=$(grep \\\":9696 \\\" /var/lib/config-data/puppet-generated/haproxy/etc/haproxy/haproxy.cfg | \\\\\\n  grep server | grep -v {{groups[\'neutron_api\'][1]}} | head -n1 | awk \'{print $3}\')\\nIP=${LOCAL_BACKEND%:*}\\nPORT=9696\\nif [[ $IP =~ .*:.* ]]\\n  then PROTOCOL=\\\"ip6\\\"\\n  else PROTOCOL=\\\"ip\\\"\\nfi\\nREMOTE_IP=${REMOTE_BACKEND%:*}\\nnft add rule $PROTOCOL nat postrouting $PROTOCOL daddr $REMOTE_IP tcp dport 9696 counter meta time $(date +%s)-$(date -d\'+60 seconds\' +%s) masquerade comment neutron_api\\nnft add rule $PROTOCOL nat prerouting $PROTOCOL daddr $IP tcp dport 9696 counter meta time $(date +%s)-$(date -d\'+60 seconds\' +%s) dnat to $REMOTE_IP comment neutron_api\\n\"}, {\"name\": \"Insanity neutron update first\", \"delegate_to\": \"{{groups[\'neutron_api\'][1]}}\", \"become\": true, \"tripleo_container_manage\": {\"config_dir\": \"/var/lib/tripleo-config/container-startup-config/step_4\", \"config_id\": [\"neutron_api\"], \"config_patterns\": \"*neutron_api.json\", \"config_overrides\": {\".*neutron_api\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNeutronApiImage\"]}, \"name\": \"neutron_api\"}}}, \"when\": [\"groups[\'neutron_api\'] | default([]) | length > 1\"]}, {\"wait_for\": {\"timeout\": 50}, \"when\": [\"groups[\'neutron_api\'] | default([]) | length > 1\"]}, {\"name\": \"Delete redirect rules\", \"delegate_to\": \"{{groups[\'neutron_api\'][1]}}\", \"when\": [\"groups[\'neutron_api\'] | default([]) | length > 1\"], \"shell\": \"set -o pipefail\\nLOCAL_BACKEND=$(grep {{groups[\'neutron_api\'][1]}} /var/lib/config-data/puppet-generated/haproxy/etc/haproxy/haproxy.cfg | \\\\\\n  grep \\\":9696 \\\" | awk \'{print $3}\')\\nIP=${LOCAL_BACKEND%:*}\\nif [[ $IP =~ .*:.* ]]\\n  then PROTOCOL=\\\"ip6\\\"\\n  else PROTOCOL=\\\"ip\\\"\\nfi\\nnft -a list chain $PROTOCOL nat postrouting | grep neutron_api | awk -F# \'{print \\\"nat postrouting \\\"$2}\' | \\\\\\nwhile read i; do bash -c \\\"nft delete rule $PROTOCOL $i\\\"; done\\nnft -a list chain $PROTOCOL nat prerouting | grep neutron_api | awk -F# \'{print \\\"nat prerouting \\\"$2}\' | \\\\\\nwhile read i; do bash -c \\\"nft delete rule $PROTOCOL $i\\\"; done\\n\"}, {\"name\": \"Move virtual IPs to another node before stopping pacemaker\", \"delegate_to\": \"{{groups[\'neutron_api\'][2]}}\", \"when\": [\"hostvars[groups[\'neutron_api\'][2]][\\\"haproxy_node_names\\\"]|default([])|length > 1\", \"groups[\'neutron_api\'] | default([]) | length > 2\"], \"shell\": \"CLUSTER_NODE=$(crm_node -n)\\necho \\\"Retrieving all the VIPs which are hosted on this node\\\"\\nVIPS_TO_MOVE=$(crm_mon --as-xml | xmllint --xpath \'//resource[@resource_agent=\\\"ocf:heartbeat:IPaddr2\\\" and @role = \\\"Started\\\" and @managed = \\\"true\\\" and ./node[@name = \\\"\'${CLUSTER_NODE}\'\\\"]]/@id\' - | sed -e \'s/id=//g\' -e \'s/\\\"//g\')\\nfor v in ${VIPS_TO_MOVE}; do\\n    echo \\\"Moving VIP $v on another node\\\"\\n    pcs resource ban $v ${CLUSTER_NODE} --wait=300\\ndone\\necho \\\"Removing the location constraints that were created to move the VIPs\\\"\\nfor v in ${VIPS_TO_MOVE}; do\\n    echo \\\"Removing location ban for VIP $v\\\"\\n    ban_id=$(cibadmin --query | xmllint --xpath \'string(//rsc_location[@rsc=\\\"\'${v}\'\\\" and @node=\\\"\'${CLUSTER_NODE}\'\\\" and @score=\\\"-INFINITY\\\"]/@id)\' -)\\n    if [ -n \\\"$ban_id\\\" ]; then\\n        pcs constraint remove ${ban_id}\\n    else\\n        echo \\\"Could not retrieve and clear location constraint for VIP $v\\\" 2>&1\\n    fi\\ndone\\n\"}, {\"name\": \"Create firewall nat prerouting and postrouting\", \"delegate_to\": \"{{groups[\'neutron_api\'][2]}}\", \"when\": [\"groups[\'neutron_api\'] | default([]) | length > 2\"], \"shell\": \"set -o pipefail\\nLOCAL_BACKEND=$(grep {{groups[\'neutron_api\'][2]}} /var/lib/config-data/puppet-generated/haproxy/etc/haproxy/haproxy.cfg | \\\\\\n  grep \\\":9696 \\\" | awk \'{print $3}\')\\nIP=${LOCAL_BACKEND%:*}\\nif [[ $IP =~ .*:.* ]]\\n  then\\n       PROTOCOL=\\\"ip6\\\"\\n       # we need to temporarly allow ipv6 forwarding, this will get reset by deployment run\\n       sysctl -w net.ipv6.conf.all.forwarding=1\\n  else PROTOCOL=\\\"ip\\\"\\nfi\\nnft add table $PROTOCOL nat\\nnft -- add chain $PROTOCOL nat prerouting { type nat hook prerouting priority -100 \\\\; }\\nnft add chain $PROTOCOL nat postrouting { type nat hook postrouting priority 100 \\\\; }\\n\"}, {\"name\": \"Redirect neutron backend traffic for 60s to other host\", \"delegate_to\": \"{{groups[\'neutron_api\'][2]}}\", \"when\": [\"groups[\'neutron_api\'] | default([]) | length > 2\"], \"shell\": \"set -o pipefail\\nsource /etc/os-release; test  \\\"${VERSION_ID%*}\\\" = \\\"9.0\\\" && exit 0\\nLOCAL_BACKEND=$(grep {{groups[\'neutron_api\'][2]}} /var/lib/config-data/puppet-generated/haproxy/etc/haproxy/haproxy.cfg | \\\\\\n  grep \\\":9696 \\\" | awk \'{print $3}\')\\nREMOTE_BACKEND=$(grep \\\":9696 \\\" /var/lib/config-data/puppet-generated/haproxy/etc/haproxy/haproxy.cfg | \\\\\\n  grep server | grep -v {{groups[\'neutron_api\'][2]}} | head -n1 | awk \'{print $3}\')\\nIP=${LOCAL_BACKEND%:*}\\nPORT=9696\\nif [[ $IP =~ .*:.* ]]\\n  then PROTOCOL=\\\"ip6\\\"\\n  else PROTOCOL=\\\"ip\\\"\\nfi\\nREMOTE_IP=${REMOTE_BACKEND%:*}\\nnft add rule $PROTOCOL nat postrouting $PROTOCOL daddr $REMOTE_IP tcp dport 9696 counter meta time $(date +%s)-$(date -d\'+60 seconds\' +%s) masquerade comment neutron_api\\nnft add rule $PROTOCOL nat prerouting $PROTOCOL daddr $IP tcp dport 9696 counter meta time $(date +%s)-$(date -d\'+60 seconds\' +%s) dnat to $REMOTE_IP comment neutron_api\\n\"}, {\"name\": \"Insanity neutron update first\", \"delegate_to\": \"{{groups[\'neutron_api\'][2]}}\", \"become\": true, \"tripleo_container_manage\": {\"config_dir\": \"/var/lib/tripleo-config/container-startup-config/step_4\", \"config_id\": [\"neutron_api\"], \"config_patterns\": \"*neutron_api.json\", \"config_overrides\": {\".*neutron_api\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNeutronApiImage\"]}, \"name\": \"neutron_api\"}}}, \"when\": [\"groups[\'neutron_api\'] | default([]) | length > 2\"]}, {\"wait_for\": {\"timeout\": 50}, \"when\": [\"groups[\'neutron_api\'] | default([]) | length > 2\"]}, {\"name\": \"Delete redirect rules\", \"delegate_to\": \"{{groups[\'neutron_api\'][2]}}\", \"shell\": \"set -o pipefail\\nLOCAL_BACKEND=$(grep {{groups[\'neutron_api\'][2]}} /var/lib/config-data/puppet-generated/haproxy/etc/haproxy/haproxy.cfg | \\\\\\n  grep \\\":9696 \\\" | awk \'{print $3}\')\\nIP=${LOCAL_BACKEND%:*}\\nif [[ $IP =~ .*:.* ]]\\n  then PROTOCOL=\\\"ip6\\\"\\n  else PROTOCOL=\\\"ip\\\"\\nfi\\nnft -a list chain $PROTOCOL nat postrouting | grep neutron_api | awk -F# \'{print \\\"nat postrouting \\\"$2}\' | \\\\\\nwhile read i; do bash -c \\\"nft delete rule $PROTOCOL $i\\\"; done\\nnft -a list chain $PROTOCOL nat prerouting | grep neutron_api | awk -F# \'{print \\\"nat prerouting \\\"$2}\' | \\\\\\nwhile read i; do bash -c \\\"nft delete rule $PROTOCOL $i\\\"; done\\n\", \"when\": [\"groups[\'neutron_api\'] | default([]) | length > 2\"]}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(162,'2026-06-10 07:47:18',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mysql client settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role for setting mysql client parameters\", \"value\": {\"service_name\": \"mysql_client\", \"config_settings\": {\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"tripleo::profile::base::database::mysql::client::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}}, \"step_config\": \"include tripleo::profile::base::database::mysql::client\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(163,'2026-06-10 07:47:18',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Load kernel modules with kmod and configure kernel options with sysctl.\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"KernelPidMax\": {\"default\": 1048576, \"description\": \"Configures sysctl kernel.pid_max key\", \"type\": \"number\"}, \"KernelDisableIPv6\": {\"default\": 0, \"description\": \"Configures sysctl net.ipv6.{default/all}.disable_ipv6 keys\", \"type\": \"number\"}, \"KernelIpForward\": {\"default\": 1, \"description\": \"Configures net.ipv4.ip_forward key\", \"type\": \"number\"}, \"KernelIpv6ConfAllForwarding\": {\"default\": 0, \"description\": \"Configures the net.ipv6.conf.all.forwarding key\", \"type\": \"number\"}, \"KernelIpv4ConfAllRpFilter\": {\"default\": 1, \"description\": \"Configures the net.ipv4.conf.all.rp_filter key\", \"type\": \"number\"}, \"KernelIpNonLocalBind\": {\"default\": 1, \"description\": \"Configures net.ipv{4,6}.ip_nonlocal_bind key\", \"type\": \"number\"}, \"NeighbourGcThreshold1\": {\"default\": 1024, \"description\": \"Configures sysctl net.ipv4.neigh.default.gc_thresh1 value. This is the minimum number of entries to keep in the ARP cache. The garbage collector will not run if there are fewer than this number of entries in the cache.\", \"type\": \"number\"}, \"NeighbourGcThreshold2\": {\"default\": 2048, \"description\": \"Configures sysctl net.ipv4.neigh.default.gc_thresh2 value. This is the soft maximum number of entries to keep in the ARP cache. The garbage collector will  allow the number of entries to exceed this for 5 seconds before collection will be performed.\", \"type\": \"number\"}, \"NeighbourGcThreshold3\": {\"default\": 4096, \"description\": \"Configures sysctl net.ipv4.neigh.default.gc_thresh3 value. This is the hard maximum number of entries to keep in the ARP cache. The garbage collector will always run if there are more than this number of entries in the cache.\", \"type\": \"number\"}, \"InotifyInstancesMax\": {\"default\": 1024, \"description\": \"Configures sysctl fs.inotify.max_user_instances key\", \"type\": \"number\"}, \"BridgeNfCallArpTables\": {\"default\": 1, \"description\": \"Configures sysctl net.bridge.bridge-nf-call-arptables key\", \"type\": \"number\"}, \"BridgeNfCallIpTables\": {\"default\": 1, \"description\": \"Configures sysctl net.bridge.bridge-nf-call-iptables key\", \"type\": \"number\"}, \"BridgeNfCallIp6Tables\": {\"default\": 1, \"description\": \"Configures sysctl net.bridge.bridge-nf-call-ip6tables key\", \"type\": \"number\"}, \"ExtraKernelModules\": {\"default\": {}, \"description\": \"Hash of extra Kernel modules to load.\", \"type\": \"json\", \"tags\": [\"role_specific\"]}, \"ExtraKernelPackages\": {\"default\": {}, \"description\": \"List of extra kernel related packages to install.\", \"type\": \"json\", \"tags\": [\"role_specific\"]}, \"ExtraSysctlSettings\": {\"default\": {}, \"description\": \"Hash of extra sysctl settings to apply.\", \"type\": \"json\", \"tags\": [\"role_specific\"]}, \"FsAioMaxNumber\": {\"default\": 0, \"description\": \"The kernel allocates aio memory on demand, and this number limits the number of parallel aio requests; the only drawback of a larger limit is that a malicious guest could issue parallel requests to cause the kernel to set aside memory.  Set this number at least as large as\\n  128 * (number of virtual disks on the host)\\nLibvirt uses a default of 1M requests to allow 8k disks, with at most 64M of kernel memory if all disks hit an aio request at the same time.\\n\", \"type\": \"number\", \"tags\": [\"role_specific\"]}, \"InotifyIntancesMax\": {\"default\": 1024, \"description\": \"Configures sysctl fs.inotify.max_user_instances key\", \"type\": \"number\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"Do not use deprecated params, they will be removed.\", \"parameters\": [\"InotifyIntancesMax\"]}], \"conditions\": {\"ipv6_disabled\": {\"equals\": [{\"get_param\": \"KernelDisableIPv6\"}, 1]}, \"is_inotify_intances_max_default\": {\"equals\": [{\"get_param\": \"InotifyIntancesMax\"}, 1024]}, \"fs_aio_max_number_set\": {\"and\": [{\"not\": {\"equals\": [{\"get_param\": [\"RoleParameters\", \"FsAioMaxNumber\"]}, 0]}}, {\"not\": {\"equals\": [{\"get_param\": [\"RoleParameters\", \"FsAioMaxNumber\"]}, \"\"]}}]}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"extra_kernel_modules\": \"ExtraKernelModules\", \"extra_kernel_packages\": \"ExtraKernelPackages\", \"extra_sysctl_settings\": \"ExtraSysctlSettings\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ExtraKernelModules\": {\"get_param\": \"ExtraKernelModules\"}, \"ExtraKernelPackages\": {\"get_param\": \"ExtraKernelPackages\"}, \"ExtraSysctlSettings\": {\"get_param\": \"ExtraSysctlSettings\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Kernel modules\", \"value\": {\"service_name\": \"kernel\", \"host_prep_tasks\": [{\"include_role\": {\"name\": \"tripleo_kernel\"}}], \"ansible_group_vars\": {\"hieradata_localhost_address\": {\"if\": [\"ipv6_disabled\", \"127.0.0.1\", \"localhost\"]}, \"tripleo_kernel_extra_modules\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"extra_kernel_modules\"]}, \"tripleo_kernel_extra_packages\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"extra_kernel_packages\"]}, \"tripleo_kernel_sysctl_extra_settings\": {\"map_merge\": [{\"net.ipv6.conf.default.disable_ipv6\": {\"value\": {\"get_param\": \"KernelDisableIPv6\"}}, \"net.ipv4.ip_local_reserved_ports\": {\"value\": \"35357,49000-49001\"}, \"net.ipv6.conf.all.disable_ipv6\": {\"value\": {\"get_param\": \"KernelDisableIPv6\"}}, \"net.ipv6.conf.lo.disable_ipv6\": {\"value\": 0}, \"net.ipv4.ip_forward\": {\"value\": {\"get_param\": \"KernelIpForward\"}}, \"net.ipv4.conf.all.rp_filter\": {\"value\": {\"get_param\": \"KernelIpv4ConfAllRpFilter\"}}, \"net.ipv6.conf.all.forwarding\": {\"value\": {\"get_param\": \"KernelIpv6ConfAllForwarding\"}}, \"net.ipv4.ip_nonlocal_bind\": {\"value\": {\"get_param\": \"KernelIpNonLocalBind\"}}, \"net.ipv6.ip_nonlocal_bind\": {\"value\": {\"get_param\": \"KernelIpNonLocalBind\"}}, \"kernel.pid_max\": {\"value\": {\"get_param\": \"KernelPidMax\"}}, \"net.ipv4.neigh.default.gc_thresh1\": {\"value\": {\"get_param\": \"NeighbourGcThreshold1\"}}, \"net.ipv4.neigh.default.gc_thresh2\": {\"value\": {\"get_param\": \"NeighbourGcThreshold2\"}}, \"net.ipv4.neigh.default.gc_thresh3\": {\"value\": {\"get_param\": \"NeighbourGcThreshold3\"}}, \"net.bridge.bridge-nf-call-arptables\": {\"value\": {\"get_param\": \"BridgeNfCallArpTables\"}}, \"net.bridge.bridge-nf-call-iptables\": {\"value\": {\"get_param\": \"BridgeNfCallIpTables\"}}, \"net.bridge.bridge-nf-call-ip6tables\": {\"value\": {\"get_param\": \"BridgeNfCallIp6Tables\"}}, \"fs.inotify.max_user_instances\": {\"value\": {\"if\": [\"is_inotify_intances_max_default\", {\"get_param\": \"InotifyInstancesMax\"}, {\"get_param\": \"InotifyIntancesMax\"}]}}}, {\"if\": [\"fs_aio_max_number_set\", {\"fs.aio-max-nr\": {\"value\": {\"get_param\": [\"RoleParameters\", \"FsAioMaxNumber\"]}}}]}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"extra_sysctl_settings\"]}]}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(164,'2026-06-10 07:47:18',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Qpid dispatch router service for metrics and monitoring purposes\\n\", \"parameters\": {\"ContainerMetricsQdrImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\"}, \"ContainerMetricsQdrConfigImage\": {\"description\": \"The container image to use for the qdrouterd config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"MonitoringSubscriptionQdr\": {\"default\": \"overcloud-qdr\", \"type\": \"string\"}, \"MetricsQdrLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.nova.consoleauth\", \"file\": \"/var/log/containers/metrics_qdr/metrics_qdr.log\", \"startmsg.regex\": \"^[0-9]{4}-[0-9]{2}-[0-9]{2} [0-9]{2}:[0-9]{2}:[0-9]{2}(.[0-9]+ \\\\\\\\+[0-9]+)? [A-Z]+ \\\\\\\\([a-z]+\\\\\\\\) \"}}, \"MetricsQdrPort\": {\"default\": 5666, \"description\": \"Service name or port number on which the qdrouterd will accept connections.\", \"type\": \"number\"}, \"MetricsQdrUsername\": {\"default\": \"guest\", \"description\": \"Username which should be used to authenticate to the deployed qdrouterd.\", \"type\": \"string\"}, \"MetricsQdrPassword\": {\"default\": \"guest\", \"description\": \"Password which should be used to authenticate to the deployed qdrouterd.\", \"type\": \"string\", \"hidden\": true}, \"MetricsQdrConnectors\": {\"default\": [], \"description\": \"Connectors configuration (array of hashes).\", \"type\": \"json\"}, \"MetricsQdrSSLProfiles\": {\"default\": [{\"name\": \"sslProfile\"}], \"description\": \"SSL Profiles for the connectors (array of hashes).\", \"type\": \"json\"}, \"MetricsQdrAddresses\": {\"default\": [{\"prefix\": \"collectd\", \"distribution\": \"multicast\"}, {\"prefix\": \"ceilometer/metering.sample\", \"distribution\": \"multicast\"}, {\"prefix\": \"ceilometer/event.sample\", \"distribution\": \"multicast\"}], \"description\": \"Addresses configuration (array of hashes).\", \"type\": \"json\"}, \"MetricsQdrAutoLinks\": {\"default\": [], \"description\": \"AutoLinks for the Configured Addresses\", \"type\": \"json\"}, \"MetricsQdrUseSSL\": {\"default\": false, \"description\": \"Set to true if it is required to use SSL or TLS on the connection for the local listener. !WARNING! Currently breaks connections from collectd and ceilometer.\", \"type\": \"boolean\"}, \"MetricsQdrUseEncryption\": {\"default\": false, \"description\": \"Set to true if it is required to encrypt connection to the peer for listener. Not currently implemented, use EnableInternalTLS instead. This option can be ignored.\", \"type\": \"boolean\"}, \"MetricsQdrSaslMechanisms\": {\"default\": \"ANONYMOUS\", \"description\": \"List of accepted SASL auth mechanisms for listener in format of comma separated list.\", \"type\": \"string\"}, \"MetricsQdrSslCertDb\": {\"default\": \"/etc/ipa/ca.crt\", \"description\": \"Path to SSL certificate db for listener.\", \"type\": \"string\"}, \"MetricsQdrSslCertFile\": {\"default\": \"/etc/pki/tls/certs/metrics_qdr.crt\", \"description\": \"Path to SSL certificate file for listener.\", \"type\": \"string\"}, \"MetricsQdrSslKeyFile\": {\"default\": \"/etc/pki/tls/private/metrics_qdr.key\", \"description\": \"Path to SSL private key file for listener.\", \"type\": \"string\"}, \"MetricsQdrSslPwFile\": {\"default\": \"\", \"description\": \"Path to SSL password file for certificate key for listener.\", \"type\": \"string\"}, \"MetricsQdrSslPassword\": {\"default\": \"\", \"description\": \"SSL password to be supplied for listener.\", \"type\": \"string\"}, \"MetricsQdrTrustedCerts\": {\"default\": \"\", \"description\": \"Path to file containing trusted certificates for listener.\", \"type\": \"string\"}, \"MetricsQdrAuthenticateClient\": {\"default\": false, \"description\": \"Authenticate the client using SSL/TLS\", \"type\": \"boolean\"}, \"MetricsQdrExternalEndpoint\": {\"default\": false, \"description\": \"Whether QDR should listen on external network interface. To enable listening on external network one must deploy QDRs in mesh mode.\", \"type\": \"boolean\"}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"EnableSTF\": {\"default\": false, \"description\": \"Set to true to enable configuration for STF client.\", \"type\": \"boolean\"}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"QdrCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"listener_ssl_enabled\": {\"equals\": [{\"get_param\": \"MetricsQdrUseSSL\"}, true]}, \"enable_stf\": {\"equals\": [{\"get_param\": \"EnableSTF\"}, true]}, \"key_size_override_unset\": {\"equals\": [{\"get_param\": \"QdrCertificateKeySize\"}, \"\"]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerMetricsQdrImage\": \"ContainerMetricsQdrImage\", \"ContainerMetricsQdrConfigImage\": \"ContainerMetricsQdrConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerMetricsQdrImage\": {\"get_param\": \"ContainerMetricsQdrImage\"}, \"ContainerMetricsQdrConfigImage\": {\"get_param\": \"ContainerMetricsQdrConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the metrics Qdr role.\", \"value\": {\"service_name\": \"metrics_qdr\", \"firewall_rules\": {\"map_merge\": [{\"109 metrics qdr\": {\"dport\": [{\"get_param\": \"MetricsQdrPort\"}]}}, {\"map_merge\": {\"repeat\": {\"for_each\": {\"<%net_cidr%>\": {\"get_param\": [\"ServiceData\", \"net_cidr_map\", \"ctlplane\"]}}, \"template\": {\"109 accept internal metrics qdr ctlplane subnet <%net_cidr%>\": {\"dport\": [5667, 5668]}}}}}]}, \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionQdr\"}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_metrics_qdr\": [{\"get_param\": \"MetricsQdrLoggingSource\"}]}}, \"config_settings\": {\"map_merge\": [{\"tripleo::profile::base::metrics::qdr::listener_addr\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", {\"str_replace\": {\"template\": \"ROLENAMEMetricsQdrNetwork\", \"params\": {\"ROLENAME\": {\"get_param\": \"RoleName\"}}}}]}}}}, \"tripleo::haproxy::metrics_qdr\": {\"get_param\": \"MetricsQdrExternalEndpoint\"}, \"tripleo::profile::base::metrics::qdr::listener_port\": {\"get_param\": \"MetricsQdrPort\"}, \"tripleo::profile::base::metrics::qdr::username\": {\"get_param\": \"MetricsQdrUsername\"}, \"tripleo::profile::base::metrics::qdr::password\": {\"get_param\": \"MetricsQdrPassword\"}, \"tripleo::profile::base::metrics::qdr::connectors\": {\"get_param\": \"MetricsQdrConnectors\"}, \"tripleo::profile::base::metrics::qdr::addresses\": {\"get_param\": \"MetricsQdrAddresses\"}, \"tripleo::profile::base::metrics::qdr::autolink_addresses\": {\"get_param\": \"MetricsQdrAutoLinks\"}, \"tripleo::profile::base::metrics::qdr::listener_require_ssl\": {\"if\": [\"listener_ssl_enabled\", true, false]}, \"tripleo::profile::base::metrics::qdr::listener_require_encrypt\": {\"get_param\": \"MetricsQdrUseEncryption\"}, \"tripleo::profile::base::metrics::qdr::listener_sasl_mech\": {\"get_param\": \"MetricsQdrSaslMechanisms\"}, \"tripleo::profile::base::metrics::qdr::listener_ssl_cert_db\": {\"get_param\": \"MetricsQdrSslCertDb\"}, \"tripleo::profile::base::metrics::qdr::listener_ssl_cert_file\": {\"get_param\": \"MetricsQdrSslCertFile\"}, \"tripleo::profile::base::metrics::qdr::listener_ssl_key_file\": {\"get_param\": \"MetricsQdrSslKeyFile\"}, \"tripleo::profile::base::metrics::qdr::listener_ssl_pw_file\": {\"get_param\": \"MetricsQdrSslPwFile\"}, \"tripleo::profile::base::metrics::qdr::listener_ssl_password\": {\"get_param\": \"MetricsQdrSslPassword\"}, \"tripleo::profile::base::metrics::qdr::listener_trusted_certs\": {\"get_param\": \"MetricsQdrTrustedCerts\"}, \"qdr::log_enable\": \"info+\", \"qdr::log_output\": \"/var/log/qdrouterd/metrics_qdr.log\", \"qdr::listener_auth_peer\": {\"get_param\": \"MetricsQdrAuthenticateClient\"}}, {\"if\": [\"internal_tls_enabled\", {\"tripleo::profile::base::metrics::qdr::ssl_profiles\": {\"list_concat\": [{\"get_param\": \"MetricsQdrSSLProfiles\"}, [{\"name\": \"tlsProfile\", \"certFile\": \"/etc/pki/tls/certs/metrics_qdr.crt\", \"keyFile\": \"/etc/pki/tls/private/metrics_qdr.key\", \"caCertFile\": {\"get_param\": \"InternalTLSCAFile\"}}]]}}, {\"tripleo::profile::base::metrics::qdr::ssl_profiles\": {\"get_param\": \"MetricsQdrSSLProfiles\"}}]}, {\"if\": [\"enable_stf\", {\"tripleo::profile::base::metrics::qdr::interior_mesh_nodes\": \"\", \"tripleo::profile::base::metrics::qdr::router_mode\": \"edge\"}, null]}]}, \"metadata_settings\": {\"if\": [\"internal_tls_enabled\", [{\"service\": \"metrics_qdr\", \"network\": {\"get_param\": [\"ServiceNetMap\", {\"str_replace\": {\"template\": \"ROLENAMEMetricsQdrNetwork\", \"params\": {\"ROLENAME\": {\"get_param\": \"RoleName\"}}}}]}, \"type\": \"node\"}], null]}, \"puppet_config\": {\"config_volume\": \"metrics_qdr\", \"step_config\": \"include tripleo::profile::base::metrics::qdr\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMetricsQdrConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/metrics_qdr.json\": {\"command\": \"/usr/sbin/qdrouterd -c /etc/qpid-dispatch/qdrouterd.conf\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true, \"optional\": true}], \"permissions\": [{\"path\": \"/var/lib/qdrouterd\", \"owner\": \"qdrouterd:qdrouterd\", \"recurse\": true}, {\"path\": \"/etc/pki/tls/certs/metrics_qdr.crt\", \"owner\": \"qdrouterd:qdrouterd\", \"optional\": true}, {\"path\": \"/etc/pki/tls/private/metrics_qdr.key\", \"owner\": \"qdrouterd:qdrouterd\", \"optional\": true}]}}, \"docker_config\": {\"step_1\": {\"metrics_qdr_init_logs\": {\"start_order\": 0, \"detach\": false, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMetricsQdrImage\"]}, \"net\": \"none\", \"privileged\": false, \"user\": \"root\", \"volumes\": [\"/var/log/containers/metrics_qdr:/var/log/qdrouterd:z\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R qdrouterd:qdrouterd /var/log/qdrouterd\"]}, \"metrics_qdr\": {\"start_order\": 1, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMetricsQdrImage\"]}, \"net\": \"host\", \"user\": \"qdrouterd\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/metrics_qdr.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/metrics_qdr:/var/lib/kolla/config_files/src:ro\", \"/var/lib/metrics_qdr:/var/lib/qdrouterd:z\", \"/var/log/containers/metrics_qdr:/var/log/qdrouterd:z\"], {\"if\": [\"internal_tls_enabled\", [\"/etc/pki/tls/certs/metrics_qdr.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/metrics_qdr.crt:ro\", \"/etc/pki/tls/private/metrics_qdr.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/metrics_qdr.key:ro\"], null]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"deploy_steps_tasks\": [{\"name\": \"Certificate generation\", \"when\": [\"step|int == 1\", \"enable_internal_tls\"], \"block\": [{\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": [{\"name\": \"metrics_qdr\", \"dns\": {\"str_replace\": {\"template\": \"{{fqdn_NETWORK}}\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", {\"str_replace\": {\"template\": \"ROLENAMEMetricsQdrNetwork\", \"params\": {\"ROLENAME\": {\"get_param\": \"RoleName\"}}}}]}}}}, \"principal\": {\"str_replace\": {\"template\": \"metrics_qdr/{{fqdn_NETWORK}}@{{idm_realm}}\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", {\"str_replace\": {\"template\": \"ROLENAMEMetricsQdrNetwork\", \"params\": {\"ROLENAME\": {\"get_param\": \"RoleName\"}}}}]}}}}, \"run_after\": \"container_name=$({{container_cli}} ps --format=\\\\{\\\\{.Names\\\\}\\\\} | grep metrics_qdr)\\nservice_crt=\\\"/etc/pki/tls/certs/metrics_qdr.crt\\\"\\nservice_key=\\\"/etc/pki/tls/private/metrics_qdr.key\\n# Copy the new cert from the mount-point to the real path\\n{{container_cli}} exec \\\"$container_name\\\" cp \\\"/var/lib/kolla/config_files/src-tls$service_crt\\\" \\\"$service_crt\\\"\\n# Copy the new key from the mount-point to the real path\\n{{container_cli}} exec \\\"$container_name\\\" cp \\\"/var/lib/kolla/config_files/src-tls$service_key\\\" \\\"$service_key\\\"\\n# Set appropriate permissions\\n{{container_cli}} exec \\\"$container_name\\\" chown qdrouterd:qdrouterd \\\"$service_crt\\\"\\n{{container_cli}} exec \\\"$container_name\\\" chown qdrouterd:qdrouterd \\\"$service_key\\\"\\n# Trigger a container restart to read the new certificate\\n{{container_cli}} restart \\\"$container_name\\\"\\n\", \"key_size\": {\"if\": [\"key_size_override_unset\", {\"get_param\": \"CertificateKeySize\"}, {\"get_param\": \"QdrCertificateKeySize\"}]}, \"ca\": \"ipa\"}]}}]}], \"host_prep_tasks\": [{\"name\": \"create persistent logs directory\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/metrics_qdr\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/metrics_qdr\", \"setype\": \"container_file_t\"}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (165,'2026-06-10 07:47:19',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(166,'2026-06-10 07:47:19',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Neutron base service. Shared for all Neutron agents.\\n\", \"parameters\": {\"DatabaseSyncTimeout\": {\"default\": 900, \"description\": \"DB Sync Timeout default\", \"type\": \"number\"}, \"NeutronDhcpAgentsPerNetwork\": {\"type\": \"number\", \"default\": 0, \"description\": \"The number of neutron dhcp agents to schedule per network\"}, \"DhcpAgentNotification\": {\"default\": false, \"description\": \"Whether or not to enable DHCP agent notifications.\", \"type\": \"boolean\"}, \"NeutronDnsDomain\": {\"type\": \"string\", \"default\": \"openstacklocal\", \"description\": \"Domain to use for building the hostnames.\"}, \"NeutronCorePlugin\": {\"default\": \"ml2\", \"description\": \"The core plugin for Neutron. The value should be the entrypoint to be loaded\\nfrom neutron.core_plugins namespace.\\n\", \"type\": \"string\"}, \"NeutronServicePlugins\": {\"default\": \"qos,ovn-router,trunk,segments,port_forwarding,log\", \"description\": \"Comma-separated list of service plugin entrypoints to be loaded from the\\nneutron.service_plugins namespace.\\n\", \"type\": \"comma_delimited_list\"}, \"Debug\": {\"type\": \"boolean\", \"default\": true, \"description\": \"Set to True to enable debugging on all services.\"}, \"NeutronDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Neutron services.\", \"type\": \"boolean\"}, \"EnableConfigPurge\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Remove configuration that is not generated by TripleO. Used to avoid configuration remnants after upgrades.\\n\"}, \"NeutronGlobalPhysnetMtu\": {\"type\": \"number\", \"default\": 1350, \"description\": \"MTU of the underlying physical network. Neutron uses this value to\\ncalculate MTU for all virtual network components. For flat and VLAN\\nnetworks, neutron uses this value without modification. For overlay\\nnetworks such as VXLAN, neutron automatically subtracts the overlay\\nprotocol overhead from this value.\\n(If this is not changed TenantNetPhysnetMtu will be used.)\\n\"}, \"TenantNetPhysnetMtu\": {\"type\": \"number\", \"default\": 1500, \"description\": \"MTU of the underlying physical network. Neutron uses this value to\\ncalculate MTU for all virtual network components. For flat and VLAN\\nnetworks, neutron uses this value without modification. For overlay\\nnetworks such as VXLAN, neutron automatically subtracts the overlay\\nprotocol overhead from this value.\\n(The mtu setting of the Tenant network in network_data.yaml\\ncontrol\'s this parameter.)\\n\"}, \"NeutronDBSyncExtraParams\": {\"default\": \"\", \"description\": \"String of extra command line parameters to append to the neutron-db-manage\\nupgrade head command.\\n\", \"type\": \"string\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"noop\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"EnableVLANTransparency\": {\"default\": false, \"description\": \"If True, then allow plugins that support it to create VLAN transparent networks.\\n\", \"type\": \"boolean\"}, \"NeutronGlobalReportInterval\": {\"default\": 300, \"description\": \"Seconds between nodes reporting state to server; should be less than NeutronAgentDownTime, best if it is half or less than NeutronAgentDownTime.\\n\", \"type\": \"number\"}}, \"conditions\": {\"dhcp_agents_zero\": {\"equals\": [{\"get_param\": \"NeutronDhcpAgentsPerNetwork\"}, 0]}, \"global_physnet_mtu_unset\": {\"equals\": [{\"get_param\": \"NeutronGlobalPhysnetMtu\"}, 0]}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Neutron base service.\", \"value\": {\"service_name\": \"neutron_base\", \"config_settings\": {\"map_merge\": [{\"neutron::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"neutron::core_plugin\": {\"get_param\": \"NeutronCorePlugin\"}, \"neutron::service_plugins\": {\"get_param\": \"NeutronServicePlugins\"}, \"neutron::report_interval\": {\"get_param\": \"NeutronGlobalReportInterval\"}, \"neutron::logging::debug\": {\"if\": [{\"get_param\": \"NeutronDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"neutron::purge_config\": {\"get_param\": \"EnableConfigPurge\"}, \"neutron::allow_overlapping_ips\": true, \"neutron::dhcp_agent_notification\": {\"get_param\": \"DhcpAgentNotification\"}, \"neutron::dns_domain\": {\"get_param\": \"NeutronDnsDomain\"}, \"neutron::rabbit_heartbeat_timeout_threshold\": 60, \"neutron::host\": \"%{hiera(\'fqdn_canonical\')}\", \"neutron::db::database_db_max_retries\": -1, \"neutron::db::database_max_retries\": -1, \"neutron::db::sync::db_sync_timeout\": {\"get_param\": \"DatabaseSyncTimeout\"}, \"neutron::global_physnet_mtu\": {\"if\": [\"global_physnet_mtu_unset\", {\"get_param\": \"TenantNetPhysnetMtu\"}, {\"get_param\": \"NeutronGlobalPhysnetMtu\"}]}, \"neutron::db::sync::extra_params\": {\"get_param\": \"NeutronDBSyncExtraParams\"}, \"neutron::vlan_transparent\": {\"get_param\": \"EnableVLANTransparency\"}, \"neutron::rabbit_heartbeat_in_pthread\": false}, {\"if\": [\"dhcp_agents_zero\", {}, {\"tripleo::profile::base::neutron::dhcp_agents_per_network\": {\"get_param\": \"NeutronDhcpAgentsPerNetwork\"}}]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(167,'2026-06-10 07:47:19',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Manila Scheduler service\\n\", \"parameters\": {\"ContainerManilaSchedulerImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\"}, \"ContainerManilaConfigImage\": {\"description\": \"The container image to use for the manila config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"MonitoringSubscriptionManilaScheduler\": {\"default\": \"overcloud-manila-scheduler\", \"type\": \"string\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MySQLClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\"}, \"ManilaBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-base.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerManilaSchedulerImage\": \"ContainerManilaSchedulerImage\", \"ContainerManilaConfigImage\": \"ContainerManilaConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerManilaSchedulerImage\": {\"get_param\": \"ContainerManilaSchedulerImage\"}, \"ContainerManilaConfigImage\": {\"get_param\": \"ContainerManilaConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Manila Scheduler role.\", \"value\": {\"service_name\": \"manila_scheduler\", \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionManilaScheduler\"}, \"config_settings\": {\"get_attr\": [\"ManilaBase\", \"role_data\", \"config_settings\"]}, \"service_config_settings\": {\"get_attr\": [\"ManilaBase\", \"role_data\", \"service_config_settings\"]}, \"puppet_config\": {\"config_volume\": \"manila\", \"puppet_tags\": \"manila_config,manila_scheduler_paste_ini\", \"step_config\": {\"list_join\": [\"\\n\", [\"include tripleo::profile::base::manila::scheduler\", {\"get_attr\": [\"MySQLClient\", \"role_data\", \"step_config\"]}]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerManilaConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/manila_scheduler.json\": {\"command\": \"/usr/bin/manila-scheduler --config-file /usr/share/manila/manila-dist.conf --config-file /etc/manila/manila.conf\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/manila\", \"owner\": \"manila:manila\", \"recurse\": true}]}}, \"docker_config\": {\"step_4\": {\"manila_scheduler\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerManilaSchedulerImage\"]}, \"net\": \"host\", \"restart\": \"always\", \"healthcheck\": {\"get_attr\": [\"ContainersCommon\", \"healthcheck_rpc_port\"]}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/manila_scheduler.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/manila:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/manila:/var/log/manila:z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"host_prep_tasks\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/manila\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}, {\"name\": \"enable virt_sandbox_use_netlink for healthcheck\", \"seboolean\": {\"name\": \"virt_sandbox_use_netlink\", \"persistent\": true, \"state\": true}, \"when\": [\"ansible_facts.selinux is defined\", \"ansible_facts.selinux.status == \\\"enabled\\\"\"]}], \"upgrade_tasks\": [], \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop manila scheduler container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"manila_scheduler\"], \"tripleo_delegate_to\": \"{{ groups[\'manila_scheduler\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(168,'2026-06-10 07:47:19',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Keystone service\\n\", \"parameters\": {\"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ContainerKeystoneImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\"}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerKeystoneImage\": \"ContainerKeystoneImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerKeystoneImage\": {\"get_param\": \"ContainerKeystoneImage\"}}}]}}}}, \"outputs\": {\"config_settings\": {\"description\": \"Extra hieradata needed to log to files in the host.\", \"value\": null}, \"volumes\": {\"description\": \"The volumes needed to log to files in the host.\", \"value\": [\"/var/log/containers/keystone:/var/log/keystone:z\", \"/var/log/containers/httpd/keystone:/var/log/httpd:z\"]}, \"docker_config\": {\"description\": \"Extra containers needed for logging to files in the host.\", \"value\": {\"step_2\": {\"keystone_init_log\": {\"start_order\": 1, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerKeystoneImage\"]}, \"net\": \"none\", \"user\": \"root\", \"command\": [\"/bin/bash\", \"-c\", \"chown -R keystone:keystone /var/log/keystone\"], \"volumes\": [\"/var/log/containers/keystone:/var/log/keystone:z\", \"/var/log/containers/httpd/keystone:/var/log/httpd:z\"]}}}}, \"environment\": {\"description\": \"Extra environment variables needed for the service to log to files.\", \"value\": null}, \"host_prep_tasks\": {\"description\": \"Extra ansible tasks needed for logging to files in the host.\", \"value\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/keystone\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/log/containers/httpd/keystone\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}]}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(169,'2026-06-10 07:47:20',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Openstack Manila base service. Shared by manila-api/scheduler/share services\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ManilaIPv6\": {\"default\": false, \"description\": \"Set to True to enable IPv6 access in manila.\", \"type\": \"boolean\"}, \"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"ManilaDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Manila services.\", \"type\": \"boolean\"}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}, \"ManilaPassword\": {\"description\": \"The password for the manila service account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"KqSyIJe4bogoBLLwnLhZJDRFk\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"noop\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"ManilaStorageAvailabilityZone\": {\"default\": \"nova\", \"description\": \"The Manila service\'s storage availability zone.\", \"type\": \"string\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Manila Base service.\", \"value\": {\"service_name\": \"manila_base\", \"config_settings\": {\"manila::storage_availability_zone\": {\"get_param\": \"ManilaStorageAvailabilityZone\"}, \"manila::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"manila::logging::debug\": {\"if\": [{\"get_param\": \"ManilaDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"manila::db::database_db_max_retries\": -1, \"manila::db::database_max_retries\": -1, \"manila::sql_connection\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"protocol\"]}, \"username\": \"manila\", \"password\": {\"get_param\": \"ManilaPassword\"}, \"host\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"host\"]}, \"path\": \"/manila\", \"query\": {\"if\": [{\"get_param\": \"EnableSQLAlchemyCollectd\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\", \"plugin\": \"collectd\", \"collectd_program_name\": \"manila\", \"collectd_host\": \"localhost\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\"}]}}}, \"manila::network::neutron::network_plugin_ipv6_enabled\": {\"get_param\": \"ManilaIPv6\"}, \"manila::network::neutron::network_plugin_ipv4_enabled\": {\"if\": [{\"get_param\": \"ManilaIPv6\"}, false, true]}, \"manila::rabbit_heartbeat_in_pthread\": false}, \"service_config_settings\": {\"mysql\": {\"manila::db::mysql::password\": {\"get_param\": \"ManilaPassword\"}, \"manila::db::mysql::user\": \"manila\", \"manila::db::mysql::host\": \"%\", \"manila::db::mysql::dbname\": \"manila\"}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(170,'2026-06-10 07:47:21',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mysql client settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role for setting mysql client parameters\", \"value\": {\"service_name\": \"mysql_client\", \"config_settings\": {\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"tripleo::profile::base::database::mysql::client::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}}, \"step_config\": \"include tripleo::profile::base::database::mysql::client\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(171,'2026-06-10 07:47:21',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Neutron ML2 Plugin configured with Puppet\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"ContainerNeutronConfigImage\": {\"description\": \"The container image to use for the neutron config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"NeutronPluginMl2PuppetTags\": {\"default\": \"neutron_plugin_ml2\", \"description\": \"Puppet resource tag names that are used to generate config files with puppet\", \"type\": \"string\"}}, \"resources\": {\"NeutronBase\": {\"type\": \"OS::TripleO::Services::NeutronMl2PluginBase\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerNeutronConfigImage\": \"ContainerNeutronConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerNeutronConfigImage\": {\"get_param\": \"ContainerNeutronConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Neutron ML2 Plugin role.\", \"value\": {\"service_name\": {\"get_attr\": [\"NeutronBase\", \"role_data\", \"service_name\"]}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"NeutronBase\", \"role_data\", \"config_settings\"]}]}, \"service_config_settings\": {\"get_attr\": [\"NeutronBase\", \"role_data\", \"service_config_settings\"]}, \"metadata_settings\": {\"get_attr\": [\"NeutronBase\", \"role_data\", \"metadata_settings\"]}, \"puppet_config\": {\"config_volume\": \"neutron\", \"puppet_tags\": {\"get_param\": \"NeutronPluginMl2PuppetTags\"}, \"step_config\": {\"get_attr\": [\"NeutronBase\", \"role_data\", \"step_config\"]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNeutronConfigImage\"]}}, \"kolla_config\": {}, \"docker_config\": {}, \"host_prep_tasks\": []}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(172,'2026-06-10 07:47:22',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(173,'2026-06-10 07:47:22',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Manila Share service\\n\", \"parameters\": {\"ContainerManilaShareImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\"}, \"ContainerManilaConfigImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\"}, \"ClusterCommonTag\": {\"default\": false, \"description\": \"When set to false, a pacemaker service is configured to use a floating tag for its container image name, e.g. \'REGISTRY/NAMESPACE/IMAGENAME:pcmklatest\'. When set to true, the service uses a floating prefix as well, e.g. \'cluster.common.tag/IMAGENAME:pcmklatest\'.\", \"type\": \"boolean\"}, \"ClusterFullTag\": {\"default\": true, \"description\": \"When set to true, the pacemaker service uses a fully constant tag for its container image name, e.g. \'cluster.common.tag/SERVICENAME:pcmklatest\'.\", \"type\": \"boolean\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ConfigDebug\": {\"default\": false, \"description\": \"Whether to run config management (e.g. Puppet) in debug mode.\", \"type\": \"boolean\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}, \"DeployIdentifier\": {\"default\": 1781077560, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}, \"CephConfigPath\": {\"type\": \"string\", \"default\": \"/var/lib/tripleo-config/ceph\", \"description\": \"The path where the Ceph Cluster config files are stored on the host.\\n\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MySQLClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\"}, \"ManilaShareContainerBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-container-puppet.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"ManilaCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-common.yaml\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerManilaShareImage\": \"ContainerManilaShareImage\", \"ContainerManilaConfigImage\": \"ContainerManilaConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerManilaShareImage\": {\"get_param\": \"ContainerManilaShareImage\"}, \"ContainerManilaConfigImage\": {\"get_param\": \"ContainerManilaConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Manila Share role.\", \"value\": {\"service_name\": \"manila_share\", \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"ManilaShareContainerBase\", \"role_data\", \"config_settings\"]}, {\"tripleo::profile::pacemaker::manila::share_bundle::manila_share_docker_image\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/manila-share:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerManilaShareImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerManilaShareImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"tripleo::profile::pacemaker::manila::share_bundle::docker_volumes\": {\"get_attr\": [\"ManilaCommon\", \"manila_share_volumes\"]}, \"tripleo::profile::pacemaker::manila::share_bundle::docker_environment\": {\"get_attr\": [\"ManilaCommon\", \"manila_share_environment\"]}, \"tripleo::profile::pacemaker::manila::share_bundle::container_backend\": {\"get_param\": \"ContainerCli\"}, \"tripleo::profile::pacemaker::manila::share_bundle::ceph_conf_path\": {\"get_param\": \"CephConfigPath\"}, \"manila::share::manage_service\": false, \"manila::share::enabled\": false, \"manila::host\": \"hostgroup\"}]}, \"service_config_settings\": {\"get_attr\": [\"ManilaShareContainerBase\", \"role_data\", \"service_config_settings\"]}, \"puppet_config\": {\"config_volume\": \"manila\", \"puppet_tags\": \"manila_config,file,concat,file_line\", \"step_config\": {\"list_join\": [\"\\n\", [\"include tripleo::profile::pacemaker::manila::share_bundle\", {\"get_attr\": [\"MySQLClient\", \"role_data\", \"step_config\"]}]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerManilaConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/manila_share.json\": {\"command\": \"/usr/bin/manila-share --config-file /usr/share/manila/manila-dist.conf --config-file /etc/manila/manila.conf\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-ceph/\", \"dest\": \"/etc/ceph/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/manila\", \"owner\": \"manila:manila\", \"recurse\": true}]}}, \"container_config_scripts\": {\"get_attr\": [\"ContainersCommon\", \"container_config_scripts\"]}, \"docker_config\": {\"step_3\": {\"manila_share_init_logs\": {\"start_order\": 0, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerManilaShareImage\"]}, \"net\": \"none\", \"privileged\": false, \"user\": \"root\", \"volumes\": [\"/var/log/containers/manila:/var/log/manila:z\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R manila:manila /var/log/manila\"]}}}, \"host_prep_tasks\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/manila\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/manila\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], \"deploy_steps_tasks\": [{\"name\": \"Manila Share tag container image for pacemaker\", \"when\": \"step|int == 1\", \"import_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerManilaShareImage\"]}, \"container_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/manila-share:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerManilaShareImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerManilaShareImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}}}, {\"name\": \"Manila-Share HA Wrappers Step\", \"when\": \"step|int == 5\", \"block\": [{\"name\": \"Manila-Share puppet bundle\", \"import_role\": {\"name\": \"tripleo_ha_wrapper\"}, \"vars\": {\"tripleo_ha_wrapper_service_name\": \"manila_share\", \"tripleo_ha_wrapper_resource_name\": \"openstack-manila-share\", \"tripleo_ha_wrapper_bundle_name\": \"openstack-manila-share\", \"tripleo_ha_wrapper_resource_state\": \"_ Started\", \"tripleo_ha_wrapper_puppet_config_volume\": \"manila\", \"tripleo_ha_wrapper_puppet_execute\": \"include ::tripleo::profile::base::pacemaker; include ::tripleo::profile::pacemaker::manila::share_bundle\", \"tripleo_ha_wrapper_puppet_tags\": \"pacemaker::resource::bundle,pacemaker::property,pacemaker::resource::ip,pacemaker::resource::ocf,pacemaker::constraint::order,pacemaker::constraint::colocation\", \"tripleo_ha_wrapper_puppet_debug\": {\"get_param\": \"ConfigDebug\"}, \"tripleo_ha_wrapper_config_suffix\": \".previous_run\"}}]}], \"external_update_tasks\": [{\"when\": \"step|int == 1\", \"tags\": \"ha_image_update\", \"block\": [{\"block\": [{\"name\": \"Get manila_share image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_manila_share_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'openstack-manila-share\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container manila_share image\", \"set_fact\": {\"manila_share_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerManilaShareImage\"]}, \"manila_share_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/manila-share:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerManilaShareImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerManilaShareImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"pcmk_manila_share_image\": \"{{xmllint_pcmk_manila_share_image.stdout}}\"}}], \"delegate_to\": \"{{ (groups[\\\"manila_share\\\"] | difference(groups[\\\"excluded_overcloud\\\"]))[0] }}\"}, {\"name\": \"manila-share temporary pacemaker container tag in case of image switch\", \"become\": true, \"import_role\": {\"name\": \"tripleo_ha_image_update\"}, \"vars\": {\"tripleo_ha_image_update_node_names\": \"{{ groups[\\\"manila_share\\\"] | difference(groups[\\\"excluded_overcloud\\\"]) }}\", \"tripleo_ha_image_update_bundle\": \"openstack-manila-share\", \"tripleo_ha_image_update_new_image\": \"{{manila_share_image_latest}}\", \"tripleo_ha_image_update_old_image\": \"{{pcmk_manila_share_image}}\"}, \"when\": [\"(pcmk_manila_share_image != \\\"\\\")\", \"(pcmk_manila_share_image != manila_share_image_latest)\"]}]}], \"update_tasks\": [{\"block\": [{\"name\": \"Get manila_share image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_manila_share_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'openstack-manila-share\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container manila_share image\", \"set_fact\": {\"manila_share_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerManilaShareImage\"]}, \"manila_share_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/manila-share:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerManilaShareImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerManilaShareImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"pcmk_manila_share_image\": \"{{xmllint_pcmk_manila_share_image.stdout}}\"}}], \"when\": \"(step|int == 0 or step|int == 2)\"}, {\"name\": \"Check for update of manila-share container image name\", \"when\": \"step|int == 0\", \"assert\": {\"that\": \"pcmk_manila_share_image == manila_share_image_latest\", \"fail_msg\": \"manila-share image change detected, run overcloud external-update --tags ha_image_update first\"}}, {\"name\": \"manila_share fetch and retag container image for pacemaker\", \"when\": \"step|int == 2\", \"block\": [{\"name\": \"Retag pcmklatest to latest manila_share image\", \"include_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{manila_share_image}}\", \"container_image_latest\": \"{{manila_share_image_latest}}\"}}]}], \"post_update_tasks\": [{\"name\": \"Manila-share bundle post update\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"Manila-Share puppet bundle\", \"import_role\": {\"name\": \"tripleo_ha_wrapper\"}, \"vars\": {\"tripleo_ha_wrapper_service_name\": \"manila_share\", \"tripleo_ha_wrapper_resource_name\": \"openstack-manila-share\", \"tripleo_ha_wrapper_bundle_name\": \"openstack-manila-share\", \"tripleo_ha_wrapper_resource_state\": \"_ Started\", \"tripleo_ha_wrapper_puppet_config_volume\": \"manila\", \"tripleo_ha_wrapper_puppet_execute\": \"include ::tripleo::profile::base::pacemaker; include ::tripleo::profile::pacemaker::manila::share_bundle\", \"tripleo_ha_wrapper_puppet_tags\": \"pacemaker::resource::bundle,pacemaker::property,pacemaker::resource::ip,pacemaker::resource::ocf,pacemaker::constraint::order,pacemaker::constraint::colocation\", \"tripleo_ha_wrapper_puppet_debug\": {\"get_param\": \"ConfigDebug\"}, \"tripleo_ha_wrapper_config_suffix\": \".previous_run\"}}], \"vars\": {\"tripleo_ha_wrapper_minor_update\": true}}], \"upgrade_tasks\": [{\"name\": \"Prepare switch of manila_share image name\", \"when\": [\"step|int == 0\"], \"block\": [{\"name\": \"Get manila_share image id currently used by pacemaker\", \"shell\": \"pcs resource config openstack-manila-share | grep -Eo \'image=[^ ]+\' | awk -F= \'{print $2;}\'\", \"register\": \"manila_share_image_current_res\", \"failed_when\": false}, {\"name\": \"manila_share image facts\", \"set_fact\": {\"manila_share_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/manila-share:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerManilaShareImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerManilaShareImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"manila_share_image_current\": \"{{manila_share_image_current_res.stdout}}\"}}, {\"name\": \"Temporarily tag the current manila_share image id with the upgraded image name\", \"import_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{manila_share_image_current}}\", \"container_image_latest\": \"{{manila_share_image_latest}}\", \"pull_image\": false}, \"when\": [\"manila_share_image_current != \'\'\", \"manila_share_image_current != manila_share_image_latest\"]}, {\"name\": \"Create manila_share retag statefile\", \"file\": {\"path\": \"/var/lib/tripleo/manila_share_needs_retag\", \"state\": \"touch\"}, \"when\": [\"manila_share_image_current != \'\'\", \"manila_share_image_current != manila_share_image_latest\"]}]}, {\"name\": \"Update openstack-manila-share pcs resource bundle for new container image\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"set is_manila_share_bootstrap_node fact\", \"tags\": \"common\", \"set_fact\": \"is_manila_share_bootstrap_node={{manila_share_short_bootstrap_node_name|lower == ansible_facts[\'hostname\']|lower}}\"}, {\"name\": \"Check for manila_share retag statefile\", \"stat\": {\"path\": \"/var/lib/tripleo/manila_share_needs_retag\"}, \"register\": \"manila_share_retag_state_file\"}]}, {\"name\": \"Update openstack-manila-share pcs resource bundle for new container image\", \"when\": [\"step|int == 1\", \"is_manila_share_bootstrap_node\", \"manila_share_retag_state_file.stat.exists|bool\"], \"block\": [{\"name\": \"Disable the manila_share cluster resource before container upgrade\", \"pacemaker_resource\": {\"resource\": \"openstack-manila-share\", \"state\": \"disable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}, {\"name\": \"pcs resource bundle update manila_share for new container image name\", \"command\": \"pcs resource bundle update openstack-manila-share container image={{manila_share_image_latest}}\"}, {\"name\": \"Enable the manila_share cluster resource\", \"pacemaker_resource\": {\"resource\": \"openstack-manila-share\", \"state\": \"enable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}]}, {\"name\": \"Check for manila_share retag statefile\", \"when\": [\"step|int == 3\"], \"stat\": {\"path\": \"/var/lib/tripleo/manila_share_needs_retag\"}, \"register\": \"manila_share_retag_state_file\"}, {\"name\": \"Retag openstack-manila-share container image\", \"when\": [\"step|int == 3\"], \"block\": [{\"name\": \"Disable the manila_share cluster resource before container upgrade\", \"pacemaker_resource\": {\"resource\": \"openstack-manila-share\", \"state\": \"disable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}, {\"name\": \"Retag the pacemaker image if containerized\", \"block\": [{\"block\": [{\"name\": \"Get manila_share image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_manila_share_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'openstack-manila-share\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container manila_share image\", \"set_fact\": {\"manila_share_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerManilaShareImage\"]}, \"manila_share_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/manila-share:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerManilaShareImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerManilaShareImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"pcmk_manila_share_image\": \"{{xmllint_pcmk_manila_share_image.stdout}}\"}}]}, {\"block\": [{\"name\": \"Retag pcmklatest to latest manila_share image\", \"include_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{manila_share_image}}\", \"container_image_latest\": \"{{manila_share_image_latest}}\"}}]}]}, {\"name\": \"Enable the manila_share cluster resource\", \"pacemaker_resource\": {\"resource\": \"openstack-manila-share\", \"state\": \"enable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}, {\"name\": \"Remove manila_share retag statefile\", \"file\": {\"path\": \"/var/lib/tripleo/manila_share_needs_retag\", \"state\": \"absent\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(174,'2026-06-10 07:47:22',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (175,'2026-06-10 07:47:22',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Neutron ML2/OVN plugin configured with Puppet\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"OVNSouthboundServerPort\": {\"description\": \"Port of the OVN Southbound DB server\", \"type\": \"number\", \"default\": 6642}, \"OVNNorthboundServerPort\": {\"description\": \"Port of the OVN Northbound DB server\", \"type\": \"number\", \"default\": 6641}, \"OVNDbConnectionTimeout\": {\"description\": \"Timeout in seconds for the OVSDB connection transaction\", \"type\": \"number\", \"default\": 180}, \"OVNOvsdbProbeInterval\": {\"description\": \"Probe interval in ms for the OVSDB session\", \"type\": \"number\", \"default\": 60000}, \"OVNNeutronSyncMode\": {\"description\": \"The synchronization mode of OVN with Neutron DB\", \"type\": \"string\", \"default\": \"log\", \"constraints\": [{\"allowed_values\": [\"log\", false, \"repair\"]}]}, \"OVNQosDriver\": {\"description\": \"OVN notification driver for Neutron QOS service plugin\", \"type\": \"string\", \"default\": \"ovn-qos\"}, \"NeutronGeneveMaxHeaderSize\": {\"description\": \"Geneve encapsulation header size\", \"type\": \"number\", \"default\": 38}, \"NeutronEnableDVR\": {\"description\": \"Enable Neutron DVR.\", \"default\": \"\", \"type\": \"string\"}, \"NeutronEnableIgmpSnooping\": {\"description\": \"Enable IGMP Snooping.\", \"type\": \"boolean\", \"default\": false}, \"OVNMetadataEnabled\": {\"description\": \"Whether Metadata Service has to be enabled\", \"type\": \"boolean\", \"default\": true}, \"OVNDnsServers\": {\"default\": [], \"description\": \"List of servers to use as as dns forwarders\", \"type\": \"comma_delimited_list\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"NeutronVhostuserSocketDir\": {\"default\": \"\", \"description\": \"The vhost-user socket directory for OVS\", \"type\": \"string\", \"tags\": [\"role_specific\"]}, \"OVNEmitNeedToFrag\": {\"type\": \"boolean\", \"default\": true, \"description\": \"Configure OVN to emit \\\"need to frag\\\" packets in case of MTU mismatches. You may have to disable this option if you are running an old host kernel (version < 5.2). You may check the output of the following command: \'ovs-appctl -t ovs-vswitchd dpif/show-dp-features \\\\ br-int | grep \\\"Check pkt length action\\\"\'.\\n\"}, \"NeutronOVNLoggingRateLimit\": {\"default\": 100, \"description\": \"Maximum number of packets logging per second\\n\", \"type\": \"number\"}, \"NeutronOVNLoggingBurstLimit\": {\"default\": 25, \"description\": \"Maximum number of packets per rate_limit\\n\", \"type\": \"number\"}, \"NeutronOVNLoggingLocalOutputLogBase\": {\"default\": \"\", \"description\": \"Output logfile path on agent side, default syslog file\\n\", \"type\": \"string\"}}, \"conditions\": {\"neutron_dvr_unset\": {\"equals\": [{\"get_param\": \"NeutronEnableDVR\"}, \"\"]}, \"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"vhostuser_dir_set\": {\"or\": [{\"not\": {\"equals\": [{\"get_param\": \"NeutronVhostuserSocketDir\"}, \"\"]}}, {\"not\": {\"equals\": [{\"get_param\": [\"RoleParameters\", \"NeutronVhostuserSocketDir\"]}, \"\"]}}]}, \"network_log_local_output_log_base_set\": {\"not\": {\"equals\": [{\"get_param\": \"NeutronOVNLoggingLocalOutputLogBase\"}, \"\"]}}}, \"resources\": {\"NeutronMl2Base\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Neutron ML2/OVN plugin.\", \"value\": {\"service_name\": \"neutron_plugin_ml2_ovn\", \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"NeutronMl2Base\", \"role_data\", \"config_settings\"]}, {\"ovn::southbound::port\": {\"get_param\": \"OVNSouthboundServerPort\"}, \"ovn::northbound::port\": {\"get_param\": \"OVNNorthboundServerPort\"}, \"neutron::plugins::ml2::ovn::ovsdb_connection_timeout\": {\"get_param\": \"OVNDbConnectionTimeout\"}, \"neutron::plugins::ml2::ovn::ovsdb_probe_interval\": {\"get_param\": \"OVNOvsdbProbeInterval\"}, \"neutron::plugins::ml2::ovn::neutron_sync_mode\": {\"get_param\": \"OVNNeutronSyncMode\"}, \"neutron::plugins::ml2::ovn::ovn_metadata_enabled\": {\"get_param\": \"OVNMetadataEnabled\"}, \"neutron::server::qos_notification_drivers\": {\"get_param\": \"OVNQosDriver\"}, \"neutron::server::igmp_snooping_enable\": {\"get_param\": \"NeutronEnableIgmpSnooping\"}, \"neutron::plugins::ml2::max_header_size\": {\"get_param\": \"NeutronGeneveMaxHeaderSize\"}, \"neutron::plugins::ml2::ovn::dns_servers\": {\"get_param\": \"OVNDnsServers\"}, \"neutron::plugins::ml2::ovn::ovn_emit_need_to_frag\": {\"get_param\": \"OVNEmitNeedToFrag\"}}, {\"if\": [\"internal_tls_enabled\", {\"neutron::plugins::ml2::ovn::ovn_sb_ca_cert\": {\"get_param\": \"InternalTLSCAFile\"}, \"neutron::plugins::ml2::ovn::ovn_sb_certificate\": \"/etc/pki/tls/certs/ovn_neutron_client.crt\", \"neutron::plugins::ml2::ovn::ovn_sb_private_key\": \"/etc/pki/tls/private/ovn_neutron_client.key\", \"neutron::plugins::ml2::ovn::ovn_nb_ca_cert\": {\"get_param\": \"InternalTLSCAFile\"}, \"neutron::plugins::ml2::ovn::ovn_nb_certificate\": \"/etc/pki/tls/certs/ovn_neutron_client.crt\", \"neutron::plugins::ml2::ovn::ovn_nb_private_key\": \"/etc/pki/tls/private/ovn_neutron_client.key\"}, {}]}, {\"if\": [\"neutron_dvr_unset\", {\"neutron::plugins::ml2::ovn::dvr_enabled\": true}, {\"neutron::plugins::ml2::ovn::dvr_enabled\": {\"get_param\": \"NeutronEnableDVR\"}}]}, {\"if\": [\"vhostuser_dir_set\", {\"map_replace\": [{\"map_replace\": [{\"neutron::plugins::ml2::ovn::vhostuser_socket_dir\": \"NeutronVhostuserSocketDir\"}, {\"values\": {\"get_param\": \"RoleParameters\"}}]}, {\"values\": {\"NeutronVhostuserSocketDir\": {\"get_param\": \"NeutronVhostuserSocketDir\"}}}]}, {}]}, {\"neutron::plugins::ml2::ovn::network_log_rate_limit\": {\"get_param\": \"NeutronOVNLoggingRateLimit\"}}, {\"neutron::plugins::ml2::ovn::network_log_burst_limit\": {\"get_param\": \"NeutronOVNLoggingBurstLimit\"}}, {\"if\": [\"network_log_local_output_log_base_set\", {\"neutron::plugins::ml2::ovn::network_log_local_output_log_base\": {\"get_param\": \"NeutronOVNLoggingLocalOutputLogBase\"}}]}]}, \"step_config\": \"include tripleo::profile::base::neutron::plugins::ml2\\n\", \"metadata_settings\": {\"get_attr\": [\"NeutronMl2Base\", \"role_data\", \"metadata_settings\"]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(176,'2026-06-10 07:47:22',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mysql client settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role for setting mysql client parameters\", \"value\": {\"service_name\": \"mysql_client\", \"config_settings\": {\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"tripleo::profile::base::database::mysql::client::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}}, \"step_config\": \"include tripleo::profile::base::database::mysql::client\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(177,'2026-06-10 07:47:22',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Neutron ML2 Plugin configured with Puppet\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"NeutronMechanismDrivers\": {\"default\": \"ovn\", \"description\": \"The mechanism drivers for the Neutron tenant network.\\n\", \"type\": \"comma_delimited_list\"}, \"NeutronTypeDrivers\": {\"default\": \"geneve,vxlan,vlan,flat\", \"description\": \"Comma-separated list of network type driver entrypoints to be loaded.\\n\", \"type\": \"comma_delimited_list\"}, \"NeutronFlatNetworks\": {\"type\": \"comma_delimited_list\", \"default\": \"datacentre\", \"description\": \"If set, flat networks to configure in neutron plugins.\"}, \"NeutronPluginExtensions\": {\"default\": \"qos,port_security,dns_domain_ports\", \"description\": \"Comma-separated list of extensions enabled for the Neutron plugin.\\n\", \"type\": \"comma_delimited_list\"}, \"NeutronNetworkVLANRanges\": {\"default\": \"datacentre:1:1000\", \"description\": \"The Neutron ML2 and OpenVSwitch vlan mapping range to support. See the Neutron documentation for permitted values. Defaults to permitting VLANs 1 to 1000 on the \'datacentre\' physical network (See NeutronBridgeMappings).\\n\", \"type\": \"comma_delimited_list\"}, \"NeutronTunnelIdRanges\": {\"description\": \"Comma-separated list of <tun_min>:<tun_max> tuples enumerating ranges\\nof GRE tunnel IDs that are available for tenant network allocation\\n\", \"default\": [\"1:4094\"], \"type\": \"comma_delimited_list\"}, \"NeutronVniRanges\": {\"description\": \"Comma-separated list of <vni_min>:<vni_max> tuples enumerating ranges\\nof VXLAN VNI IDs that are available for tenant network allocation\\n\", \"default\": [\"1:65536\"], \"type\": \"comma_delimited_list\"}, \"NeutronNetworkType\": {\"default\": \"geneve\", \"description\": \"The tenant network type for Neutron.\", \"type\": \"comma_delimited_list\"}, \"NeutronOverlayIPVersion\": {\"default\": 4, \"description\": \"IP version used for all overlay network endpoints.\", \"type\": \"number\", \"constraints\": [{\"allowed_values\": [4, 6]}]}, \"NeutronML2PhysicalNetworkMtus\": {\"default\": [], \"description\": \"A list of mappings of physical networks to MTU values. The format of\\nthe mapping is <physnet>:<mtu val>. This mapping allows specifying a\\nphysical network MTU value that differs from the default segment_mtu\\nvalue in ML2 plugin. And overwrite values from global_physnet_mtu for\\nselected network.\\n\", \"type\": \"comma_delimited_list\"}, \"NeutronOvsVnicTypeBlacklist\": {\"description\": \"Comma-separated list of VNIC types for which support in Neutron is\\nadministratively prohibited by the OVS mechanism driver.\\n\", \"type\": \"comma_delimited_list\", \"default\": \"\"}, \"NeutronSriovVnicTypeBlacklist\": {\"description\": \"Comma-separated list of VNIC types for which support in Neutron is administratively prohibited by the SR-IOV mechanism driver.\\n\", \"type\": \"comma_delimited_list\", \"default\": \"\"}, \"NeutronFirewallDriver\": {\"description\": \"Firewall driver for realizing neutron security group function\", \"type\": \"string\", \"default\": \"\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"The following parameters are deprecated and will be removed. They should not\\nbe relied on for new deployments. If you have concerns regarding deprecated\\nparameters, please contact the TripleO development team on IRC or the\\nOpenStack mailing list.\\n\", \"parameters\": [\"NeutronOverlayIPVersion\"]}], \"conditions\": {\"physical_network_mtus_set\": {\"not\": {\"equals\": [{\"get_param\": \"NeutronML2PhysicalNetworkMtus\"}, []]}}}, \"resources\": {\"NeutronBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-base.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Neutron ML2 plugin.\", \"value\": {\"service_name\": \"neutron_plugin_ml2\", \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"NeutronBase\", \"role_data\", \"config_settings\"]}, {\"neutron::plugins::ml2::mechanism_drivers\": {\"get_param\": \"NeutronMechanismDrivers\"}, \"neutron::plugins::ml2::type_drivers\": {\"get_param\": \"NeutronTypeDrivers\"}, \"neutron::plugins::ml2::flat_networks\": {\"get_param\": \"NeutronFlatNetworks\"}, \"neutron::plugins::ml2::extension_drivers\": {\"get_param\": \"NeutronPluginExtensions\"}, \"neutron::plugins::ml2::network_vlan_ranges\": {\"get_param\": \"NeutronNetworkVLANRanges\"}, \"neutron::plugins::ml2::tunnel_id_ranges\": {\"get_param\": \"NeutronTunnelIdRanges\"}, \"neutron::plugins::ml2::vni_ranges\": {\"get_param\": \"NeutronVniRanges\"}, \"neutron::plugins::ml2::tenant_network_types\": {\"get_param\": \"NeutronNetworkType\"}, \"neutron::plugins::ml2::ovs_driver::vnic_type_blacklist\": {\"get_param\": \"NeutronOvsVnicTypeBlacklist\"}, \"neutron::plugins::ml2::sriov_driver::vnic_type_blacklist\": {\"get_param\": \"NeutronSriovVnicTypeBlacklist\"}, \"neutron::plugins::ml2::overlay_ip_version\": {\"get_param\": [\"ServiceData\", \"net_ip_version_map\", {\"get_param\": [\"ServiceNetMap\", \"NeutronTenantNetwork\"]}]}}, {\"if\": [\"physical_network_mtus_set\", {\"neutron::plugins::ml2::physical_network_mtus\": {\"get_param\": \"NeutronML2PhysicalNetworkMtus\"}}, null]}]}, \"step_config\": \"include tripleo::profile::base::neutron::plugins::ml2\\n\", \"service_config_settings\": {\"horizon\": {\"neutron::plugins::ml2::mechanism_drivers\": {\"get_param\": \"NeutronMechanismDrivers\"}}}, \"metadata_settings\": {\"get_attr\": [\"NeutronBase\", \"role_data\", \"metadata_settings\"]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(178,'2026-06-10 07:47:22',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Neutron base service. Shared for all Neutron agents.\\n\", \"parameters\": {\"DatabaseSyncTimeout\": {\"default\": 900, \"description\": \"DB Sync Timeout default\", \"type\": \"number\"}, \"NeutronDhcpAgentsPerNetwork\": {\"type\": \"number\", \"default\": 0, \"description\": \"The number of neutron dhcp agents to schedule per network\"}, \"DhcpAgentNotification\": {\"default\": false, \"description\": \"Whether or not to enable DHCP agent notifications.\", \"type\": \"boolean\"}, \"NeutronDnsDomain\": {\"type\": \"string\", \"default\": \"openstacklocal\", \"description\": \"Domain to use for building the hostnames.\"}, \"NeutronCorePlugin\": {\"default\": \"ml2\", \"description\": \"The core plugin for Neutron. The value should be the entrypoint to be loaded\\nfrom neutron.core_plugins namespace.\\n\", \"type\": \"string\"}, \"NeutronServicePlugins\": {\"default\": \"qos,ovn-router,trunk,segments,port_forwarding,log\", \"description\": \"Comma-separated list of service plugin entrypoints to be loaded from the\\nneutron.service_plugins namespace.\\n\", \"type\": \"comma_delimited_list\"}, \"Debug\": {\"type\": \"boolean\", \"default\": true, \"description\": \"Set to True to enable debugging on all services.\"}, \"NeutronDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Neutron services.\", \"type\": \"boolean\"}, \"EnableConfigPurge\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Remove configuration that is not generated by TripleO. Used to avoid configuration remnants after upgrades.\\n\"}, \"NeutronGlobalPhysnetMtu\": {\"type\": \"number\", \"default\": 1350, \"description\": \"MTU of the underlying physical network. Neutron uses this value to\\ncalculate MTU for all virtual network components. For flat and VLAN\\nnetworks, neutron uses this value without modification. For overlay\\nnetworks such as VXLAN, neutron automatically subtracts the overlay\\nprotocol overhead from this value.\\n(If this is not changed TenantNetPhysnetMtu will be used.)\\n\"}, \"TenantNetPhysnetMtu\": {\"type\": \"number\", \"default\": 1500, \"description\": \"MTU of the underlying physical network. Neutron uses this value to\\ncalculate MTU for all virtual network components. For flat and VLAN\\nnetworks, neutron uses this value without modification. For overlay\\nnetworks such as VXLAN, neutron automatically subtracts the overlay\\nprotocol overhead from this value.\\n(The mtu setting of the Tenant network in network_data.yaml\\ncontrol\'s this parameter.)\\n\"}, \"NeutronDBSyncExtraParams\": {\"default\": \"\", \"description\": \"String of extra command line parameters to append to the neutron-db-manage\\nupgrade head command.\\n\", \"type\": \"string\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"noop\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"EnableVLANTransparency\": {\"default\": false, \"description\": \"If True, then allow plugins that support it to create VLAN transparent networks.\\n\", \"type\": \"boolean\"}, \"NeutronGlobalReportInterval\": {\"default\": 300, \"description\": \"Seconds between nodes reporting state to server; should be less than NeutronAgentDownTime, best if it is half or less than NeutronAgentDownTime.\\n\", \"type\": \"number\"}}, \"conditions\": {\"dhcp_agents_zero\": {\"equals\": [{\"get_param\": \"NeutronDhcpAgentsPerNetwork\"}, 0]}, \"global_physnet_mtu_unset\": {\"equals\": [{\"get_param\": \"NeutronGlobalPhysnetMtu\"}, 0]}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Neutron base service.\", \"value\": {\"service_name\": \"neutron_base\", \"config_settings\": {\"map_merge\": [{\"neutron::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"neutron::core_plugin\": {\"get_param\": \"NeutronCorePlugin\"}, \"neutron::service_plugins\": {\"get_param\": \"NeutronServicePlugins\"}, \"neutron::report_interval\": {\"get_param\": \"NeutronGlobalReportInterval\"}, \"neutron::logging::debug\": {\"if\": [{\"get_param\": \"NeutronDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"neutron::purge_config\": {\"get_param\": \"EnableConfigPurge\"}, \"neutron::allow_overlapping_ips\": true, \"neutron::dhcp_agent_notification\": {\"get_param\": \"DhcpAgentNotification\"}, \"neutron::dns_domain\": {\"get_param\": \"NeutronDnsDomain\"}, \"neutron::rabbit_heartbeat_timeout_threshold\": 60, \"neutron::host\": \"%{hiera(\'fqdn_canonical\')}\", \"neutron::db::database_db_max_retries\": -1, \"neutron::db::database_max_retries\": -1, \"neutron::db::sync::db_sync_timeout\": {\"get_param\": \"DatabaseSyncTimeout\"}, \"neutron::global_physnet_mtu\": {\"if\": [\"global_physnet_mtu_unset\", {\"get_param\": \"TenantNetPhysnetMtu\"}, {\"get_param\": \"NeutronGlobalPhysnetMtu\"}]}, \"neutron::db::sync::extra_params\": {\"get_param\": \"NeutronDBSyncExtraParams\"}, \"neutron::vlan_transparent\": {\"get_param\": \"EnableVLANTransparency\"}, \"neutron::rabbit_heartbeat_in_pthread\": false}, {\"if\": [\"dhcp_agents_zero\", {}, {\"tripleo::profile::base::neutron::dhcp_agents_per_network\": {\"get_param\": \"NeutronDhcpAgentsPerNetwork\"}}]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(179,'2026-06-10 07:47:23',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Neutron API service\\n\", \"parameters\": {\"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ContainerNeutronApiImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\"}, \"NeutronServiceName\": {\"description\": \"service name\", \"type\": \"string\"}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerNeutronApiImage\": \"ContainerNeutronApiImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerNeutronApiImage\": {\"get_param\": \"ContainerNeutronApiImage\"}}}]}}}}, \"outputs\": {\"cmd_extra_args\": {\"description\": \"Extra command line arguments for running the service in the container.\", \"value\": {\"str_replace\": {\"template\": \"--log-file=/var/log/neutron/SERVICE.log\", \"params\": {\"SERVICE\": {\"get_param\": \"NeutronServiceName\"}}}}}, \"config_settings\": {\"description\": \"Extra hieradata needed to log to files in the host.\", \"value\": null}, \"volumes\": {\"description\": \"extra volumes\", \"value\": [\"/var/log/containers/neutron:/var/log/neutron:z\", \"/var/log/containers/httpd/neutron-api:/var/log/httpd:z\"]}, \"docker_config\": {\"description\": \"Extra containers needed for logging to files in the host.\", \"value\": {\"step_2\": {\"neutron_init_logs\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNeutronApiImage\"]}, \"net\": \"none\", \"privileged\": false, \"user\": \"root\", \"volumes\": [\"/var/log/containers/neutron:/var/log/neutron:z\", \"/var/log/containers/httpd/neutron-api:/var/log/httpd:z\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R neutron:neutron /var/log/neutron\"]}}}}, \"host_prep_tasks\": {\"description\": \"Extra ansible tasks needed for logging to files in the host.\", \"value\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/neutron\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/log/containers/httpd/neutron-api\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}]}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"NeutronServiceName\": \"server\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(180,'2026-06-10 07:47:23',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Provides the list of Docker volumes and environment to be used by the ManilaShare service. The same list is used for HA and non-HA deployments.\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ManilaCephFSCephFSProtocolHelperType\": {\"default\": \"CEPHFS\", \"description\": \"Protocol type (\'CEPHFS\' or \'NFS\') when cephfs back end is enabled.  Set via manila cephfs environment files.\", \"type\": \"string\", \"constraints\": [{\"allowed_values\": [\"CEPHFS\", \"NFS\"]}]}, \"CephConfigPath\": {\"type\": \"string\", \"default\": \"/var/lib/tripleo-config/ceph\", \"description\": \"The path where the Ceph Cluster config files are stored on the host.\\n\"}}, \"conditions\": {\"cephfs_nfs_enabled\": {\"equals\": [{\"get_param\": \"ManilaCephFSCephFSProtocolHelperType\"}, \"NFS\"]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}}, \"outputs\": {\"manila_share_volumes\": {\"description\": \"Volumes for the manila-share container (HA or non-HA)\", \"value\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/manila_share.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/manila:/var/lib/kolla/config_files/src:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/dev:/dev\", \"/run:/run\", \"/sys:/sys\", \"/lib/modules:/lib/modules:ro\", \"/var/lib/manila:/var/lib/manila:z\", \"/var/log/containers/manila:/var/log/manila:z\"], {\"if\": [\"cephfs_nfs_enabled\", [\"/etc/ganesha:/etc/ganesha\", \"/run/dbus/system_bus_socket:/run/dbus/system_bus_socket\"]]}]}}, \"manila_share_environment\": {\"description\": \"Docker environment for the manila-share container (HA or non-HA)\", \"value\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(181,'2026-06-10 07:47:23',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(182,'2026-06-10 07:47:24',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"MySQL service deployment with pacemaker bundle\\n\", \"parameters\": {\"ContainerMysqlImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\"}, \"ContainerMysqlConfigImage\": {\"description\": \"The container image to use for the mysql config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\"}, \"ClusterCommonTag\": {\"default\": false, \"description\": \"When set to false, a pacemaker service is configured to use a floating tag for its container image name, e.g. \'REGISTRY/NAMESPACE/IMAGENAME:pcmklatest\'. When set to true, the service uses a floating prefix as well, e.g. \'cluster.common.tag/IMAGENAME:pcmklatest\'.\", \"type\": \"boolean\"}, \"ClusterFullTag\": {\"default\": true, \"description\": \"When set to true, the pacemaker service uses a fully constant tag for its container image name, e.g. \'cluster.common.tag/SERVICENAME:pcmklatest\'.\", \"type\": \"boolean\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"MysqlRootPassword\": {\"type\": \"string\", \"hidden\": true, \"default\": \"wDcXw6Z0DC\"}, \"MysqlClustercheckPassword\": {\"type\": \"string\", \"hidden\": true, \"default\": \"hepAGELIsa9DMKgtpIM5NwEsU\"}, \"MysqlUpgradePersist\": {\"type\": \"boolean\", \"default\": false}, \"MysqlUpgradeTransfer\": {\"type\": \"boolean\", \"default\": true}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"ConfigDebug\": {\"default\": false, \"description\": \"Whether to run config management (e.g. Puppet) in debug mode.\", \"type\": \"boolean\"}, \"DeployIdentifier\": {\"default\": 1781077560, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}, \"MysqlGaleraSSTMethod\": {\"type\": \"string\", \"default\": \"rsync\", \"description\": \"Method used by galera to perform State Snapshot Transfers\", \"constraints\": [{\"allowed_values\": [\"rsync\", \"mariabackup\"]}]}, \"MysqlMariabackupUser\": {\"type\": \"string\", \"default\": \"mariabackup\", \"description\": \"When MysqlGaleraSSTMethod is set to mariabackup, the name of the database user that executes the SST.\"}, \"MysqlMariabackupPassword\": {\"type\": \"string\", \"hidden\": true, \"description\": \"When MysqlGaleraSSTMethod is set to mariabackup, the password of the database user that executes the SST.\", \"default\": \"8I5mvt66ebeLQhZAOpOekHv6P\"}, \"MysqlGaleraSSLCipher\": {\"type\": \"string\", \"default\": \"AES128-SHA256\", \"description\": \"Symmetric cipher to use.\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MysqlBase\": {\"type\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-base.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerMysqlImage\": \"ContainerMysqlImage\", \"ContainerMysqlConfigImage\": \"ContainerMysqlConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerMysqlImage\": {\"get_param\": \"ContainerMysqlImage\"}, \"ContainerMysqlConfigImage\": {\"get_param\": \"ContainerMysqlConfigImage\"}}}]}}}}, \"conditions\": {\"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"role_data\": {\"description\": \"Containerized service MySQL using composable services.\", \"value\": {\"service_name\": {\"get_attr\": [\"MysqlBase\", \"role_data\", \"service_name\"]}, \"firewall_rules\": {\"104 mysql galera-bundle\": {\"dport\": [873, 3123, 3306, 4444, 4567, 4568, 9200]}}, \"firewall_frontend_rules\": {\"100 mysql_haproxy\": {\"dport\": [3306]}}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"MysqlBase\", \"role_data\", \"config_settings\"]}, {\"tripleo::profile::pacemaker::database::mysql::bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::pacemaker::database::mysql::gmcast_listen_addr\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::pacemaker::database::mysql::ca_file\": {\"get_param\": \"InternalTLSCAFile\"}, \"tripleo::profile::pacemaker::database::mysql_bundle::mysql_docker_image\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/mariadb:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"tripleo::profile::pacemaker::database::mysql_bundle::control_port\": 3123, \"tripleo::profile::pacemaker::database::mysql_bundle::container_backend\": {\"get_param\": \"ContainerCli\"}, \"tripleo::profile::pacemaker::database::mysql_bundle::bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::pacemaker::database::mysql_bundle::ca_file\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"get_param\": \"InternalTLSCAFile\"}]}, \"tripleo::profile::pacemaker::database::mysql_bundle::sst_method\": {\"get_param\": \"MysqlGaleraSSTMethod\"}, \"tripleo::profile::pacemaker::database::mysql_bundle::mariabackup_user\": {\"get_param\": \"MysqlMariabackupUser\"}, \"tripleo::profile::pacemaker::database::mysql_bundle::mariabackup_password\": {\"get_param\": \"MysqlMariabackupPassword\"}, \"tripleo::profile::pacemaker::database::mysql_bundle::force_ocf\": true, \"tripleo::profile::pacemaker::database::mysql_bundle::gcomm_cipher\": {\"get_param\": \"MysqlGaleraSSLCipher\"}}]}, \"puppet_config\": {\"config_volume\": \"mysql\", \"puppet_tags\": \"file\", \"step_config\": {\"list_join\": [\"\\n\", [\"[\'Mysql_datadir\', \'Mysql_user\', \'Mysql_database\', \'Mysql_grant\', \'Mysql_plugin\'].each |String $val| { noop_resource($val) }\", \"exec {\'wait-for-settle\': command => \'/bin/true\' }\", \"include tripleo::profile::pacemaker::database::mysql_bundle\"]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/mysql.json\": {\"command\": \"/usr/sbin/pacemaker_remoted\", \"config_files\": [{\"dest\": \"/etc/libqb/force-filesystem-sockets\", \"source\": \"/dev/null\", \"owner\": \"root\", \"perm\": \"0644\"}, {\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"optional\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/mysql\", \"owner\": \"mysql:mysql\", \"recurse\": true}, {\"path\": \"/etc/pki/tls/certs/mysql.crt\", \"owner\": \"mysql:mysql\", \"perm\": \"0600\", \"optional\": true}, {\"path\": \"/etc/pki/tls/private/mysql.key\", \"owner\": \"mysql:mysql\", \"perm\": \"0600\", \"optional\": true}]}}, \"container_config_scripts\": {\"get_attr\": [\"ContainersCommon\", \"container_config_scripts\"]}, \"docker_config\": {\"step_1\": {\"mysql_data_ownership\": {\"start_order\": 0, \"detach\": false, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"net\": \"host\", \"user\": \"root\", \"command\": [\"chown\", \"-R\", \"mysql:\", \"/var/lib/mysql\"], \"volumes\": [\"/var/lib/mysql:/var/lib/mysql:z\"]}, \"mysql_bootstrap\": {\"start_order\": 1, \"detach\": false, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"net\": \"host\", \"user\": \"root\", \"command\": [\"bash\", \"-ec\", {\"list_join\": [\"\\n\", [\"if [ -e /var/lib/mysql/mysql ]; then exit 0; fi\", \"echo -e \\\"\\\\n[mysqld]\\\\nwsrep_provider=none\\\" >> /etc/my.cnf\", \"export DB_ROOT_PASSWORD=$(hiera \'mysql::server::root_password\')\", \"kolla_set_configs\", \"sudo -u mysql -E kolla_extend_start\", \"timeout ${DB_MAX_TIMEOUT} /bin/bash -c \'while pgrep -af /usr/bin/mysqld_safe | grep -q -v grep; do sleep 1; done\'\", \"mysqld_safe --skip-networking --wsrep-on=OFF &\", \"timeout ${DB_MAX_TIMEOUT} /bin/bash -c \'until mysqladmin -uroot -p\\\"$(hiera \'mysql::server::root_password\')\\\" ping 2>/dev/null; do sleep 1; done\'\"], {\"if\": [{\"equals\": [{\"get_param\": \"MysqlGaleraSSTMethod\"}, \"mariabackup\"]}, [\"mysql -uroot -p\\\"$(hiera \'mysql::server::root_password\')\\\" -e \\\"CREATE USER \'${DB_MARIABACKUP_USER}\'@\'localhost\' IDENTIFIED BY \'${DB_MARIABACKUP_PASSWORD}\';\\\"\", \"mysql -uroot -p\\\"$(hiera \'mysql::server::root_password\')\\\" -e \\\"GRANT RELOAD, PROCESS, LOCK TABLES, REPLICATION CLIENT ON *.* TO \'${DB_MARIABACKUP_USER}\'@\'localhost\';\\\"\"]]}, [\"mysql -uroot -p\\\"$(hiera \'mysql::server::root_password\')\\\" -e \\\"CREATE USER \'clustercheck\'@\'localhost\' IDENTIFIED BY \'$(hiera mysql_clustercheck_password)\';\\\"\", \"mysql -uroot -p\\\"$(hiera \'mysql::server::root_password\')\\\" -e \\\"GRANT PROCESS ON *.* TO \'clustercheck\'@\'localhost\' WITH GRANT OPTION;\\\"\", \"mysql -uroot -p\\\"$(hiera \'mysql::server::root_password\')\\\" -e \\\"DELETE FROM mysql.user WHERE user = \'root\' AND host NOT IN (\'%\',\'localhost\');\\\"\", \"timeout ${DB_MAX_TIMEOUT} mysqladmin -uroot -p\\\"$(hiera \'mysql::server::root_password\')\\\" shutdown\"]]}], \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/mysql.json:/var/lib/kolla/config_files/config.json:rw,z\", \"/var/lib/config-data/puppet-generated/mysql:/var/lib/kolla/config_files/src:ro,z\", \"/var/lib/mysql:/var/lib/mysql:rw,z\"], {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [\"/etc/pki/tls/certs/mysql.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/mysql.crt:ro\", \"/etc/pki/tls/private/mysql.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/mysql.key:ro\"]]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\", \"KOLLA_BOOTSTRAP\": true, \"DB_MAX_TIMEOUT\": 60, \"DB_MARIABACKUP_USER\": {\"get_param\": \"MysqlMariabackupUser\"}, \"DB_MARIABACKUP_PASSWORD\": {\"get_param\": \"MysqlMariabackupPassword\"}}}}, \"step_2\": {\"mysql_wait_bundle\": {\"start_order\": 0, \"detach\": false, \"net\": \"host\", \"ipc\": \"host\", \"user\": \"root\", \"command\": {\"list_concat\": [[\"/container_puppet_apply.sh\", \"2\", \"file,file_line,concat,augeas,galera_ready,mysql_database,mysql_grant,mysql_user\", \"include tripleo::profile::pacemaker::database::mysql_bundle\"], {\"if\": [{\"get_param\": \"ConfigDebug\"}, [\"--debug\"]]}]}, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"container_puppet_apply_volumes\"]}, [\"/var/lib/mysql:/var/lib/mysql:rw,z\", \"/var/lib/config-data/puppet-generated/mysql/root:/root:rw\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"]]}]}, \"environment\": {\"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}}}}}, \"host_prep_tasks\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/mysql\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/mysql\", \"setype\": \"container_file_t\"}, {\"path\": \"/var/log/mariadb\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}], \"metadata_settings\": {\"get_attr\": [\"MysqlBase\", \"role_data\", \"metadata_settings\"]}, \"deploy_steps_tasks\": {\"list_concat\": [{\"get_attr\": [\"MysqlBase\", \"role_data\", \"deploy_steps_tasks\"]}, [{\"name\": \"MySQL tag container image for pacemaker\", \"when\": \"step|int == 1\", \"import_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"container_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/mariadb:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}}}, {\"name\": \"MySQL HA Wrappers Step\", \"when\": \"step|int == 2\", \"block\": [{\"name\": \"Mysql puppet bundle\", \"import_role\": {\"name\": \"tripleo_ha_wrapper\"}, \"vars\": {\"tripleo_ha_wrapper_service_name\": \"mysql\", \"tripleo_ha_wrapper_resource_name\": \"galera\", \"tripleo_ha_wrapper_bundle_name\": \"galera-bundle\", \"tripleo_ha_wrapper_resource_state\": \"Master\", \"tripleo_ha_wrapper_puppet_config_volume\": \"mysql\", \"tripleo_ha_wrapper_puppet_execute\": \"[\\\"Mysql_datadir\\\", \\\"Mysql_user\\\", \\\"Mysql_database\\\", \\\"Mysql_grant\\\", \\\"Mysql_plugin\\\"].each |String $val| { noop_resource($val) }; include ::tripleo::profile::base::pacemaker; include ::tripleo::profile::pacemaker::database::mysql_bundle\", \"tripleo_ha_wrapper_puppet_tags\": \"pacemaker::resource::bundle,pacemaker::property,pacemaker::resource::ocf,pacemaker::constraint::order,pacemaker::constraint::colocation\", \"tripleo_ha_wrapper_puppet_debug\": {\"get_param\": \"ConfigDebug\"}, \"tripleo_ha_wrapper_config_suffix\": \".previous_run\"}}]}]]}, \"external_update_tasks\": [{\"when\": \"step|int == 1\", \"tags\": \"ha_image_update\", \"block\": [{\"block\": [{\"name\": \"Get galera image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_galera_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'galera-bundle\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container galera image\", \"set_fact\": {\"galera_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"galera_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/mariadb:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"pcmk_galera_image\": \"{{xmllint_pcmk_galera_image.stdout}}\"}}], \"delegate_to\": \"{{ (groups[\\\"mysql\\\"] | difference(groups[\\\"excluded_overcloud\\\"]))[0] }}\"}, {\"name\": \"MySQL temporary pacemaker container tag in case of image switch\", \"become\": true, \"import_role\": {\"name\": \"tripleo_ha_image_update\"}, \"vars\": {\"tripleo_ha_image_update_node_names\": \"{{ groups[\\\"mysql\\\"] | difference(groups[\\\"excluded_overcloud\\\"]) }}\", \"tripleo_ha_image_update_bundle\": \"galera-bundle\", \"tripleo_ha_image_update_new_image\": \"{{galera_image_latest}}\", \"tripleo_ha_image_update_old_image\": \"{{pcmk_galera_image}}\"}, \"when\": [\"(pcmk_galera_image != \\\"\\\")\", \"(pcmk_galera_image != galera_image_latest)\"]}]}], \"update_tasks\": [{\"block\": [{\"name\": \"Get galera image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_galera_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'galera-bundle\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container galera image\", \"set_fact\": {\"galera_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"galera_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/mariadb:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"pcmk_galera_image\": \"{{xmllint_pcmk_galera_image.stdout}}\"}}], \"when\": \"(step|int == 0 or step|int == 2)\"}, {\"name\": \"Check for update of galera container image name\", \"when\": \"step|int == 0\", \"assert\": {\"that\": \"pcmk_galera_image == galera_image_latest\", \"fail_msg\": \"galera image change detected, run overcloud external-update --tags ha_image_update first\"}}, {\"name\": \"Tear-down non-HA mysql container\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"stat mysql container\", \"command\": \"podman container exists mysql\", \"failed_when\": false, \"changed_when\": false, \"register\": \"stat_mysql_container\"}, {\"name\": \"Create clustercheck user and permissions\", \"command\": {\"argv\": \"{{ mysql_exec_data | container_exec_cmd }}\"}, \"changed_when\": true, \"when\": [\"stat_mysql_container.rc == 0\"], \"vars\": {\"mysql_exec_data\": {\"environment\": {\"CLUSTERCHECK_PASSWORD\": {\"get_param\": \"MysqlClustercheckPassword\"}}, \"command\": [\"mysql\", \"/bin/sh\", \"-c\", \"mysql -e \\\"CREATE USER IF NOT EXISTS \'clustercheck\'@\'localhost\' IDENTIFIED BY \'${CLUSTERCHECK_PASSWORD}\'; GRANT PROCESS ON *.* TO \'clustercheck\'@\'localhost\' WITH GRANT OPTION;\\\"\"]}}}, {\"name\": \"Remove non-HA mysql container\", \"include_role\": {\"name\": \"tripleo_container_rm\"}, \"vars\": {\"tripleo_container_cli\": \"{{ container_cli }}\", \"tripleo_containers_to_rm\": [\"mysql\"]}}]}, {\"name\": \"Mariadb fetch and retag container image for pacemaker\", \"when\": \"step|int == 2\", \"block\": [{\"name\": \"Retag pcmklatest to latest galera image\", \"include_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{galera_image}}\", \"container_image_latest\": \"{{galera_image_latest}}\"}}]}, {\"name\": \"Ensure mariadb-server is not installed on the host\", \"when\": \"step|int == 2\", \"yum\": {\"name\": \"mariadb-server*\", \"state\": \"absent\"}}], \"post_update_tasks\": [{\"name\": \"Mysql bundle post update\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"Mysql puppet bundle\", \"import_role\": {\"name\": \"tripleo_ha_wrapper\"}, \"vars\": {\"tripleo_ha_wrapper_service_name\": \"mysql\", \"tripleo_ha_wrapper_resource_name\": \"galera\", \"tripleo_ha_wrapper_bundle_name\": \"galera-bundle\", \"tripleo_ha_wrapper_resource_state\": \"Master\", \"tripleo_ha_wrapper_puppet_config_volume\": \"mysql\", \"tripleo_ha_wrapper_puppet_execute\": \"[\\\"Mysql_datadir\\\", \\\"Mysql_user\\\", \\\"Mysql_database\\\", \\\"Mysql_grant\\\", \\\"Mysql_plugin\\\"].each |String $val| { noop_resource($val) }; include ::tripleo::profile::base::pacemaker; include ::tripleo::profile::pacemaker::database::mysql_bundle\", \"tripleo_ha_wrapper_puppet_tags\": \"pacemaker::resource::bundle,pacemaker::property,pacemaker::resource::ocf,pacemaker::constraint::order,pacemaker::constraint::colocation\", \"tripleo_ha_wrapper_puppet_debug\": {\"get_param\": \"ConfigDebug\"}, \"tripleo_ha_wrapper_config_suffix\": \".previous_run\"}}], \"vars\": {\"tripleo_ha_wrapper_minor_update\": true}}], \"upgrade_tasks\": {\"list_concat\": [[{\"name\": \"Tear-down non-HA mysql container\", \"when\": [\"step|int == 0\"], \"block\": [{\"name\": \"stat mysql container\", \"command\": \"podman container exists mysql\", \"failed_when\": false, \"changed_when\": false, \"register\": \"stat_mysql_container\"}, {\"name\": \"Create clustercheck user and permissions\", \"command\": {\"argv\": \"{{ mysql_exec_data | container_exec_cmd }}\"}, \"changed_when\": true, \"when\": [\"stat_mysql_container.rc == 0\"], \"vars\": {\"mysql_exec_data\": {\"environment\": {\"CLUSTERCHECK_PASSWORD\": {\"get_param\": \"MysqlClustercheckPassword\"}}, \"command\": [\"mysql\", \"/bin/sh\", \"-c\", \"mysql -e \\\"CREATE USER IF NOT EXISTS \'clustercheck\'@\'localhost\' IDENTIFIED BY \'${CLUSTERCHECK_PASSWORD}\'; GRANT PROCESS ON *.* TO \'clustercheck\'@\'localhost\' WITH GRANT OPTION;\\\"\"]}}}, {\"name\": \"Remove non-HA mysql container\", \"include_role\": {\"name\": \"tripleo_container_rm\"}, \"vars\": {\"tripleo_container_cli\": \"{{ container_cli }}\", \"tripleo_containers_to_rm\": [\"mysql\"]}}]}], [{\"name\": \"set mysql container name fact\", \"when\": [\"step|int == 1\"], \"set_fact\": {\"mysql_container_name\": \"galera-bundle\"}}], {\"get_attr\": [\"MysqlBase\", \"mysql_drop_unused_users\"]}, [{\"vars\": {\"mysql_upgrade_persist\": {\"get_param\": \"MysqlUpgradePersist\"}}, \"when\": [\"step|int == 3\", \"mysql_upgrade_persist\"], \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_prepare\"], \"block\": [{\"name\": \"Persist mysql data\", \"include_role\": {\"name\": \"tripleo_persist\", \"tasks_from\": \"persist.yml\"}, \"vars\": {\"tripleo_persist_dir\": \"/var/lib/mysql\"}}]}, {\"vars\": {\"mysql_upgrade_persist\": {\"get_param\": \"MysqlUpgradePersist\"}}, \"when\": [\"step|int == 5\", \"mysql_upgrade_persist\"], \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\"], \"block\": [{\"name\": \"Restore mysql data\", \"include_role\": {\"name\": \"tripleo_persist\", \"tasks_from\": \"restore.yml\"}, \"vars\": {\"tripleo_persist_dir\": \"/var/lib/mysql\"}}]}, {\"name\": \"Prepare switch of galera image name\", \"when\": [\"step|int == 0\"], \"block\": [{\"name\": \"Get galera image id currently used by pacemaker\", \"shell\": \"pcs resource config galera-bundle | grep -Eo \'image=[^ ]+\' | awk -F= \'{print $2;}\'\", \"register\": \"galera_image_current_res\", \"failed_when\": false}, {\"name\": \"Image facts for galera\", \"set_fact\": {\"galera_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/mariadb:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"galera_image_current\": \"{{galera_image_current_res.stdout}}\"}}, {\"name\": \"Temporarily tag the current galera image id with the upgraded image name\", \"import_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{galera_image_current}}\", \"container_image_latest\": \"{{galera_image_latest}}\", \"pull_image\": false}, \"when\": [\"galera_image_current != \'\'\", \"galera_image_current != galera_image_latest\"]}, {\"name\": \"Create galera retag statefile\", \"file\": {\"path\": \"/var/lib/tripleo/galera_needs_retag\", \"state\": \"touch\"}, \"when\": [\"galera_image_current != \'\'\", \"galera_image_current != galera_image_latest\"]}]}, {\"name\": \"Update galera pcs resource bundle for new container image - check\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"set is_mysql_bootstrap_node fact\", \"tags\": \"common\", \"set_fact\": \"is_mysql_bootstrap_node={{mysql_short_bootstrap_node_name|lower == ansible_facts[\'hostname\']|lower}}\"}, {\"name\": \"Check for galera retag statefile\", \"stat\": {\"path\": \"/var/lib/tripleo/galera_needs_retag\"}, \"register\": \"galera_retag_state_file\"}]}, {\"name\": \"Update galera pcs resource bundle for new container image\", \"when\": [\"step|int == 1\", \"is_mysql_bootstrap_node|bool\", \"galera_retag_state_file.stat.exists|bool\"], \"block\": [{\"name\": \"Disable the galera cluster resource before container upgrade\", \"pacemaker_resource\": {\"resource\": \"galera-bundle\", \"state\": \"disable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}, {\"name\": \"Move Mysql logging to /var/log/containers\", \"block\": [{\"name\": \"Check Mysql logging configuration in pacemaker\", \"command\": \"cibadmin --query --xpath \\\"//storage-mapping[@id=\'mysql-log\']\\\"\", \"failed_when\": false, \"register\": \"mysql_logs_moved\"}, {\"name\": \"Change Mysql logging configuration in pacemaker\", \"when\": \"mysql_logs_moved.rc == 6\", \"block\": [{\"name\": \"Add a bind mount for logging in the galera bundle\", \"command\": \"pcs resource bundle update galera-bundle storage-map add id=mysql-log source-dir=/var/log/containers/mysql target-dir=/var/log/mysql options=rw\"}, {\"name\": \"Reconfigure Mysql log file in the galera resource agent\", \"command\": \"pcs resource update galera log=/var/log/mysql/mysqld.log\"}]}]}, {\"name\": \"Update the galera bundle to use the new container image name\", \"command\": \"pcs resource bundle update galera-bundle container image={{galera_image_latest}}\"}, {\"name\": \"Enable the galera cluster resource\", \"pacemaker_resource\": {\"resource\": \"galera-bundle\", \"state\": \"enable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}]}, {\"name\": \"Upgrade galera in step3\", \"when\": [\"step|int == 3\"], \"block\": [{\"name\": \"Bind mounts for temporary container\", \"set_fact\": {\"mysql_upgrade_db_bind_mounts\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/mysql.json:/var/lib/kolla/config_files/config.json:rw,z\", \"/var/lib/config-data/puppet-generated/mysql:/var/lib/kolla/config_files/src:ro,z\", \"/var/lib/mysql:/var/lib/mysql:rw,z\"], [\"/var/log/containers/mysql:/var/log/mysql:rw,z\"], {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [\"/etc/pki/tls/certs/mysql.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/mysql.crt:ro\", \"/etc/pki/tls/private/mysql.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/mysql.key:ro\"]]}]}}}, {\"name\": \"Check if Galera needs upgrade\", \"shell\": {\"str_replace\": {\"template\": \"CONTAINER_CLI run --rm --log-driver=k8s-file --log-opt path=LOG_DIR/db-upgrade.log \\\\ -u root --net=host UPGRADE_ENV UPGRADE_VOLUMES \\\"UPGRADE_IMAGE\\\" /bin/bash -ecx \\\"$UPGRADE_SCRIPT\\\"\", \"params\": {\"UPGRADE_ENV\": \"-e \\\"KOLLA_CONFIG_STRATEGY=COPY_ALWAYS\\\"\", \"UPGRADE_IMAGE\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/mariadb:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"UPGRADE_VOLUMES\": \"-v {{ mysql_upgrade_db_bind_mounts | join(\' -v \')}}\", \"CONTAINER_CLI\": \"{{ container_cli }}\", \"LOG_DIR\": \"/var/log/containers/mysql\"}}}, \"environment\": {\"UPGRADE_SCRIPT\": \"kolla_set_configs\\nupgraded_ver=$(cat /var/lib/mysql/mysql_upgrade_info 2>/dev/null || true)\\nmysql_ver=$(mysql --version | awk -F\'[ ,]*\' \'{print $5}\')\\nif [ \\\"${upgraded_ver}\\\" = \\\"${mysql_ver}\\\" ]; then\\n    echo \\\"mysql already upgraded\\\"\\nelse\\n    echo \\\"${upgraded_ver} VS ${mysql_ver}\\\"\\nfi\\n\"}, \"register\": \"mysql_upgrade_needed\"}, {\"name\": \"Set fact upgrade_mysql\", \"set_fact\": {\"upgrade_mysql\": \"{{ (mysql_upgrade_needed.stdout != \\\"mysql already upgraded\\\") | bool }}\"}}, {\"debug\": {\"msg\": \"MYSQL check - {{ mysql_upgrade_needed.stdout }} - Upgrade needed: {{ upgrade_mysql }}\"}}, {\"name\": \"Disable the galera cluster resource before container upgrade\", \"when\": [\"upgrade_mysql|bool\"], \"pacemaker_resource\": {\"resource\": \"galera-bundle\", \"state\": \"disable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}, {\"block\": [{\"name\": \"Get galera image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_galera_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'galera-bundle\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container galera image\", \"set_fact\": {\"galera_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"galera_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/mariadb:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"pcmk_galera_image\": \"{{xmllint_pcmk_galera_image.stdout}}\"}}]}, {\"name\": \"Check for galera retag statefile\", \"stat\": {\"path\": \"/var/lib/tripleo/galera_needs_retag\"}, \"register\": \"galera_retag_state_file\"}, {\"name\": \"Retag the pacemaker image if containerized\", \"when\": [\"galera_retag_state_file.stat.exists|bool\"], \"block\": [{\"name\": \"Retag pcmklatest to latest galera image\", \"include_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{galera_image}}\", \"container_image_latest\": \"{{galera_image_latest}}\"}}]}, {\"name\": \"Remove galera retag statefile\", \"file\": {\"path\": \"/var/lib/tripleo/galera_needs_retag\", \"state\": \"absent\"}}, {\"name\": \"Mysql upgrade script\", \"when\": [\"upgrade_mysql|bool\"], \"set_fact\": {\"mysql_upgrade_script\": {\"list_join\": [\"\\n\", [\"kolla_set_configs\\nif mysqladmin ping --silent; then exit 0; fi\\nupgraded_ver=$(cat /var/lib/mysql/mysql_upgrade_info 2>/dev/null || true)\\nmysql_ver=$(mysql --version | awk -F\'[ ,]*\' \'{print $5}\')\\nif [ \\\"${upgraded_ver}\\\" = \\\"${mysql_ver}\\\" ]; then\\n    echo \\\"mysql already upgraded\\\"\\n    exit 0\\nfi\\nchown -R mysql:mysql /var/lib/mysql\\nchown -R mysql:mysql /var/log/mysql\\nmysqld_safe --user=mysql --wsrep-provider=none --skip-networking --wsrep-on=off --log-error=/var/log/mysql/mysqld-upgrade.log &\\n\", {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/mysql_upgrade_db.sh\"}, \"mysqladmin shutdown\"]]}}}, {\"name\": \"Upgrade Mysql database from a temporary container\", \"when\": [\"upgrade_mysql|bool\"], \"shell\": {\"str_replace\": {\"template\": \"CONTAINER_CLI run --rm --log-driver=k8s-file --log-opt path=LOG_DIR/db-upgrade.log \\\\ -u root --net=host UPGRADE_ENV UPGRADE_VOLUMES \\\"UPGRADE_IMAGE\\\" /bin/bash -ecx \\\"$UPGRADE_SCRIPT\\\"\", \"params\": {\"UPGRADE_ENV\": \"-e \\\"KOLLA_CONFIG_STRATEGY=COPY_ALWAYS\\\"\", \"UPGRADE_IMAGE\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/mariadb:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"UPGRADE_VOLUMES\": \"-v {{ mysql_upgrade_db_bind_mounts | join(\' -v \')}}\", \"CONTAINER_CLI\": \"{{ container_cli }}\", \"LOG_DIR\": \"/var/log/containers/mysql\"}}}, \"environment\": {\"UPGRADE_SCRIPT\": \"{{ mysql_upgrade_script }}\"}}, {\"name\": \"Enable the galera cluster resource\", \"when\": [\"upgrade_mysql|bool\"], \"pacemaker_resource\": {\"resource\": \"galera-bundle\", \"state\": \"enable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}]}]]}, \"external_upgrade_tasks\": [{\"vars\": {\"mysql_upgrade_transfer\": {\"get_param\": \"MysqlUpgradeTransfer\"}}, \"when\": [\"step|int == 2\", \"mysql_upgrade_transfer\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\"], \"block\": [{\"name\": \"Transfer mysql data\", \"include_role\": {\"name\": \"tripleo_transfer\"}, \"vars\": {\"tripleo_transfer_src_dir\": \"/var/lib/mysql\", \"tripleo_transfer_src_host\": \"{{hostvars[groups[\'overcloud\'][0]][\'mysql_short_node_names\'][1]}}\", \"tripleo_transfer_dest_dir\": \"/var/lib/mysql\", \"tripleo_transfer_dest_host\": \"{{hostvars[groups[\'overcloud\'][0]][\'mysql_short_bootstrap_node_name\']}}\", \"tripleo_transfer_flag_file\": \"/var/lib/tripleo/transfer-flags/var-lib-mysql\", \"tripleo_transfer_sync_options\": \"--whole-file --ignore-times --inplace --archive --delete\", \"tripleo_transfer_include\": [\"/ibdata*\", \"/ib_lru_dump\", \"/ib_logfile[0-9]*\", \"/undo*\", \"/*/\"], \"tripleo_transfer_exclude\": \"/*\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(183,'2026-06-10 07:47:24',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(184,'2026-06-10 07:47:24',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"MySQL service deployment using puppet\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"MysqlMaxConnections\": {\"description\": \"Configures MySQL max_connections config setting\", \"type\": \"number\", \"default\": 4096}, \"MysqlIncreaseFileLimit\": {\"description\": \"Flag to increase MySQL open-files-limit to 16384\", \"type\": \"boolean\", \"default\": true}, \"MysqlRootPassword\": {\"type\": \"string\", \"hidden\": true, \"default\": \"wDcXw6Z0DC\"}, \"MysqlClustercheckPassword\": {\"type\": \"string\", \"hidden\": true, \"default\": \"hepAGELIsa9DMKgtpIM5NwEsU\"}, \"EnableGalera\": {\"default\": true, \"description\": \"Whether to use Galera instead of regular MariaDB.\", \"type\": \"boolean\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"EnableMysqlAuthEd25519\": {\"type\": \"boolean\", \"description\": \"Whether to configure MySQL users to connect to the server using the Ed25519-based client authentication.\", \"default\": false}, \"MysqlIPv6\": {\"default\": false, \"description\": \"Enable IPv6 in MySQL\", \"type\": \"boolean\"}, \"MysqlInnodbBufferPoolSize\": {\"type\": \"string\", \"description\": \"Buffer pool size for MySQL database; this needs to be larger for at-scale deployments\", \"default\": \"128M\"}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"MysqlCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"The following parameters are deprecated and will be removed. They should not\\nbe relied on for new deployments. If you have concerns regarding deprecated\\nparameters, please contact the TripleO development team on IRC or the\\nOpenStack mailing list.\\n\", \"parameters\": [\"MysqlIPv6\"]}], \"conditions\": {\"is_ipv6\": {\"equals\": [{\"get_param\": [\"ServiceData\", \"net_ip_version_map\", {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}]}, 6]}, \"innodb_buffer_pool_set\": {\"not\": {\"equals\": [{\"get_param\": \"MysqlInnodbBufferPoolSize\"}, \"\"]}}, \"key_size_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"MysqlCertificateKeySize\"}, \"\"]}}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared docker config scripts\", \"value\": {\"mysql_upgrade_db.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/mysql_upgrade_db.sh\"}}}}, \"mysql_drop_unused_users\": {\"description\": \"Ansible block to clean up unusued Openstack DB users\", \"value\": [{\"name\": \"Drop unused OpenStack DB users\", \"when\": [\"step|int == 1\", \"mysql_short_bootstrap_node_name|lower == ansible_facts[\'hostname\']|lower\"], \"block\": [{\"name\": \"mysql container id\", \"command\": \"podman ps -q --filter name={{ mysql_container_name }} --filter status=running\", \"register\": \"mysql_container_id\"}, {\"name\": \"set mysql container id fact\", \"set_fact\": {\"mysql_container\": \"{{ mysql_container_id.stdout }}\"}}, {\"name\": \"Mysql script to drop unused DB users\", \"when\": \"( mysql_container | length ) > 0\", \"block\": [{\"name\": \"Get the list of all OpenStack DB users\", \"shell\": \"jq -r \'to_entries[] | select(.key|endswith(\\\"::db::mysql::user\\\")) | .value\' /etc/puppet/hieradata/service_configs.json\", \"register\": \"openstack_db_users\"}, {\"name\": \"List all DB users that match the DB users to be dropped\", \"shell\": \"for u in {{ openstack_db_users.stdout_lines | join(\' \') }}; do podman exec -u root -it \\\"{{ mysql_container }}\\\" mysql -sNe \\\"select concat(\'\\\\`\',user,\'\\\\`@\\\\`\',host,\'\\\\`\') from mysql.user where user = \'$u\' and host != \'%\';\\\"; done\", \"register\": \"mysql_db_users\"}, {\"name\": \"resulting DB users to be dropped\", \"debug\": {\"msg\": \"{{ mysql_db_users.stdout_lines }}\"}}, {\"name\": \"Drop all unneeded Openstack DB users\", \"shell\": \"podman exec -u root -it \\\"{{ mysql_container }}\\\" mysql -sNe \'drop user {{ item }};\'\", \"loop\": \"{{ mysql_db_users.stdout_lines }}\"}]}]}]}, \"role_data\": {\"description\": \"Service MySQL using composable services.\", \"value\": {\"service_name\": \"mysql\", \"config_settings\": {\"mysql::server::package_name\": \"mariadb-galera-server\", \"mysql::server::manage_config_file\": true, \"mysql_ipv6\": {\"if\": [\"is_ipv6\", true, false]}, \"mysql_max_connections\": {\"get_param\": \"MysqlMaxConnections\"}, \"mysql::server::root_password\": {\"get_param\": \"MysqlRootPassword\"}, \"mysql_clustercheck_password\": {\"get_param\": \"MysqlClustercheckPassword\"}, \"enable_galera\": {\"get_param\": \"EnableGalera\"}, \"mysql_auth_ed25519\": {\"get_param\": \"EnableMysqlAuthEd25519\"}, \"mysql_bind_host\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::generate_dropin_file_limit\": {\"get_param\": \"MysqlIncreaseFileLimit\"}, \"tripleo::profile::base::database::mysql::certificate_specs\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"service_certificate\": \"/etc/pki/tls/certs/mysql.crt\", \"service_key\": \"/etc/pki/tls/private/mysql.key\"}]}, \"innodb_buffer_pool_size\": {\"if\": [\"innodb_buffer_pool_set\", {\"get_param\": \"MysqlInnodbBufferPoolSize\"}]}}, \"step_config\": \"include tripleo::profile::base::database::mysql\\n\", \"metadata_settings\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [{\"service\": \"mysql\", \"network\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}, \"type\": \"vip\"}, {\"service\": \"mysql\", \"network\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}, \"type\": \"node\"}]]}, \"deploy_steps_tasks\": [{\"name\": \"Certificate generation\", \"when\": [\"step|int == 1\", \"enable_internal_tls\"], \"block\": [{\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": [{\"name\": \"mysql\", \"dns\": [{\"str_replace\": {\"template\": \"{{fqdn_$NETWORK}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, {\"str_replace\": {\"template\": \"{{cloud_names.cloud_name_NETWORK}}\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}], \"principal\": {\"str_replace\": {\"template\": \"mysql/{{fqdn_$NETWORK}}@{{idm_realm}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"key_size\": {\"if\": [\"key_size_override_set\", {\"get_param\": \"MysqlCertificateKeySize\"}, {\"get_param\": \"CertificateKeySize\"}]}, \"ca\": \"ipa\"}]}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (185,'2026-06-10 07:47:25',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Nova Metadata service\\n\", \"parameters\": {\"ContainerNovaMetadataImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\"}, \"ContainerNovaMetadataConfigImage\": {\"description\": \"The container image to use for the nova config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\"}, \"NovaMetadataLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.nova.api.metadata\", \"file\": \"/var/log/containers/nova/nova-metadata-api.log\"}}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"NovaWorkers\": {\"default\": 1, \"description\": \"Number of workers for Nova services.\", \"type\": \"number\"}, \"NovaPassword\": {\"description\": \"The password for the nova service and db account\", \"type\": \"string\", \"hidden\": true, \"default\": \"btE80AtSdL16lZ5QqRx6f9I9L\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"NeutronMetadataProxySharedSecret\": {\"description\": \"Shared secret to prevent spoofing\", \"type\": \"string\", \"hidden\": true, \"default\": \"ZsuO7PdDpr6or9fZj2NjaPori\"}, \"MonitoringSubscriptionNovaMetadata\": {\"default\": \"overcloud-nova-metadata\", \"type\": \"string\"}, \"NovaLocalMetadataPerCell\": {\"default\": false, \"description\": \"Indicates that the nova-metadata API service has been deployed per-cell, so that we can have better performance and data isolation in a multi-cell deployment. Users should consider the use of this configuration depending on how neutron is setup. If networks span cells, you might need to run nova-metadata API service globally. If your networks are segmented along cell boundaries, then you can run nova-metadata API service per cell. When running nova-metadata API service per cell, you should also configure each Neutron metadata-agent to point to the corresponding nova-metadata API service.\\n\", \"type\": \"boolean\"}, \"MemcacheUseAdvancedPool\": {\"type\": \"boolean\", \"description\": \"Use the advanced (eventlet safe) memcached client pool.\\n\", \"default\": true}}, \"conditions\": {\"nova_workers_set\": {\"not\": {\"equals\": [{\"get_param\": \"NovaWorkers\"}, 0]}}, \"is_neutron_shared_metadata_notempty\": {\"not\": {\"equals\": [{\"get_param\": \"NeutronMetadataProxySharedSecret\"}, \"\"]}}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MySQLClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\"}, \"NovaMetadataLogging\": {\"type\": \"OS::TripleO::Services::Logging::NovaMetadata\"}, \"ApacheServiceBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}, \"EnableInternalTLS\": {\"get_param\": \"EnableInternalTLS\"}}}, \"NovaBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"NovaApiDBClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-apidb-client-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"NovaDBClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-db-client-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerNovaMetadataImage\": \"ContainerNovaMetadataImage\", \"ContainerNovaMetadataConfigImage\": \"ContainerNovaMetadataConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerNovaMetadataImage\": {\"get_param\": \"ContainerNovaMetadataImage\"}, \"ContainerNovaMetadataConfigImage\": {\"get_param\": \"ContainerNovaMetadataConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Nova Metadata service.\", \"value\": {\"service_name\": \"nova_metadata\", \"firewall_rules\": {\"139 nova_metadata\": {\"dport\": [8775]}}, \"firewall_frontend_rules\": {\"100 nova_metadatahaproxy_frontend\": {\"dport\": [8775]}}, \"firewall_ssl_frontend_rules\": {\"100 nova_metadatahaproxy_frontend_ssl\": {\"dport\": [13775]}}, \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionNovaMetadata\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"NovaBase\", \"role_data\", \"config_settings\"]}, {\"if\": [{\"not\": {\"get_param\": \"NovaLocalMetadataPerCell\"}}, {\"get_attr\": [\"NovaApiDBClient\", \"role_data\", \"config_settings\"]}]}, {\"get_attr\": [\"NovaDBClient\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"ApacheServiceBase\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"NovaMetadataLogging\", \"config_settings\"]}, {\"apache::default_vhost\": false}, {\"nova::keystone::authtoken::project_name\": \"service\", \"nova::keystone::authtoken::password\": {\"get_param\": \"NovaPassword\"}, \"nova::keystone::authtoken::www_authenticate_uri\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"uri_no_suffix\"]}, \"nova::keystone::authtoken::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"nova::keystone::authtoken::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"nova::keystone::authtoken::interface\": \"internal\", \"nova::keystone::authtoken::memcache_use_advanced_pool\": {\"get_param\": \"MemcacheUseAdvancedPool\"}, \"nova::wsgi::apache_metadata::api_port\": \"8775\", \"nova::wsgi::apache_metadata::ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"nova::metadata::local_metadata_per_cell\": {\"get_param\": \"NovaLocalMetadataPerCell\"}, \"nova::wsgi::apache_metadata::bind_host\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaMetadataNetwork\"]}}}}, \"nova::wsgi::apache_metadata::servername\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaMetadataNetwork\"]}}}}, \"nova::wsgi::apache_metadata::workers\": {\"if\": [\"nova_workers_set\", {\"get_param\": \"NovaWorkers\"}]}, \"nova::metadata::neutron_metadata_proxy_shared_secret\": {\"if\": [\"is_neutron_shared_metadata_notempty\", {\"get_param\": \"NeutronMetadataProxySharedSecret\"}]}}]}, \"service_config_settings\": {\"rabbitmq\": {\"get_attr\": [\"NovaBase\", \"role_data\", \"service_config_settings\"], \"rabbitmq\": null}, \"mysql\": {\"map_merge\": [{\"if\": [{\"not\": {\"get_param\": \"NovaLocalMetadataPerCell\"}}, {\"get_attr\": [\"NovaApiDBClient\", \"role_data\", \"service_config_settings\", \"mysql\"]}]}, {\"get_attr\": [\"NovaDBClient\", \"role_data\", \"service_config_settings\", \"mysql\"]}]}, \"rsyslog\": {\"tripleo_logging_sources_nova_metadata\": [{\"get_param\": \"NovaMetadataLoggingSource\"}]}}, \"puppet_config\": {\"config_volume\": \"nova_metadata\", \"puppet_tags\": \"nova_config,nova_api_paste_ini\", \"step_config\": {\"list_join\": [\"\\n\", [\"include tripleo::profile::base::nova::metadata\", {\"get_attr\": [\"MySQLClient\", \"role_data\", \"step_config\"]}]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaMetadataConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/nova_metadata.json\": {\"command\": \"/usr/sbin/httpd -DFOREGROUND\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.d\", \"dest\": \"/etc/httpd/conf.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.modules.d\", \"dest\": \"/etc/httpd/conf.modules.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/nova\", \"owner\": \"nova:nova\", \"recurse\": true}]}}, \"docker_config\": {\"step_2\": {\"get_attr\": [\"NovaMetadataLogging\", \"docker_config\", \"step_2\"]}, \"step_4\": {\"nova_metadata\": {\"start_order\": 2, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaMetadataImage\"]}, \"net\": \"host\", \"user\": \"root\", \"restart\": \"always\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"NovaMetadataLogging\", \"volumes\"]}, [\"/var/lib/kolla/config_files/nova_metadata.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/nova_metadata:/var/lib/kolla/config_files/src:ro\"], {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [\"/etc/pki/tls/certs/httpd:/etc/pki/tls/certs/httpd:ro\", \"/etc/pki/tls/private/httpd:/etc/pki/tls/private/httpd:ro\"]]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"deploy_steps_tasks\": {\"list_concat\": [{\"get_attr\": [\"ApacheServiceBase\", \"role_data\", \"deploy_steps_tasks\"]}, [{\"name\": \"validate nova-metadata container state\", \"containers.podman.podman_container_info\": {\"name\": \"nova_metadata\"}, \"register\": \"nova_metadata_infos\", \"failed_when\": [\"nova_metadata_infos.containers.0.Healthcheck.Status is defined\", \"\'healthy\' not in nova_metadata_infos.containers.0.Healthcheck.Status\"], \"retries\": 10, \"delay\": 30, \"tags\": [\"opendev-validation\", \"opendev-validation-nova\"], \"when\": [\"container_cli == \'podman\'\", \"not container_healthcheck_disabled\", \"step|int == 5\"]}]]}, \"host_prep_tasks\": {\"get_attr\": [\"NovaMetadataLogging\", \"host_prep_tasks\"]}, \"metadata_settings\": {\"get_attr\": [\"ApacheServiceBase\", \"role_data\", \"metadata_settings\"]}, \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop nova metadata container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"nova_metadata\"], \"tripleo_delegate_to\": \"{{ groups[\'nova_metadata\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(186,'2026-06-10 07:47:26',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Nova base service. Shared for all Nova services.\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"noop\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"NovaPassword\": {\"description\": \"The password for the nova service and db account\", \"type\": \"string\", \"hidden\": true, \"default\": \"btE80AtSdL16lZ5QqRx6f9I9L\"}, \"NeutronPassword\": {\"description\": \"The password for the neutron service and db account, used by neutron agents.\", \"type\": \"string\", \"hidden\": true, \"default\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\"}, \"PlacementPassword\": {\"description\": \"The password for the Placement service and db account\", \"type\": \"string\", \"hidden\": true, \"default\": \"LmdoVblRSfwmhsbe1og9276Oe\"}, \"PlacementAPIInterface\": {\"type\": \"string\", \"description\": \"Endpoint interface to be used for the placement API.\\n\", \"default\": \"internal\"}, \"NovaOVSBridge\": {\"default\": \"br-int\", \"description\": \"Name of integration bridge used by Open vSwitch\", \"type\": \"string\"}, \"Debug\": {\"type\": \"boolean\", \"default\": true, \"description\": \"Set to True to enable debugging on all services.\"}, \"NovaDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Nova services.\", \"type\": \"boolean\"}, \"EnableCache\": {\"description\": \"Enable caching with memcached\", \"type\": \"boolean\", \"default\": true}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}, \"EnableConfigPurge\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Remove configuration that is not generated by TripleO. Used to avoid configuration remnants after upgrades.\\n\"}, \"UpgradeLevelNovaCompute\": {\"type\": \"string\", \"description\": \"Nova Compute upgrade level\", \"default\": \"\"}, \"NovaOVSDBConnection\": {\"type\": \"string\", \"description\": \"OVS DB connection string to used by Nova\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"NovaSyncPowerStateInterval\": {\"type\": \"number\", \"description\": \"Interval to sync power states between the database and the hypervisor. Set to -1 to disable. Setting this to 0 will run at the default rate(60) defined in oslo.service.\", \"default\": 600}, \"RpcUseSSL\": {\"default\": false, \"description\": \"Messaging client subscriber parameter to specify an SSL connection to the messaging host.\\n\", \"type\": \"string\"}, \"NovaAdditionalCell\": {\"default\": false, \"description\": \"Whether this is an cell additional to the default cell.\", \"type\": \"boolean\"}, \"NovaCrossAZAttach\": {\"default\": true, \"description\": \"Whether instances can attach cinder volumes from a different availability zone.\", \"type\": \"boolean\"}, \"MemcachedTLS\": {\"default\": false, \"description\": \"Set to True to enable TLS on Memcached service. Because not all services support Memcached TLS, during the migration period, Memcached will listen on 2 ports - on the port set with MemcachedPort parameter (above) and on 11211, without TLS.\", \"type\": \"boolean\"}}, \"conditions\": {\"compute_upgrade_level_set\": {\"not\": {\"equals\": [{\"get_param\": \"UpgradeLevelNovaCompute\"}, \"\"]}}, \"tls_cache_enabled\": {\"and\": [{\"get_param\": \"EnableCache\"}, {\"get_param\": \"MemcachedTLS\"}]}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"nova::ovsdb_connection\": \"NovaOVSDBConnection\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"NovaOVSDBConnection\": {\"get_param\": \"NovaOVSDBConnection\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Nova base service.\", \"value\": {\"service_name\": \"nova_base\", \"config_settings\": {\"map_merge\": [{\"nova::my_ip\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}}}, \"nova::rabbit_use_ssl\": {\"get_param\": \"RpcUseSSL\"}, \"nova::keystone::service_user::send_service_user_token\": true, \"nova::keystone::service_user::project_name\": \"service\", \"nova::keystone::service_user::password\": {\"get_param\": \"NovaPassword\"}, \"nova::keystone::service_user::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"nova::keystone::service_user::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"nova::placement::project_name\": \"service\", \"nova::placement::password\": {\"get_param\": \"PlacementPassword\"}, \"nova::placement::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"nova::placement::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"nova::placement::valid_interfaces\": {\"get_param\": \"PlacementAPIInterface\"}, \"nova::os_region_name\": {\"get_param\": \"KeystoneRegion\"}, \"nova::logging::debug\": {\"if\": [{\"get_param\": \"NovaDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"nova::purge_config\": {\"get_param\": \"EnableConfigPurge\"}, \"nova::network::neutron::project_name\": \"service\", \"nova::network::neutron::username\": \"neutron\", \"nova::network::neutron::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"nova::dhcp_domain\": \"\", \"nova::network::neutron::password\": {\"get_param\": \"NeutronPassword\"}, \"nova::network::neutron::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneV3Internal\", \"uri\"]}, \"nova::network::neutron::valid_interfaces\": \"internal\", \"nova::glance::valid_interfaces\": \"internal\", \"nova::rabbit_heartbeat_timeout_threshold\": 60, \"nova::cinder_catalog_info\": \"volumev3:cinderv3:internalURL\", \"nova::host\": \"%{hiera(\'fqdn_canonical\')}\", \"nova::notify_on_state_change\": \"vm_and_task_state\", \"nova::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"nova::notification_format\": \"unversioned\", \"nova::network::neutron::auth_type\": \"v3password\", \"nova::db::database_db_max_retries\": -1, \"nova::db::database_max_retries\": -1, \"nova::network::neutron::ovs_bridge\": {\"get_param\": \"NovaOVSBridge\"}, \"nova::compute::sync_power_state_interval\": {\"get_param\": \"NovaSyncPowerStateInterval\"}, \"nova_is_additional_cell\": {\"get_param\": \"NovaAdditionalCell\"}, \"nova::cross_az_attach\": {\"get_param\": \"NovaCrossAZAttach\"}, \"nova::cache::enabled\": {\"get_param\": \"EnableCache\"}, \"nova::cache::tls_enabled\": {\"get_param\": \"MemcachedTLS\"}, \"nova::cache::backend\": {\"if\": [\"tls_cache_enabled\", \"dogpile.cache.pymemcache\", \"dogpile.cache.memcached\"]}, \"nova::rabbit_heartbeat_in_pthread\": false, \"nova::upgrade_level_compute\": {\"if\": [\"compute_upgrade_level_set\", {\"get_param\": \"UpgradeLevelNovaCompute\"}]}}, {\"get_attr\": [\"RoleParametersValue\", \"value\"]}]}, \"service_config_settings\": {\"rabbitmq\": {\"nova::rabbit_use_ssl\": {\"get_param\": \"RpcUseSSL\"}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(187,'2026-06-10 07:47:26',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Manila Share service\\n\", \"parameters\": {\"ContainerManilaShareImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\"}, \"ContainerManilaConfigImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ManilaCephClientUserName\": {\"default\": \"manila\", \"type\": \"string\"}, \"CephClusterName\": {\"type\": \"string\", \"default\": \"ceph\", \"description\": \"The Ceph cluster name.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9]+\", \"description\": \"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\n\"}]}, \"CephConfigPath\": {\"type\": \"string\", \"default\": \"/var/lib/tripleo-config/ceph\", \"description\": \"The path where the Ceph Cluster config files are stored on the host.\\n\"}, \"MonitoringSubscriptionManilaShare\": {\"default\": \"overcloud-manila-share\", \"type\": \"string\"}, \"ManilaPassword\": {\"description\": \"The password for the manila service account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"KqSyIJe4bogoBLLwnLhZJDRFk\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MySQLClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\"}, \"ManilaBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-base.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"ManilaShareCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-common.yaml\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerManilaShareImage\": \"ContainerManilaShareImage\", \"ContainerManilaConfigImage\": \"ContainerManilaConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerManilaShareImage\": {\"get_param\": \"ContainerManilaShareImage\"}, \"ContainerManilaConfigImage\": {\"get_param\": \"ContainerManilaConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Manila Share role.\", \"value\": {\"service_name\": \"manila_share\", \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionManilaShare\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"ManilaBase\", \"role_data\", \"config_settings\"]}, {\"manila::keystone::authtoken::password\": {\"get_param\": \"ManilaPassword\"}, \"manila::keystone::authtoken::www_authenticate_uri\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"uri\"]}, \"manila::keystone::authtoken::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"manila::keystone::authtoken::project_name\": \"service\", \"manila::keystone::authtoken::user_domain_name\": \"Default\", \"manila::keystone::authtoken::project_domain_name\": \"Default\", \"manila::keystone::authtoken::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"manila::keystone::authtoken::interface\": \"internal\", \"manila::compute::nova::username\": \"manila\", \"manila::compute::nova::password\": {\"get_param\": \"ManilaPassword\"}, \"manila::compute::nova::auth_type\": \"password\", \"manila::compute::nova::project_name\": \"service\", \"manila::compute::nova::user_domain_name\": \"Default\", \"manila::compute::nova::project_domain_name\": \"Default\", \"manila::compute::nova::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"manila::compute::nova::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"manila::network::neutron::username\": \"manila\", \"manila::network::neutron::password\": {\"get_param\": \"ManilaPassword\"}, \"manila::network::neutron::auth_type\": \"password\", \"manila::network::neutron::project_name\": \"service\", \"manila::network::neutron::user_domain_name\": \"Default\", \"manila::network::neutron::project_domain_name\": \"Default\", \"manila::network::neutron::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"manila::network::neutron::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"manila::volume::cinder::username\": \"manila\", \"manila::volume::cinder::password\": {\"get_param\": \"ManilaPassword\"}, \"manila::volume::cinder::auth_type\": \"password\", \"manila::volume::cinder::project_name\": \"service\", \"manila::volume::cinder::user_domain_name\": \"Default\", \"manila::volume::cinder::project_domain_name\": \"Default\", \"manila::volume::cinder::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"manila::volume::cinder::region_name\": {\"get_param\": \"KeystoneRegion\"}}]}, \"service_config_settings\": {\"get_attr\": [\"ManilaBase\", \"role_data\", \"service_config_settings\"]}, \"puppet_config\": {\"config_volume\": \"manila\", \"puppet_tags\": \"manila_config,file,concat,file_line\", \"step_config\": {\"list_join\": [\"\\n\", [\"include tripleo::profile::base::manila::share\", {\"get_attr\": [\"MySQLClient\", \"role_data\", \"step_config\"]}]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerManilaConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/manila_share.json\": {\"command\": \"/usr/bin/manila-share --config-file /usr/share/manila/manila-dist.conf --config-file /etc/manila/manila.conf\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-ceph/\", \"dest\": \"/etc/ceph/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/manila\", \"owner\": \"manila:manila\", \"recurse\": true}, {\"path\": \"/var/lib/manila\", \"owner\": \"manila:manila\", \"recurse\": true}, {\"path\": {\"str_replace\": {\"template\": \"/etc/ceph/CLUSTER.client.USER.keyring\", \"params\": {\"CLUSTER\": {\"get_param\": \"CephClusterName\"}, \"USER\": {\"get_param\": \"ManilaCephClientUserName\"}}}}, \"owner\": \"manila:manila\", \"perm\": \"0600\"}]}}, \"docker_config\": {\"step_4\": {\"manila_share\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerManilaShareImage\"]}, \"net\": \"host\", \"ipc\": \"host\", \"user\": \"root\", \"restart\": \"always\", \"volumes\": {\"get_attr\": [\"ManilaShareCommon\", \"manila_share_volumes\"]}, \"environment\": {\"get_attr\": [\"ManilaShareCommon\", \"manila_share_environment\"]}}}}, \"host_prep_tasks\": [{\"name\": \"create fcontext entry for manila data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/manila(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/manila\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/manila\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param:CephConfigPath\": null}, \"state\": \"directory\"}}], \"upgrade_tasks\": [], \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop manila share container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"manila_share\"], \"tripleo_delegate_to\": \"{{ groups[\'manila_share\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(188,'2026-06-10 07:47:26',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(189,'2026-06-10 07:47:27',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Nova Scheduler service\\n\", \"parameters\": {\"ContainerNovaSchedulerImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\"}, \"ContainerNovaConfigImage\": {\"description\": \"The container image to use for the nova config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\"}, \"NovaSchedulerLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.nova.scheduler\", \"file\": \"/var/log/containers/nova/nova-scheduler.log\"}}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"NovaSchedulerAvailableFilters\": {\"default\": [], \"description\": \"List of scheduler available filters\", \"type\": \"comma_delimited_list\"}, \"NovaSchedulerEnabledFilters\": {\"type\": \"comma_delimited_list\", \"default\": [], \"description\": \"An array of filters used by Nova to filter a node. These filters will be applied in the order they are listed, so place your most restrictive filters first to make the filtering process more efficient.\\n\"}, \"NovaSchedulerMaxAttempts\": {\"type\": \"number\", \"default\": 3, \"description\": \"Maximum number of attempts the scheduler will make when deploying the instance. You should keep it greater or equal to the number of bare metal nodes you expect to deploy at once to work around potential race conditions when scheduling.\\n\"}, \"MonitoringSubscriptionNovaScheduler\": {\"default\": \"overcloud-nova-scheduler\", \"type\": \"string\"}, \"NovaSchedulerDiscoverHostsInCellsInterval\": {\"type\": \"number\", \"default\": -1, \"description\": \"This value controls how often (in seconds) the scheduler should attempt to discover new hosts that have been added to cells. The default value of -1 disables the periodic task completely. It is recommended to set this parameter for deployments using Ironic.\\n\"}, \"NovaSchedulerWorkers\": {\"default\": 1, \"description\": \"Number of workers for Nova Scheduler services.\", \"type\": \"number\"}, \"NovaSchedulerQueryImageType\": {\"type\": \"boolean\", \"default\": true, \"description\": \"This setting causes the scheduler to ask placement only for compute hosts that support the disk_format of the image used in the request.\\n\"}, \"NovaSchedulerLimitTenantsToPlacementAggregate\": {\"default\": false, \"description\": \"This value allows to have tenant isolation with placement. It ensures hosts in tenant-isolated host aggregate and availability zones will only be available to specific set of tenants.\\n\", \"type\": \"boolean\"}, \"NovaSchedulerPlacementAggregateRequiredForTenants\": {\"default\": false, \"description\": \"This setting, when `NovaSchedulerLimitTenantsToPlacementAggregate` is true, controls whether or not a tenant with no aggregate affinity will be allowed to schedule to any available node. If aggregates are used to limit some tenants but not all, then this should be False. If all tenants should be confined via aggregate, then this should be True.\\n\", \"type\": \"boolean\"}, \"NovaSchedulerEnableIsolatedAggregateFiltering\": {\"default\": false, \"description\": \"This setting allows the scheduler to restrict hosts in aggregates based on matching required traits in the aggregate metadata and the instance flavor/image. If an aggregate is configured with a property with key trait:$TRAIT_NAME and value required, the instance flavor extra_specs and/or image metadata must also contain trait:$TRAIT_NAME=required to be eligible to be scheduled to hosts in that aggregate.\\n\", \"type\": \"boolean\"}, \"NovaSchedulerQueryPlacementForAvailabilityZone\": {\"default\": false, \"description\": \"This setting allows the scheduler to look up a host aggregate with metadata key of availability zone set to the value provided by incoming request, and request result from placement be limited to that aggregate.\\n\", \"type\": \"boolean\"}, \"NovaSchedulerQueryPlacementForRoutedNetworkAggregates\": {\"default\": false, \"description\": \"This setting allows the scheduler to verify if the requested networks or port are related to neutron routed network. This requires that the related aggregates to be reported in placement, so only hosts within the asked aggregates would be accepted.\\n\", \"type\": \"boolean\"}, \"NovaSchedulerHostSubsetSize\": {\"default\": 1, \"description\": \"Size of subset of best hosts selected by scheduler.\\n\", \"type\": \"number\"}, \"NovaSchedulerShuffleBestSameWeighedHosts\": {\"default\": false, \"description\": \"Enable spreading the instances between hosts with the same best weight.\\n\", \"type\": \"boolean\"}, \"NovaSchedulerDefaultFilters\": {\"type\": \"comma_delimited_list\", \"default\": [], \"description\": \"(DEPRECATED) An array of filters used by Nova to filter a node. These filters will be applied in the order they are listed, so place your most restrictive filters first to make the filtering process more efficient.\\n\"}}, \"conditions\": {\"nova_scheduler_workers_set\": {\"not\": {\"equals\": [{\"get_param\": \"NovaSchedulerWorkers\"}, 0]}}, \"scheduler_default_filters\": {\"not\": {\"equals\": [{\"get_param\": \"NovaSchedulerDefaultFilters\"}, []]}}, \"disabled_scheduler_enabled_filters\": {\"equals\": [{\"get_param\": \"NovaSchedulerEnabledFilters\"}, []]}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"The following parameters are deprecated and will be removed. They should not\\nbe relied on for new deployments. If you have concerns regarding deprecated\\nparameters, please contact the TripleO development team on IRC or the\\nOpenstack mailing list.\\n\", \"parameters\": [\"NovaSchedulerDefaultFilters\"]}], \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MySQLClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\"}, \"NovaLogging\": {\"type\": \"OS::TripleO::Services::Logging::NovaCommon\", \"properties\": {\"ContainerNovaImage\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaSchedulerImage\"]}, \"NovaServiceName\": \"scheduler\"}}, \"NovaBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"NovaApiDBClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-apidb-client-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"NovaDBClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-db-client-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerNovaSchedulerImage\": \"ContainerNovaSchedulerImage\", \"ContainerNovaConfigImage\": \"ContainerNovaConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerNovaSchedulerImage\": {\"get_param\": \"ContainerNovaSchedulerImage\"}, \"ContainerNovaConfigImage\": {\"get_param\": \"ContainerNovaConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Nova Scheduler service.\", \"value\": {\"service_name\": \"nova_scheduler\", \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionNovaScheduler\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"NovaBase\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"NovaApiDBClient\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"NovaDBClient\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"NovaLogging\", \"config_settings\"]}, {\"nova::scheduler::filter::scheduler_available_filters\": {\"get_param\": \"NovaSchedulerAvailableFilters\"}, \"nova::scheduler::filter::scheduler_enabled_filters\": {\"if\": [{\"and\": [\"scheduler_default_filters\", \"disabled_scheduler_enabled_filters\"]}, {\"get_param\": \"NovaSchedulerDefaultFilters\"}, {\"get_param\": \"NovaSchedulerEnabledFilters\"}]}, \"nova::scheduler::filter::scheduler_max_attempts\": {\"get_param\": \"NovaSchedulerMaxAttempts\"}, \"nova::scheduler::filter::scheduler_host_subset_size\": {\"get_param\": \"NovaSchedulerHostSubsetSize\"}, \"nova::scheduler::filter::shuffle_best_same_weighed_hosts\": {\"get_param\": \"NovaSchedulerShuffleBestSameWeighedHosts\"}, \"nova::scheduler::discover_hosts_in_cells_interval\": {\"get_param\": \"NovaSchedulerDiscoverHostsInCellsInterval\"}, \"nova::scheduler::query_placement_for_image_type_support\": {\"get_param\": \"NovaSchedulerQueryImageType\"}, \"nova::scheduler::limit_tenants_to_placement_aggregate\": {\"get_param\": \"NovaSchedulerLimitTenantsToPlacementAggregate\"}, \"nova::scheduler::placement_aggregate_required_for_tenants\": {\"get_param\": \"NovaSchedulerPlacementAggregateRequiredForTenants\"}, \"nova::scheduler::enable_isolated_aggregate_filtering\": {\"get_param\": \"NovaSchedulerEnableIsolatedAggregateFiltering\"}, \"nova::scheduler::query_placement_for_availability_zone\": {\"get_param\": \"NovaSchedulerQueryPlacementForAvailabilityZone\"}, \"nova::scheduler::query_placement_for_routed_network_aggregates\": {\"get_param\": \"NovaSchedulerQueryPlacementForRoutedNetworkAggregates\"}, \"nova::scheduler::workers\": {\"if\": [\"nova_scheduler_workers_set\", {\"get_param\": \"NovaSchedulerWorkers\"}]}}]}, \"service_config_settings\": {\"rabbitmq\": {\"get_attr\": [\"NovaBase\", \"role_data\", \"service_config_settings\"], \"rabbitmq\": null}, \"mysql\": {\"map_merge\": [{\"get_attr\": [\"NovaApiDBClient\", \"role_data\", \"service_config_settings\", \"mysql\"]}, {\"get_attr\": [\"NovaDBClient\", \"role_data\", \"service_config_settings\", \"mysql\"]}]}, \"rsyslog\": {\"tripleo_logging_sources_nova_scheduler\": [{\"get_param\": \"NovaSchedulerLoggingSource\"}]}}, \"puppet_config\": {\"config_volume\": \"nova\", \"puppet_tags\": \"nova_config\", \"step_config\": {\"list_join\": [\"\\n\", [\"include tripleo::profile::base::nova::scheduler\", {\"get_attr\": [\"MySQLClient\", \"role_data\", \"step_config\"]}]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/nova_scheduler.json\": {\"command\": {\"list_join\": [\" \", [\"/usr/bin/nova-scheduler\", {\"get_attr\": [\"NovaLogging\", \"cmd_extra_args\"]}]]}, \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/nova\", \"owner\": \"nova:nova\", \"recurse\": true}]}}, \"docker_config\": {\"step_4\": {\"nova_scheduler\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaSchedulerImage\"]}, \"net\": \"host\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"get_attr\": [\"ContainersCommon\", \"healthcheck_rpc_port\"]}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"NovaLogging\", \"volumes\"]}, [\"/var/lib/kolla/config_files/nova_scheduler.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/nova:/var/lib/kolla/config_files/src:ro\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"deploy_steps_tasks\": [{\"name\": \"validate nova-scheduler container state\", \"containers.podman.podman_container_info\": {\"name\": \"nova_scheduler\"}, \"register\": \"nova_scheduler_infos\", \"failed_when\": [\"nova_scheduler_infos.containers.0.Healthcheck.Status is defined\", \"\'healthy\' not in nova_scheduler_infos.containers.0.Healthcheck.Status\"], \"retries\": 10, \"delay\": 30, \"tags\": [\"opendev-validation\", \"opendev-validation-nova\"], \"when\": [\"container_cli == \'podman\'\", \"not container_healthcheck_disabled\", \"step|int == 5\"]}], \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"NovaLogging\", \"host_prep_tasks\"]}, [{\"name\": \"enable virt_sandbox_use_netlink for healthcheck\", \"seboolean\": {\"name\": \"virt_sandbox_use_netlink\", \"persistent\": true, \"state\": true}, \"when\": [\"ansible_facts.selinux is defined\", \"ansible_facts.selinux.status == \\\"enabled\\\"\"]}]]}, \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop nova scheduler container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"nova_scheduler\"], \"tripleo_delegate_to\": \"{{ groups[\'nova_scheduler\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(190,'2026-06-10 07:47:27',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(191,'2026-06-10 07:47:27',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Nova base service. Shared for all Nova services.\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"noop\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"NovaPassword\": {\"description\": \"The password for the nova service and db account\", \"type\": \"string\", \"hidden\": true, \"default\": \"btE80AtSdL16lZ5QqRx6f9I9L\"}, \"NeutronPassword\": {\"description\": \"The password for the neutron service and db account, used by neutron agents.\", \"type\": \"string\", \"hidden\": true, \"default\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\"}, \"PlacementPassword\": {\"description\": \"The password for the Placement service and db account\", \"type\": \"string\", \"hidden\": true, \"default\": \"LmdoVblRSfwmhsbe1og9276Oe\"}, \"PlacementAPIInterface\": {\"type\": \"string\", \"description\": \"Endpoint interface to be used for the placement API.\\n\", \"default\": \"internal\"}, \"NovaOVSBridge\": {\"default\": \"br-int\", \"description\": \"Name of integration bridge used by Open vSwitch\", \"type\": \"string\"}, \"Debug\": {\"type\": \"boolean\", \"default\": true, \"description\": \"Set to True to enable debugging on all services.\"}, \"NovaDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Nova services.\", \"type\": \"boolean\"}, \"EnableCache\": {\"description\": \"Enable caching with memcached\", \"type\": \"boolean\", \"default\": true}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}, \"EnableConfigPurge\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Remove configuration that is not generated by TripleO. Used to avoid configuration remnants after upgrades.\\n\"}, \"UpgradeLevelNovaCompute\": {\"type\": \"string\", \"description\": \"Nova Compute upgrade level\", \"default\": \"\"}, \"NovaOVSDBConnection\": {\"type\": \"string\", \"description\": \"OVS DB connection string to used by Nova\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"NovaSyncPowerStateInterval\": {\"type\": \"number\", \"description\": \"Interval to sync power states between the database and the hypervisor. Set to -1 to disable. Setting this to 0 will run at the default rate(60) defined in oslo.service.\", \"default\": 600}, \"RpcUseSSL\": {\"default\": false, \"description\": \"Messaging client subscriber parameter to specify an SSL connection to the messaging host.\\n\", \"type\": \"string\"}, \"NovaAdditionalCell\": {\"default\": false, \"description\": \"Whether this is an cell additional to the default cell.\", \"type\": \"boolean\"}, \"NovaCrossAZAttach\": {\"default\": true, \"description\": \"Whether instances can attach cinder volumes from a different availability zone.\", \"type\": \"boolean\"}, \"MemcachedTLS\": {\"default\": false, \"description\": \"Set to True to enable TLS on Memcached service. Because not all services support Memcached TLS, during the migration period, Memcached will listen on 2 ports - on the port set with MemcachedPort parameter (above) and on 11211, without TLS.\", \"type\": \"boolean\"}}, \"conditions\": {\"compute_upgrade_level_set\": {\"not\": {\"equals\": [{\"get_param\": \"UpgradeLevelNovaCompute\"}, \"\"]}}, \"tls_cache_enabled\": {\"and\": [{\"get_param\": \"EnableCache\"}, {\"get_param\": \"MemcachedTLS\"}]}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"nova::ovsdb_connection\": \"NovaOVSDBConnection\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"NovaOVSDBConnection\": {\"get_param\": \"NovaOVSDBConnection\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Nova base service.\", \"value\": {\"service_name\": \"nova_base\", \"config_settings\": {\"map_merge\": [{\"nova::my_ip\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}}}, \"nova::rabbit_use_ssl\": {\"get_param\": \"RpcUseSSL\"}, \"nova::keystone::service_user::send_service_user_token\": true, \"nova::keystone::service_user::project_name\": \"service\", \"nova::keystone::service_user::password\": {\"get_param\": \"NovaPassword\"}, \"nova::keystone::service_user::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"nova::keystone::service_user::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"nova::placement::project_name\": \"service\", \"nova::placement::password\": {\"get_param\": \"PlacementPassword\"}, \"nova::placement::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"nova::placement::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"nova::placement::valid_interfaces\": {\"get_param\": \"PlacementAPIInterface\"}, \"nova::os_region_name\": {\"get_param\": \"KeystoneRegion\"}, \"nova::logging::debug\": {\"if\": [{\"get_param\": \"NovaDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"nova::purge_config\": {\"get_param\": \"EnableConfigPurge\"}, \"nova::network::neutron::project_name\": \"service\", \"nova::network::neutron::username\": \"neutron\", \"nova::network::neutron::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"nova::dhcp_domain\": \"\", \"nova::network::neutron::password\": {\"get_param\": \"NeutronPassword\"}, \"nova::network::neutron::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneV3Internal\", \"uri\"]}, \"nova::network::neutron::valid_interfaces\": \"internal\", \"nova::glance::valid_interfaces\": \"internal\", \"nova::rabbit_heartbeat_timeout_threshold\": 60, \"nova::cinder_catalog_info\": \"volumev3:cinderv3:internalURL\", \"nova::host\": \"%{hiera(\'fqdn_canonical\')}\", \"nova::notify_on_state_change\": \"vm_and_task_state\", \"nova::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"nova::notification_format\": \"unversioned\", \"nova::network::neutron::auth_type\": \"v3password\", \"nova::db::database_db_max_retries\": -1, \"nova::db::database_max_retries\": -1, \"nova::network::neutron::ovs_bridge\": {\"get_param\": \"NovaOVSBridge\"}, \"nova::compute::sync_power_state_interval\": {\"get_param\": \"NovaSyncPowerStateInterval\"}, \"nova_is_additional_cell\": {\"get_param\": \"NovaAdditionalCell\"}, \"nova::cross_az_attach\": {\"get_param\": \"NovaCrossAZAttach\"}, \"nova::cache::enabled\": {\"get_param\": \"EnableCache\"}, \"nova::cache::tls_enabled\": {\"get_param\": \"MemcachedTLS\"}, \"nova::cache::backend\": {\"if\": [\"tls_cache_enabled\", \"dogpile.cache.pymemcache\", \"dogpile.cache.memcached\"]}, \"nova::rabbit_heartbeat_in_pthread\": false, \"nova::upgrade_level_compute\": {\"if\": [\"compute_upgrade_level_set\", {\"get_param\": \"UpgradeLevelNovaCompute\"}]}}, {\"get_attr\": [\"RoleParametersValue\", \"value\"]}]}, \"service_config_settings\": {\"rabbitmq\": {\"nova::rabbit_use_ssl\": {\"get_param\": \"RpcUseSSL\"}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(192,'2026-06-10 07:47:27',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(193,'2026-06-10 07:47:28',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Nova database client service.\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"NovaPassword\": {\"description\": \"The password for the nova service and db account\", \"type\": \"string\", \"hidden\": true, \"default\": \"btE80AtSdL16lZ5QqRx6f9I9L\"}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Nova base service.\", \"value\": {\"config_settings\": {\"nova::api_database_connection\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"protocol\"]}, \"username\": \"nova_api\", \"password\": {\"get_param\": \"NovaPassword\"}, \"host\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"host\"]}, \"path\": \"/nova_api\", \"query\": {\"if\": [{\"get_param\": \"EnableSQLAlchemyCollectd\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\", \"plugin\": \"collectd\", \"collectd_program_name\": \"nova_api\", \"collectd_host\": \"localhost\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\"}]}}}}, \"service_config_settings\": {\"mysql\": {\"nova::db::mysql_api::password\": {\"get_param\": \"NovaPassword\"}, \"nova::db::mysql_api::user\": \"nova_api\", \"nova::db::mysql_api::host\": \"%\", \"nova::db::mysql_api::dbname\": \"nova_api\"}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(194,'2026-06-10 07:47:28',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Template for nova\'s logging to files\\n\", \"parameters\": {\"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ContainerNovaImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"]}, \"NovaServiceName\": {\"description\": \"service name\", \"type\": \"string\"}, \"DeployIdentifier\": {\"default\": 1781077560, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}}, \"resources\": {\"InitLogContainerName\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"string\", \"value\": {\"str_replace\": {\"template\": \"nova_SERVICE_init_log\", \"params\": {\"SERVICE\": {\"get_param\": \"NovaServiceName\"}}}}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerNovaImage\": \"ContainerNovaImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerNovaImage\": {\"get_param\": \"ContainerNovaImage\"}}}]}}}}, \"outputs\": {\"cmd_extra_args\": {\"description\": \"Extra command line arguments for running the service in the container.\", \"value\": \"\"}, \"config_settings\": {\"description\": \"Extra hieradata needed to log to files in the host.\", \"value\": null}, \"volumes\": {\"description\": \"The volumes needed to log to files in the host.\", \"value\": [\"/var/log/containers/nova:/var/log/nova\"]}, \"docker_config\": {\"description\": \"Extra containers needed for logging to files in the host.\", \"value\": {\"step_2\": {\"map_replace\": [{\"CONTAINERNAME\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaImage\"]}, \"net\": \"none\", \"privileged\": false, \"user\": \"root\", \"volumes\": [\"/var/log/containers/nova:/var/log/nova:z\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R nova:nova /var/log/nova\"], \"environment\": {\"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}}}}, {\"keys\": {\"CONTAINERNAME\": {\"get_attr\": [\"InitLogContainerName\", \"value\"]}}}]}}}, \"host_prep_tasks\": {\"description\": \"Extra ansible tasks needed for logging to files in the host.\", \"value\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"setype\": \"{{ item.setype }}\", \"state\": \"directory\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/nova\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}]}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ContainerNovaImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"NovaServiceName\": \"scheduler\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (195,'2026-06-10 07:47:28',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mysql client settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role for setting mysql client parameters\", \"value\": {\"service_name\": \"mysql_client\", \"config_settings\": {\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"tripleo::profile::base::database::mysql::client::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}}, \"step_config\": \"include tripleo::profile::base::database::mysql::client\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(196,'2026-06-10 07:47:29',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Nova API service\\n\", \"parameters\": {\"ContainerNovaApiImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\"}, \"ContainerNovaConfigImage\": {\"description\": \"The container image to use for the nova config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\"}, \"NovaApiLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.nova.api\", \"file\": \"/var/log/containers/nova/nova-api.log\"}}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"DeployIdentifier\": {\"default\": 1781077560, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"NovaPassword\": {\"description\": \"The password for the nova service and db account\", \"type\": \"string\", \"hidden\": true, \"default\": \"btE80AtSdL16lZ5QqRx6f9I9L\"}, \"MysqlIPv6\": {\"default\": false, \"description\": \"Enable IPv6 in MySQL\", \"type\": \"boolean\"}, \"NovaWorkers\": {\"default\": 1, \"description\": \"Number of workers for Nova services.\", \"type\": \"number\"}, \"EnforceSecureRbac\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Setting this option to True will configure each OpenStack service to enforce Secure RBAC by setting `[oslo_policy] enforce_new_defaults` and `[oslo_policy] enforce_scope` to True. This introduces a consistent set of RBAC personas across OpenStack services that include support for system and project scope, as well as keystone\'s default roles, admin, member, and reader. Do not enable this functionality until all services in your deployment actually support secure RBAC.\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"InstanceNameTemplate\": {\"default\": \"instance-%08x\", \"description\": \"Template string to be used to generate instance names\", \"type\": \"string\"}, \"NovaEnableDBPurge\": {\"default\": true, \"description\": \"Whether to create cron job for purging soft deleted rows in Nova database.\\n\", \"type\": \"boolean\"}, \"NovaEnableDBArchive\": {\"default\": true, \"description\": \"Whether to create cron job for archiving soft deleted rows in Nova database.\\n\", \"type\": \"boolean\"}, \"MonitoringSubscriptionNovaApi\": {\"default\": \"overcloud-nova-api\", \"type\": \"string\"}, \"NovaDefaultFloatingPool\": {\"default\": \"public\", \"description\": \"Default pool for floating IP addresses\", \"type\": \"string\"}, \"NovaApiPolicies\": {\"description\": \"A hash of policies to configure for Nova API.\\ne.g. { nova-context_is_admin: { key: context_is_admin, value: \'role:admin\' } }\\n\", \"default\": {}, \"type\": \"json\"}, \"NovaAllowResizeToSameHost\": {\"default\": false, \"description\": \"Allow destination machine to match source for resize.\", \"type\": \"boolean\"}, \"NovaApiMaxLimit\": {\"default\": 1000, \"description\": \"Max number of objects returned per API query\", \"type\": \"number\"}, \"NovaCronPurgeShadowTablesMinute\": {\"type\": \"string\", \"description\": \"Cron to purge shadow tables - Minute\\n\", \"default\": \"0\"}, \"NovaCronPurgeShadowTablesHour\": {\"type\": \"string\", \"description\": \"Cron to purge shadow tables - Hour\\n\", \"default\": \"5\"}, \"NovaCronPurgeShadowTablesMonthday\": {\"type\": \"string\", \"description\": \"Cron to purge shadow tables - Month Day\\n\", \"default\": \"*\"}, \"NovaCronPurgeShadowTablesMonth\": {\"type\": \"string\", \"description\": \"Cron to purge shadow tables - Month\\n\", \"default\": \"*\"}, \"NovaCronPurgeShadowTablesWeekday\": {\"type\": \"string\", \"description\": \"Cron to purge shadow tables - Week Day\\n\", \"default\": \"*\"}, \"NovaCronPurgeShadowTablesUser\": {\"type\": \"string\", \"description\": \"Cron to purge shadow tables - User\\n\", \"default\": \"nova\"}, \"NovaCronPurgeShadowTablesDestination\": {\"type\": \"string\", \"description\": \"Cron to purge shadow tables - Log destination\\n\", \"default\": \"/var/log/nova/nova-rowspurge.log\"}, \"NovaCronPurgeShadowTablesMaxDelay\": {\"type\": \"string\", \"description\": \"Cron to purge shadow tables - Max Delay\\n\", \"default\": \"3600\"}, \"NovaCronPurgeShadowTablesAge\": {\"type\": \"number\", \"description\": \"Cron to purge shadow tables - Age This will define the retention policy when purging the shadow tables in days. 0 means, purge data older than today in shadow tables.\\n\", \"default\": 14}, \"NovaCronPurgeShadowTablesVerbose\": {\"type\": \"boolean\", \"description\": \"Cron to purge shadow tables - Verbose\\n\", \"default\": false}, \"NovaCronPurgeShadowTablesAllCells\": {\"type\": \"boolean\", \"description\": \"Cron to purge shadow tables - All cells\\n\", \"default\": true}, \"NovaCronArchiveDeleteRowsMinute\": {\"type\": \"string\", \"description\": \"Cron to move deleted instances to another table - Minute\\n\", \"default\": \"1\"}, \"NovaCronArchiveDeleteRowsHour\": {\"type\": \"string\", \"description\": \"Cron to move deleted instances to another table - Hour\\n\", \"default\": \"0\"}, \"NovaCronArchiveDeleteRowsMonthday\": {\"type\": \"string\", \"description\": \"Cron to move deleted instances to another table - Month Day\\n\", \"default\": \"*\"}, \"NovaCronArchiveDeleteRowsMonth\": {\"type\": \"string\", \"description\": \"Cron to move deleted instances to another table - Month\\n\", \"default\": \"*\"}, \"NovaCronArchiveDeleteRowsWeekday\": {\"type\": \"string\", \"description\": \"Cron to move deleted instances to another table - Week Day\\n\", \"default\": \"*\"}, \"NovaCronArchiveDeleteRowsMaxRows\": {\"type\": \"string\", \"description\": \"Cron to move deleted instances to another table - Max Rows\\n\", \"default\": \"1000\"}, \"NovaCronArchiveDeleteRowsUser\": {\"type\": \"string\", \"description\": \"Cron to move deleted instances to another table - User\\n\", \"default\": \"nova\"}, \"NovaCronArchiveDeleteRowsDestination\": {\"type\": \"string\", \"description\": \"Cron to move deleted instances to another table - Log destination\\n\", \"default\": \"/var/log/nova/nova-rowsflush.log\"}, \"NovaCronArchiveDeleteRowsMaxDelay\": {\"type\": \"string\", \"description\": \"Cron to move deleted instances to another table - Max Delay\\n\", \"default\": \"3600\"}, \"NovaCronArchiveDeleteRowsUntilComplete\": {\"type\": \"boolean\", \"description\": \"Cron to move deleted instances to another table - Until complete\\n\", \"default\": true}, \"NovaCronArchiveDeleteRowsPurge\": {\"type\": \"boolean\", \"description\": \"Purge shadow tables immediately after scheduled archiving\\n\", \"default\": false}, \"NovaCronArchiveDeleteAllCells\": {\"type\": \"boolean\", \"description\": \"Archive deleted instances from all cells\\n\", \"default\": true}, \"NovaCronArchiveDeleteRowsAge\": {\"type\": \"number\", \"description\": \"Cron to archive deleted instances - Age This will define the retention policy when archiving the deleted instances entries in days. 0 means, purge data older than today in shadow tables.\\n\", \"default\": 90}, \"MemcacheUseAdvancedPool\": {\"type\": \"boolean\", \"description\": \"Use the advanced (eventlet safe) memcached client pool.\\n\", \"default\": true}, \"NovaShowHostStatus\": {\"type\": \"string\", \"description\": \"Allow overriding API policies to access the compute host status in the\\nrequested Nova server details. The default value \'hidden\' allows only admins to\\naccess it. Setting it to \'all\' (\'unknown-only\') without additional fine-grained\\ntuning of NovaApiHostStatusPolicy shows the full (limited) host_status\\nto the system/project readers.\\n\", \"default\": \"hidden\", \"constraints\": [{\"allowed_values\": [\"all\", \"unknown-only\", \"hidden\"]}]}, \"NovaApiHostStatusPolicy\": {\"description\": \"A custom API policy for os_compute_api:servers:show:host_status and\\nos_compute_api:servers:show:host_status:unknown-only.\\nThese rules, or roles, replace the admins-only policies based on the given\\nNovaShowHostStatus: \'unknown-only\' shows the limited host status UNKNOWN\\nwhenever a heartbeat was not received within the configured threshold, and\\n\'all\' also reveals UP, DOWN, or MAINTENANCE statuses in the Nova server\\ndetails. NovaShowHostStatus \'hidden\' puts it back being visible only for admins.\\nAdditional policies specified using NovaApiPolicies get merged with this\\npolicy.\\n\", \"default\": \"role:reader\", \"type\": \"string\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"The following parameters are deprecated and will be removed. They should not\\nbe relied on for new deployments. If you have concerns regarding deprecated\\nparameters, please contact the TripleO development team on IRC or the\\nOpenStack mailing list.\\n\", \"parameters\": [\"MysqlIPv6\"]}], \"conditions\": {\"mysql_ipv6_use_ip_address\": {\"and\": [{\"equals\": [{\"get_param\": [\"ServiceData\", \"net_ip_version_map\", {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}]}, 6]}, {\"not\": {\"get_param\": \"EnableInternalTLS\"}}]}, \"nova_workers_set\": {\"not\": {\"equals\": [{\"get_param\": \"NovaWorkers\"}, 0]}}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MySQLClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\"}, \"NovaApiLogging\": {\"type\": \"OS::TripleO::Services::Logging::NovaApi\"}, \"ApacheServiceBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}, \"EnableInternalTLS\": {\"get_param\": \"EnableInternalTLS\"}}}, \"NovaBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"NovaApiDBClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-apidb-client-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"NovaDBClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-db-client-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerNovaApiImage\": \"ContainerNovaApiImage\", \"ContainerNovaConfigImage\": \"ContainerNovaConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerNovaApiImage\": {\"get_param\": \"ContainerNovaApiImage\"}, \"ContainerNovaConfigImage\": {\"get_param\": \"ContainerNovaConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Nova API role.\", \"value\": {\"service_name\": \"nova_api\", \"firewall_rules\": {\"113 nova_api\": {\"dport\": [8774]}}, \"firewall_frontend_rules\": {\"100 nova_osapi_haproxy_frontend\": {\"dport\": [8774]}}, \"firewall_ssl_frontend_rules\": {\"100 nova_osapi_haproxy_frontend_ssl\": {\"dport\": [13774]}}, \"keystone_resources\": {\"nova\": {\"endpoints\": {\"public\": {\"get_param\": [\"EndpointMap\", \"NovaPublic\", \"uri\"]}, \"internal\": {\"get_param\": [\"EndpointMap\", \"NovaInternal\", \"uri\"]}, \"admin\": {\"get_param\": [\"EndpointMap\", \"NovaAdmin\", \"uri\"]}}, \"users\": {\"nova\": {\"roles\": [\"admin\", \"service\"], \"password\": {\"get_param\": \"NovaPassword\"}}}, \"region\": {\"get_param\": \"KeystoneRegion\"}, \"service\": \"compute\"}}, \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionNovaApi\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"NovaBase\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"NovaApiDBClient\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"NovaDBClient\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"NovaApiLogging\", \"config_settings\"]}, {\"apache::default_vhost\": false, \"nova::keystone::authtoken::project_name\": \"service\", \"nova::keystone::authtoken::user_domain_name\": \"Default\", \"nova::keystone::authtoken::project_domain_name\": \"Default\", \"nova::keystone::authtoken::password\": {\"get_param\": \"NovaPassword\"}, \"nova::keystone::authtoken::www_authenticate_uri\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"uri_no_suffix\"]}, \"nova::keystone::authtoken::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"nova::keystone::authtoken::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"nova::keystone::authtoken::interface\": \"internal\", \"nova::keystone::authtoken::memcache_use_advanced_pool\": {\"get_param\": \"MemcacheUseAdvancedPool\"}, \"nova::api::max_limit\": {\"get_param\": \"NovaApiMaxLimit\"}, \"nova::api::enabled\": true, \"nova::network::neutron::default_floating_pool\": {\"get_param\": \"NovaDefaultFloatingPool\"}, \"nova::api::enable_proxy_headers_parsing\": true, \"nova::api::api_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}}}, \"nova::api::service_name\": \"httpd\", \"nova::wsgi::apache_api::ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"nova::wsgi::apache_api::bind_host\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}}}, \"nova::wsgi::apache_api::servername\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}}}, \"nova::api::instance_name_template\": {\"get_param\": \"InstanceNameTemplate\"}, \"nova::policy::policies\": {\"map_merge\": [{\"get_param\": \"NovaApiPolicies\"}, {\"if\": [{\"equals\": [{\"get_param\": \"NovaShowHostStatus\"}, \"all\"]}, {\"nova-os_compute_api_servers_show_host_status\": {\"key\": \"os_compute_api:servers:show:host_status\", \"value\": {\"get_param\": \"NovaApiHostStatusPolicy\"}}}, {}]}, {\"if\": [{\"equals\": [{\"get_param\": \"NovaShowHostStatus\"}, \"unknown-only\"]}, {\"nova-os_compute_api_servers_show_host_status_unknown-only\": {\"key\": \"os_compute_api:servers:show:host_status:unknown-only\", \"value\": {\"get_param\": \"NovaApiHostStatusPolicy\"}}}, {}]}]}, \"nova::api::allow_resize_to_same_host\": {\"get_param\": \"NovaAllowResizeToSameHost\"}, \"nova_enable_db_purge\": {\"get_param\": \"NovaEnableDBPurge\"}, \"nova::cron::purge_shadow_tables::minute\": {\"get_param\": \"NovaCronPurgeShadowTablesMinute\"}, \"nova::cron::purge_shadow_tables::hour\": {\"get_param\": \"NovaCronPurgeShadowTablesHour\"}, \"nova::cron::purge_shadow_tables::monthday\": {\"get_param\": \"NovaCronPurgeShadowTablesMonthday\"}, \"nova::cron::purge_shadow_tables::month\": {\"get_param\": \"NovaCronPurgeShadowTablesMonth\"}, \"nova::cron::purge_shadow_tables::weekday\": {\"get_param\": \"NovaCronPurgeShadowTablesWeekday\"}, \"nova::cron::purge_shadow_tables::user\": {\"get_param\": \"NovaCronPurgeShadowTablesUser\"}, \"nova::cron::purge_shadow_tables::destination\": {\"get_param\": \"NovaCronPurgeShadowTablesDestination\"}, \"nova::cron::purge_shadow_tables::maxdelay\": {\"get_param\": \"NovaCronPurgeShadowTablesMaxDelay\"}, \"nova::cron::purge_shadow_tables::age\": {\"get_param\": \"NovaCronPurgeShadowTablesAge\"}, \"nova::cron::purge_shadow_tables::verbose\": {\"get_param\": \"NovaCronPurgeShadowTablesVerbose\"}, \"nova::cron::purge_shadow_tables::all_cells\": {\"get_param\": \"NovaCronPurgeShadowTablesAllCells\"}, \"nova_enable_db_archive\": {\"get_param\": \"NovaEnableDBArchive\"}, \"nova::cron::archive_deleted_rows::minute\": {\"get_param\": \"NovaCronArchiveDeleteRowsMinute\"}, \"nova::cron::archive_deleted_rows::hour\": {\"get_param\": \"NovaCronArchiveDeleteRowsHour\"}, \"nova::cron::archive_deleted_rows::monthday\": {\"get_param\": \"NovaCronArchiveDeleteRowsMonthday\"}, \"nova::cron::archive_deleted_rows::month\": {\"get_param\": \"NovaCronArchiveDeleteRowsMonth\"}, \"nova::cron::archive_deleted_rows::weekday\": {\"get_param\": \"NovaCronArchiveDeleteRowsWeekday\"}, \"nova::cron::archive_deleted_rows::max_rows\": {\"get_param\": \"NovaCronArchiveDeleteRowsMaxRows\"}, \"nova::cron::archive_deleted_rows::user\": {\"get_param\": \"NovaCronArchiveDeleteRowsUser\"}, \"nova::cron::archive_deleted_rows::destination\": {\"get_param\": \"NovaCronArchiveDeleteRowsDestination\"}, \"nova::cron::archive_deleted_rows::maxdelay\": {\"get_param\": \"NovaCronArchiveDeleteRowsMaxDelay\"}, \"nova::cron::archive_deleted_rows::until_complete\": {\"get_param\": \"NovaCronArchiveDeleteRowsUntilComplete\"}, \"nova::cron::archive_deleted_rows::purge\": {\"get_param\": \"NovaCronArchiveDeleteRowsPurge\"}, \"nova::cron::archive_deleted_rows::all_cells\": {\"get_param\": \"NovaCronArchiveDeleteAllCells\"}, \"nova::cron::archive_deleted_rows::age\": {\"get_param\": \"NovaCronArchiveDeleteRowsAge\"}, \"nova::policy::enforce_new_defaults\": {\"get_param\": \"EnforceSecureRbac\"}, \"nova::policy::enforce_scope\": {\"get_param\": \"EnforceSecureRbac\"}}, {\"if\": [\"nova_workers_set\", {\"nova::api::osapi_compute_workers\": {\"get_param\": \"NovaWorkers\"}, \"nova::wsgi::apache_api::workers\": {\"get_param\": \"NovaWorkers\"}}]}]}, \"service_config_settings\": {\"rabbitmq\": {\"get_attr\": [\"NovaBase\", \"role_data\", \"service_config_settings\"], \"rabbitmq\": null}, \"mysql\": {\"map_merge\": [{\"get_attr\": [\"NovaApiDBClient\", \"role_data\", \"service_config_settings\", \"mysql\"]}, {\"get_attr\": [\"NovaDBClient\", \"role_data\", \"service_config_settings\", \"mysql\"]}]}, \"rsyslog\": {\"tripleo_logging_sources_nova_api\": [{\"get_param\": \"NovaApiLoggingSource\"}]}}, \"puppet_config\": {\"config_volume\": \"nova\", \"puppet_tags\": \"nova_config,nova_api_paste_ini\", \"step_config\": {\"list_join\": [\"\\n\", [\"[\'Nova_cell_v2\'].each |String $val| { noop_resource($val) }\", \"include tripleo::profile::base::nova::api\", {\"get_attr\": [\"MySQLClient\", \"role_data\", \"step_config\"]}]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/nova_api.json\": {\"command\": \"/usr/sbin/httpd -DFOREGROUND\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.d\", \"dest\": \"/etc/httpd/conf.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.modules.d\", \"dest\": \"/etc/httpd/conf.modules.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/nova\", \"owner\": \"nova:nova\", \"recurse\": true}]}, \"/var/lib/kolla/config_files/nova_api_db_sync.json\": {\"command\": \"/usr/bin/bootstrap_host_exec nova_api su nova -s /bin/bash -c \'/usr/bin/nova-manage api_db sync\'\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.d\", \"dest\": \"/etc/httpd/conf.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.modules.d\", \"dest\": \"/etc/httpd/conf.modules.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/nova\", \"owner\": \"nova:nova\", \"recurse\": true}]}, \"/var/lib/kolla/config_files/nova_api_ensure_default_cells.json\": {\"command\": \"/usr/bin/bootstrap_host_exec nova_api su nova -s /bin/bash -c \'/container-config-scripts/pyshim.sh /container-config-scripts/nova_api_ensure_default_cells.py\'\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.d\", \"dest\": \"/etc/httpd/conf.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.modules.d\", \"dest\": \"/etc/httpd/conf.modules.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/nova\", \"owner\": \"nova:nova\", \"recurse\": true}]}, \"/var/lib/kolla/config_files/nova_api_cron.json\": {\"command\": \"/usr/sbin/crond -n\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/nova\", \"owner\": \"nova:nova\", \"recurse\": true}]}, \"/var/lib/kolla/config_files/nova_wait_for_api_service.json\": {\"command\": \"/usr/bin/bootstrap_host_exec nova_api su nova -s /bin/bash -c \'/container-config-scripts/pyshim.sh /container-config-scripts/nova_wait_for_api_service.py\'\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.d\", \"dest\": \"/etc/httpd/conf.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.modules.d\", \"dest\": \"/etc/httpd/conf.modules.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/nova\", \"owner\": \"nova:nova\", \"recurse\": true}]}}, \"container_config_scripts\": {\"map_merge\": [{\"get_attr\": [\"ContainersCommon\", \"container_config_scripts\"]}, {\"nova_wait_for_api_service.py\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/nova_wait_for_api_service.py\"}}, \"nova_api_ensure_default_cells.py\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/nova_api_ensure_default_cells.py\"}}}]}, \"docker_config\": {\"step_2\": {\"get_attr\": [\"NovaApiLogging\", \"docker_config\", \"step_2\"]}, \"step_3\": {\"nova_api_db_sync\": {\"start_order\": 0, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaApiImage\"]}, \"cap_add\": [\"AUDIT_WRITE\"], \"net\": \"host\", \"detach\": false, \"user\": \"root\", \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"NovaApiLogging\", \"volumes\"]}, [\"/var/lib/kolla/config_files/nova_api_db_sync.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/nova:/var/lib/kolla/config_files/src:ro\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\", \"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}}}, \"nova_api_ensure_default_cells\": {\"start_order\": 1, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaApiImage\"]}, \"user\": \"root\", \"net\": \"host\", \"privileged\": false, \"detach\": false, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"NovaApiLogging\", \"volumes\"]}, [\"/var/lib/kolla/config_files/nova_api_ensure_default_cells.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/nova:/var/lib/kolla/config_files/src:ro\", \"/var/lib/container-config-scripts:/container-config-scripts:z\"]]}, \"environment\": {\"__OS_DEBUG\": {\"yaql\": {\"expression\": \"str($.data.debug)\", \"data\": {\"debug\": {\"get_attr\": [\"NovaBase\", \"role_data\", \"config_settings\", \"nova::logging::debug\"]}}}}, \"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}, \"step_4\": {\"nova_api\": {\"start_order\": 2, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaApiImage\"]}, \"net\": \"host\", \"user\": \"root\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"NovaApiLogging\", \"volumes\"]}, [\"/var/lib/kolla/config_files/nova_api.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/nova:/var/lib/kolla/config_files/src:ro\"], {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [\"/etc/pki/tls/certs/httpd:/etc/pki/tls/certs/httpd:ro\", \"/etc/pki/tls/private/httpd:/etc/pki/tls/private/httpd:ro\"]]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}, \"nova_wait_for_api_service\": {\"start_order\": 3, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaApiImage\"]}, \"user\": \"root\", \"net\": \"host\", \"privileged\": false, \"detach\": false, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"NovaApiLogging\", \"volumes\"]}, [\"/var/lib/kolla/config_files/nova_wait_for_api_service.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/nova:/var/lib/kolla/config_files/src:ro\", \"/var/lib/container-config-scripts:/container-config-scripts:z\"]]}, \"environment\": {\"__OS_DEBUG\": {\"yaql\": {\"expression\": \"str($.data.debug)\", \"data\": {\"debug\": {\"get_attr\": [\"NovaBase\", \"role_data\", \"config_settings\", \"nova::logging::debug\"]}}}}, \"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}, \"nova_api_cron\": {\"start_order\": 4, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaApiImage\"]}, \"net\": \"host\", \"user\": \"root\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/usr/share/openstack-tripleo-common/healthcheck/cron nova\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"NovaApiLogging\", \"volumes\"]}, [\"/var/lib/kolla/config_files/nova_api_cron.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/nova:/var/lib/kolla/config_files/src:ro\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"metadata_settings\": {\"get_attr\": [\"ApacheServiceBase\", \"role_data\", \"metadata_settings\"]}, \"deploy_steps_tasks\": {\"list_concat\": [{\"get_attr\": [\"ApacheServiceBase\", \"role_data\", \"deploy_steps_tasks\"]}, [{\"name\": \"validate nova-api container state\", \"containers.podman.podman_container_info\": {\"name\": \"nova_api\"}, \"register\": \"nova_api_infos\", \"failed_when\": [\"nova_api_infos.containers.0.Healthcheck.Status is defined\", \"\'healthy\' not in nova_api_infos.containers.0.Healthcheck.Status\"], \"retries\": 10, \"delay\": 30, \"tags\": [\"opendev-validation\", \"opendev-validation-nova\"], \"when\": [\"container_cli == \'podman\'\", \"not container_healthcheck_disabled\", \"step|int == 4\"]}]]}, \"host_prep_tasks\": {\"get_attr\": [\"NovaApiLogging\", \"host_prep_tasks\"]}, \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop nova api container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"nova_api\", \"nova_api_cron\"], \"tripleo_delegate_to\": \"{{ groups[\'nova_api\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(197,'2026-06-10 07:47:29',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(198,'2026-06-10 07:47:29',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mysql client settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role for setting mysql client parameters\", \"value\": {\"service_name\": \"mysql_client\", \"config_settings\": {\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"tripleo::profile::base::database::mysql::client::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}}, \"step_config\": \"include tripleo::profile::base::database::mysql::client\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(199,'2026-06-10 07:47:29',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Provides the list of Docker volumes and environment to be used by the ManilaShare service. The same list is used for HA and non-HA deployments.\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ManilaCephFSCephFSProtocolHelperType\": {\"default\": \"CEPHFS\", \"description\": \"Protocol type (\'CEPHFS\' or \'NFS\') when cephfs back end is enabled.  Set via manila cephfs environment files.\", \"type\": \"string\", \"constraints\": [{\"allowed_values\": [\"CEPHFS\", \"NFS\"]}]}, \"CephConfigPath\": {\"type\": \"string\", \"default\": \"/var/lib/tripleo-config/ceph\", \"description\": \"The path where the Ceph Cluster config files are stored on the host.\\n\"}}, \"conditions\": {\"cephfs_nfs_enabled\": {\"equals\": [{\"get_param\": \"ManilaCephFSCephFSProtocolHelperType\"}, \"NFS\"]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}}, \"outputs\": {\"manila_share_volumes\": {\"description\": \"Volumes for the manila-share container (HA or non-HA)\", \"value\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/manila_share.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/manila:/var/lib/kolla/config_files/src:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/dev:/dev\", \"/run:/run\", \"/sys:/sys\", \"/lib/modules:/lib/modules:ro\", \"/var/lib/manila:/var/lib/manila:z\", \"/var/log/containers/manila:/var/log/manila:z\"], {\"if\": [\"cephfs_nfs_enabled\", [\"/etc/ganesha:/etc/ganesha\", \"/run/dbus/system_bus_socket:/run/dbus/system_bus_socket\"]]}]}}, \"manila_share_environment\": {\"description\": \"Docker environment for the manila-share container (HA or non-HA)\", \"value\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(200,'2026-06-10 07:47:30',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(201,'2026-06-10 07:47:30',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mysql client settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role for setting mysql client parameters\", \"value\": {\"service_name\": \"mysql_client\", \"config_settings\": {\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"tripleo::profile::base::database::mysql::client::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}}, \"step_config\": \"include tripleo::profile::base::database::mysql::client\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(202,'2026-06-10 07:47:30',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Nova database client service.\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"NovaPassword\": {\"description\": \"The password for the nova service and db account\", \"type\": \"string\", \"hidden\": true, \"default\": \"btE80AtSdL16lZ5QqRx6f9I9L\"}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Nova base service.\", \"value\": {\"config_settings\": {\"nova::api_database_connection\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"protocol\"]}, \"username\": \"nova_api\", \"password\": {\"get_param\": \"NovaPassword\"}, \"host\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"host\"]}, \"path\": \"/nova_api\", \"query\": {\"if\": [{\"get_param\": \"EnableSQLAlchemyCollectd\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\", \"plugin\": \"collectd\", \"collectd_program_name\": \"nova_api\", \"collectd_host\": \"localhost\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\"}]}}}}, \"service_config_settings\": {\"mysql\": {\"nova::db::mysql_api::password\": {\"get_param\": \"NovaPassword\"}, \"nova::db::mysql_api::user\": \"nova_api\", \"nova::db::mysql_api::host\": \"%\", \"nova::db::mysql_api::dbname\": \"nova_api\"}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(203,'2026-06-10 07:47:30',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Openstack Manila base service. Shared by manila-api/scheduler/share services\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ManilaIPv6\": {\"default\": false, \"description\": \"Set to True to enable IPv6 access in manila.\", \"type\": \"boolean\"}, \"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"ManilaDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Manila services.\", \"type\": \"boolean\"}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}, \"ManilaPassword\": {\"description\": \"The password for the manila service account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"KqSyIJe4bogoBLLwnLhZJDRFk\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"noop\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"ManilaStorageAvailabilityZone\": {\"default\": \"nova\", \"description\": \"The Manila service\'s storage availability zone.\", \"type\": \"string\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Manila Base service.\", \"value\": {\"service_name\": \"manila_base\", \"config_settings\": {\"manila::storage_availability_zone\": {\"get_param\": \"ManilaStorageAvailabilityZone\"}, \"manila::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"manila::logging::debug\": {\"if\": [{\"get_param\": \"ManilaDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"manila::db::database_db_max_retries\": -1, \"manila::db::database_max_retries\": -1, \"manila::sql_connection\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"protocol\"]}, \"username\": \"manila\", \"password\": {\"get_param\": \"ManilaPassword\"}, \"host\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"host\"]}, \"path\": \"/manila\", \"query\": {\"if\": [{\"get_param\": \"EnableSQLAlchemyCollectd\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\", \"plugin\": \"collectd\", \"collectd_program_name\": \"manila\", \"collectd_host\": \"localhost\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\"}]}}}, \"manila::network::neutron::network_plugin_ipv6_enabled\": {\"get_param\": \"ManilaIPv6\"}, \"manila::network::neutron::network_plugin_ipv4_enabled\": {\"if\": [{\"get_param\": \"ManilaIPv6\"}, false, true]}, \"manila::rabbit_heartbeat_in_pthread\": false}, \"service_config_settings\": {\"mysql\": {\"manila::db::mysql::password\": {\"get_param\": \"ManilaPassword\"}, \"manila::db::mysql::user\": \"manila\", \"manila::db::mysql::host\": \"%\", \"manila::db::mysql::dbname\": \"manila\"}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(204,'2026-06-10 07:47:31',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Nova database client service.\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"NovaPassword\": {\"description\": \"The password for the nova service and db account\", \"type\": \"string\", \"hidden\": true, \"default\": \"btE80AtSdL16lZ5QqRx6f9I9L\"}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Nova base service.\", \"value\": {\"config_settings\": {\"nova::database_connection\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MysqlCellInternal\", \"protocol\"]}, \"username\": \"nova\", \"password\": {\"get_param\": \"NovaPassword\"}, \"host\": {\"get_param\": [\"EndpointMap\", \"MysqlCellInternal\", \"host\"]}, \"path\": \"/nova\", \"query\": {\"if\": [{\"get_param\": \"EnableSQLAlchemyCollectd\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\", \"plugin\": \"collectd\", \"collectd_program_name\": \"nova\", \"collectd_host\": \"localhost\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\"}]}}}}, \"service_config_settings\": {\"mysql\": {\"nova::db::mysql::password\": {\"get_param\": \"NovaPassword\"}, \"nova::db::mysql::user\": \"nova\", \"nova::db::mysql::host\": \"%\", \"nova::db::mysql::dbname\": \"nova\"}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (205,'2026-06-10 07:47:31',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Nova database client service.\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"NovaPassword\": {\"description\": \"The password for the nova service and db account\", \"type\": \"string\", \"hidden\": true, \"default\": \"btE80AtSdL16lZ5QqRx6f9I9L\"}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Nova base service.\", \"value\": {\"config_settings\": {\"nova::database_connection\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MysqlCellInternal\", \"protocol\"]}, \"username\": \"nova\", \"password\": {\"get_param\": \"NovaPassword\"}, \"host\": {\"get_param\": [\"EndpointMap\", \"MysqlCellInternal\", \"host\"]}, \"path\": \"/nova\", \"query\": {\"if\": [{\"get_param\": \"EnableSQLAlchemyCollectd\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\", \"plugin\": \"collectd\", \"collectd_program_name\": \"nova\", \"collectd_host\": \"localhost\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\"}]}}}}, \"service_config_settings\": {\"mysql\": {\"nova::db::mysql::password\": {\"get_param\": \"NovaPassword\"}, \"nova::db::mysql::user\": \"nova\", \"nova::db::mysql::host\": \"%\", \"nova::db::mysql::dbname\": \"nova\"}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(206,'2026-06-10 07:47:31',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Template for nova-api\'s logging to files\\n\", \"parameters\": {\"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ContainerNovaApiImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\"}, \"DeployIdentifier\": {\"default\": 1781077560, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerNovaApiImage\": \"ContainerNovaApiImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerNovaApiImage\": {\"get_param\": \"ContainerNovaApiImage\"}}}]}}}}, \"outputs\": {\"config_settings\": {\"description\": \"Extra hieradata needed to log to files in the host.\", \"value\": null}, \"volumes\": {\"description\": \"The volumes needed to log to files in the host.\", \"value\": [\"/var/log/containers/nova:/var/log/nova:z\", \"/var/log/containers/httpd/nova-api:/var/log/httpd:z\"]}, \"docker_config\": {\"description\": \"Extra containers needed for logging to files in the host.\", \"value\": {\"step_2\": {\"nova_api_init_logs\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaApiImage\"]}, \"net\": \"none\", \"privileged\": false, \"user\": \"root\", \"volumes\": [\"/var/log/containers/nova:/var/log/nova:z\", \"/var/log/containers/httpd/nova-api:/var/log/httpd:z\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R nova:nova /var/log/nova\"], \"environment\": {\"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}}}}}}, \"host_prep_tasks\": {\"description\": \"Extra ansible tasks needed for logging to files in the host.\", \"value\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"setype\": \"{{ item.setype }}\", \"state\": \"directory\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/nova\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/log/containers/httpd/nova-api\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}]}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(207,'2026-06-10 07:47:32',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Template for nova-metadata\'s logging to files\\n\", \"parameters\": {\"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ContainerNovaMetadataImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\"}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerNovaMetadataImage\": \"ContainerNovaMetadataImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerNovaMetadataImage\": {\"get_param\": \"ContainerNovaMetadataImage\"}}}]}}}}, \"outputs\": {\"config_settings\": {\"description\": \"Extra hieradata needed to log to files in the host.\", \"value\": null}, \"volumes\": {\"description\": \"The volumes needed to log to files in the host.\", \"value\": [\"/var/log/containers/nova:/var/log/nova:z\", \"/var/log/containers/httpd/nova-metadata:/var/log/httpd:z\"]}, \"docker_config\": {\"description\": \"Extra containers needed for logging to files in the host.\", \"value\": {\"step_2\": {\"nova_metadata_init_logs\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaMetadataImage\"]}, \"net\": \"none\", \"privileged\": false, \"user\": \"root\", \"volumes\": [\"/var/log/containers/nova:/var/log/nova:z\", \"/var/log/containers/httpd/nova-metadata:/var/log/httpd:z\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R nova:nova /var/log/nova\"]}}}}, \"host_prep_tasks\": {\"description\": \"Extra ansible tasks needed for logging to files in the host.\", \"value\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/nova\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/log/containers/httpd/nova-metadata\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}]}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(208,'2026-06-10 07:47:32',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mysql client settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role for setting mysql client parameters\", \"value\": {\"service_name\": \"mysql_client\", \"config_settings\": {\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"tripleo::profile::base::database::mysql::client::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}}, \"step_config\": \"include tripleo::profile::base::database::mysql::client\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(209,'2026-06-10 07:47:32',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Nova base service. Shared for all Nova services.\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"noop\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"NovaPassword\": {\"description\": \"The password for the nova service and db account\", \"type\": \"string\", \"hidden\": true, \"default\": \"btE80AtSdL16lZ5QqRx6f9I9L\"}, \"NeutronPassword\": {\"description\": \"The password for the neutron service and db account, used by neutron agents.\", \"type\": \"string\", \"hidden\": true, \"default\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\"}, \"PlacementPassword\": {\"description\": \"The password for the Placement service and db account\", \"type\": \"string\", \"hidden\": true, \"default\": \"LmdoVblRSfwmhsbe1og9276Oe\"}, \"PlacementAPIInterface\": {\"type\": \"string\", \"description\": \"Endpoint interface to be used for the placement API.\\n\", \"default\": \"internal\"}, \"NovaOVSBridge\": {\"default\": \"br-int\", \"description\": \"Name of integration bridge used by Open vSwitch\", \"type\": \"string\"}, \"Debug\": {\"type\": \"boolean\", \"default\": true, \"description\": \"Set to True to enable debugging on all services.\"}, \"NovaDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Nova services.\", \"type\": \"boolean\"}, \"EnableCache\": {\"description\": \"Enable caching with memcached\", \"type\": \"boolean\", \"default\": true}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}, \"EnableConfigPurge\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Remove configuration that is not generated by TripleO. Used to avoid configuration remnants after upgrades.\\n\"}, \"UpgradeLevelNovaCompute\": {\"type\": \"string\", \"description\": \"Nova Compute upgrade level\", \"default\": \"\"}, \"NovaOVSDBConnection\": {\"type\": \"string\", \"description\": \"OVS DB connection string to used by Nova\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"NovaSyncPowerStateInterval\": {\"type\": \"number\", \"description\": \"Interval to sync power states between the database and the hypervisor. Set to -1 to disable. Setting this to 0 will run at the default rate(60) defined in oslo.service.\", \"default\": 600}, \"RpcUseSSL\": {\"default\": false, \"description\": \"Messaging client subscriber parameter to specify an SSL connection to the messaging host.\\n\", \"type\": \"string\"}, \"NovaAdditionalCell\": {\"default\": false, \"description\": \"Whether this is an cell additional to the default cell.\", \"type\": \"boolean\"}, \"NovaCrossAZAttach\": {\"default\": true, \"description\": \"Whether instances can attach cinder volumes from a different availability zone.\", \"type\": \"boolean\"}, \"MemcachedTLS\": {\"default\": false, \"description\": \"Set to True to enable TLS on Memcached service. Because not all services support Memcached TLS, during the migration period, Memcached will listen on 2 ports - on the port set with MemcachedPort parameter (above) and on 11211, without TLS.\", \"type\": \"boolean\"}}, \"conditions\": {\"compute_upgrade_level_set\": {\"not\": {\"equals\": [{\"get_param\": \"UpgradeLevelNovaCompute\"}, \"\"]}}, \"tls_cache_enabled\": {\"and\": [{\"get_param\": \"EnableCache\"}, {\"get_param\": \"MemcachedTLS\"}]}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"nova::ovsdb_connection\": \"NovaOVSDBConnection\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"NovaOVSDBConnection\": {\"get_param\": \"NovaOVSDBConnection\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Nova base service.\", \"value\": {\"service_name\": \"nova_base\", \"config_settings\": {\"map_merge\": [{\"nova::my_ip\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}}}, \"nova::rabbit_use_ssl\": {\"get_param\": \"RpcUseSSL\"}, \"nova::keystone::service_user::send_service_user_token\": true, \"nova::keystone::service_user::project_name\": \"service\", \"nova::keystone::service_user::password\": {\"get_param\": \"NovaPassword\"}, \"nova::keystone::service_user::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"nova::keystone::service_user::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"nova::placement::project_name\": \"service\", \"nova::placement::password\": {\"get_param\": \"PlacementPassword\"}, \"nova::placement::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"nova::placement::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"nova::placement::valid_interfaces\": {\"get_param\": \"PlacementAPIInterface\"}, \"nova::os_region_name\": {\"get_param\": \"KeystoneRegion\"}, \"nova::logging::debug\": {\"if\": [{\"get_param\": \"NovaDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"nova::purge_config\": {\"get_param\": \"EnableConfigPurge\"}, \"nova::network::neutron::project_name\": \"service\", \"nova::network::neutron::username\": \"neutron\", \"nova::network::neutron::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"nova::dhcp_domain\": \"\", \"nova::network::neutron::password\": {\"get_param\": \"NeutronPassword\"}, \"nova::network::neutron::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneV3Internal\", \"uri\"]}, \"nova::network::neutron::valid_interfaces\": \"internal\", \"nova::glance::valid_interfaces\": \"internal\", \"nova::rabbit_heartbeat_timeout_threshold\": 60, \"nova::cinder_catalog_info\": \"volumev3:cinderv3:internalURL\", \"nova::host\": \"%{hiera(\'fqdn_canonical\')}\", \"nova::notify_on_state_change\": \"vm_and_task_state\", \"nova::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"nova::notification_format\": \"unversioned\", \"nova::network::neutron::auth_type\": \"v3password\", \"nova::db::database_db_max_retries\": -1, \"nova::db::database_max_retries\": -1, \"nova::network::neutron::ovs_bridge\": {\"get_param\": \"NovaOVSBridge\"}, \"nova::compute::sync_power_state_interval\": {\"get_param\": \"NovaSyncPowerStateInterval\"}, \"nova_is_additional_cell\": {\"get_param\": \"NovaAdditionalCell\"}, \"nova::cross_az_attach\": {\"get_param\": \"NovaCrossAZAttach\"}, \"nova::cache::enabled\": {\"get_param\": \"EnableCache\"}, \"nova::cache::tls_enabled\": {\"get_param\": \"MemcachedTLS\"}, \"nova::cache::backend\": {\"if\": [\"tls_cache_enabled\", \"dogpile.cache.pymemcache\", \"dogpile.cache.memcached\"]}, \"nova::rabbit_heartbeat_in_pthread\": false, \"nova::upgrade_level_compute\": {\"if\": [\"compute_upgrade_level_set\", {\"get_param\": \"UpgradeLevelNovaCompute\"}]}}, {\"get_attr\": [\"RoleParametersValue\", \"value\"]}]}, \"service_config_settings\": {\"rabbitmq\": {\"nova::rabbit_use_ssl\": {\"get_param\": \"RpcUseSSL\"}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(210,'2026-06-10 07:47:33',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Apache service configured with Puppet. Note this is typically included automatically via other services which run via Apache.\\n\", \"parameters\": {\"ApacheMaxRequestWorkers\": {\"default\": 100, \"description\": \"Maximum number of simultaneously processed requests.\", \"type\": \"number\"}, \"ApacheServerLimit\": {\"default\": 100, \"description\": \"Maximum number of Apache processes.\", \"type\": \"number\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"ApacheCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}, \"ApacheTimeout\": {\"type\": \"number\", \"default\": 90, \"description\": \"The timeout in seconds for Apache, which defines duration Apache waits for I/O operations\"}}, \"conditions\": {\"key_size_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"ApacheCertificateKeySize\"}, \"\"]}}}, \"resources\": {\"ApacheNetworks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"Controller\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"CellController\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"CellControllerCompute\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"Compute\": [\"ctlplane\", \"storage\", \"internal_api\"], \"BlockStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"ObjectStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"CephStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\"], \"Networker\": [\"ctlplane\", \"internal_api\"]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Apache role.\", \"value\": {\"service_name\": \"apache\", \"config_settings\": {\"map_merge\": [{\"apache::ip\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ApacheNetwork\"]}}}}, \"apache::default_vhost\": false, \"apache::trace_enable\": \"Off\", \"apache::server_signature\": \"Off\", \"apache::server_tokens\": \"Prod\", \"apache::timeout\": {\"get_param\": \"ApacheTimeout\"}, \"apache::default_mods\": false, \"apache::mod::prefork::maxrequestworkers\": {\"get_param\": \"ApacheMaxRequestWorkers\"}, \"apache::mod::prefork::serverlimit\": {\"get_param\": \"ApacheServerLimit\"}, \"apache::mod::remoteip::proxy_ips\": {\"get_param\": [\"ServiceData\", \"net_cidr_map\", {\"get_param\": [\"ServiceNetMap\", \"ApacheNetwork\"]}]}, \"apache::mod::alias::icons_options\": \"None\"}, {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"apache::mod::ssl::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}, \"apache::mod::ssl::ssl_protocol\": [\"all\", \"-SSLv2\", \"-SSLv3\", \"-TLSv1\"], \"apache_certificates_specs\": {\"map_merge\": {\"repeat\": {\"template\": {\"httpd-NETWORK\": {\"service_certificate\": \"/etc/pki/tls/certs/httpd/httpd-NETWORK.crt\", \"service_key\": \"/etc/pki/tls/private/httpd/httpd-NETWORK.key\"}}, \"for_each\": {\"NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}}}]}]}, \"metadata_settings\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"repeat\": {\"template\": [{\"service\": \"HTTP\", \"network\": \"$NETWORK\", \"type\": \"node\"}], \"for_each\": {\"$NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}]}, \"upgrade_tasks\": [], \"deploy_steps_tasks\": [{\"name\": \"Certificate generation\", \"when\": [\"step|int == 1\", \"enable_internal_tls\"], \"block\": [{\"name\": \"Create dirs for certificates and keys\", \"file\": {\"path\": \"{{ item }}\", \"state\": \"directory\", \"serole\": \"object_r\", \"setype\": \"cert_t\", \"seuser\": \"system_u\"}, \"with_items\": [\"/etc/pki/tls/certs/httpd\", \"/etc/pki/tls/private/httpd\"]}, {\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": {\"repeat\": {\"template\": {\"name\": \"httpd-NETWORK\", \"dns\": \"{{ fqdn_NETWORK }}\", \"principal\": \"HTTP/{{ fqdn_NETWORK }}@{{ idm_realm }}\", \"run_after\": \"cp /etc/pki/tls/certs/httpd-NETWORK.crt /etc/pki/tls/certs/httpd/httpd-NETWORK.crt\\ncp /etc/pki/tls/private/httpd-NETWORK.key /etc/pki/tls/private/httpd/httpd-NETWORK.key\\npkill -USR1 httpd\\n\", \"key_size\": {\"if\": [\"key_size_override_set\", {\"get_param\": \"ApacheCertificateKeySize\"}, {\"get_param\": \"CertificateKeySize\"}]}, \"ca\": \"ipa\"}, \"for_each\": {\"NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"EnableInternalTLS\": false}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(211,'2026-06-10 07:47:33',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Apache service configured with Puppet. Note this is typically included automatically via other services which run via Apache.\\n\", \"parameters\": {\"ApacheMaxRequestWorkers\": {\"default\": 100, \"description\": \"Maximum number of simultaneously processed requests.\", \"type\": \"number\"}, \"ApacheServerLimit\": {\"default\": 100, \"description\": \"Maximum number of Apache processes.\", \"type\": \"number\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"ApacheCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}, \"ApacheTimeout\": {\"type\": \"number\", \"default\": 90, \"description\": \"The timeout in seconds for Apache, which defines duration Apache waits for I/O operations\"}}, \"conditions\": {\"key_size_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"ApacheCertificateKeySize\"}, \"\"]}}}, \"resources\": {\"ApacheNetworks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"Controller\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"CellController\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"CellControllerCompute\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"Compute\": [\"ctlplane\", \"storage\", \"internal_api\"], \"BlockStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"ObjectStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"CephStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\"], \"Networker\": [\"ctlplane\", \"internal_api\"]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Apache role.\", \"value\": {\"service_name\": \"apache\", \"config_settings\": {\"map_merge\": [{\"apache::ip\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ApacheNetwork\"]}}}}, \"apache::default_vhost\": false, \"apache::trace_enable\": \"Off\", \"apache::server_signature\": \"Off\", \"apache::server_tokens\": \"Prod\", \"apache::timeout\": {\"get_param\": \"ApacheTimeout\"}, \"apache::default_mods\": false, \"apache::mod::prefork::maxrequestworkers\": {\"get_param\": \"ApacheMaxRequestWorkers\"}, \"apache::mod::prefork::serverlimit\": {\"get_param\": \"ApacheServerLimit\"}, \"apache::mod::remoteip::proxy_ips\": {\"get_param\": [\"ServiceData\", \"net_cidr_map\", {\"get_param\": [\"ServiceNetMap\", \"ApacheNetwork\"]}]}, \"apache::mod::alias::icons_options\": \"None\"}, {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"apache::mod::ssl::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}, \"apache::mod::ssl::ssl_protocol\": [\"all\", \"-SSLv2\", \"-SSLv3\", \"-TLSv1\"], \"apache_certificates_specs\": {\"map_merge\": {\"repeat\": {\"template\": {\"httpd-NETWORK\": {\"service_certificate\": \"/etc/pki/tls/certs/httpd/httpd-NETWORK.crt\", \"service_key\": \"/etc/pki/tls/private/httpd/httpd-NETWORK.key\"}}, \"for_each\": {\"NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}}}]}]}, \"metadata_settings\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"repeat\": {\"template\": [{\"service\": \"HTTP\", \"network\": \"$NETWORK\", \"type\": \"node\"}], \"for_each\": {\"$NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}]}, \"upgrade_tasks\": [], \"deploy_steps_tasks\": [{\"name\": \"Certificate generation\", \"when\": [\"step|int == 1\", \"enable_internal_tls\"], \"block\": [{\"name\": \"Create dirs for certificates and keys\", \"file\": {\"path\": \"{{ item }}\", \"state\": \"directory\", \"serole\": \"object_r\", \"setype\": \"cert_t\", \"seuser\": \"system_u\"}, \"with_items\": [\"/etc/pki/tls/certs/httpd\", \"/etc/pki/tls/private/httpd\"]}, {\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": {\"repeat\": {\"template\": {\"name\": \"httpd-NETWORK\", \"dns\": \"{{ fqdn_NETWORK }}\", \"principal\": \"HTTP/{{ fqdn_NETWORK }}@{{ idm_realm }}\", \"run_after\": \"cp /etc/pki/tls/certs/httpd-NETWORK.crt /etc/pki/tls/certs/httpd/httpd-NETWORK.crt\\ncp /etc/pki/tls/private/httpd-NETWORK.key /etc/pki/tls/private/httpd/httpd-NETWORK.key\\npkill -USR1 httpd\\n\", \"key_size\": {\"if\": [\"key_size_override_set\", {\"get_param\": \"ApacheCertificateKeySize\"}, {\"get_param\": \"CertificateKeySize\"}]}, \"ca\": \"ipa\"}, \"for_each\": {\"NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"EnableInternalTLS\": false}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(212,'2026-06-10 07:47:34',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mysql client settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role for setting mysql client parameters\", \"value\": {\"service_name\": \"mysql_client\", \"config_settings\": {\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"tripleo::profile::base::database::mysql::client::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}}, \"step_config\": \"include tripleo::profile::base::database::mysql::client\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(213,'2026-06-10 07:47:34',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Nova database client service.\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"NovaPassword\": {\"description\": \"The password for the nova service and db account\", \"type\": \"string\", \"hidden\": true, \"default\": \"btE80AtSdL16lZ5QqRx6f9I9L\"}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Nova base service.\", \"value\": {\"config_settings\": {\"nova::database_connection\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MysqlCellInternal\", \"protocol\"]}, \"username\": \"nova\", \"password\": {\"get_param\": \"NovaPassword\"}, \"host\": {\"get_param\": [\"EndpointMap\", \"MysqlCellInternal\", \"host\"]}, \"path\": \"/nova\", \"query\": {\"if\": [{\"get_param\": \"EnableSQLAlchemyCollectd\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\", \"plugin\": \"collectd\", \"collectd_program_name\": \"nova\", \"collectd_host\": \"localhost\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\"}]}}}}, \"service_config_settings\": {\"mysql\": {\"nova::db::mysql::password\": {\"get_param\": \"NovaPassword\"}, \"nova::db::mysql::user\": \"nova\", \"nova::db::mysql::host\": \"%\", \"nova::db::mysql::dbname\": \"nova\"}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(214,'2026-06-10 07:47:35',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Ovn Controller agent.\\n\", \"parameters\": {\"RootStackName\": {\"description\": \"The name of the stack/plan.\", \"type\": \"string\", \"default\": \"overcloud\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ContainerOvnControllerImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\"}, \"ContainerOvnControllerConfigImage\": {\"description\": \"The container image to use for the ovn_controller config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"DeployIdentifier\": {\"default\": 1781077560, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}, \"OVNSouthboundServerPort\": {\"description\": \"Port of the Southbound DB Server\", \"type\": \"number\", \"default\": 6642}, \"NeutronBridgeMappings\": {\"description\": \"The OVS logical->physical bridge mappings to use. See the Neutron documentation for details. Defaults to mapping br-ex - the external bridge on hosts - to a physical name \'datacentre\' which can be used to create provider networks (and we use this for the default floating network) - if changing this either use different post-install network scripts or be sure to keep \'datacentre\' as a mapping network name.\\n\", \"type\": \"comma_delimited_list\", \"default\": \"datacentre:br-ex\", \"tags\": [\"role_specific\"]}, \"EnableVLANTransparency\": {\"default\": false, \"description\": \"If True, then allow plugins that support it to create VLAN transparent networks.\\n\", \"type\": \"boolean\"}, \"OVNEncapType\": {\"description\": \"Type of encapsulation used in OVN. It can be \\\"geneve\\\" or \\\"vxlan\\\".\\n\", \"type\": \"string\", \"default\": \"geneve\", \"constraints\": [{\"allowed_values\": [\"geneve\", \"vxlan\"]}]}, \"OVNIntegrationBridge\": {\"description\": \"Name of the OVS bridge to use as integration bridge by OVN Controller.\\n\", \"type\": \"string\", \"default\": \"br-int\"}, \"OVNMetadataEnabled\": {\"description\": \"Whether Metadata Service has to be enabled\", \"type\": \"boolean\", \"default\": true}, \"OVNAvailabilityZone\": {\"description\": \"The az options to configure in ovs db. eg. [\'az-0\', \'az-1\', \'az-2\']\", \"type\": \"comma_delimited_list\", \"default\": [], \"tags\": [\"role_specific\"]}, \"OVNCMSOptions\": {\"description\": \"The CMS options to configure in ovs db\", \"type\": \"string\", \"default\": \"enable-chassis-as-gw\", \"tags\": [\"role_specific\"]}, \"OVNEncapTos\": {\"description\": \"The value to be applied to OVN tunnel interface\'s option:tos as specified in the Open_vSwitch database Interface table. This feature is supported from OVN v21.12.0.\\n\", \"type\": \"string\", \"default\": \"0\", \"tags\": [\"role_specific\"]}, \"OvsHwOffload\": {\"default\": false, \"description\": \"Enable OVS Hardware Offload. This feature supported from OVS 2.8.0\\n\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"OVNRemoteProbeInterval\": {\"description\": \"Probe interval in ms\", \"type\": \"number\", \"default\": 60000}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"OVNOpenflowProbeInterval\": {\"description\": \"The inactivity probe interval of the OpenFlow connection to the OpenvSwitch integration bridge, in seconds.\\n\", \"type\": \"number\", \"default\": 60}, \"OVNOfctrlWaitBeforeClear\": {\"description\": \"Sets the time ovn-controller will wait on startup before clearing all openflow rules and installing the new ones, in ms.\\n\", \"type\": \"number\", \"default\": 8000}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"ContainerOvnCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}, \"OVNContainerCpusetCpus\": {\"description\": \"Limit the specific CPUs or cores a container can use. It can be specified as a single core (ex. 0), as a comma-separated list (ex. 0,1), as a range (ex. 0-3) or a combination if previous methods (ex 0-3,7,11-15).  The selected cores should be isolated from guests and hypervisor in order to obtain best possible performance.\\n\", \"type\": \"string\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"OVNStaticBridgeMacMappings\": {\"type\": \"json\", \"default\": {}, \"description\": \"Static OVN Bridge MAC address mappings. Unique OVN bridge mac addresses\\nis dynamically allocated by creating neutron ports. When neutron isn\'t\\navailable, for instance in the standalone deployment, use this parameter\\nto provide static OVN bridge mac addresses. For example:\\n   controller-0:\\n     datacenter: 00:00:5E:00:53:00\\n     provider: 00:00:5E:00:53:01\\n   compute-0:\\n     datacenter: 00:00:5E:00:54:00\\n     provider: 00:00:5E:00:54:01\\n\", \"tags\": [\"role_specific\"]}, \"AuthCloudName\": {\"description\": \"Entry in clouds.yaml to use for authentication\", \"type\": \"string\", \"default\": \"\"}, \"OVNControllerImageUpdateTimeout\": {\"description\": \"During update, how long we wait for the container image to be updated, in seconds.\\n\", \"type\": \"number\", \"default\": 600}, \"OVNControllerUpdateTimeout\": {\"description\": \"During update, how long we wait for the container to be updated, in seconds.\\n\", \"type\": \"number\", \"default\": 600}, \"OVNControllerGarpMaxTimeout\": {\"description\": \"When used, this configuration value specifies the maximum timeout (in seconds) between two consecutive GARP packets sent by ovn-controller.\\n\", \"type\": \"number\", \"default\": 0}}, \"conditions\": {\"force_config_drive\": {\"equals\": [{\"get_param\": \"OVNMetadataEnabled\"}, false]}, \"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"key_size_override_unset\": {\"equals\": [{\"get_param\": \"ContainerOvnCertificateKeySize\"}, \"\"]}, \"enable_vlan_transparency\": {\"equals\": [{\"get_param\": \"EnableVLANTransparency\"}, true]}, \"auth_cloud_name_set\": {\"not\": {\"equals\": [{\"get_param\": \"AuthCloudName\"}, \"\"]}}, \"ovn_cpu_set\": {\"or\": [{\"not\": {\"equals\": [{\"get_param\": \"OVNContainerCpusetCpus\"}, \"\"]}}, {\"not\": {\"equals\": [{\"get_param\": [\"RoleParameters\", \"OVNContainerCpusetCpus\"]}, \"\"]}}]}, \"key_size_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"ContainerOvnCertificateKeySize\"}, \"\"]}}, \"az_ovn_unset\": {\"and\": [{\"equals\": [{\"get_param\": \"OVNAvailabilityZone\"}, []]}, {\"equals\": [{\"get_param\": [\"RoleParameters\", \"OVNAvailabilityZone\"]}, \"\"]}]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ovn::controller::ovn_bridge_mappings\": \"NeutronBridgeMappings\", \"ovn::controller::ovn_cms_options\": {\"if\": [\"az_ovn_unset\", \"OVNCMSOptions\", \"OVNCMSOptionsMerged\"]}, \"ovn::controller::ovn_encap_tos\": \"OVNEncapTos\", \"vswitch::ovs::enable_hw_offload\": \"OvsHwOffload\", \"container_cpuset_cpus\": \"OVNContainerCpusetCpus\", \"ContainerOvnControllerImage\": \"ContainerOvnControllerImage\", \"ContainerOvnControllerConfigImage\": \"ContainerOvnControllerConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"NeutronBridgeMappings\": {\"get_param\": \"NeutronBridgeMappings\"}, \"OVNCMSOptions\": {\"get_param\": \"OVNCMSOptions\"}, \"OVNCMSOptionsMerged\": {\"list_join\": [\"\", [{\"str_replace\": {\"template\": \"$OVNCMSOptions\", \"params\": {\"if\": [{\"not\": {\"equals\": [{\"get_param\": [\"RoleParameters\", \"OVNCMSOptions\"]}, \"\"]}}, {\"$OVNCMSOptions\": {\"get_param\": [\"RoleParameters\", \"OVNCMSOptions\"]}}, {\"$OVNCMSOptions\": {\"get_param\": \"OVNCMSOptions\"}}]}}}, {\"str_replace\": {\"template\": \",availability-zones=$OVNAvailabilityZone\", \"params\": {\"if\": [{\"not\": {\"equals\": [{\"get_param\": [\"RoleParameters\", \"OVNAvailabilityZone\"]}, \"\"]}}, {\"$OVNAvailabilityZone\": {\"get_param\": [\"RoleParameters\", \"OVNAvailabilityZone\"]}}, {\"$OVNAvailabilityZone\": {\"list_join\": [\",\", {\"get_param\": \"OVNAvailabilityZone\"}]}}]}}}]]}, \"OVNEncapTos\": {\"get_param\": \"OVNEncapTos\"}, \"OvsHwOffload\": {\"get_param\": \"OvsHwOffload\"}, \"OVNContainerCpusetCpus\": {\"get_param\": \"OVNContainerCpusetCpus\"}, \"ContainerOvnControllerImage\": {\"get_param\": \"ContainerOvnControllerImage\"}, \"ContainerOvnControllerConfigImage\": {\"get_param\": \"ContainerOvnControllerConfigImage\"}}}]}}}, \"OVNBridgeMappingsValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ovn_bridge_mappings\": \"NeutronBridgeMappings\", \"ovn_static_bridge_mac_mappings\": \"OVNStaticBridgeMacMappings\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"NeutronBridgeMappings\": {\"get_param\": \"NeutronBridgeMappings\"}, \"OVNStaticBridgeMacMappings\": {\"get_param\": \"OVNStaticBridgeMacMappings\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Ovn Controller agent.\", \"value\": {\"service_name\": \"ovn_controller\", \"firewall_rules\": {\"118 neutron vxlan networks\": {\"proto\": \"udp\", \"dport\": 4789, \"state\": []}, \"119 neutron geneve networks\": {\"proto\": \"udp\", \"dport\": 6081, \"state\": []}, \"120 neutron geneve networks no conntrack\": {\"proto\": \"udp\", \"dport\": 6081, \"table\": \"raw\", \"chain\": \"OUTPUT\", \"jump\": \"NOTRACK\", \"action\": \"append\", \"state\": [\"INVALID\"]}, \"121 neutron geneve networks no conntrack\": {\"proto\": \"udp\", \"dport\": 6081, \"table\": \"raw\", \"chain\": \"PREROUTING\", \"jump\": \"NOTRACK\", \"action\": \"append\", \"state\": [\"INVALID\"]}}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"RoleParametersValue\", \"value\"]}, {\"ovn::southbound::port\": {\"get_param\": \"OVNSouthboundServerPort\"}, \"ovn::controller::ovn_encap_ip\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NeutronTenantNetwork\"]}}}}, \"ovn::controller::ovn_encap_type\": {\"get_param\": \"OVNEncapType\"}, \"ovn::controller::ovn_bridge\": {\"get_param\": \"OVNIntegrationBridge\"}, \"ovn::controller::hostname\": \"%{hiera(\'fqdn_canonical\')}\", \"ovn::controller::ovn_remote_probe_interval\": {\"get_param\": \"OVNRemoteProbeInterval\"}, \"ovn::controller::ovn_openflow_probe_interval\": {\"get_param\": \"OVNOpenflowProbeInterval\"}, \"ovn::controller::ovn_ofctrl_wait_before_clear\": {\"get_param\": \"OVNOfctrlWaitBeforeClear\"}, \"ovn::controller::garp_max_timeout_sec\": {\"get_param\": \"OVNControllerGarpMaxTimeout\"}, \"ovn::controller::ovn_monitor_all\": true}, {\"if\": [\"force_config_drive\", {\"nova::compute::force_config_drive\": true}, {}]}, {\"if\": [\"internal_tls_enabled\", {\"tripleo::profile::base::neutron::agents::ovn::protocol\": \"ssl\"}, {}]}, {\"if\": [\"enable_vlan_transparency\", {\"vswitch::ovs::vlan_limit\": 0}, {}]}]}, \"service_config_settings\": {}, \"puppet_config\": {\"puppet_tags\": \"vs_config,exec\", \"config_volume\": \"ovn_controller\", \"step_config\": \"include tripleo::profile::base::neutron::agents::ovn\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerOvnControllerConfigImage\"]}, \"volumes\": [\"/lib/modules:/lib/modules:ro\", \"/run/openvswitch:/run/openvswitch:shared,z\", \"/etc/sysconfig/modules:/etc/sysconfig/modules\"]}, \"kolla_config\": {\"/var/lib/kolla/config_files/ovn_controller.json\": {\"command\": {\"list_join\": [\" \", [\"/usr/bin/ovn-controller --pidfile --log-file unix:/run/openvswitch/db.sock\", {\"if\": [\"internal_tls_enabled\", {\"list_join\": [\" \", [\"-p /etc/pki/tls/private/ovn_controller.key -c /etc/pki/tls/certs/ovn_controller.crt -C\", {\"get_param\": \"InternalTLSCAFile\"}]]}, \"\"]}]]}, \"permissions\": [{\"path\": \"/var/log/openvswitch\", \"owner\": \"root:root\", \"recurse\": true}, {\"path\": \"/var/log/ovn\", \"owner\": \"root:root\", \"recurse\": true}]}}, \"metadata_settings\": {\"if\": [\"internal_tls_enabled\", [{\"service\": \"ovn_controller\", \"network\": {\"get_param\": [\"ServiceNetMap\", \"OvnDbsNetwork\"]}, \"type\": \"node\"}], null]}, \"docker_config\": {\"step_4\": {\"configure_cms_options\": {\"start_order\": 0, \"detach\": false, \"net\": \"host\", \"privileged\": true, \"user\": \"root\", \"command\": [\"/bin/bash\", \"-c\", \"CMS_OPTS=$(hiera ovn::controller::ovn_cms_options -c /etc/puppet/hiera.yaml);  if [ X\\\"$CMS_OPTS\\\" !=  X ]; then ovs-vsctl set open . external_ids:ovn-cms-options=$CMS_OPTS;else ovs-vsctl remove open . external_ids ovn-cms-options; fi\"], \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerOvnControllerImage\"]}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/lib/modules:/lib/modules:ro\", \"/run/openvswitch:/run/openvswitch:shared,z\"]]}, \"environment\": {\"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}}}, \"ovn_controller\": {\"map_merge\": [{\"start_order\": 1, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerOvnControllerImage\"]}, \"net\": \"host\", \"privileged\": true, \"user\": \"root\", \"restart\": \"always\", \"depends_on\": [\"openvswitch.service\"]}, {\"if\": [\"ovn_cpu_set\", {\"cpuset_cpus\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"container_cpuset_cpus\"]}}]}, {\"healthcheck\": {\"test\": {\"list_join\": [\" \", [\"/openstack/healthcheck\", {\"yaql\": {\"expression\": \"str($.data.port)\", \"data\": {\"port\": {\"get_param\": \"OVNSouthboundServerPort\"}}}}]]}}, \"volumes\": {\"list_concat\": [[\"/var/lib/kolla/config_files/ovn_controller.json:/var/lib/kolla/config_files/config.json:ro\", \"/lib/modules:/lib/modules:ro\", \"/run:/run\", \"/var/lib/openvswitch/ovn:/run/ovn:shared,z\", \"/var/log/containers/openvswitch:/var/log/openvswitch:z\", \"/var/log/containers/openvswitch:/var/log/ovn:z\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}, \"/etc/pki/tls/certs/ovn_controller.crt:/etc/pki/tls/certs/ovn_controller.crt\", \"/etc/pki/tls/private/ovn_controller.key:/etc/pki/tls/private/ovn_controller.key\"], null]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}]}}}, \"deploy_steps_tasks\": [{\"name\": \"Certificate generation\", \"when\": [\"step|int == 1\", \"enable_internal_tls\"], \"block\": [{\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": [{\"name\": \"ovn_controller\", \"dns\": {\"str_replace\": {\"template\": \"{{fqdn_$NETWORK}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"OvnDbsNetwork\"]}}}}, \"principal\": {\"str_replace\": {\"template\": \"ovn_controller/{{fqdn_$NETWORK}}@{{idm_realm}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"OvnDbsNetwork\"]}}}}, \"run_after\": \"systemctl restart tripleo_ovn_controller\\n\", \"key_size\": {\"if\": [\"key_size_override_unset\", {\"get_param\": \"CertificateKeySize\"}, {\"get_param\": \"ContainerOvnCertificateKeySize\"}]}, \"ca\": \"ipa\"}]}}]}], \"host_prep_tasks\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/openvswitch\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/openvswitch/ovn\", \"setype\": \"container_file_t\"}]}, {\"name\": \"enable virt_sandbox_use_netlink for healthcheck\", \"seboolean\": {\"name\": \"virt_sandbox_use_netlink\", \"persistent\": true, \"state\": true}, \"when\": [\"ansible_facts.selinux is defined\", \"ansible_facts.selinux.status == \\\"enabled\\\"\"]}, {\"name\": \"Copy in cleanup script\", \"copy\": {\"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-cleanup\"}, \"dest\": \"/usr/libexec/neutron-cleanup\", \"force\": true, \"mode\": \"0755\"}}, {\"name\": \"Copy in cleanup service\", \"copy\": {\"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-cleanup.service\"}, \"dest\": \"/usr/lib/systemd/system/neutron-cleanup.service\", \"force\": true}}, {\"name\": \"Enabling the cleanup service\", \"service\": {\"name\": \"neutron-cleanup\", \"enabled\": true}, \"when\": \"not (ansible_check_mode|bool)\"}], \"external_deploy_tasks\": [{\"when\": [\"step|int == 0\"], \"name\": \"ovn_controller_external_deploy_init\", \"block\": [{\"name\": {\"str_replace\": {\"template\": \"create ovn mac address for $ROLE_NAME role nodes\", \"params\": {\"$ROLE_NAME\": {\"get_param\": \"RoleName\"}}}}, \"tripleo_ovn_mac_addresses\": {\"playbook_dir\": \"{{ playbook_dir }}\", \"stack_name\": {\"get_param\": \"RootStackName\"}, \"role_name\": {\"get_param\": \"RoleName\"}, \"server_resource_names\": {\"str_replace\": {\"template\": \"{{ groups[\\\"$ROLE_NAME\\\"] }}\", \"params\": {\"$ROLE_NAME\": {\"get_param\": \"RoleName\"}}}}, \"ovn_bridge_mappings\": {\"get_attr\": [\"OVNBridgeMappingsValue\", \"value\", \"ovn_bridge_mappings\"]}, \"ovn_static_bridge_mac_mappings\": {\"get_attr\": [\"OVNBridgeMappingsValue\", \"value\", \"ovn_static_bridge_mac_mappings\"]}}}]}], \"external_update_tasks\": [{\"name\": \"Force pull image in case image name doesn\'t change.\", \"when\": \"step|int == 1\", \"tags\": [\"ovn\", \"ovn_image\"], \"become\": true, \"loop\": \"{{ groups[\'ovn_controller\'] | difference(groups[\'excluded_overcloud\']) }}\", \"delegate_to\": \"{{ item }}\", \"async\": {\"get_param\": \"OVNControllerImageUpdateTimeout\"}, \"poll\": 0, \"register\": \"ovn_controller_image_update\", \"containers.podman.podman_image\": {\"name\": {\"get_param\": \"ContainerOvnControllerConfigImage\"}, \"validate_certs\": false, \"force\": true}}, {\"name\": \"Was the ovn_controller image pull successful.\", \"when\": [\"step|int == 1\", \"\'results\' in ovn_controller_image_update\"], \"tags\": [\"ovn\", \"ovn_image\"], \"become\": true, \"delegate_to\": \"{{ async_result_item.item }}\", \"async_status\": {\"jid\": \"{{ async_result_item.ansible_job_id }}\"}, \"loop\": \"{{ovn_controller_image_update.results }}\", \"loop_control\": {\"loop_var\": \"async_result_item\"}, \"register\": \"async_poll_results\", \"until\": \"async_poll_results.finished\", \"retries\": {\"get_param\": \"OVNControllerImageUpdateTimeout\"}, \"delay\": 1}, {\"name\": \"OVN Container image used\", \"debug\": {\"msg\": \"ovn container will be using {{ image }}\"}, \"vars\": {\"image\": {\"get_param\": \"ContainerOvnControllerConfigImage\"}}, \"when\": \"step|int == 1\", \"tags\": \"ovn\"}, {\"name\": \"Update OVN OVS related parameters before update.\", \"when\": [\"step|int == 1\"], \"tags\": [\"ovn\"], \"become\": true, \"vars\": {\"timeout\": {\"get_param\": \"OVNOfctrlWaitBeforeClear\"}}, \"shell\": \"set -e\\novs-vsctl set Open_vSwitch . external_ids:ovn-ofctrl-wait-before-clear={{ timeout }}\\novs-vsctl set Open_vSwitch . external_ids:ovn-monitor-all=true\\novs-vsctl set Open_vSwitch . external_ids:ovn-match-northd-version=false\\n\", \"async\": {\"get_param\": \"OVNControllerUpdateTimeout\"}, \"poll\": 0, \"register\": \"ovs_vsctl\", \"loop\": \"{{ groups[\'ovn_controller\'] | difference(groups[\'excluded_overcloud\']) }}\", \"delegate_to\": \"{{ item }}\"}, {\"name\": \"Was the update of OVN OVS related parameter successful.\", \"when\": [\"step|int == 1\", \"\'results\' in ovs_vsctl\"], \"become\": true, \"tags\": [\"ovn\"], \"delegate_to\": \"{{ async_result_item.item }}\", \"async_status\": {\"jid\": \"{{ async_result_item.ansible_job_id }}\"}, \"loop\": \"{{ovs_vsctl.results }}\", \"loop_control\": {\"loop_var\": \"async_result_item\"}, \"register\": \"async_poll_results\", \"until\": \"async_poll_results.finished\", \"retries\": {\"get_param\": \"OVNControllerUpdateTimeout\"}, \"delay\": 1}, {\"set_fact\": {\"any_ovn_host\": \"{{groups[\'ovn_controller\'] | difference(groups[\'excluded_overcloud\']) | first }}\"}, \"tags\": \"ovn\", \"when\": \"step|int == 1\"}, {\"name\": \"Find ovn_controller configs in container-startup-configs\", \"find\": {\"paths\": \"/var/lib/tripleo-config/container-startup-config/\", \"patterns\": \"*ovn_controller.json\", \"recurse\": true}, \"register\": \"ovn_cont_17_0\", \"delegate_to\": \"{{ any_ovn_host }}\", \"when\": \"(step|int == 1) and (any_ovn_host is defined) and (any_ovn_host|length > 0)\", \"tags\": [\"ovn\"], \"become\": true}, {\"name\": \"get directory path from the ovn_cont_17_0\", \"set_fact\": {\"ovn_config_path\": \"{{ ovn_cont_17_0.files.0.path | dirname }}\"}, \"when\": \"step|int == 1\", \"tags\": \"ovn\"}, {\"name\": \"Get PIDfile used by systemd on each ovn node\", \"when\": [\"step|int == 1\"], \"tags\": [\"ovn\"], \"become\": true, \"shell\": \"set -e\\ngrep PID /etc/systemd/system/tripleo_ovn_controller.service | cut -d= -f2\\n\", \"register\": \"pidfile\", \"loop\": \"{{ groups[\'ovn_controller\'] | difference(groups[\'excluded_overcloud\']) }}\", \"delegate_to\": \"{{ item }}\"}, {\"name\": \"Update ovn_controller.\", \"vars\": {\"config_step\": \"{{ (\'step_4\' in ovn_config_path) | ternary(\'4\', \'3\')}}\", \"query\": \"results[?item == \'{{item}}\'].stdout\"}, \"when\": \"step|int == 1\", \"tags\": \"ovn\", \"become\": true, \"loop\": \"{{ groups[\'ovn_controller\'] | difference(groups[\'excluded_overcloud\']) }}\", \"delegate_to\": \"{{ item }}\", \"async\": {\"get_param\": \"OVNControllerUpdateTimeout\"}, \"poll\": 0, \"register\": \"ovn_controller_update\", \"tripleo_container_manage\": {\"config_dir\": \"{{ ovn_config_path }}\", \"config_patterns\": \"*ovn_controller.json\", \"config_id\": [\"tripleo_step{{config_step}}\"], \"log_base_path\": \"{{ container_log_stdout_path }}\", \"debug\": \"{{ enable_debug | bool }}\", \"config_overrides\": {\".*ovn_controller\": {\"image\": {\"get_param\": \"ContainerOvnControllerConfigImage\"}, \"conmon_pidfile\": \"{{ pidfile | json_query(query) | first }}\", \"name\": \"ovn_controller\"}}}}, {\"name\": \"Was the ovn_controller successful.\", \"when\": [\"step|int == 1\", \"\'results\' in ovn_controller_update\"], \"tags\": \"ovn\", \"become\": true, \"delegate_to\": \"{{ async_result_item.item }}\", \"async_status\": {\"jid\": \"{{ async_result_item.ansible_job_id }}\"}, \"loop\": \"{{ovn_controller_update.results }}\", \"loop_control\": {\"loop_var\": \"async_result_item\"}, \"register\": \"async_poll_results\", \"until\": \"async_poll_results.finished\", \"retries\": {\"get_param\": \"OVNControllerUpdateTimeout\"}, \"delay\": 1}, {\"name\": \"Pause for 30s to give ovn_controllers time to reconnect to dbs\", \"when\": [\"step|int == 1\"], \"tags\": \"ovn\", \"wait_for\": {\"timeout\": 30}}], \"upgrade_tasks\": [{\"name\": \"Fetch running ovn_controller image\", \"shell\": \"set -e\\npodman inspect --format \\\"{{\'{{\'}}.ImageName{{\'}}\'}}\\\" ovn_controller\\n\", \"register\": \"running_ovn_image\", \"when\": [\"step|int == 4\"], \"tags\": [\"ovn\", \"ovn_image\"]}, {\"name\": \"Run ovn_controller upgrade\", \"tags\": [\"ovn\", \"ovn_image\"], \"vars\": {\"ovn_controller_image\": {\"get_param\": \"ContainerOvnControllerConfigImage\"}}, \"when\": [\"step|int == 4\", \"running_ovn_image.stdout != ovn_controller_image\"], \"block\": [{\"name\": \"Force pull image in case image name doesn\'t change.\", \"when\": \"step|int == 4\", \"tags\": [\"ovn\", \"ovn_image\"], \"containers.podman.podman_image\": {\"name\": {\"get_param\": \"ContainerOvnControllerConfigImage\"}, \"validate_certs\": false, \"force\": true}}, {\"name\": \"Update OVN OVS related parameters before update.\", \"when\": [\"step|int == 4\"], \"tags\": [\"ovn\"], \"vars\": {\"timeout\": {\"get_param\": \"OVNOfctrlWaitBeforeClear\"}}, \"shell\": \"set -e\\novs-vsctl set Open_vSwitch . external_ids:ovn-ofctrl-wait-before-clear={{ timeout }}\\novs-vsctl set Open_vSwitch . external_ids:ovn-monitor-all=true\\novs-vsctl set Open_vSwitch . external_ids:ovn-match-northd-version=false\\n\"}, {\"name\": \"Find ovn_controller configs in container-startup-configs\", \"find\": {\"paths\": \"/var/lib/tripleo-config/container-startup-config/\", \"patterns\": \"*ovn_controller.json\", \"recurse\": true}, \"register\": \"ovn_cont_17_0\", \"when\": [\"step|int == 4\"], \"tags\": [\"ovn\"]}, {\"name\": \"get directory path from the ovn_cont_17_0\", \"set_fact\": {\"ovn_config_path\": \"{{ ovn_cont_17_0.files.0.path | dirname }}\"}, \"when\": \"step|int == 4\", \"tags\": \"ovn\"}, {\"name\": \"Get PIDfile used by systemd on each ovn node\", \"when\": [\"step|int == 4\"], \"tags\": [\"ovn\"], \"shell\": \"set -e\\ngrep PID /etc/systemd/system/tripleo_ovn_controller.service | cut -d= -f2\\n\", \"register\": \"pidfile\"}, {\"name\": \"Update ovn_controller.\", \"vars\": {\"config_step\": \"{{ (\'step_4\' in ovn_config_path) | ternary(\'4\', \'3\')}}\"}, \"when\": \"step|int == 4\", \"tags\": \"ovn\", \"tripleo_container_manage\": {\"config_dir\": \"{{ ovn_config_path }}\", \"config_patterns\": \"*ovn_controller.json\", \"config_id\": [\"tripleo_step{{config_step}}\"], \"log_base_path\": \"{{ container_log_stdout_path }}\", \"debug\": \"{{ enable_debug | bool }}\", \"config_overrides\": {\".*ovn_controller\": {\"image\": {\"get_param\": \"ContainerOvnControllerConfigImage\"}, \"conmon_pidfile\": \"{{ pidfile.stdout }}\", \"name\": \"ovn_controller\"}}}}, {\"name\": \"Pause for 30s to give ovn_controllers time to reconnect to dbs\", \"when\": [\"step|int == 4\"], \"tags\": \"ovn\", \"wait_for\": {\"timeout\": 30}}]}], \"scale_tasks\": [{\"when\": [\"step|int == 1\", \"container_cli == \'podman\'\"], \"tags\": \"down\", \"become\": true, \"environment\": {\"OS_CLOUD\": {\"if\": [\"auth_cloud_name_set\", {\"get_param\": \"AuthCloudName\"}, {\"get_param\": \"RootStackName\"}]}}, \"block\": [{\"name\": \"Get neutron agents ID\", \"command\": \"openstack network agent list --column ID --column Host --column Binary --format yaml\", \"register\": \"neutron_agents_result\", \"delegate_to\": \"{{ groups[\'Undercloud\'] | first }}\", \"check_mode\": false, \"changed_when\": false}, {\"name\": \"Filter only current host\", \"set_fact\": {\"neutron_agents\": \"{{ neutron_agents_result.stdout | from_yaml | selectattr(\'Host\', \'match\', ansible_facts[\'fqdn\'] ~ \'.*\') | list }}\"}, \"delegate_to\": \"{{ groups[\'Undercloud\'] | first }}\", \"check_mode\": false}, {\"name\": \"Deleting OVN agents\", \"block\": [{\"name\": \"Stop OVN containers\", \"loop\": [\"tripleo_ovn_controller\", \"tripleo_ovn_metadata_agent\"], \"service\": {\"name\": \"{{ item }}\", \"state\": \"stopped\", \"enabled\": false}, \"become\": true, \"register\": \"stop_containers\", \"failed_when\": \"(\'msg\' in stop_containers and \'Could not find the requested service\' not in stop_containers.msg) or (\'rc\' in stop_containers and stop_containers.rc != 0)\"}, {\"name\": \"Delete neutron agents\", \"loop\": \"{{ neutron_agents }}\", \"loop_control\": {\"loop_var\": \"agent\", \"label\": \"{{ agent.Host }}/{{ agent.Binary }}\"}, \"command\": \"openstack network agent delete {{ agent.ID }}\", \"delegate_to\": \"{{ groups[\'Undercloud\'] | first }}\", \"check_mode\": false}]}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (215,'2026-06-10 07:47:35',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Nova Conductor service\\n\", \"parameters\": {\"ContainerNovaConductorImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\"}, \"ContainerNovaConfigImage\": {\"description\": \"The container image to use for the nova config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\"}, \"NovaConductorLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.nova.conductor\", \"file\": \"/var/log/containers/nova/nova-conductor.log\"}}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"DeployIdentifier\": {\"default\": 1781077560, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}, \"NovaWorkers\": {\"default\": 1, \"description\": \"Number of workers for Nova services.\", \"type\": \"number\"}, \"MonitoringSubscriptionNovaConductor\": {\"default\": \"overcloud-nova-conductor\", \"type\": \"string\"}, \"NovaPassword\": {\"description\": \"The password for the nova service and db account\", \"type\": \"string\", \"hidden\": true, \"default\": \"btE80AtSdL16lZ5QqRx6f9I9L\"}, \"NovaAdditionalCell\": {\"default\": false, \"description\": \"Whether this is an cell additional to the default cell.\", \"type\": \"boolean\"}}, \"conditions\": {\"nova_workers_set\": {\"not\": {\"equals\": [{\"get_param\": \"NovaWorkers\"}, 0]}}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MySQLClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\"}, \"NovaLogging\": {\"type\": \"OS::TripleO::Services::Logging::NovaCommon\", \"properties\": {\"ContainerNovaImage\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaConductorImage\"]}, \"NovaServiceName\": \"conductor\"}}, \"NovaBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"NovaApiDBClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-apidb-client-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"NovaDBClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-db-client-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerNovaConductorImage\": \"ContainerNovaConductorImage\", \"ContainerNovaConfigImage\": \"ContainerNovaConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerNovaConductorImage\": {\"get_param\": \"ContainerNovaConductorImage\"}, \"ContainerNovaConfigImage\": {\"get_param\": \"ContainerNovaConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Nova Conductor service.\", \"value\": {\"service_name\": \"nova_conductor\", \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionNovaConductor\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"NovaBase\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"NovaApiDBClient\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"NovaDBClient\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"NovaLogging\", \"config_settings\"]}, {\"if\": [\"nova_workers_set\", {\"nova::conductor::workers\": {\"get_param\": \"NovaWorkers\"}}]}]}, \"service_config_settings\": {\"rabbitmq\": {\"get_attr\": [\"NovaBase\", \"role_data\", \"service_config_settings\"], \"rabbitmq\": null}, \"mysql\": {\"map_merge\": [{\"get_attr\": [\"NovaApiDBClient\", \"role_data\", \"service_config_settings\", \"mysql\"]}, {\"get_attr\": [\"NovaDBClient\", \"role_data\", \"service_config_settings\", \"mysql\"]}]}, \"rsyslog\": {\"tripleo_logging_sources_nova_conductor\": [{\"get_param\": \"NovaConductorLoggingSource\"}]}}, \"puppet_config\": {\"config_volume\": \"nova\", \"puppet_tags\": \"nova_config\", \"step_config\": {\"list_join\": [\"\\n\", [\"include tripleo::profile::base::nova::conductor\", {\"get_attr\": [\"MySQLClient\", \"role_data\", \"step_config\"]}]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/nova_conductor.json\": {\"command\": {\"list_join\": [\" \", [\"/usr/bin/nova-conductor\", {\"get_attr\": [\"NovaLogging\", \"cmd_extra_args\"]}]]}, \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/nova\", \"owner\": \"nova:nova\", \"recurse\": true}]}, \"/var/lib/kolla/config_files/nova_conductor_db_sync.json\": {\"command\": {\"str_replace\": {\"template\": \"/usr/bin/bootstrap_host_exec nova_conductor su nova -s /bin/bash -c \'/usr/bin/nova-manage db sync DB_SYNC_ARGS\'\", \"params\": {\"if\": [{\"get_param\": \"NovaAdditionalCell\"}, {\"DB_SYNC_ARGS\": \"--local_cell\"}, {\"DB_SYNC_ARGS\": \"\"}]}}}, \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/nova\", \"owner\": \"nova:nova\", \"recurse\": true}]}}, \"docker_config\": {\"step_2\": {\"get_attr\": [\"NovaLogging\", \"docker_config\", \"step_2\"]}, \"step_3\": {\"nova_db_sync\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaConductorImage\"]}, \"cap_add\": [\"AUDIT_WRITE\"], \"start_order\": 3, \"net\": \"host\", \"detach\": false, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"NovaLogging\", \"volumes\"]}, [\"/var/lib/kolla/config_files/nova_conductor_db_sync.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/nova:/var/lib/kolla/config_files/src:ro\"]]}, \"user\": \"root\", \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\", \"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}}}}, \"step_4\": {\"nova_conductor\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaConductorImage\"]}, \"net\": \"host\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"get_attr\": [\"ContainersCommon\", \"healthcheck_rpc_port\"]}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"NovaLogging\", \"volumes\"]}, [\"/var/lib/kolla/config_files/nova_conductor.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/nova:/var/lib/kolla/config_files/src:ro\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"deploy_steps_tasks\": [{\"name\": \"validate nova-conductor container state\", \"containers.podman.podman_container_info\": {\"name\": \"nova_conductor\"}, \"register\": \"nova_conductor_infos\", \"failed_when\": [\"nova_conductor_infos.containers.0.Healthcheck.Status is defined\", \"\'healthy\' not in nova_conductor_infos.containers.0.Healthcheck.Status\"], \"retries\": 10, \"delay\": 30, \"tags\": [\"opendev-validation\", \"opendev-validation-nova\"], \"when\": [\"container_cli == \'podman\'\", \"not container_healthcheck_disabled\", \"step|int == 5\"]}], \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"NovaLogging\", \"host_prep_tasks\"]}, [{\"name\": \"enable virt_sandbox_use_netlink for healthcheck\", \"seboolean\": {\"name\": \"virt_sandbox_use_netlink\", \"persistent\": true, \"state\": true}, \"when\": [\"ansible_facts.selinux is defined\", \"ansible_facts.selinux.status == \\\"enabled\\\"\"]}]]}, \"external_upgrade_tasks\": [{\"when\": \"step|int == 1\", \"block\": [{\"name\": \"Set facts for running online DB migrations\", \"set_fact\": {\"is_additional_cell\": {\"get_param\": \"NovaAdditionalCell\"}}, \"tags\": [\"online_upgrade\", \"online_upgrade_nova\"]}, {\"name\": \"Online data migration for Nova\", \"when\": \"not is_additional_cell|bool\", \"command\": \"{{ container_cli }} exec nova_conductor nova-manage db online_data_migrations\", \"delegate_to\": \"{{ (groups[\'nova_conductor\'] | difference(groups[\'excluded_overcloud\']))[0] }}\", \"become\": true, \"tags\": [\"online_upgrade\", \"online_upgrade_nova\"]}]}, {\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop nova conductor container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"nova_conductor\"], \"tripleo_delegate_to\": \"{{ groups[\'nova_conductor\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}], \"external_update_tasks\": [{\"when\": \"step|int == 1\", \"block\": [{\"name\": \"Set facts for running online DB migrations\", \"set_fact\": {\"is_additional_cell\": {\"get_param\": \"NovaAdditionalCell\"}}, \"tags\": [\"online_upgrade\", \"online_upgrade_nova\"]}, {\"name\": \"Online data migration for Nova\", \"when\": \"not is_additional_cell|bool\", \"command\": \"{{ container_cli }} exec nova_conductor nova-manage db online_data_migrations\", \"delegate_to\": \"{{ (groups[\'nova_conductor\'] | difference(groups[\'excluded_overcloud\']))[0] }}\", \"become\": true, \"tags\": [\"online_upgrade\", \"online_upgrade_nova\"]}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(216,'2026-06-10 07:47:35',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(217,'2026-06-10 07:47:35',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(218,'2026-06-10 07:47:35',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized OVN DBs service in cluster mode\\n\", \"parameters\": {\"ContainerOvnNbDbImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\"}, \"ContainerOvnSbDbImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\"}, \"ContainerOvnNorthdImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\"}, \"ContainerNeutronApiImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\"}, \"ContainerOvnMetadataImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry.  This mapping overrides those in ServiceNetMapDefaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"OVNOvsdbProbeInterval\": {\"description\": \"Probe interval in ms for the OVSDB session\", \"type\": \"number\", \"default\": 60000}, \"OVNNorthboundServerPort\": {\"description\": \"Port of the OVN Northbound DB server\", \"type\": \"number\", \"default\": 6641}, \"OVNSouthboundServerPort\": {\"description\": \"Port of the OVN Southbound DB server\", \"type\": \"number\", \"default\": 6642}, \"OVNNorthboundClusterPort\": {\"description\": \"Cluster port of the OVN Northbound DB server\", \"type\": \"number\", \"default\": 6643}, \"OVNSouthboundClusterPort\": {\"description\": \"Cluster port of the OVN Southbound DB server\", \"type\": \"number\", \"default\": 6644}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"OvnDBSCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}}, \"conditions\": {\"key_size_override_unset\": {\"equals\": [{\"get_param\": \"OvnDBSCertificateKeySize\"}, \"\"]}, \"is_ipv6\": {\"equals\": [{\"get_param\": [\"ServiceData\", \"net_ip_version_map\", {\"get_param\": [\"ServiceNetMap\", \"OvnDbsNetwork\"]}]}, 6]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerOvnNbDbImage\": \"ContainerOvnNbDbImage\", \"ContainerOvnSbDbImage\": \"ContainerOvnSbDbImage\", \"ContainerOvnNorthdImage\": \"ContainerOvnNorthdImage\", \"ContainerNeutronApiImage\": \"ContainerNeutronApiImage\", \"ContainerOvnMetadataImage\": \"ContainerOvnMetadataImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerOvnNbDbImage\": {\"get_param\": \"ContainerOvnNbDbImage\"}, \"ContainerOvnSbDbImage\": {\"get_param\": \"ContainerOvnSbDbImage\"}, \"ContainerOvnNorthdImage\": {\"get_param\": \"ContainerOvnNorthdImage\"}, \"ContainerNeutronApiImage\": {\"get_param\": \"ContainerNeutronApiImage\"}, \"ContainerOvnMetadataImage\": {\"get_param\": \"ContainerOvnMetadataImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the OVN multi-active cluster role.\", \"value\": {\"service_name\": \"ovn_dbs\", \"firewall_rules\": {\"map_merge\": {\"repeat\": {\"for_each\": {\"<%net_cidr%>\": {\"get_param\": [\"ServiceData\", \"net_cidr_map\", {\"get_param\": [\"ServiceNetMap\", \"OvnDbsNetwork\"]}]}}, \"template\": {\"121 OVN DB server and cluster ports for <%net_cidr%>\": {\"proto\": \"tcp\", \"source\": \"<%net_cidr%>\", \"dport\": [{\"get_param\": \"OVNNorthboundServerPort\"}, {\"get_param\": \"OVNSouthboundServerPort\"}, {\"get_param\": \"OVNNorthboundClusterPort\"}, {\"get_param\": \"OVNSouthboundClusterPort\"}]}}}}}, \"kolla_config\": {\"/var/lib/kolla/config_files/ovn_cluster_north_db_server.json\": {\"command\": \"bash -c $* -- eval source /etc/sysconfig/ovn_cluster; exec /usr/local/bin/start-nb-db-server ${OVN_NB_DB_OPTS}\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true, \"optional\": true}], \"permissions\": [{\"path\": \"/var/log/openvswitch\", \"owner\": \"root:root\", \"recurse\": true}, {\"path\": \"/var/log/ovn\", \"owner\": \"root:root\", \"recurse\": true}]}, \"/var/lib/kolla/config_files/ovn_cluster_south_db_server.json\": {\"command\": \"bash -c $* -- eval source /etc/sysconfig/ovn_cluster; exec /usr/local/bin/start-sb-db-server ${OVN_SB_DB_OPTS}\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true, \"optional\": true}], \"permissions\": [{\"path\": \"/var/log/openvswitch\", \"owner\": \"root:root\", \"recurse\": true}, {\"path\": \"/var/log/ovn\", \"owner\": \"root:root\", \"recurse\": true}]}, \"/var/lib/kolla/config_files/ovn_cluster_northd.json\": {\"command\": \"bash -c $* -- eval source /etc/sysconfig/ovn_cluster; exec /usr/bin/ovn-northd ${OVN_NORTHD_OPTS}\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true, \"optional\": true}], \"permissions\": [{\"path\": \"/var/log/openvswitch\", \"owner\": \"root:root\", \"recurse\": true}, {\"path\": \"/var/log/ovn\", \"owner\": \"root:root\", \"recurse\": true}]}}, \"docker_config\": {\"step_0\": {\"ovn_cluster_north_db_server\": {\"start_order\": 0, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerOvnNbDbImage\"]}, \"net\": \"host\", \"privileged\": false, \"restart\": \"always\", \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/ovn_cluster_north_db_server.json:/var/lib/kolla/config_files/config.json:ro\", \"/lib/modules:/lib/modules:ro\", \"/var/lib/openvswitch/ovn:/var/lib/openvswitch:shared,z\", \"/var/lib/openvswitch/ovn:/run/openvswitch:shared,z\", \"/var/log/containers/openvswitch:/var/log/openvswitch:z\", \"/var/lib/openvswitch/ovn:/var/lib/ovn:shared,z\", \"/var/lib/openvswitch/ovn:/etc/openvswitch:shared,z\", \"/var/lib/openvswitch/ovn:/etc/ovn:shared,z\", \"/var/lib/openvswitch/ovn:/run/ovn:shared,z\", \"/var/log/containers/openvswitch:/var/log/ovn:z\", \"/var/lib/config-data/ansible-generated/ovn:/var/lib/kolla/config_files/src:ro\"], {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [\"/etc/pki/tls/private/ovn_dbs.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/ovn_dbs.key:ro\", \"/etc/pki/tls/certs/ovn_dbs.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/ovn_dbs.crt:ro\"], null]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}, \"ovn_cluster_south_db_server\": {\"start_order\": 0, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerOvnSbDbImage\"]}, \"net\": \"host\", \"privileged\": false, \"restart\": \"always\", \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/ovn_cluster_south_db_server.json:/var/lib/kolla/config_files/config.json:ro\", \"/lib/modules:/lib/modules:ro\", \"/var/lib/openvswitch/ovn:/var/lib/openvswitch:shared,z\", \"/var/lib/openvswitch/ovn:/run/openvswitch:shared,z\", \"/var/log/containers/openvswitch:/var/log/openvswitch:z\", \"/var/lib/openvswitch/ovn:/var/lib/ovn:shared,z\", \"/var/lib/openvswitch/ovn:/etc/openvswitch:shared,z\", \"/var/lib/openvswitch/ovn:/etc/ovn:shared,z\", \"/var/lib/openvswitch/ovn:/run/ovn:shared,z\", \"/var/log/containers/openvswitch:/var/log/ovn:z\", \"/var/lib/config-data/ansible-generated/ovn:/var/lib/kolla/config_files/src:ro\"], {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [\"/etc/pki/tls/private/ovn_dbs.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/ovn_dbs.key:ro\", \"/etc/pki/tls/certs/ovn_dbs.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/ovn_dbs.crt:ro\"], null]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}, \"ovn_cluster_northd\": {\"start_order\": 2, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerOvnNorthdImage\"]}, \"net\": \"host\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/ovn_cluster_northd.json:/var/lib/kolla/config_files/config.json:ro\", \"/lib/modules:/lib/modules:ro\", \"/var/lib/openvswitch/ovn:/run/openvswitch:shared,z\", \"/var/log/containers/openvswitch:/var/log/openvswitch:z\", \"/var/lib/openvswitch/ovn:/run/ovn:shared,z\", \"/var/log/containers/openvswitch:/var/log/ovn:z\", \"/var/lib/config-data/ansible-generated/ovn:/var/lib/kolla/config_files/src:ro\"], {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [\"/etc/pki/tls/private/ovn_dbs.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/ovn_dbs.key:ro\", \"/etc/pki/tls/certs/ovn_dbs.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/ovn_dbs.crt:ro\"], null]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"global_config_settings\": {\"ovn_db_clustered\": true}, \"metadata_settings\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [{\"service\": \"ovn_dbs\", \"network\": {\"get_param\": [\"ServiceNetMap\", \"OvnDbsNetwork\"]}, \"type\": \"node\"}], null]}, \"host_prep_tasks\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"loop\": [{\"path\": \"/var/log/containers/openvswitch\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/openvswitch/ovn\", \"setype\": \"container_file_t\"}]}], \"deploy_steps_tasks\": [{\"name\": \"set is_ovn_dbs_bootstrap_node fact\", \"set_fact\": \"is_ovn_dbs_bootstrap_node={{ovn_dbs_short_bootstrap_node_name|lower == ansible_facts[\'hostname\']|lower}}\", \"when\": [\"step|int == 1\"]}, {\"name\": \"Populate ansible service facts so we can check for pacemaker service\", \"ansible.builtin.service_facts\": null, \"when\": [\"is_ovn_dbs_bootstrap_node | bool\", \"step|int == 1\"]}, {\"name\": \"Remove OVNDBs from Pacemaker\", \"when\": [\"step|int == 1\", \"is_ovn_dbs_bootstrap_node | bool\", \"ansible_facts[\'services\'][\'pacemaker.service\'][\'state\']  | default(\'unknown\') == \'running\'\"], \"block\": [{\"name\": \"Fetch ovn-dbs-bundle\", \"shell\": \"pcs status |grep ovn-dbs-bundle ||true\\n\", \"register\": \"ovn_dbs\"}, {\"name\": \"Fetch ovn VIP\", \"shell\": \"pcs constraint config |grep \\\"with ovn-dbs-bundle\\\" |awk \'{print $1}\'\\n\", \"register\": \"ovn_vip\"}, {\"name\": \"Remove OVNDBs from pacemaker\", \"pacemaker_resource\": {\"resource\": \"ovn-dbs-bundle\", \"state\": \"delete\"}, \"when\": \"ovn_dbs.stdout |length  > 0\"}, {\"name\": \"Remove OVNDBs VIP from pacemaker\", \"pacemaker_resource\": {\"resource\": \"{{ ovn_vip.stdout }}\", \"state\": \"delete\"}, \"when\": \"ovn_vip.stdout |length > 0\"}, {\"name\": \"Clean up pacemaker remote nodes cache\", \"shell\": \"pcs cluster node clear ovn-dbs-bundle-0\\npcs cluster node clear ovn-dbs-bundle-1\\npcs cluster node clear ovn-dbs-bundle-2\\ncrm_attribute --name OVN_REPL_INFO --delete\\n\"}, {\"name\": \"Remove pacemaker attributes\", \"shell\": \"pcs node attribute \\\"{{ item }}\\\" ovn-dbs-role= || true\\n\", \"loop\": \"{{ ovn_dbs_short_node_names }}\"}]}, {\"name\": \"Prepare OVN cluster\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"Certificate generation\", \"when\": \"enable_internal_tls | bool\", \"block\": [{\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": [{\"name\": \"ovn_dbs\", \"dns\": {\"str_replace\": {\"template\": \"{{fqdn_$NETWORK}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"OvnDbsNetwork\"]}}}}, \"principal\": {\"str_replace\": {\"template\": \"ovn_dbs/{{fqdn_$NETWORK}}@{{idm_realm}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"OvnDbsNetwork\"]}}}}, \"key_size\": {\"if\": [\"key_size_override_unset\", {\"get_param\": \"CertificateKeySize\"}, {\"get_param\": \"OvnDBSCertificateKeySize\"}]}, \"ca\": \"ipa\"}]}}]}, {\"block\": [{\"name\": \"Configure OVN DBs and northd\", \"include_role\": {\"name\": \"tripleo_ovn_cluster\"}, \"vars\": {\"tripleo_ovn_cluster_dbs_protocol\": \"{{ enable_internal_tls | ternary(\'ssl\', \'tcp\', \'tcp\') }}\", \"tripleo_ovn_cluster_network\": {\"get_param\": [\"ServiceNetMap\", \"OvnDbsNetwork\"]}, \"tripleo_ovn_cluster_nb_db_port\": {\"get_param\": \"OVNNorthboundServerPort\"}, \"tripleo_ovn_cluster_sb_db_port\": {\"get_param\": \"OVNSouthboundServerPort\"}, \"tripleo_ovn_cluster_nb_local_port\": {\"get_param\": \"OVNNorthboundClusterPort\"}, \"tripleo_ovn_cluster_nb_remote_port\": {\"get_param\": \"OVNNorthboundClusterPort\"}, \"tripleo_ovn_cluster_sb_local_port\": {\"get_param\": \"OVNSouthboundClusterPort\"}, \"tripleo_ovn_cluster_sb_remote_port\": {\"get_param\": \"OVNSouthboundClusterPort\"}, \"tripleo_ovn_cluster_northd_ssl_ca_cert\": {\"get_param\": \"InternalTLSCAFile\"}, \"tripleo_ovn_cluster_sb_ssl_ca_cert\": {\"get_param\": \"InternalTLSCAFile\"}, \"tripleo_ovn_cluster_nb_ssl_ca_cert\": {\"get_param\": \"InternalTLSCAFile\"}}}]}]}, {\"name\": \"Start OVN DBs and northd containers (bootstrap node)\", \"when\": [\"step|int == 3\", \"is_ovn_dbs_bootstrap_node | bool\"], \"block\": [{\"block\": [{\"name\": \"Start OVN container\", \"include_role\": {\"name\": \"tripleo_container_manage\"}, \"vars\": {\"tripleo_container_manage_config\": \"/var/lib/tripleo-config/container-startup-config/step_0\", \"tripleo_container_manage_config_id\": \"{{ ovn_container }}\", \"tripleo_container_manage_config_patterns\": \"{{ ovn_container }}.json\"}, \"loop\": [\"ovn_cluster_north_db_server\", \"ovn_cluster_south_db_server\", \"ovn_cluster_northd\"], \"loop_control\": {\"loop_var\": \"ovn_container\"}}]}, {\"name\": \"Set NB connection\", \"become\": true, \"shell\": \"podman exec ovn_cluster_north_db_server bash -c \\\"ovn-nbctl --no-leader-only --inactivity-probe={{ tripleo_ovn_cluster_probe_interval }} set-connection p{{ tripleo_ovn_cluster_dbs_protocol }}:{{ tripleo_ovn_cluster_nb_db_port }}:{{ tripleo_ovn_cluster_dbs_addr }}\\\"\\n\", \"register\": \"nb_result\", \"retries\": 20, \"delay\": 5, \"until\": \"nb_result.rc == 0\", \"when\": [\"is_ovn_dbs_bootstrap_node | bool\"], \"vars\": {\"tripleo_ovn_cluster_network\": {\"get_param\": [\"ServiceNetMap\", \"OvnDbsNetwork\"]}, \"tripleo_ovn_cluster_nb_db_port\": {\"get_param\": \"OVNNorthboundServerPort\"}, \"tripleo_ovn_cluster_dbs_protocol\": \"{{ enable_internal_tls | ternary(\'ssl\', \'tcp\', \'tcp\') }}\", \"tripleo_ovn_cluster_dbs_addr\": {\"if\": [\"is_ipv6\", \"[::]\", \"0.0.0.0\"]}, \"tripleo_ovn_cluster_probe_interval\": {\"get_param\": \"OVNOvsdbProbeInterval\"}}}, {\"name\": \"Set SB connection\", \"become\": true, \"shell\": \"podman exec ovn_cluster_south_db_server bash -c \\\"ovn-sbctl --no-leader-only --inactivity-probe={{ tripleo_ovn_cluster_probe_interval }} set-connection p{{ tripleo_ovn_cluster_dbs_protocol }}:{{ tripleo_ovn_cluster_sb_db_port }}:{{ tripleo_ovn_cluster_dbs_addr }}\\\"\\n\", \"register\": \"sb_result\", \"retries\": 20, \"delay\": 5, \"until\": \"sb_result.rc == 0\", \"when\": [\"is_ovn_dbs_bootstrap_node | bool\"], \"vars\": {\"tripleo_ovn_cluster_network\": {\"get_param\": [\"ServiceNetMap\", \"OvnDbsNetwork\"]}, \"tripleo_ovn_cluster_sb_db_port\": {\"get_param\": \"OVNSouthboundServerPort\"}, \"tripleo_ovn_cluster_dbs_protocol\": \"{{ enable_internal_tls | ternary(\'ssl\', \'tcp\', \'tcp\') }}\", \"tripleo_ovn_cluster_dbs_addr\": {\"if\": [\"is_ipv6\", \"[::]\", \"0.0.0.0\"]}, \"tripleo_ovn_cluster_probe_interval\": {\"get_param\": \"OVNOvsdbProbeInterval\"}}}]}, {\"name\": \"Start OVN DBs and northd containers (non-bootstrap nodes)\", \"when\": [\"step|int == 4\", \"not is_ovn_dbs_bootstrap_node | bool\"], \"block\": [{\"block\": [{\"name\": \"Start OVN container\", \"include_role\": {\"name\": \"tripleo_container_manage\"}, \"vars\": {\"tripleo_container_manage_config\": \"/var/lib/tripleo-config/container-startup-config/step_0\", \"tripleo_container_manage_config_id\": \"{{ ovn_container }}\", \"tripleo_container_manage_config_patterns\": \"{{ ovn_container }}.json\"}, \"loop\": [\"ovn_cluster_north_db_server\", \"ovn_cluster_south_db_server\", \"ovn_cluster_northd\"], \"loop_control\": {\"loop_var\": \"ovn_container\"}}]}, {\"name\": \"Set NB connection\", \"become\": true, \"shell\": \"podman exec ovn_cluster_north_db_server bash -c \\\"ovn-nbctl --no-leader-only --inactivity-probe={{ tripleo_ovn_cluster_probe_interval }} set-connection p{{ tripleo_ovn_cluster_dbs_protocol }}:{{ tripleo_ovn_cluster_nb_db_port }}:{{ tripleo_ovn_cluster_dbs_addr }}\\\"\\n\", \"register\": \"nb_result\", \"retries\": 20, \"delay\": 5, \"until\": \"nb_result.rc == 0\", \"when\": [\"is_ovn_dbs_bootstrap_node | bool\"], \"vars\": {\"tripleo_ovn_cluster_network\": {\"get_param\": [\"ServiceNetMap\", \"OvnDbsNetwork\"]}, \"tripleo_ovn_cluster_nb_db_port\": {\"get_param\": \"OVNNorthboundServerPort\"}, \"tripleo_ovn_cluster_dbs_protocol\": \"{{ enable_internal_tls | ternary(\'ssl\', \'tcp\', \'tcp\') }}\", \"tripleo_ovn_cluster_dbs_addr\": {\"if\": [\"is_ipv6\", \"[::]\", \"0.0.0.0\"]}, \"tripleo_ovn_cluster_probe_interval\": {\"get_param\": \"OVNOvsdbProbeInterval\"}}}, {\"name\": \"Set SB connection\", \"become\": true, \"shell\": \"podman exec ovn_cluster_south_db_server bash -c \\\"ovn-sbctl --no-leader-only --inactivity-probe={{ tripleo_ovn_cluster_probe_interval }} set-connection p{{ tripleo_ovn_cluster_dbs_protocol }}:{{ tripleo_ovn_cluster_sb_db_port }}:{{ tripleo_ovn_cluster_dbs_addr }}\\\"\\n\", \"register\": \"sb_result\", \"retries\": 20, \"delay\": 5, \"until\": \"sb_result.rc == 0\", \"when\": [\"is_ovn_dbs_bootstrap_node | bool\"], \"vars\": {\"tripleo_ovn_cluster_network\": {\"get_param\": [\"ServiceNetMap\", \"OvnDbsNetwork\"]}, \"tripleo_ovn_cluster_sb_db_port\": {\"get_param\": \"OVNSouthboundServerPort\"}, \"tripleo_ovn_cluster_dbs_protocol\": \"{{ enable_internal_tls | ternary(\'ssl\', \'tcp\', \'tcp\') }}\", \"tripleo_ovn_cluster_dbs_addr\": {\"if\": [\"is_ipv6\", \"[::]\", \"0.0.0.0\"]}, \"tripleo_ovn_cluster_probe_interval\": {\"get_param\": \"OVNOvsdbProbeInterval\"}}}]}], \"external_update_tasks\": [{\"name\": \"Run ovndbs update\", \"tags\": [\"ovn\", \"ovn_image\"], \"when\": \"step|int == 2\", \"block\": [{\"name\": \"Get OVN_Northbound cluster leader\", \"become\": true, \"shell\": \"podman exec -u root ovn_cluster_north_db_server ovs-appctl -t /var/run/ovn/ovnnb_db.ctl cluster/status OVN_Northbound | grep \'Leader: \'\\n\", \"register\": \"ovn_nb_dbs_cluster_leader\", \"loop\": \"{{groups[\'ovn_dbs\'] | difference(groups[\'excluded_overcloud\']) }}\", \"delegate_to\": \"{{ item }}\"}, {\"set_fact\": {\"ovn_nb_leader\": \"{{ ovn_nb_dbs_cluster_leader| json_query(\\\"results[?contains(stdout,\'Leader: self\')].item\\\") }}\"}}, {\"name\": \"Graceful stop OVN NB leader container\", \"delegate_to\": \"{{ ovn_nb_leader[0] }}\", \"become\": true, \"shell\": \"podman exec -u root ovn_cluster_north_db_server ovs-appctl -t /var/run/ovn/ovnnb_db.ctl exit\\n\"}, {\"name\": \"Start OVN NB leader container\", \"delegate_to\": \"{{ ovn_nb_leader[0] }}\", \"become\": true, \"tripleo_container_manage\": {\"config_dir\": \"/var/lib/tripleo-config/container-startup-config/step_0\", \"config_id\": [\"ovn_cluster_north_db_server\"], \"config_patterns\": \"*ovn_cluster_north_db_server.json\", \"config_overrides\": {\".*ovn_cluster_north_db_server\": {\"image\": {\"get_param\": \"ContainerOvnNbDbImage\"}, \"name\": \"ovn_cluster_north_db_server\"}}}}, {\"name\": \"Get OVN_Southbound cluster leader\", \"become\": true, \"shell\": \"sudo podman exec -u root ovn_cluster_south_db_server ovs-appctl -t /var/run/ovn/ovnsb_db.ctl cluster/status OVN_Southbound | grep \'Leader: \'\\n\", \"register\": \"ovn_sb_dbs_cluster_leader\", \"loop\": \"{{groups[\'ovn_dbs\'] | difference(groups[\'excluded_overcloud\']) }}\", \"delegate_to\": \"{{ item }}\"}, {\"set_fact\": {\"ovn_sb_leader\": \"{{ ovn_sb_dbs_cluster_leader | json_query(\\\"results[?contains(stdout,\'Leader: self\')].item\\\") }}\"}}, {\"name\": \"Graceful stop OVN SB leader container\", \"delegate_to\": \"{{ ovn_sb_leader[0] }}\", \"become\": true, \"shell\": \"sudo podman exec -u root ovn_cluster_south_db_server ovs-appctl -t /var/run/ovn/ovnsb_db.ctl exit\\n\"}, {\"name\": \"Start OVN SB leader container\", \"delegate_to\": \"{{ ovn_sb_leader[0] }}\", \"become\": true, \"tripleo_container_manage\": {\"config_dir\": \"/var/lib/tripleo-config/container-startup-config/step_0\", \"config_id\": [\"ovn_cluster_south_db_server\"], \"config_patterns\": \"*ovn_cluster_south_db_server.json\", \"config_overrides\": {\".*ovn_cluster_south_db_server\": {\"image\": {\"get_param\": \"ContainerOvnSbDbImage\"}, \"name\": \"ovn_cluster_south_db_server\"}}}}, {\"name\": \"Loop on OVN_Northbound cluster for leader election\", \"become\": true, \"shell\": \"podman exec -u root ovn_cluster_north_db_server ovs-appctl -t /var/run/ovn/ovnnb_db.ctl cluster/status OVN_Northbound | grep \'Leader: \'\\n\", \"register\": \"wait_leader\", \"delegate_to\": \"{{ groups[\'ovn_dbs\'] | difference(groups[\'excluded_overcloud\']) |  difference(ovn_nb_leader[0]) | first }}\", \"failed_when\": \"\'Leader: unknown\' in wait_leader.stdout or wait_leader.stderr != \'\'\", \"until\": \"\'Leader: unknown\' not in wait_leader.stdout and wait_leader.stderr == \'\'\", \"retries\": 10, \"delay\": 5}, {\"name\": \"Loop on OVN_Southbound cluster for leader election\", \"become\": true, \"shell\": \"podman exec -u root ovn_cluster_south_db_server ovs-appctl -t /var/run/ovn/ovnsb_db.ctl cluster/status OVN_Southbound | grep \'Leader: \'\\n\", \"register\": \"wait_leader\", \"delegate_to\": \"{{ groups[\'ovn_dbs\'] | difference(groups[\'excluded_overcloud\']) |  difference(ovn_nb_leader[0]) | first }}\", \"failed_when\": \"\'Leader: unknown\' in wait_leader.stdout or wait_leader.stderr != \'\'\", \"until\": \"\'Leader: unknown\' not in wait_leader.stdout and wait_leader.stderr == \'\'\", \"retries\": 10, \"delay\": 5}, {\"name\": \"Pause for 30 seconds to ensure ovn db leader knows it was elected and clients reconnect\", \"wait_for\": {\"timeout\": 30}}, {\"name\": \"Get OVN_Northbound cluster new leader\", \"become\": true, \"shell\": \"podman exec -u root ovn_cluster_north_db_server ovs-appctl -t /var/run/ovn/ovnnb_db.ctl cluster/status OVN_Northbound | grep \'Leader: \'\\n\", \"register\": \"ovn_nb_dbs_cluster_leader_new\", \"loop\": \"{{groups[\'ovn_dbs\'] | difference(groups[\'excluded_overcloud\']) }}\", \"until\": \"\'Leader: unknown\' not in ovn_nb_dbs_cluster_leader_new.stdout\", \"retries\": 10, \"delay\": 5, \"delegate_to\": \"{{ item }}\"}, {\"set_fact\": {\"ovn_nb_leader_new\": \"{{ ovn_nb_dbs_cluster_leader_new| json_query(\\\"results[?contains(stdout,\'Leader: self\')].item\\\") }}\"}}, {\"name\": \"Get OVN_Southbound cluster new leader\", \"become\": true, \"shell\": \"sudo podman exec -u root ovn_cluster_south_db_server ovs-appctl -t /var/run/ovn/ovnsb_db.ctl cluster/status OVN_Southbound | grep \'Leader: \'\\n\", \"register\": \"ovn_sb_dbs_cluster_leader_new\", \"loop\": \"{{groups[\'ovn_dbs\'] | difference(groups[\'excluded_overcloud\']) }}\", \"until\": \"\'Leader: unknown\' not in ovn_sb_dbs_cluster_leader_new.stdout\", \"retries\": 10, \"delay\": 5, \"delegate_to\": \"{{ item }}\"}, {\"set_fact\": {\"ovn_sb_leader_new\": \"{{ ovn_sb_dbs_cluster_leader_new | json_query(\\\"results[?contains(stdout,\'Leader: self\')].item\\\") }}\"}}, {\"name\": \"Start OVN NB containers (non-leader nodes)\", \"delegate_to\": \"{{ item }}\", \"become\": true, \"tripleo_container_manage\": {\"config_dir\": \"/var/lib/tripleo-config/container-startup-config/step_0\", \"config_id\": [\"ovn_cluster_north_db_server\"], \"config_patterns\": \"*ovn_cluster_north_db_server.json\", \"config_overrides\": {\".*ovn_cluster_north_db_server\": {\"image\": {\"get_param\": \"ContainerOvnNbDbImage\"}, \"name\": \"ovn_cluster_north_db_server\"}}}, \"loop\": \"{{groups[\'ovn_dbs\'] | difference(groups[\'excluded_overcloud\']) | difference(ovn_nb_leader[0])| difference(ovn_nb_leader_new[0])}}\", \"loop_control\": {\"pause\": 15}}, {\"name\": \"Start OVN SB containers (non-leader nodes)\", \"delegate_to\": \"{{ item }}\", \"become\": true, \"tripleo_container_manage\": {\"config_dir\": \"/var/lib/tripleo-config/container-startup-config/step_0\", \"config_id\": [\"ovn_cluster_south_db_server\"], \"config_patterns\": \"*ovn_cluster_south_db_server.json\", \"config_overrides\": {\".*ovn_cluster_south_db_server\": {\"image\": {\"get_param\": \"ContainerOvnSbDbImage\"}, \"name\": \"ovn_cluster_south_db_server\"}}}, \"loop\": \"{{groups[\'ovn_dbs\'] | difference(groups[\'excluded_overcloud\']) | difference(ovn_sb_leader[0])| difference(ovn_sb_leader_new[0])}}\", \"loop_control\": {\"pause\": 15}}, {\"name\": \"Pause for 50 seconds before restarting new leaders of OVN\", \"wait_for\": {\"timeout\": 50}}, {\"name\": \"Graceful stop OVN NB new-leader container\", \"delegate_to\": \"{{ ovn_nb_leader_new[0] }}\", \"become\": true, \"shell\": \"podman exec -u root ovn_cluster_north_db_server ovs-appctl -t /var/run/ovn/ovnnb_db.ctl exit\\n\", \"when\": \"ovn_nb_leader_new[0] != ovn_nb_leader[0]\"}, {\"name\": \"Start OVN NB containers (new-leader nodes)\", \"delegate_to\": \"{{ ovn_nb_leader_new[0] }}\", \"become\": true, \"tripleo_container_manage\": {\"config_dir\": \"/var/lib/tripleo-config/container-startup-config/step_0\", \"config_id\": [\"ovn_cluster_north_db_server\"], \"config_patterns\": \"*ovn_cluster_north_db_server.json\", \"config_overrides\": {\".*ovn_cluster_north_db_server\": {\"image\": {\"get_param\": \"ContainerOvnNbDbImage\"}, \"name\": \"ovn_cluster_north_db_server\"}}}, \"when\": \"ovn_nb_leader_new[0] != ovn_nb_leader[0]\"}, {\"name\": \"Graceful stop OVN SB new-leader container\", \"delegate_to\": \"{{ ovn_sb_leader_new[0] }}\", \"become\": true, \"shell\": \"sudo podman exec -u root ovn_cluster_south_db_server ovs-appctl -t /var/run/ovn/ovnsb_db.ctl exit\\n\", \"when\": \"ovn_sb_leader_new[0] != ovn_sb_leader[0]\"}, {\"name\": \"Start OVN SB containers (new-leader nodes)\", \"delegate_to\": \"{{ ovn_sb_leader_new[0] }}\", \"become\": true, \"tripleo_container_manage\": {\"config_dir\": \"/var/lib/tripleo-config/container-startup-config/step_0\", \"config_id\": [\"ovn_cluster_south_db_server\"], \"config_patterns\": \"*ovn_cluster_south_db_server.json\", \"config_overrides\": {\".*ovn_cluster_south_db_server\": {\"image\": {\"get_param\": \"ContainerOvnSbDbImage\"}, \"name\": \"ovn_cluster_south_db_server\"}}}, \"when\": \"ovn_sb_leader_new[0] != ovn_sb_leader[0]\"}, {\"name\": \"Start OVN northd container\", \"delegate_to\": \"{{ item }}\", \"become\": true, \"tripleo_container_manage\": {\"config_dir\": \"/var/lib/tripleo-config/container-startup-config/step_0\", \"config_id\": [\"ovn_cluster_northd\"], \"config_patterns\": \"*ovn_cluster_northd.json\", \"config_overrides\": {\".*ovn_cluster_northd\": {\"image\": {\"get_param\": \"ContainerOvnNorthdImage\"}, \"name\": \"ovn_cluster_northd\"}}}, \"loop\": \"{{groups[\'ovn_dbs\'] | difference(groups[\'excluded_overcloud\'])}}\", \"loop_control\": {\"pause\": 15}}]}], \"update_tasks\": [{\"name\": \"Configure OVN cluster during update\", \"when\": \"step|int == 4\", \"block\": [{\"name\": \"Configure OVN DBs and northd\", \"include_role\": {\"name\": \"tripleo_ovn_cluster\"}, \"vars\": {\"tripleo_ovn_cluster_dbs_protocol\": \"{{ enable_internal_tls | ternary(\'ssl\', \'tcp\', \'tcp\') }}\", \"tripleo_ovn_cluster_network\": {\"get_param\": [\"ServiceNetMap\", \"OvnDbsNetwork\"]}, \"tripleo_ovn_cluster_nb_db_port\": {\"get_param\": \"OVNNorthboundServerPort\"}, \"tripleo_ovn_cluster_sb_db_port\": {\"get_param\": \"OVNSouthboundServerPort\"}, \"tripleo_ovn_cluster_nb_local_port\": {\"get_param\": \"OVNNorthboundClusterPort\"}, \"tripleo_ovn_cluster_nb_remote_port\": {\"get_param\": \"OVNNorthboundClusterPort\"}, \"tripleo_ovn_cluster_sb_local_port\": {\"get_param\": \"OVNSouthboundClusterPort\"}, \"tripleo_ovn_cluster_sb_remote_port\": {\"get_param\": \"OVNSouthboundClusterPort\"}, \"tripleo_ovn_cluster_northd_ssl_ca_cert\": {\"get_param\": \"InternalTLSCAFile\"}, \"tripleo_ovn_cluster_sb_ssl_ca_cert\": {\"get_param\": \"InternalTLSCAFile\"}, \"tripleo_ovn_cluster_nb_ssl_ca_cert\": {\"get_param\": \"InternalTLSCAFile\"}}}]}, {\"name\": \"Update OVN cluster containers\", \"when\": \"step|int == 4\", \"block\": [{\"name\": \"Start OVN container\", \"include_role\": {\"name\": \"tripleo_container_manage\"}, \"vars\": {\"tripleo_container_manage_config\": \"/var/lib/tripleo-config/container-startup-config/step_0\", \"tripleo_container_manage_config_id\": \"{{ ovn_container }}\", \"tripleo_container_manage_config_patterns\": \"{{ ovn_container }}.json\"}, \"loop\": [\"ovn_cluster_north_db_server\", \"ovn_cluster_south_db_server\", \"ovn_cluster_northd\"], \"loop_control\": {\"loop_var\": \"ovn_container\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(219,'2026-06-10 07:47:35',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(220,'2026-06-10 07:47:36',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Nova database client service.\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"NovaPassword\": {\"description\": \"The password for the nova service and db account\", \"type\": \"string\", \"hidden\": true, \"default\": \"btE80AtSdL16lZ5QqRx6f9I9L\"}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Nova base service.\", \"value\": {\"config_settings\": {\"nova::api_database_connection\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"protocol\"]}, \"username\": \"nova_api\", \"password\": {\"get_param\": \"NovaPassword\"}, \"host\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"host\"]}, \"path\": \"/nova_api\", \"query\": {\"if\": [{\"get_param\": \"EnableSQLAlchemyCollectd\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\", \"plugin\": \"collectd\", \"collectd_program_name\": \"nova_api\", \"collectd_host\": \"localhost\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\"}]}}}}, \"service_config_settings\": {\"mysql\": {\"nova::db::mysql_api::password\": {\"get_param\": \"NovaPassword\"}, \"nova::db::mysql_api::user\": \"nova_api\", \"nova::db::mysql_api::host\": \"%\", \"nova::db::mysql_api::dbname\": \"nova_api\"}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(221,'2026-06-10 07:47:36',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Nova database client service.\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"NovaPassword\": {\"description\": \"The password for the nova service and db account\", \"type\": \"string\", \"hidden\": true, \"default\": \"btE80AtSdL16lZ5QqRx6f9I9L\"}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Nova base service.\", \"value\": {\"config_settings\": {\"nova::api_database_connection\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"protocol\"]}, \"username\": \"nova_api\", \"password\": {\"get_param\": \"NovaPassword\"}, \"host\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"host\"]}, \"path\": \"/nova_api\", \"query\": {\"if\": [{\"get_param\": \"EnableSQLAlchemyCollectd\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\", \"plugin\": \"collectd\", \"collectd_program_name\": \"nova_api\", \"collectd_host\": \"localhost\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\"}]}}}}, \"service_config_settings\": {\"mysql\": {\"nova::db::mysql_api::password\": {\"get_param\": \"NovaPassword\"}, \"nova::db::mysql_api::user\": \"nova_api\", \"nova::db::mysql_api::host\": \"%\", \"nova::db::mysql_api::dbname\": \"nova_api\"}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(222,'2026-06-10 07:47:37',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(223,'2026-06-10 07:47:37',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Nova base service. Shared for all Nova services.\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"noop\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"NovaPassword\": {\"description\": \"The password for the nova service and db account\", \"type\": \"string\", \"hidden\": true, \"default\": \"btE80AtSdL16lZ5QqRx6f9I9L\"}, \"NeutronPassword\": {\"description\": \"The password for the neutron service and db account, used by neutron agents.\", \"type\": \"string\", \"hidden\": true, \"default\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\"}, \"PlacementPassword\": {\"description\": \"The password for the Placement service and db account\", \"type\": \"string\", \"hidden\": true, \"default\": \"LmdoVblRSfwmhsbe1og9276Oe\"}, \"PlacementAPIInterface\": {\"type\": \"string\", \"description\": \"Endpoint interface to be used for the placement API.\\n\", \"default\": \"internal\"}, \"NovaOVSBridge\": {\"default\": \"br-int\", \"description\": \"Name of integration bridge used by Open vSwitch\", \"type\": \"string\"}, \"Debug\": {\"type\": \"boolean\", \"default\": true, \"description\": \"Set to True to enable debugging on all services.\"}, \"NovaDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Nova services.\", \"type\": \"boolean\"}, \"EnableCache\": {\"description\": \"Enable caching with memcached\", \"type\": \"boolean\", \"default\": true}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}, \"EnableConfigPurge\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Remove configuration that is not generated by TripleO. Used to avoid configuration remnants after upgrades.\\n\"}, \"UpgradeLevelNovaCompute\": {\"type\": \"string\", \"description\": \"Nova Compute upgrade level\", \"default\": \"\"}, \"NovaOVSDBConnection\": {\"type\": \"string\", \"description\": \"OVS DB connection string to used by Nova\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"NovaSyncPowerStateInterval\": {\"type\": \"number\", \"description\": \"Interval to sync power states between the database and the hypervisor. Set to -1 to disable. Setting this to 0 will run at the default rate(60) defined in oslo.service.\", \"default\": 600}, \"RpcUseSSL\": {\"default\": false, \"description\": \"Messaging client subscriber parameter to specify an SSL connection to the messaging host.\\n\", \"type\": \"string\"}, \"NovaAdditionalCell\": {\"default\": false, \"description\": \"Whether this is an cell additional to the default cell.\", \"type\": \"boolean\"}, \"NovaCrossAZAttach\": {\"default\": true, \"description\": \"Whether instances can attach cinder volumes from a different availability zone.\", \"type\": \"boolean\"}, \"MemcachedTLS\": {\"default\": false, \"description\": \"Set to True to enable TLS on Memcached service. Because not all services support Memcached TLS, during the migration period, Memcached will listen on 2 ports - on the port set with MemcachedPort parameter (above) and on 11211, without TLS.\", \"type\": \"boolean\"}}, \"conditions\": {\"compute_upgrade_level_set\": {\"not\": {\"equals\": [{\"get_param\": \"UpgradeLevelNovaCompute\"}, \"\"]}}, \"tls_cache_enabled\": {\"and\": [{\"get_param\": \"EnableCache\"}, {\"get_param\": \"MemcachedTLS\"}]}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"nova::ovsdb_connection\": \"NovaOVSDBConnection\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"NovaOVSDBConnection\": {\"get_param\": \"NovaOVSDBConnection\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Nova base service.\", \"value\": {\"service_name\": \"nova_base\", \"config_settings\": {\"map_merge\": [{\"nova::my_ip\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}}}, \"nova::rabbit_use_ssl\": {\"get_param\": \"RpcUseSSL\"}, \"nova::keystone::service_user::send_service_user_token\": true, \"nova::keystone::service_user::project_name\": \"service\", \"nova::keystone::service_user::password\": {\"get_param\": \"NovaPassword\"}, \"nova::keystone::service_user::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"nova::keystone::service_user::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"nova::placement::project_name\": \"service\", \"nova::placement::password\": {\"get_param\": \"PlacementPassword\"}, \"nova::placement::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"nova::placement::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"nova::placement::valid_interfaces\": {\"get_param\": \"PlacementAPIInterface\"}, \"nova::os_region_name\": {\"get_param\": \"KeystoneRegion\"}, \"nova::logging::debug\": {\"if\": [{\"get_param\": \"NovaDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"nova::purge_config\": {\"get_param\": \"EnableConfigPurge\"}, \"nova::network::neutron::project_name\": \"service\", \"nova::network::neutron::username\": \"neutron\", \"nova::network::neutron::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"nova::dhcp_domain\": \"\", \"nova::network::neutron::password\": {\"get_param\": \"NeutronPassword\"}, \"nova::network::neutron::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneV3Internal\", \"uri\"]}, \"nova::network::neutron::valid_interfaces\": \"internal\", \"nova::glance::valid_interfaces\": \"internal\", \"nova::rabbit_heartbeat_timeout_threshold\": 60, \"nova::cinder_catalog_info\": \"volumev3:cinderv3:internalURL\", \"nova::host\": \"%{hiera(\'fqdn_canonical\')}\", \"nova::notify_on_state_change\": \"vm_and_task_state\", \"nova::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"nova::notification_format\": \"unversioned\", \"nova::network::neutron::auth_type\": \"v3password\", \"nova::db::database_db_max_retries\": -1, \"nova::db::database_max_retries\": -1, \"nova::network::neutron::ovs_bridge\": {\"get_param\": \"NovaOVSBridge\"}, \"nova::compute::sync_power_state_interval\": {\"get_param\": \"NovaSyncPowerStateInterval\"}, \"nova_is_additional_cell\": {\"get_param\": \"NovaAdditionalCell\"}, \"nova::cross_az_attach\": {\"get_param\": \"NovaCrossAZAttach\"}, \"nova::cache::enabled\": {\"get_param\": \"EnableCache\"}, \"nova::cache::tls_enabled\": {\"get_param\": \"MemcachedTLS\"}, \"nova::cache::backend\": {\"if\": [\"tls_cache_enabled\", \"dogpile.cache.pymemcache\", \"dogpile.cache.memcached\"]}, \"nova::rabbit_heartbeat_in_pthread\": false, \"nova::upgrade_level_compute\": {\"if\": [\"compute_upgrade_level_set\", {\"get_param\": \"UpgradeLevelNovaCompute\"}]}}, {\"get_attr\": [\"RoleParametersValue\", \"value\"]}]}, \"service_config_settings\": {\"rabbitmq\": {\"nova::rabbit_use_ssl\": {\"get_param\": \"RpcUseSSL\"}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (224,'2026-06-10 07:47:38',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Rabbitmq service\\n\", \"parameters\": {\"ContainerRabbitmqImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\"}, \"ContainerRabbitmqConfigImage\": {\"description\": \"The container image to use for the rabbitmq config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\"}, \"ClusterCommonTag\": {\"default\": false, \"description\": \"When set to false, a pacemaker service is configured to use a floating tag for its container image name, e.g. \'REGISTRY/NAMESPACE/IMAGENAME:pcmklatest\'. When set to true, the service uses a floating prefix as well, e.g. \'cluster.common.tag/IMAGENAME:pcmklatest\'.\", \"type\": \"boolean\"}, \"ClusterFullTag\": {\"default\": true, \"description\": \"When set to true, the pacemaker service uses a fully constant tag for its container image name, e.g. \'cluster.common.tag/SERVICENAME:pcmklatest\'.\", \"type\": \"boolean\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RabbitCookie\": {\"type\": \"string\", \"default\": \"mSuIvlFkPdOYUvFgLZx2\", \"hidden\": true}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ConfigDebug\": {\"default\": false, \"description\": \"Whether to run config management (e.g. Puppet) in debug mode.\", \"type\": \"boolean\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}, \"DeployIdentifier\": {\"default\": 1781077560, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}}, \"conditions\": {\"puppet_debug_enabled\": {\"get_param\": \"ConfigDebug\"}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}, \"common_tag_enabled\": {\"equals\": [{\"get_param\": \"ClusterCommonTag\"}, true]}, \"common_tag_full\": {\"equals\": [{\"get_param\": \"ClusterFullTag\"}, true]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml\"}, \"RabbitmqBase\": {\"type\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-container-puppet.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerRabbitmqImage\": \"ContainerRabbitmqImage\", \"ContainerRabbitmqConfigImage\": \"ContainerRabbitmqConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerRabbitmqImage\": {\"get_param\": \"ContainerRabbitmqImage\"}, \"ContainerRabbitmqConfigImage\": {\"get_param\": \"ContainerRabbitmqConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Rabbitmq API role.\", \"value\": {\"service_name\": {\"get_attr\": [\"RabbitmqBase\", \"role_data\", \"service_name\"]}, \"firewall_rules\": {\"109 rabbitmq-bundle\": {\"dport\": [3122, 4369, 5672, 25672, \"25673-25683\"]}}, \"global_config_settings\": {\"get_attr\": [\"RabbitmqBase\", \"role_data\", \"global_config_settings\"]}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"RabbitmqBase\", \"role_data\", \"config_settings\"]}, {\"rabbitmq::service_manage\": false, \"tripleo::profile::pacemaker::rabbitmq_bundle::rabbitmq_docker_image\": {\"if\": [\"common_tag_full\", \"cluster.common.tag/rabbitmq:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [\"common_tag_enabled\", {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerRabbitmqImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerRabbitmqImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"tripleo::profile::pacemaker::rabbitmq_bundle::control_port\": 3122, \"tripleo::profile::pacemaker::rabbitmq_bundle::container_backend\": {\"get_param\": \"ContainerCli\"}, \"tripleo::profile::pacemaker::rabbitmq_bundle::force_ocf\": true}]}, \"service_config_settings\": {\"get_attr\": [\"RabbitmqBase\", \"role_data\", \"service_config_settings\"]}, \"puppet_config\": {\"config_volume\": \"rabbitmq\", \"puppet_tags\": \"file,file_line\", \"step_config\": {\"list_join\": [\"\\n\", [\"[\'Rabbitmq_policy\', \'Rabbitmq_user\'].each |String $val| { noop_resource($val) }\", \"include tripleo::profile::pacemaker::rabbitmq_bundle\"]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerRabbitmqConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/rabbitmq.json\": {\"command\": \"/usr/sbin/pacemaker_remoted\", \"config_files\": [{\"dest\": \"/etc/libqb/force-filesystem-sockets\", \"source\": \"/dev/null\", \"owner\": \"root\", \"perm\": \"0644\"}, {\"dest\": \"/var/log/btmp\", \"source\": \"/dev/null\", \"owner\": \"root:utmp\", \"perm\": \"0600\"}, {\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"optional\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/lib/rabbitmq\", \"owner\": \"rabbitmq:rabbitmq\", \"recurse\": true}, {\"path\": \"/var/log/rabbitmq\", \"owner\": \"rabbitmq:rabbitmq\", \"recurse\": true}, {\"path\": \"/etc/pki/tls/certs/rabbitmq.crt\", \"owner\": \"rabbitmq:rabbitmq\", \"perm\": \"0600\", \"optional\": true}, {\"path\": \"/etc/pki/tls/private/rabbitmq.key\", \"owner\": \"rabbitmq:rabbitmq\", \"perm\": \"0600\", \"optional\": true}]}}, \"container_config_scripts\": {\"get_attr\": [\"ContainersCommon\", \"container_config_scripts\"]}, \"docker_config\": {\"step_1\": {\"rabbitmq_bootstrap\": {\"start_order\": 0, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerRabbitmqImage\"]}, \"net\": \"host\", \"privileged\": false, \"user\": \"root\", \"command\": [\"bash\", \"-ec\", {\"list_join\": [\"\\n\", [\"kolla_set_configs\", \"if [[ -e \\\"/var/lib/rabbitmq/.erlang.cookie\\\" ]]; then rm -f /var/lib/rabbitmq/.erlang.cookie; fi\", \"hiera \'rabbitmq::erlang_cookie\' > /var/lib/rabbitmq/.erlang.cookie\", \"chown rabbitmq:rabbitmq /var/lib/rabbitmq/.erlang.cookie\", \"chmod 400 /var/lib/rabbitmq/.erlang.cookie\"]]}], \"volumes\": [\"/var/lib/kolla/config_files/rabbitmq.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/rabbitmq:/var/lib/kolla/config_files/src:ro\", \"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/var/lib/rabbitmq:/var/lib/rabbitmq:z\", \"/etc/puppet:/etc/puppet:ro,z\"], \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\", \"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}}}}, \"step_2\": {\"rabbitmq_wait_bundle\": {\"start_order\": 0, \"detach\": false, \"net\": \"host\", \"ipc\": \"host\", \"user\": \"root\", \"command\": {\"list_concat\": [[\"/container_puppet_apply.sh\", \"2\", \"file,file_line,concat,augeas,rabbitmq_policy,rabbitmq_user,rabbitmq_ready\", \"include tripleo::profile::pacemaker::rabbitmq_bundle\"], {\"if\": [\"puppet_debug_enabled\", [\"--debug\"], [\"\"]]}]}, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerRabbitmqImage\"]}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"container_puppet_apply_volumes\"]}, [\"/bin/true:/bin/epmd\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\", \"KOLLA_BOOTSTRAP\": true, \"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}}}}}, \"metadata_settings\": {\"get_attr\": [\"RabbitmqBase\", \"role_data\", \"metadata_settings\"]}, \"host_prep_tasks\": [{\"name\": \"create fcontext for rabbitmq data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/rabbitmq(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/lib/rabbitmq\", \"setype\": \"container_file_t\"}, {\"path\": \"/var/log/containers/rabbitmq\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}, {\"name\": \"stop the Erlang port mapper on the host and make sure it cannot bind to the port used by container\", \"shell\": \"echo \'export ERL_EPMD_ADDRESS=127.0.0.1\' > /etc/rabbitmq/rabbitmq-env.conf\\necho \'export ERL_EPMD_PORT=4370\' >> /etc/rabbitmq/rabbitmq-env.conf\\nfor pid in $(pgrep epmd --ns 1 --nslist pid); do kill $pid; done\\n\"}], \"deploy_steps_tasks\": {\"list_concat\": [{\"get_attr\": [\"RabbitmqBase\", \"role_data\", \"deploy_steps_tasks\"]}, [{\"name\": \"RabbitMQ tag container image for pacemaker\", \"when\": \"step|int == 1\", \"import_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerRabbitmqImage\"]}, \"container_image_latest\": {\"if\": [\"common_tag_full\", \"cluster.common.tag/rabbitmq:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [\"common_tag_enabled\", {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerRabbitmqImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerRabbitmqImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}}}, {\"name\": \"RabbitMQ RPC HA Wrappers Step\", \"when\": \"step|int == 2\", \"block\": [{\"name\": \"Rabbitmq rpc puppet bundle\", \"import_role\": {\"name\": \"tripleo_ha_wrapper\"}, \"vars\": {\"tripleo_ha_wrapper_service_name\": \"oslo_messaging_rpc\", \"tripleo_ha_wrapper_resource_name\": \"rabbitmq\", \"tripleo_ha_wrapper_bundle_name\": \"rabbitmq-bundle\", \"tripleo_ha_wrapper_resource_state\": \"Started\", \"tripleo_ha_wrapper_puppet_config_volume\": \"rabbitmq\", \"tripleo_ha_wrapper_puppet_execute\": \"[\\\"Rabbitmq_policy\\\", \\\"Rabbitmq_user\\\"].each |String $val| { noop_resource($val) }; include ::tripleo::profile::base::pacemaker; include ::tripleo::profile::pacemaker::rabbitmq_bundle\", \"tripleo_ha_wrapper_puppet_tags\": \"pacemaker::resource::bundle,pacemaker::property,pacemaker::resource::ip,pacemaker::resource::ocf,pacemaker::constraint::order,pacemaker::constraint::colocation\", \"tripleo_ha_wrapper_puppet_debug\": {\"get_param\": \"ConfigDebug\"}, \"tripleo_ha_wrapper_config_suffix\": \".previous_run\"}}]}]]}, \"external_update_tasks\": [{\"when\": \"step|int == 1\", \"tags\": \"ha_image_update\", \"block\": [{\"block\": [{\"name\": \"Get rabbitmq image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_rabbitmq_rpc_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'rabbitmq-bundle\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container rabbitmq image\", \"set_fact\": {\"rabbitmq_rpc_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerRabbitmqImage\"]}, \"rabbitmq_rpc_image_latest\": {\"if\": [\"common_tag_full\", \"cluster.common.tag/rabbitmq:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [\"common_tag_enabled\", {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerRabbitmqImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerRabbitmqImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"pcmk_rabbitmq_rpc_image\": \"{{xmllint_pcmk_rabbitmq_rpc_image.stdout}}\"}}], \"delegate_to\": \"{{ (groups[\\\"oslo_messaging_rpc\\\"] | difference(groups[\\\"excluded_overcloud\\\"]))[0] }}\"}, {\"name\": \"rabbitmq temporary pacemaker container tag in case of image switch\", \"become\": true, \"import_role\": {\"name\": \"tripleo_ha_image_update\"}, \"vars\": {\"tripleo_ha_image_update_node_names\": \"{{ groups[\\\"oslo_messaging_rpc\\\"] | difference(groups[\\\"excluded_overcloud\\\"]) }}\", \"tripleo_ha_image_update_bundle\": \"rabbitmq-bundle\", \"tripleo_ha_image_update_new_image\": \"{{rabbitmq_rpc_image_latest}}\", \"tripleo_ha_image_update_old_image\": \"{{pcmk_rabbitmq_rpc_image}}\"}, \"when\": [\"(pcmk_rabbitmq_rpc_image != \\\"\\\")\", \"(pcmk_rabbitmq_rpc_image != rabbitmq_rpc_image_latest)\"]}]}], \"update_tasks\": [{\"block\": [{\"name\": \"Get rabbitmq image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_rabbitmq_rpc_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'rabbitmq-bundle\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container rabbitmq image\", \"set_fact\": {\"rabbitmq_rpc_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerRabbitmqImage\"]}, \"rabbitmq_rpc_image_latest\": {\"if\": [\"common_tag_full\", \"cluster.common.tag/rabbitmq:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [\"common_tag_enabled\", {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerRabbitmqImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerRabbitmqImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"pcmk_rabbitmq_rpc_image\": \"{{xmllint_pcmk_rabbitmq_rpc_image.stdout}}\"}}], \"when\": \"(step|int == 0 or step|int == 2)\"}, {\"name\": \"Check for update of rabbitmq container image name\", \"when\": \"step|int == 0\", \"assert\": {\"that\": \"pcmk_rabbitmq_rpc_image == rabbitmq_rpc_image_latest\", \"fail_msg\": \"rabbitmq image change detected, run overcloud external-update --tags ha_image_update first\"}}, {\"name\": \"Tear-down non-HA rabbitmq container\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"Remove non-HA rabbitmq container\", \"include_role\": {\"name\": \"tripleo_container_rm\"}, \"vars\": {\"tripleo_container_cli\": \"{{ container_cli }}\", \"tripleo_containers_to_rm\": [\"rabbitmq\"]}}]}, {\"name\": \"Rabbitmq fetch and retag container image for pacemaker\", \"when\": \"step|int == 2\", \"block\": [{\"name\": \"Retag pcmklatest to latest rabbitmq image\", \"include_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{rabbitmq_rpc_image}}\", \"container_image_latest\": \"{{rabbitmq_rpc_image_latest}}\"}}]}], \"post_update_tasks\": [{\"name\": \"Rabbitmq rpc bundle post update\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"Rabbitmq rpc puppet bundle\", \"import_role\": {\"name\": \"tripleo_ha_wrapper\"}, \"vars\": {\"tripleo_ha_wrapper_service_name\": \"oslo_messaging_rpc\", \"tripleo_ha_wrapper_resource_name\": \"rabbitmq\", \"tripleo_ha_wrapper_bundle_name\": \"rabbitmq-bundle\", \"tripleo_ha_wrapper_resource_state\": \"Started\", \"tripleo_ha_wrapper_puppet_config_volume\": \"rabbitmq\", \"tripleo_ha_wrapper_puppet_execute\": \"[\\\"Rabbitmq_policy\\\", \\\"Rabbitmq_user\\\"].each |String $val| { noop_resource($val) }; include ::tripleo::profile::base::pacemaker; include ::tripleo::profile::pacemaker::rabbitmq_bundle\", \"tripleo_ha_wrapper_puppet_tags\": \"pacemaker::resource::bundle,pacemaker::property,pacemaker::resource::ip,pacemaker::resource::ocf,pacemaker::constraint::order,pacemaker::constraint::colocation\", \"tripleo_ha_wrapper_puppet_debug\": {\"get_param\": \"ConfigDebug\"}, \"tripleo_ha_wrapper_config_suffix\": \".previous_run\"}}], \"vars\": {\"tripleo_ha_wrapper_minor_update\": true}}], \"upgrade_tasks\": [{\"name\": \"Tear-down non-HA rabbitmq container\", \"when\": [\"step|int == 0\"], \"block\": [{\"name\": \"Remove non-HA rabbitmq container\", \"include_role\": {\"name\": \"tripleo_container_rm\"}, \"vars\": {\"tripleo_container_cli\": \"{{ container_cli }}\", \"tripleo_containers_to_rm\": [\"rabbitmq\"]}}]}, {\"name\": \"Prepare switch of rabbitmq image name\", \"when\": [\"step|int == 0\"], \"block\": [{\"name\": \"Get rabbitmq image id currently used by pacemaker\", \"shell\": \"pcs resource config rabbitmq-bundle | grep -Eo \'image=[^ ]+\' | awk -F= \'{print $2;}\'\", \"register\": \"rabbitmq_rpc_image_current_res\", \"failed_when\": false}, {\"name\": \"Image facts for rabbitmq\", \"set_fact\": {\"rabbitmq_rpc_image_latest\": {\"if\": [\"common_tag_full\", \"cluster.common.tag/rabbitmq:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [\"common_tag_enabled\", {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerRabbitmqImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerRabbitmqImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"rabbitmq_rpc_image_current\": \"{{rabbitmq_rpc_image_current_res.stdout}}\"}}, {\"name\": \"Temporarily tag the current rabbitmq image id with the upgraded image name\", \"import_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{rabbitmq_rpc_image_current}}\", \"container_image_latest\": \"{{rabbitmq_rpc_image_latest}}\", \"pull_image\": false}, \"when\": [\"rabbitmq_rpc_image_current != \'\'\", \"rabbitmq_rpc_image_current != rabbitmq_rpc_image_latest\"]}, {\"name\": \"Create rabbitmq_rpc retag statefile\", \"file\": {\"path\": \"/var/lib/tripleo/rabbitmq_rpc_needs_retag\", \"state\": \"touch\"}, \"when\": [\"rabbitmq_rpc_image_current != \'\'\", \"rabbitmq_rpc_image_current != rabbitmq_rpc_image_latest\"]}]}, {\"name\": \"Update rabbitmq-bundle pcs resource bundle for new container image\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"set is_rpc_rabbitmq_bootstrap_node fact\", \"set_fact\": \"is_rpc_rabbitmq_bootstrap_node={{oslo_messaging_rpc_short_bootstrap_node_name|lower == ansible_facts[\'hostname\']|lower}}\"}, {\"name\": \"Check for rabbitmq_rpc retag statefile\", \"stat\": {\"path\": \"/var/lib/tripleo/rabbitmq_rpc_needs_retag\"}, \"register\": \"rabbitmq_rpc_retag_state_file\"}]}, {\"name\": \"Update rabbitmq-bundle pcs resource bundle for new container image\", \"when\": [\"step|int == 1\", \"is_rpc_rabbitmq_bootstrap_node|bool\", \"rabbitmq_rpc_retag_state_file.stat.exists|bool\"], \"block\": [{\"name\": \"Disable the rabbitmq cluster resource before container upgrade\", \"pacemaker_resource\": {\"resource\": \"rabbitmq-bundle\", \"state\": \"disable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}, {\"name\": \"Check rabbitmq logging configuration in pacemaker\", \"command\": \"cibadmin --query --xpath \\\"//storage-mapping[@id=\'rabbitmq-log\']\\\"\", \"failed_when\": false, \"register\": \"rabbitmq_logs_moved\"}, {\"name\": \"Add a bind mount for logging in the rabbitmq bundle\", \"when\": \"rabbitmq_logs_moved.rc == 6\", \"command\": \"pcs resource bundle update rabbitmq-bundle storage-map add id=rabbitmq-log source-dir=/var/log/containers/rabbitmq target-dir=/var/log/rabbitmq options=rw\"}, {\"name\": \"Update the rabbitmq bundle to use the new container image name\", \"command\": \"pcs resource bundle update rabbitmq-bundle container image={{rabbitmq_rpc_image_latest}}\"}, {\"name\": \"Enable the rabbitmq cluster resource\", \"pacemaker_resource\": {\"resource\": \"rabbitmq-bundle\", \"state\": \"enable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}]}, {\"name\": \"Check for rabbitmq_rpc retag statefile\", \"when\": [\"step|int == 3\"], \"stat\": {\"path\": \"/var/lib/tripleo/rabbitmq_rpc_needs_retag\"}, \"register\": \"rabbitmq_rpc_retag_state_file\"}, {\"name\": \"Retag rabbitmq-bundle container image\", \"when\": [\"step|int == 3\", \"rabbitmq_rpc_retag_state_file.stat.exists|bool\"], \"block\": [{\"name\": \"Disable the rabbitmq cluster resource before container upgrade\", \"pacemaker_resource\": {\"resource\": \"rabbitmq-bundle\", \"state\": \"disable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}, {\"name\": \"Retag the pacemaker image if containerized\", \"block\": [{\"block\": [{\"name\": \"Get rabbitmq image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_rabbitmq_rpc_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'rabbitmq-bundle\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container rabbitmq image\", \"set_fact\": {\"rabbitmq_rpc_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerRabbitmqImage\"]}, \"rabbitmq_rpc_image_latest\": {\"if\": [\"common_tag_full\", \"cluster.common.tag/rabbitmq:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [\"common_tag_enabled\", {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerRabbitmqImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerRabbitmqImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"pcmk_rabbitmq_rpc_image\": \"{{xmllint_pcmk_rabbitmq_rpc_image.stdout}}\"}}]}, {\"block\": [{\"name\": \"Retag pcmklatest to latest rabbitmq image\", \"include_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{rabbitmq_rpc_image}}\", \"container_image_latest\": \"{{rabbitmq_rpc_image_latest}}\"}}]}]}, {\"name\": \"Enable the rabbitmq cluster resource\", \"pacemaker_resource\": {\"resource\": \"rabbitmq-bundle\", \"state\": \"enable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}, {\"name\": \"Remove rabbitmq_rpc retag statefile\", \"file\": {\"path\": \"/var/lib/tripleo/rabbitmq_rpc_needs_retag\", \"state\": \"absent\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(225,'2026-06-10 07:47:38',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Template for nova\'s logging to files\\n\", \"parameters\": {\"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ContainerNovaImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"]}, \"NovaServiceName\": {\"description\": \"service name\", \"type\": \"string\"}, \"DeployIdentifier\": {\"default\": 1781077560, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}}, \"resources\": {\"InitLogContainerName\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"string\", \"value\": {\"str_replace\": {\"template\": \"nova_SERVICE_init_log\", \"params\": {\"SERVICE\": {\"get_param\": \"NovaServiceName\"}}}}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerNovaImage\": \"ContainerNovaImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerNovaImage\": {\"get_param\": \"ContainerNovaImage\"}}}]}}}}, \"outputs\": {\"cmd_extra_args\": {\"description\": \"Extra command line arguments for running the service in the container.\", \"value\": \"\"}, \"config_settings\": {\"description\": \"Extra hieradata needed to log to files in the host.\", \"value\": null}, \"volumes\": {\"description\": \"The volumes needed to log to files in the host.\", \"value\": [\"/var/log/containers/nova:/var/log/nova\"]}, \"docker_config\": {\"description\": \"Extra containers needed for logging to files in the host.\", \"value\": {\"step_2\": {\"map_replace\": [{\"CONTAINERNAME\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaImage\"]}, \"net\": \"none\", \"privileged\": false, \"user\": \"root\", \"volumes\": [\"/var/log/containers/nova:/var/log/nova:z\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R nova:nova /var/log/nova\"], \"environment\": {\"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}}}}, {\"keys\": {\"CONTAINERNAME\": {\"get_attr\": [\"InitLogContainerName\", \"value\"]}}}]}}}, \"host_prep_tasks\": {\"description\": \"Extra ansible tasks needed for logging to files in the host.\", \"value\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"setype\": \"{{ item.setype }}\", \"state\": \"directory\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/nova\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}]}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ContainerNovaImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"NovaServiceName\": \"conductor\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(226,'2026-06-10 07:47:39',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Nova database client service.\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"NovaPassword\": {\"description\": \"The password for the nova service and db account\", \"type\": \"string\", \"hidden\": true, \"default\": \"btE80AtSdL16lZ5QqRx6f9I9L\"}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Nova base service.\", \"value\": {\"config_settings\": {\"nova::database_connection\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MysqlCellInternal\", \"protocol\"]}, \"username\": \"nova\", \"password\": {\"get_param\": \"NovaPassword\"}, \"host\": {\"get_param\": [\"EndpointMap\", \"MysqlCellInternal\", \"host\"]}, \"path\": \"/nova\", \"query\": {\"if\": [{\"get_param\": \"EnableSQLAlchemyCollectd\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\", \"plugin\": \"collectd\", \"collectd_program_name\": \"nova\", \"collectd_host\": \"localhost\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\"}]}}}}, \"service_config_settings\": {\"mysql\": {\"nova::db::mysql::password\": {\"get_param\": \"NovaPassword\"}, \"nova::db::mysql::user\": \"nova\", \"nova::db::mysql::host\": \"%\", \"nova::db::mysql::dbname\": \"nova\"}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(227,'2026-06-10 07:47:39',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Nova Vncproxy service\\n\", \"parameters\": {\"ContainerNovaVncProxyImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\"}, \"ContainerNovaConfigImage\": {\"description\": \"The container image to use for the nova config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\"}, \"NovaVncproxyLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.nova.vncproxy\", \"file\": \"/var/log/containers/nova/nova-novncproxy.log\"}}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"UseTLSTransportForVnc\": {\"type\": \"boolean\", \"default\": true, \"description\": \"If set to true and if EnableInternalTLS is enabled, it will enable TLS transaport for libvirt VNC and configure the relevant keys for libvirt.\"}, \"InternalTLSVncProxyCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the CA cert to use for VNC TLS.\"}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"NovaVNCCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}, \"LibvirtVNCClientCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}, \"LibvirtVncCACert\": {\"type\": \"string\", \"default\": \"\", \"description\": \"This specifies the CA certificate to use for VNC TLS. This file will be symlinked to the default CA path, which is /etc/pki/CA/certs/vnc.crt. This parameter should be used if the default (which comes from the InternalTLSVncProxyCAFile parameter) is not desired. The current default reflects TripleO\'s default CA, which is FreeIPA. It will only be used if internal TLS is enabled.\"}, \"NovaVNCProxySSLCiphers\": {\"type\": \"string\", \"default\": \"\", \"description\": \"OpenSSL cipher preference string that specifies what ciphers to allow for TLS connections from clients.  See the man page for the OpenSSL \'ciphers\' command for details of the cipher preference string format and allowed values.\"}, \"NovaVNCProxySSLMinimumVersion\": {\"type\": \"string\", \"default\": \"default\", \"description\": \"Minimum allowed SSL/TLS protocol version.  Valid values are \'default\', \'tlsv1_1\', \'tlsv1_2\', and \'tlsv1_3\'.  A value of \'default\' will use the underlying system OpenSSL defaults.\", \"constraints\": [{\"allowed_values\": [\"default\", \"tlsv1_1\", \"tlsv1_2\", \"tlsv1_3\"]}]}, \"RootStackName\": {\"description\": \"The name of the stack/plan.\", \"type\": \"string\", \"default\": \"overcloud\"}, \"AuthCloudName\": {\"description\": \"Entry in clouds.yaml to use for authentication\", \"type\": \"string\", \"default\": \"\"}}, \"conditions\": {\"auth_cloud_name_set\": {\"not\": {\"equals\": [{\"get_param\": \"AuthCloudName\"}, \"\"]}}, \"use_tls_for_vnc\": {\"and\": [{\"get_param\": \"EnableInternalTLS\"}, {\"get_param\": \"UseTLSTransportForVnc\"}]}, \"libvirt_vnc_specific_ca_set\": {\"not\": {\"equals\": [{\"get_param\": \"LibvirtVncCACert\"}, \"\"]}}, \"proxy_ssl_ciphers_set\": {\"not\": {\"equals\": [{\"get_param\": \"NovaVNCProxySSLCiphers\"}, \"\"]}}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MySQLClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\"}, \"NovaLogging\": {\"type\": \"OS::TripleO::Services::Logging::NovaCommon\", \"properties\": {\"ContainerNovaImage\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaVncProxyImage\"]}, \"NovaServiceName\": \"vncproxy\"}}, \"NovaBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"NovaDBClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-db-client-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerNovaVncProxyImage\": \"ContainerNovaVncProxyImage\", \"ContainerNovaConfigImage\": \"ContainerNovaConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerNovaVncProxyImage\": {\"get_param\": \"ContainerNovaVncProxyImage\"}, \"ContainerNovaConfigImage\": {\"get_param\": \"ContainerNovaConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Nova Vncproxy service.\", \"value\": {\"service_name\": \"nova_vnc_proxy\", \"firewall_rules\": {\"137 nova_vnc_proxy\": {\"dport\": [6080]}}, \"firewall_frontend_rules\": {\"100 nova_vncproxy_haproxy_frontend\": {\"dport\": [6080]}}, \"firewall_ssl_frontend_rules\": {\"100 nova_vncproxy_haproxy_frontend_ssl\": {\"dport\": [13080]}}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"NovaBase\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"NovaDBClient\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"NovaLogging\", \"config_settings\"]}, {\"nova::vncproxy::enabled\": true, \"nova::vncproxy::common::vncproxy_protocol\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyCellPublic\", \"protocol\"]}, \"nova::vncproxy::common::vncproxy_host\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyCellPublic\", \"host_nobrackets\"]}, \"nova::vncproxy::common::vncproxy_port\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyCellPublic\", \"port\"]}, \"nova::vncproxy::host\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}}}}}, {\"if\": [\"use_tls_for_vnc\", {\"nova::vncproxy::allow_vencrypt\": true, \"nova::vncproxy::vencrypt_key\": \"/etc/pki/tls/private/libvirt-vnc-client-cert.key\", \"nova::vncproxy::vencrypt_cert\": \"/etc/pki/tls/certs/libvirt-vnc-client-cert.crt\", \"nova::vncproxy::vencrypt_ca\": \"/etc/pki/CA/certs/vnc.crt\", \"nova::ssl_only\": true, \"nova::console_ssl_ciphers\": {\"if\": [\"proxy_ssl_ciphers_set\", {\"get_param\": \"NovaVNCProxySSLCiphers\"}]}, \"nova::console_ssl_minimum_version\": {\"get_param\": \"NovaVNCProxySSLMinimumVersion\"}, \"nova::cert\": \"/etc/pki/tls/certs/novnc-proxy.crt\", \"nova::key\": \"/etc/pki/tls/private/novnc-proxy.key\"}]}]}, \"service_config_settings\": {\"rabbitmq\": {\"get_attr\": [\"NovaBase\", \"role_data\", \"service_config_settings\"], \"rabbitmq\": null}, \"mysql\": {\"map_merge\": [{\"get_attr\": [\"NovaDBClient\", \"role_data\", \"service_config_settings\", \"mysql\"]}]}, \"rsyslog\": {\"tripleo_logging_sources_nova_vnc_proxy\": [{\"get_param\": \"NovaVncproxyLoggingSource\"}]}}, \"puppet_config\": {\"config_volume\": \"nova\", \"puppet_tags\": \"nova_config\", \"step_config\": {\"list_join\": [\"\\n\", [\"include tripleo::profile::base::nova::vncproxy\", {\"get_attr\": [\"MySQLClient\", \"role_data\", \"step_config\"]}]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/nova_vnc_proxy.json\": {\"command\": {\"list_join\": [\" \", [\"/usr/bin/nova-novncproxy --web /usr/share/novnc/\", {\"get_attr\": [\"NovaLogging\", \"cmd_extra_args\"]}]]}, \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true, \"optional\": true}], \"permissions\": [{\"path\": \"/var/log/nova\", \"owner\": \"nova:nova\", \"recurse\": true}, {\"path\": \"/etc/pki/tls/certs/novnc-proxy.crt\", \"owner\": \"root:root\", \"perm\": \"0644\"}, {\"path\": \"/etc/pki/tls/private/novnc-proxy.key\", \"owner\": \"root:qemu\", \"perm\": \"0640\"}, {\"path\": \"/etc/pki/tls/certs/libvirt-vnc-client-cert.crt\", \"owner\": \"root:root\", \"perm\": \"0644\"}, {\"path\": \"/etc/pki/tls/private/libvirt-vnc-client-cert.key\", \"owner\": \"root:qemu\", \"perm\": \"0640\"}]}}, \"docker_config\": {\"step_4\": {\"nova_vnc_proxy\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaVncProxyImage\"]}, \"net\": \"host\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"NovaLogging\", \"volumes\"]}, [\"/var/lib/kolla/config_files/nova_vnc_proxy.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/nova:/var/lib/kolla/config_files/src:ro\"], {\"if\": [\"use_tls_for_vnc\", [{\"str_replace\": {\"template\": \"CACERT:/etc/pki/CA/certs/vnc.crt:ro\", \"params\": {\"CACERT\": {\"if\": [\"libvirt_vnc_specific_ca_set\", {\"get_param\": \"LibvirtVncCACert\"}, {\"get_param\": \"InternalTLSVncProxyCAFile\"}]}}}}, \"/etc/pki/tls/certs/libvirt-vnc-client-cert.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/libvirt-vnc-client-cert.crt:ro\", \"/etc/pki/tls/private/libvirt-vnc-client-cert.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/libvirt-vnc-client-cert.key:ro\", \"/etc/pki/tls/certs/novnc-proxy.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/novnc-proxy.crt:ro\", \"/etc/pki/tls/private/novnc-proxy.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/novnc-proxy.key:ro\"]]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"metadata_settings\": {\"if\": [\"use_tls_for_vnc\", [{\"service\": \"libvirt-vnc\", \"network\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}, \"type\": \"node\"}, {\"service\": \"novnc-proxy\", \"network\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}, \"type\": \"node\"}]]}, \"deploy_steps_tasks\": {\"list_concat\": [[{\"name\": \"validate nova-vnc-proxy container state\", \"containers.podman.podman_container_info\": {\"name\": \"nova_vnc_proxy\"}, \"register\": \"nova_vnc_proxy_infos\", \"failed_when\": [\"nova_vnc_proxy_infos.containers.0.Healthcheck.Status is defined\", \"\'healthy\' not in nova_vnc_proxy_infos.containers.0.Healthcheck.Status\"], \"retries\": 10, \"delay\": 30, \"tags\": [\"opendev-validation\", \"opendev-validation-nova\"], \"when\": [\"container_cli == \'podman\'\", \"not container_healthcheck_disabled\", \"step|int == 5\"]}], {\"if\": [\"use_tls_for_vnc\", [{\"name\": \"Certificate generation\", \"when\": \"step|int == 1\", \"vars\": {\"cert_key_size\": {\"get_param\": \"CertificateKeySize\"}, \"nova_vnc_key_size\": {\"get_param\": \"NovaVNCCertificateKeySize\"}, \"libvirt_vnc_key_size\": {\"get_param\": \"LibvirtVNCClientCertificateKeySize\"}, \"libvirt_network\": {\"str_replace\": {\"template\": \"{{ fqdn_NETWORK }}\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}}}}}, \"block\": [{\"name\": \"Execute system role for Nova/Libvirt VNC certs\", \"loop\": [{\"name\": \"libvirt-vnc-client-cert\", \"key_size\": \"{{ libvirt_vnc_key_size | default(cert_key_size, true) }}\", \"principal\": \"libvirt-vnc/{{ libvirt_network }}@{{ idm_realm }}\"}, {\"name\": \"novnc-proxy\", \"key_size\": \"{{ nova_vnc_key_size | default(cert_key_size, true) }}\", \"principal\": \"novnc-proxy/{{ libvirt_network }}@{{ idm_realm }}\"}], \"loop_control\": {\"loop_var\": \"cert\"}, \"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": [{\"name\": \"{{ cert.name }}\", \"dns\": \"{{ libvirt_network }}\", \"principal\": \"{{ cert.principal }}\", \"key_size\": \"{{ cert.key_size }}\", \"run_after\": \"container_name=$({{container_cli}} ps --format=\\\\{\\\\{.Names\\\\}\\\\} | grep nova_vnc_proxy)\\nservice_crt=\\\"/etc/pki/tls/certs/{{ cert.name }}.crt\\\"\\nservice_key=\\\"/etc/pki/tls/private/{{ cert.name }}.key\\\"\\n# Copy the new cert from the mount-point to the real path\\n{{container_cli}} exec -u root \\\"$container_name\\\" cp \\\"/var/lib/kolla/config_files/src-tls$service_crt\\\" \\\"$service_crt\\\"\\n# Copy the new key from the mount-point to the real path\\n{{container_cli}} exec -u root \\\"$container_name\\\" cp \\\"/var/lib/kolla/config_files/src-tls$service_key\\\" \\\"$service_key\\\"\\n\\n# Set permissions\\n{{container_cli}} exec -u root \\\"$container_name\\\" chmod 0644 $service_crt\\n{{container_cli}} exec -u root \\\"$container_name\\\" chmod 0640 $service_key\\n{{container_cli}} exec -u root \\\"$container_name\\\" chgrp qemu $service_key\\n\\n# No need to trigger a reload for novnc proxy since the cert is not cached\\n\", \"ca\": \"ipa\"}]}}]}]]}]}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"NovaLogging\", \"host_prep_tasks\"]}, [{\"name\": \"ensure qemu group is present on the host\", \"group\": {\"name\": \"qemu\", \"gid\": 107, \"state\": \"present\"}}, {\"name\": \"ensure qemu user is present on the host\", \"user\": {\"name\": \"qemu\", \"uid\": 107, \"group\": \"qemu\", \"state\": \"present\", \"shell\": \"/sbin/nologin\", \"comment\": \"qemu user\"}}]]}, \"post_upgrade_tasks\": [{\"when\": [\"step|int == 3\"], \"become\": true, \"environment\": {\"OS_CLOUD\": {\"if\": [\"auth_cloud_name_set\", {\"get_param\": \"AuthCloudName\"}, {\"get_param\": \"RootStackName\"}]}}, \"block\": [{\"name\": \"Get nova-consoleauth service ID\", \"command\": \"openstack compute service list --service nova-consoleauth --column ID  --column Host --format yaml\", \"register\": \"nova_compute_service_result\", \"check_mode\": false, \"run_once\": true, \"changed_when\": false, \"failed_when\": false, \"delegate_to\": \"{{ groups[\'Undercloud\'] | first }}\"}, {\"name\": \"Deleting nova-consoleauth\", \"command\": \"openstack compute service delete {{ item.ID }}\", \"loop\": \"{{ nova_compute_service_result.stdout | from_yaml | default([]) }}\", \"run_once\": true, \"delegate_to\": \"{{ groups[\'Undercloud\'] | first }}\", \"failed_when\": false}]}], \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop nova vnc proxy container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"nova_vnc_proxy\"], \"tripleo_delegate_to\": \"{{ groups[\'nova_vnc_proxy\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(228,'2026-06-10 07:47:39',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Rabbitmq service\\n\", \"parameters\": {\"ContainerRabbitmqImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\"}, \"ContainerRabbitmqConfigImage\": {\"description\": \"The container image to use for the rabbitmq config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"RabbitCookie\": {\"type\": \"string\", \"default\": \"mSuIvlFkPdOYUvFgLZx2\", \"hidden\": true}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"RpcUserName\": {\"default\": \"guest\", \"description\": \"The username for messaging backend\", \"type\": \"string\"}, \"RpcPassword\": {\"description\": \"The password for messaging backend\", \"type\": \"string\", \"hidden\": true, \"default\": \"nn2j7FFx97Fxmpoub5H3UFEYy\"}, \"RpcUseSSL\": {\"default\": false, \"description\": \"Messaging client subscriber parameter to specify an SSL connection to the messaging host.\\n\", \"type\": \"string\"}, \"DeployIdentifier\": {\"default\": 1781077560, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"RpcCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}, \"RabbitFIPS\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Configures RabbitMQ to run in FIPS mode\"}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"key_size_override_unset\": {\"equals\": [{\"get_param\": \"RpcCertificateKeySize\"}, \"\"]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml\"}, \"RabbitMQServiceBase\": {\"type\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-container-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerRabbitmqImage\": \"ContainerRabbitmqImage\", \"ContainerRabbitmqConfigImage\": \"ContainerRabbitmqConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerRabbitmqImage\": {\"get_param\": \"ContainerRabbitmqImage\"}, \"ContainerRabbitmqConfigImage\": {\"get_param\": \"ContainerRabbitmqConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Rabbitmq API role.\", \"value\": {\"service_name\": \"oslo_messaging_rpc\", \"firewall_rules\": {\"109 rabbitmq\": {\"dport\": [4369, {\"get_param\": \"RpcPort\"}, 25672, \"25673-25683\"]}}, \"monitoring_subscription\": {\"get_attr\": [\"RabbitMQServiceBase\", \"role_data\", \"monitoring_subscription\"]}, \"global_config_settings\": {\"map_merge\": [{\"get_attr\": [\"RabbitMQServiceBase\", \"role_data\", \"global_config_settings\"]}, {\"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_user_name\": {\"get_param\": \"RpcUserName\"}, \"oslo_messaging_rpc_password\": {\"get_param\": \"RpcPassword\"}, \"oslo_messaging_rpc_use_ssl\": {\"get_param\": \"RpcUseSSL\"}, \"oslo_messaging_rpc_port\": {\"get_param\": \"RpcPort\"}}]}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"RabbitMQServiceBase\", \"role_data\", \"config_settings\"]}, {\"rabbitmq::default_user\": {\"get_param\": \"RpcUserName\"}, \"rabbitmq::default_pass\": {\"get_param\": \"RpcPassword\"}, \"rabbitmq::port\": {\"get_param\": \"RpcPort\"}, \"rabbitmq::interface\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"OsloMessagingRpcNetwork\"]}}}}, \"rabbitmq::ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"rabbitmq::ssl_erl_dist\": {\"get_param\": \"EnableInternalTLS\"}, \"rabbitmq::ssl_port\": {\"get_param\": \"RpcPort\"}, \"rabbitmq::ssl_only\": {\"get_param\": \"EnableInternalTLS\"}, \"rabbitmq::ssl_interface\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"OsloMessagingRpcNetwork\"]}}}}, \"tripleo::profile::base::rabbitmq::enable_internal_tls\": {\"get_param\": \"EnableInternalTLS\"}, \"rabbitmq::collect_statistics_interval\": 30000, \"rabbitmq::admin_enable\": false, \"rabbitmq::management_enable\": true, \"rabbitmq::use_config_file_for_plugins\": true, \"rabbitmq::management_ip_address\": \"127.0.0.1\", \"rabbitmq::config_management_variables\": {\"rates_mode\": \"none\"}}, {\"if\": [\"internal_tls_enabled\", {\"tripleo::rabbitmq::service_certificate\": \"/etc/pki/tls/certs/rabbitmq.crt\", \"tripleo::certmonger::rabbitmq::postsave_cmd\": \"true\", \"tripleo::profile::base::rabbitmq::certificate_specs\": {\"service_certificate\": \"/etc/pki/tls/certs/rabbitmq.crt\", \"service_key\": \"/etc/pki/tls/private/rabbitmq.key\"}, \"rabbitmq::ssl_versions\": {\"if\": [{\"get_param\": \"RabbitFIPS\"}, [\"tlsv1.2\", \"tlsv1.3\"], [\"tlsv1.2\"]]}}, {}]}]}, \"puppet_config\": {\"config_volume\": \"rabbitmq\", \"step_config\": {\"list_join\": [\"\\n\", [\"[\'Rabbitmq_policy\', \'Rabbitmq_user\'].each |String $val| { noop_resource($val) }\", \"include tripleo::profile::base::rabbitmq\"]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerRabbitmqConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/rabbitmq.json\": {\"command\": \"/usr/lib/rabbitmq/bin/rabbitmq-server\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true, \"optional\": true}], \"permissions\": [{\"path\": \"/var/lib/rabbitmq\", \"owner\": \"rabbitmq:rabbitmq\", \"recurse\": true}, {\"path\": \"/etc/pki/tls/certs/rabbitmq.crt\", \"owner\": \"rabbitmq:rabbitmq\", \"optional\": true}, {\"path\": \"/etc/pki/tls/private/rabbitmq.key\", \"owner\": \"rabbitmq:rabbitmq\", \"optional\": true}]}}, \"docker_config\": {\"step_1\": {\"rabbitmq_init_logs\": {\"start_order\": 0, \"detach\": false, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerRabbitmqImage\"]}, \"net\": \"none\", \"privileged\": false, \"user\": \"root\", \"volumes\": [\"/var/log/containers/rabbitmq:/var/log/rabbitmq:z\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R rabbitmq:rabbitmq /var/log/rabbitmq\"]}, \"rabbitmq_bootstrap\": {\"start_order\": 1, \"detach\": false, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerRabbitmqImage\"]}, \"net\": \"host\", \"privileged\": false, \"user\": \"root\", \"command\": [\"bash\", \"-ec\", {\"list_join\": [\"\\n\", [\"kolla_set_configs\", \"if [[ -e \\\"/var/lib/rabbitmq/.erlang.cookie\\\" ]]; then rm -f /var/lib/rabbitmq/.erlang.cookie; fi\", \"hiera \'rabbitmq::erlang_cookie\' > /var/lib/rabbitmq/.erlang.cookie\", \"chown rabbitmq:rabbitmq /var/lib/rabbitmq/.erlang.cookie\", \"chmod 400 /var/lib/rabbitmq/.erlang.cookie\"]]}], \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/rabbitmq.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/rabbitmq:/var/lib/kolla/config_files/src:ro\", \"/var/lib/rabbitmq:/var/lib/rabbitmq:z\", \"/var/log/containers/rabbitmq:/var/log/rabbitmq:z\"], {\"if\": [\"internal_tls_enabled\", [\"/etc/pki/tls/certs/rabbitmq.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/rabbitmq.crt:ro\", \"/etc/pki/tls/private/rabbitmq.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/rabbitmq.key:ro\"], null]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\", \"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}}}, \"rabbitmq\": {\"start_order\": 2, \"stop_grace_period\": 60, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerRabbitmqImage\"]}, \"net\": \"host\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/rabbitmq.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/rabbitmq:/var/lib/kolla/config_files/src:ro\", \"/var/lib/rabbitmq:/var/lib/rabbitmq:z\", \"/var/log/containers/rabbitmq:/var/log/rabbitmq:z\"], {\"if\": [\"internal_tls_enabled\", [\"/etc/pki/tls/certs/rabbitmq.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/rabbitmq.crt:ro\", \"/etc/pki/tls/private/rabbitmq.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/rabbitmq.key:ro\"], null]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"container_puppet_tasks\": {\"step_2\": {\"config_volume\": \"rabbit_init_tasks\", \"puppet_tags\": \"rabbitmq_policy,rabbitmq_user\", \"step_config\": \"include tripleo::profile::base::rabbitmq\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerRabbitmqConfigImage\"]}, \"volumes\": [\"/var/lib/config-data/puppet-generated/rabbitmq/etc/rabbitmq:/etc/rabbitmq:ro\", \"/var/lib/rabbitmq:/var/lib/rabbitmq:z\"]}}, \"metadata_settings\": {\"if\": [\"internal_tls_enabled\", [{\"service\": \"rabbitmq\", \"network\": {\"get_param\": [\"ServiceNetMap\", \"OsloMessagingRpcNetwork\"]}, \"type\": \"node\"}], null]}, \"deploy_steps_tasks\": [{\"name\": \"Certificate generation\", \"when\": [\"step|int == 1\", \"enable_internal_tls\"], \"block\": [{\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": [{\"name\": \"rabbitmq\", \"dns\": {\"str_replace\": {\"template\": \"{{fqdn_$NETWORK}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"OsloMessagingRpcNetwork\"]}}}}, \"principal\": {\"str_replace\": {\"template\": \"rabbitmq/{{fqdn_$NETWORK}}@{{idm_realm}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"OsloMessagingRpcNetwork\"]}}}}, \"run_after\": \"container_name=$({{container_cli}} ps --format=\\\\{\\\\{.Names\\\\}\\\\} | grep -w -E \'rabbitmq(-bundle-.*-[0-9]+)?\')\\nservice_crt=\\\"/etc/pki/tls/certs/rabbitmq.crt\\\"\\nservice_key=\\\"/etc/pki/tls/private/rabbitmq.key\\\"\\nif echo \\\"$container_name\\\" | grep -q \\\"^rabbitmq-bundle\\\"; then\\n  # lp#1917868: Do not use podman cp with HA containers as they get\\n  # frozen temporarily and that can make pacemaker operation fail.\\n  tar -c \\\"$service_crt\\\" \\\"$service_key\\\" | {{container_cli}} exec -i \\\"$container_name\\\" tar -C / -xv\\n  # no need to update the mount point, because pacemaker\\n  # recreates the container when it\'s restarted\\nelse\\n  # Refresh the cert at the mount-point\\n  {{container_cli}} cp $service_crt \\\"$container_name:/var/lib/kolla/config_files/src-tls/$service_crt\\\"\\n  # Refresh the key at the mount-point\\n  {{container_cli}} cp $service_key \\\"$container_name:/var/lib/kolla/config_files/src-tls/$service_key\\\"\\n  # Copy the new cert from the mount-point to the real path\\n  {{container_cli}} exec -u root \\\"$container_name\\\" cp \\\"/var/lib/kolla/config_files/src-tls$service_crt\\\" \\\"$service_crt\\\"\\n  # Copy the new key from the mount-point to the real path\\n  {{container_cli}} exec -u root \\\"$container_name\\\" cp \\\"/var/lib/kolla/config_files/src-tls$service_key\\\" \\\"$service_key\\\"\\nfi\\n# Set appropriate permissions\\n{{container_cli}} exec -u root \\\"$container_name\\\" chown rabbitmq:rabbitmq \\\"$service_crt\\\"\\n{{container_cli}} exec -u root \\\"$container_name\\\" chown rabbitmq:rabbitmq \\\"$service_key\\\"\\n# Trigger a pem cache clear in RabbitMQ to read the new certificates\\n{{container_cli}} exec \\\"$container_name\\\" rabbitmqctl eval \\\"ssl:clear_pem_cache().\\\"\\n\", \"key_size\": {\"if\": [\"key_size_override_unset\", {\"get_param\": \"CertificateKeySize\"}, {\"get_param\": \"RpcCertificateKeySize\"}]}, \"ca\": \"ipa\"}]}}]}], \"host_prep_tasks\": [{\"name\": \"create fcontext for rabbitmq data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/rabbitmq(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/rabbitmq\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/rabbitmq\", \"setype\": \"container_file_t\"}]}], \"upgrade_tasks\": [], \"update_tasks\": null}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(229,'2026-06-10 07:47:39',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Oslo Notify using a shared OpenStack containerized Rabbitmq service\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"RpcUserName\": {\"default\": \"guest\", \"description\": \"The username for messaging backend\", \"type\": \"string\"}, \"RpcPassword\": {\"description\": \"The password for messaging backend\", \"type\": \"string\", \"hidden\": true, \"default\": \"nn2j7FFx97Fxmpoub5H3UFEYy\"}, \"RpcUseSSL\": {\"default\": false, \"description\": \"Messaging client subscriber parameter to specify an SSL connection to the messaging host.\\n\", \"type\": \"string\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the oslo messaging notify role.\", \"value\": {\"service_name\": \"oslo_messaging_notify\", \"global_config_settings\": {\"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_user_name\": {\"get_param\": \"RpcUserName\"}, \"oslo_messaging_notify_password\": {\"get_param\": \"RpcPassword\"}, \"oslo_messaging_notify_use_ssl\": {\"get_param\": \"RpcUseSSL\"}, \"oslo_messaging_notify_port\": {\"get_param\": \"RpcPort\"}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(230,'2026-06-10 07:47:39',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Template for nova\'s logging to files\\n\", \"parameters\": {\"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ContainerNovaImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"]}, \"NovaServiceName\": {\"description\": \"service name\", \"type\": \"string\"}, \"DeployIdentifier\": {\"default\": 1781077560, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}}, \"resources\": {\"InitLogContainerName\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"string\", \"value\": {\"str_replace\": {\"template\": \"nova_SERVICE_init_log\", \"params\": {\"SERVICE\": {\"get_param\": \"NovaServiceName\"}}}}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerNovaImage\": \"ContainerNovaImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerNovaImage\": {\"get_param\": \"ContainerNovaImage\"}}}]}}}}, \"outputs\": {\"cmd_extra_args\": {\"description\": \"Extra command line arguments for running the service in the container.\", \"value\": \"\"}, \"config_settings\": {\"description\": \"Extra hieradata needed to log to files in the host.\", \"value\": null}, \"volumes\": {\"description\": \"The volumes needed to log to files in the host.\", \"value\": [\"/var/log/containers/nova:/var/log/nova\"]}, \"docker_config\": {\"description\": \"Extra containers needed for logging to files in the host.\", \"value\": {\"step_2\": {\"map_replace\": [{\"CONTAINERNAME\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaImage\"]}, \"net\": \"none\", \"privileged\": false, \"user\": \"root\", \"volumes\": [\"/var/log/containers/nova:/var/log/nova:z\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R nova:nova /var/log/nova\"], \"environment\": {\"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}}}}, {\"keys\": {\"CONTAINERNAME\": {\"get_attr\": [\"InitLogContainerName\", \"value\"]}}}]}}}, \"host_prep_tasks\": {\"description\": \"Extra ansible tasks needed for logging to files in the host.\", \"value\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"setype\": \"{{ item.setype }}\", \"state\": \"directory\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/nova\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}]}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ContainerNovaImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"NovaServiceName\": \"vncproxy\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(231,'2026-06-10 07:47:39',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(232,'2026-06-10 07:47:40',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mysql client settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role for setting mysql client parameters\", \"value\": {\"service_name\": \"mysql_client\", \"config_settings\": {\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"tripleo::profile::base::database::mysql::client::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}}, \"step_config\": \"include tripleo::profile::base::database::mysql::client\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(233,'2026-06-10 07:47:40',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (234,'2026-06-10 07:47:40',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Nova base service. Shared for all Nova services.\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"noop\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"NovaPassword\": {\"description\": \"The password for the nova service and db account\", \"type\": \"string\", \"hidden\": true, \"default\": \"btE80AtSdL16lZ5QqRx6f9I9L\"}, \"NeutronPassword\": {\"description\": \"The password for the neutron service and db account, used by neutron agents.\", \"type\": \"string\", \"hidden\": true, \"default\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\"}, \"PlacementPassword\": {\"description\": \"The password for the Placement service and db account\", \"type\": \"string\", \"hidden\": true, \"default\": \"LmdoVblRSfwmhsbe1og9276Oe\"}, \"PlacementAPIInterface\": {\"type\": \"string\", \"description\": \"Endpoint interface to be used for the placement API.\\n\", \"default\": \"internal\"}, \"NovaOVSBridge\": {\"default\": \"br-int\", \"description\": \"Name of integration bridge used by Open vSwitch\", \"type\": \"string\"}, \"Debug\": {\"type\": \"boolean\", \"default\": true, \"description\": \"Set to True to enable debugging on all services.\"}, \"NovaDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Nova services.\", \"type\": \"boolean\"}, \"EnableCache\": {\"description\": \"Enable caching with memcached\", \"type\": \"boolean\", \"default\": true}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}, \"EnableConfigPurge\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Remove configuration that is not generated by TripleO. Used to avoid configuration remnants after upgrades.\\n\"}, \"UpgradeLevelNovaCompute\": {\"type\": \"string\", \"description\": \"Nova Compute upgrade level\", \"default\": \"\"}, \"NovaOVSDBConnection\": {\"type\": \"string\", \"description\": \"OVS DB connection string to used by Nova\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"NovaSyncPowerStateInterval\": {\"type\": \"number\", \"description\": \"Interval to sync power states between the database and the hypervisor. Set to -1 to disable. Setting this to 0 will run at the default rate(60) defined in oslo.service.\", \"default\": 600}, \"RpcUseSSL\": {\"default\": false, \"description\": \"Messaging client subscriber parameter to specify an SSL connection to the messaging host.\\n\", \"type\": \"string\"}, \"NovaAdditionalCell\": {\"default\": false, \"description\": \"Whether this is an cell additional to the default cell.\", \"type\": \"boolean\"}, \"NovaCrossAZAttach\": {\"default\": true, \"description\": \"Whether instances can attach cinder volumes from a different availability zone.\", \"type\": \"boolean\"}, \"MemcachedTLS\": {\"default\": false, \"description\": \"Set to True to enable TLS on Memcached service. Because not all services support Memcached TLS, during the migration period, Memcached will listen on 2 ports - on the port set with MemcachedPort parameter (above) and on 11211, without TLS.\", \"type\": \"boolean\"}}, \"conditions\": {\"compute_upgrade_level_set\": {\"not\": {\"equals\": [{\"get_param\": \"UpgradeLevelNovaCompute\"}, \"\"]}}, \"tls_cache_enabled\": {\"and\": [{\"get_param\": \"EnableCache\"}, {\"get_param\": \"MemcachedTLS\"}]}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"nova::ovsdb_connection\": \"NovaOVSDBConnection\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"NovaOVSDBConnection\": {\"get_param\": \"NovaOVSDBConnection\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Nova base service.\", \"value\": {\"service_name\": \"nova_base\", \"config_settings\": {\"map_merge\": [{\"nova::my_ip\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}}}, \"nova::rabbit_use_ssl\": {\"get_param\": \"RpcUseSSL\"}, \"nova::keystone::service_user::send_service_user_token\": true, \"nova::keystone::service_user::project_name\": \"service\", \"nova::keystone::service_user::password\": {\"get_param\": \"NovaPassword\"}, \"nova::keystone::service_user::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"nova::keystone::service_user::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"nova::placement::project_name\": \"service\", \"nova::placement::password\": {\"get_param\": \"PlacementPassword\"}, \"nova::placement::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"nova::placement::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"nova::placement::valid_interfaces\": {\"get_param\": \"PlacementAPIInterface\"}, \"nova::os_region_name\": {\"get_param\": \"KeystoneRegion\"}, \"nova::logging::debug\": {\"if\": [{\"get_param\": \"NovaDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"nova::purge_config\": {\"get_param\": \"EnableConfigPurge\"}, \"nova::network::neutron::project_name\": \"service\", \"nova::network::neutron::username\": \"neutron\", \"nova::network::neutron::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"nova::dhcp_domain\": \"\", \"nova::network::neutron::password\": {\"get_param\": \"NeutronPassword\"}, \"nova::network::neutron::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneV3Internal\", \"uri\"]}, \"nova::network::neutron::valid_interfaces\": \"internal\", \"nova::glance::valid_interfaces\": \"internal\", \"nova::rabbit_heartbeat_timeout_threshold\": 60, \"nova::cinder_catalog_info\": \"volumev3:cinderv3:internalURL\", \"nova::host\": \"%{hiera(\'fqdn_canonical\')}\", \"nova::notify_on_state_change\": \"vm_and_task_state\", \"nova::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"nova::notification_format\": \"unversioned\", \"nova::network::neutron::auth_type\": \"v3password\", \"nova::db::database_db_max_retries\": -1, \"nova::db::database_max_retries\": -1, \"nova::network::neutron::ovs_bridge\": {\"get_param\": \"NovaOVSBridge\"}, \"nova::compute::sync_power_state_interval\": {\"get_param\": \"NovaSyncPowerStateInterval\"}, \"nova_is_additional_cell\": {\"get_param\": \"NovaAdditionalCell\"}, \"nova::cross_az_attach\": {\"get_param\": \"NovaCrossAZAttach\"}, \"nova::cache::enabled\": {\"get_param\": \"EnableCache\"}, \"nova::cache::tls_enabled\": {\"get_param\": \"MemcachedTLS\"}, \"nova::cache::backend\": {\"if\": [\"tls_cache_enabled\", \"dogpile.cache.pymemcache\", \"dogpile.cache.memcached\"]}, \"nova::rabbit_heartbeat_in_pthread\": false, \"nova::upgrade_level_compute\": {\"if\": [\"compute_upgrade_level_set\", {\"get_param\": \"UpgradeLevelNovaCompute\"}]}}, {\"get_attr\": [\"RoleParametersValue\", \"value\"]}]}, \"service_config_settings\": {\"rabbitmq\": {\"nova::rabbit_use_ssl\": {\"get_param\": \"RpcUseSSL\"}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(235,'2026-06-10 07:47:40',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(236,'2026-06-10 07:47:41',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Nova database client service.\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"NovaPassword\": {\"description\": \"The password for the nova service and db account\", \"type\": \"string\", \"hidden\": true, \"default\": \"btE80AtSdL16lZ5QqRx6f9I9L\"}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Nova base service.\", \"value\": {\"config_settings\": {\"nova::database_connection\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MysqlCellInternal\", \"protocol\"]}, \"username\": \"nova\", \"password\": {\"get_param\": \"NovaPassword\"}, \"host\": {\"get_param\": [\"EndpointMap\", \"MysqlCellInternal\", \"host\"]}, \"path\": \"/nova\", \"query\": {\"if\": [{\"get_param\": \"EnableSQLAlchemyCollectd\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\", \"plugin\": \"collectd\", \"collectd_program_name\": \"nova\", \"collectd_host\": \"localhost\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\"}]}}}}, \"service_config_settings\": {\"mysql\": {\"nova::db::mysql::password\": {\"get_param\": \"NovaPassword\"}, \"nova::db::mysql::user\": \"nova\", \"nova::db::mysql::host\": \"%\", \"nova::db::mysql::dbname\": \"nova\"}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(237,'2026-06-10 07:47:41',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Rabbitmq service\\n\", \"parameters\": {\"ContainerRabbitmqImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\"}, \"ContainerRabbitmqConfigImage\": {\"description\": \"The container image to use for the rabbitmq config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"RabbitCookie\": {\"type\": \"string\", \"default\": \"mSuIvlFkPdOYUvFgLZx2\", \"hidden\": true}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"RabbitUserName\": {\"default\": \"guest\", \"description\": \"The username for RabbitMQ\", \"type\": \"string\"}, \"RabbitPassword\": {\"description\": \"The password for RabbitMQ\", \"type\": \"string\", \"hidden\": true, \"default\": \"YBsJWf2H0b7bOztSoZY2lUw6b\"}, \"RabbitFDLimit\": {\"default\": 65536, \"description\": \"Configures RabbitMQ FD limit\", \"type\": \"number\"}, \"RabbitTCPBacklog\": {\"default\": 4096, \"description\": \"Configures RabbitMQ maximum TCP Backlog\", \"type\": \"number\"}, \"RabbitIPv6\": {\"default\": false, \"description\": \"Enable IPv6 in RabbitMQ\", \"type\": \"boolean\"}, \"RabbitHAQueues\": {\"description\": \"The number of HA queues to be configured in rabbit. The default is -1 which translates to \\\"ha-mode all\\\". The special value 0 will be automatically overridden to CEIL(N/2) where N is the number of nodes running rabbitmq.\", \"default\": 0, \"type\": \"number\"}, \"RabbitNetTickTime\": {\"description\": \"The number of seconds to configure the value of the erlang net_ticktime kernel variable.\", \"default\": 15, \"type\": \"number\"}, \"RabbitFIPS\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Configures RabbitMQ to run in FIPS mode\"}, \"RabbitAdditionalErlArgs\": {\"description\": \"Additional parameters passed to the Erlang subsystem. The string needs to be enclosed in quotes twice. We default to \'+sbwt none +sbwtdcpu none +sbwtdio none\' in order to have the erlang vm be less busy on spinlocks, but we allow a simple way of overriding it.\", \"default\": \"\'+sbwt none +sbwtdcpu none +sbwtdio none\'\", \"type\": \"string\"}, \"MonitoringSubscriptionRabbitmq\": {\"default\": \"overcloud-rabbitmq\", \"type\": \"string\"}, \"DeployIdentifier\": {\"default\": 1781077560, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"RabbitmqCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RabbitmqEnableManagementAccess\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Allow access to RabbitMQ management plugin over network\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"The following parameters are deprecated and will be removed. They should not\\nbe relied on for new deployments. If you have concerns regarding deprecated\\nparameters, please contact the TripleO development team on IRC or the\\nOpenStack mailing list.\\n\", \"parameters\": [\"RabbitIPv6\"]}], \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"is_ipv6\": {\"equals\": [{\"get_param\": [\"ServiceData\", \"net_ip_version_map\", {\"get_param\": [\"ServiceNetMap\", \"RabbitmqNetwork\"]}]}, 6]}, \"key_size_override_unset\": {\"equals\": [{\"get_param\": \"RabbitmqCertificateKeySize\"}, \"\"]}, \"rabbitmq_cacert_set\": {\"not\": {\"equals\": [{\"get_param\": \"InternalTLSCAFile\"}, \"\"]}}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerRabbitmqImage\": \"ContainerRabbitmqImage\", \"ContainerRabbitmqConfigImage\": \"ContainerRabbitmqConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerRabbitmqImage\": {\"get_param\": \"ContainerRabbitmqImage\"}, \"ContainerRabbitmqConfigImage\": {\"get_param\": \"ContainerRabbitmqConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Rabbitmq API role.\", \"value\": {\"service_name\": \"rabbitmq\", \"firewall_rules\": {\"109 rabbitmq\": {\"dport\": {\"list_concat\": [[4369, 5672, 25672, \"25673-25683\"], {\"if\": [{\"get_param\": \"RabbitmqEnableManagementAccess\"}, [15672]]}]}}}, \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionRabbitmq\"}, \"config_settings\": {\"map_merge\": [{\"rabbitmq::file_limit\": {\"get_param\": \"RabbitFDLimit\"}, \"rabbitmq::default_user\": {\"get_param\": \"RabbitUserName\"}, \"rabbitmq::default_pass\": {\"get_param\": \"RabbitPassword\"}, \"rabbit_ipv6\": {\"if\": [\"is_ipv6\", true, false]}, \"rabbitmq::delete_guest_user\": false, \"rabbitmq::wipe_db_on_cookie_change\": true, \"rabbitmq::port\": 5672, \"rabbitmq::loopback_users\": [], \"rabbitmq::tcp_backlog\": {\"get_param\": \"RabbitTCPBacklog\"}, \"rabbitmq::repos_ensure\": false, \"rabbitmq::tcp_keepalive\": true, \"rabbitmq_environment\": {\"LANG\": \"en_US.UTF-8\", \"LC_ALL\": \"en_US.UTF-8\", \"NODE_PORT\": \"\", \"NODE_IP_ADDRESS\": \"\", \"RABBITMQ_NODENAME\": {\"str_replace\": {\"template\": \"rabbit@%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"RabbitmqNetwork\"]}}}}, \"RABBITMQ_USE_LONGNAME\": \"true\", \"RABBITMQ_CTL_DIST_PORT_MIN\": \"25673\", \"RABBITMQ_CTL_DIST_PORT_MAX\": \"25683\", \"export ERL_EPMD_ADDRESS\": \"%{hiera(\'rabbitmq::interface\')}\"}, \"tripleo::profile::base::rabbitmq::additional_erl_args\": {\"get_param\": \"RabbitAdditionalErlArgs\"}, \"rabbitmq_kernel_variables\": {\"inet_dist_listen_min\": \"25672\", \"inet_dist_listen_max\": \"25672\", \"net_ticktime\": {\"get_param\": \"RabbitNetTickTime\"}}, \"rabbitmq_config_variables\": {\"cluster_partition_handling\": \"ignore\", \"queue_master_locator\": \"<<\\\"min-masters\\\">>\"}, \"rabbitmq::config_additional_variables\": {\"lager\": \"[{crash_log_count, 0}, { crash_log_date, \\\"\\\"}, { crash_log_size, 0 }]\"}, \"rabbitmq::erlang_cookie\": {\"get_param\": \"RabbitCookie\"}, \"rabbitmq::interface\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"RabbitmqNetwork\"]}}}}, \"rabbitmq::nr_ha_queues\": {\"get_param\": \"RabbitHAQueues\"}, \"rabbitmq::ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"rabbitmq::ssl_erl_dist\": {\"get_param\": \"EnableInternalTLS\"}, \"rabbitmq::ssl_port\": 5672, \"rabbitmq::ssl_depth\": 1, \"rabbitmq::ssl_only\": {\"get_param\": \"EnableInternalTLS\"}, \"rabbitmq::ssl_interface\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"RabbitmqNetwork\"]}}}}, \"tripleo::profile::base::rabbitmq::enable_internal_tls\": {\"get_param\": \"EnableInternalTLS\"}, \"tripleo::profile::base::rabbitmq::fips_mode\": {\"get_param\": \"RabbitFIPS\"}, \"rabbitmq::collect_statistics_interval\": 30000}, {\"if\": [\"internal_tls_enabled\", {\"tripleo::rabbitmq::service_certificate\": \"/etc/pki/tls/certs/rabbitmq.crt\", \"tripleo::profile::base::rabbitmq::certificate_specs\": {\"service_certificate\": \"/etc/pki/tls/certs/rabbitmq.crt\", \"service_key\": \"/etc/pki/tls/private/rabbitmq.key\"}, \"rabbitmq::ssl_versions\": {\"if\": [{\"get_param\": \"RabbitFIPS\"}, [\"tlsv1.2\", \"tlsv1.3\"], [\"tlsv1.2\"]]}}, {}]}, {\"rabbitmq::admin_enable\": false, \"rabbitmq::management_enable\": true, \"rabbitmq::use_config_file_for_plugins\": true, \"rabbitmq::management_ip_address\": {\"if\": [{\"get_param\": \"RabbitmqEnableManagementAccess\"}, {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"RabbitmqManagementNetwork\"]}}}}, \"127.0.0.1\"]}, \"rabbitmq::management_port\": 15672, \"rabbitmq::config_management_variables\": {\"rates_mode\": \"none\"}}, {\"if\": [\"rabbitmq_cacert_set\", {\"rabbitmq::ssl_cacert\": {\"get_param\": \"InternalTLSCAFile\"}, \"rabbitmq::ssl_management_cacert\": {\"get_param\": \"InternalTLSCAFile\"}}]}, {\"if\": [\"internal_tls_enabled\", {\"tripleo::certmonger::rabbitmq::postsave_cmd\": \"true\"}, {}]}]}, \"puppet_config\": {\"config_volume\": \"rabbitmq\", \"step_config\": {\"list_join\": [\"\\n\", [\"[\'Rabbitmq_policy\', \'Rabbitmq_user\'].each |String $val| { noop_resource($val) }\", \"include tripleo::profile::base::rabbitmq\"]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerRabbitmqConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/rabbitmq.json\": {\"command\": \"/usr/lib/rabbitmq/bin/rabbitmq-server\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true, \"optional\": true}], \"permissions\": [{\"path\": \"/var/lib/rabbitmq\", \"owner\": \"rabbitmq:rabbitmq\", \"recurse\": true}, {\"path\": \"/etc/pki/tls/certs/rabbitmq.crt\", \"owner\": \"rabbitmq:rabbitmq\", \"optional\": true}, {\"path\": \"/etc/pki/tls/private/rabbitmq.key\", \"owner\": \"rabbitmq:rabbitmq\", \"optional\": true}]}}, \"docker_config\": {\"step_1\": {\"rabbitmq_init_logs\": {\"start_order\": 0, \"detach\": false, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerRabbitmqImage\"]}, \"net\": \"none\", \"privileged\": false, \"user\": \"root\", \"volumes\": [\"/var/log/containers/rabbitmq:/var/log/rabbitmq\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R rabbitmq:rabbitmq /var/log/rabbitmq\"]}, \"rabbitmq_bootstrap\": {\"start_order\": 1, \"detach\": false, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerRabbitmqImage\"]}, \"net\": \"host\", \"privileged\": false, \"user\": \"root\", \"command\": [\"bash\", \"-ec\", {\"list_join\": [\"\\n\", [\"kolla_set_configs\", \"if [[ -e \\\"/var/lib/rabbitmq/.erlang.cookie\\\" ]]; then rm -f /var/lib/rabbitmq/.erlang.cookie; fi\", \"hiera \'rabbitmq::erlang_cookie\' > /var/lib/rabbitmq/.erlang.cookie\", \"chown rabbitmq:rabbitmq /var/lib/rabbitmq/.erlang.cookie\", \"chmod 400 /var/lib/rabbitmq/.erlang.cookie\"]]}], \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/rabbitmq.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/rabbitmq:/var/lib/kolla/config_files/src:ro\", \"/etc/puppet:/etc/puppet:ro\", \"/var/lib/rabbitmq:/var/lib/rabbitmq\", \"/var/log/containers/rabbitmq:/var/log/rabbitmq\"], {\"if\": [\"internal_tls_enabled\", [\"/etc/pki/tls/certs/rabbitmq.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/rabbitmq.crt:ro\", \"/etc/pki/tls/private/rabbitmq.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/rabbitmq.key:ro\"], null]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\", \"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}}}, \"rabbitmq\": {\"start_order\": 2, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerRabbitmqImage\"]}, \"net\": \"host\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/rabbitmq.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/rabbitmq:/var/lib/kolla/config_files/src:ro\", \"/var/lib/rabbitmq:/var/lib/rabbitmq:z\", \"/var/log/containers/rabbitmq:/var/log/rabbitmq:z\"], {\"if\": [\"internal_tls_enabled\", [\"/etc/pki/tls/certs/rabbitmq.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/rabbitmq.crt:ro\", \"/etc/pki/tls/private/rabbitmq.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/rabbitmq.key:ro\"], null]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"container_puppet_tasks\": {\"step_2\": {\"config_volume\": \"rabbit_init_tasks\", \"puppet_tags\": \"rabbitmq_policy,rabbitmq_user\", \"step_config\": \"include tripleo::profile::base::rabbitmq\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerRabbitmqConfigImage\"]}, \"volumes\": [\"/var/lib/config-data/puppet-generated/rabbitmq/etc/rabbitmq:/etc/rabbitmq:ro\", \"/var/lib/rabbitmq:/var/lib/rabbitmq\"]}}, \"metadata_settings\": {\"if\": [\"internal_tls_enabled\", [{\"service\": \"rabbitmq\", \"network\": {\"get_param\": [\"ServiceNetMap\", \"RabbitmqNetwork\"]}, \"type\": \"node\"}], null]}, \"deploy_steps_tasks\": [{\"name\": \"Certificate generation\", \"when\": [\"step|int == 1\", \"enable_internal_tls\"], \"block\": [{\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": [{\"name\": \"rabbitmq\", \"dns\": {\"str_replace\": {\"template\": \"{{fqdn_$NETWORK}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"RabbitmqNetwork\"]}}}}, \"principal\": {\"str_replace\": {\"template\": \"rabbitmq/{{fqdn_$NETWORK}}@{{idm_realm}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"RabbitmqNetwork\"]}}}}, \"run_after\": \"container_name=$({{container_cli}} ps --format=\\\\{\\\\{.Names\\\\}\\\\} | grep -w -E \'rabbitmq(-bundle-.*-[0-9]+)?\')\\nservice_crt=\\\"/etc/pki/tls/certs/rabbitmq.crt\\\"\\nservice_key=\\\"/etc/pki/tls/private/rabbitmq.key\\\"\\nif echo \\\"$container_name\\\" | grep -q \\\"^rabbitmq-bundle\\\"; then\\n  # lp#1917868: Do not use podman cp with HA containers as they get\\n  # frozen temporarily and that can make pacemaker operation fail.\\n  tar -c \\\"$service_crt\\\" \\\"$service_key\\\" | {{container_cli}} exec -i \\\"$container_name\\\" tar -C / -xv\\n  # no need to update the mount point, because pacemaker\\n  # recreates the container when it\'s restarted\\nelse\\n  # Refresh the cert at the mount-point\\n  {{container_cli}} cp $service_crt \\\"$container_name:/var/lib/kolla/config_files/src-tls/$service_crt\\\"\\n  # Refresh the key at the mount-point\\n  {{container_cli}} cp $service_key \\\"$container_name:/var/lib/kolla/config_files/src-tls/$service_key\\\"\\n  # Copy the new cert from the mount-point to the real path\\n  {{container_cli}} exec -u root \\\"$container_name\\\" cp \\\"/var/lib/kolla/config_files/src-tls$service_crt\\\" \\\"$service_crt\\\"\\n  # Copy the new key from the mount-point to the real path\\n  {{container_cli}} exec -u root \\\"$container_name\\\" cp \\\"/var/lib/kolla/config_files/src-tls$service_key\\\" \\\"$service_key\\\"\\nfi\\n# Set appropriate permissions\\n{{container_cli}} exec -u root \\\"$container_name\\\" chown rabbitmq:rabbitmq \\\"$service_crt\\\"\\n{{container_cli}} exec -u root \\\"$container_name\\\" chown rabbitmq:rabbitmq \\\"$service_key\\\"\\n# Trigger a pem cache clear in RabbitMQ to read the new certificates\\n{{container_cli}} exec \\\"$container_name\\\" rabbitmqctl eval \\\"ssl:clear_pem_cache().\\\"\\n\", \"key_size\": {\"if\": [\"key_size_override_unset\", {\"get_param\": \"CertificateKeySize\"}, {\"get_param\": \"RabbitmqCertificateKeySize\"}]}, \"ca\": \"ipa\"}]}}]}], \"host_prep_tasks\": [{\"name\": \"creat fcontext entry for rabbitmq data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/rabbitmq(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/rabbitmq\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/rabbitmq\", \"setype\": \"container_file_t\"}]}], \"upgrade_tasks\": [], \"update_tasks\": null}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(238,'2026-06-10 07:47:42',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"SNMP client configured with Puppet, to facilitate Ceilometer Hardware monitoring in the undercloud. This service is required to enable hardware monitoring.\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"SnmpdReadonlyUserName\": {\"default\": \"ro_snmp_user\", \"description\": \"The user name for SNMPd with readonly rights running on all Overcloud nodes\", \"type\": \"string\"}, \"SnmpdReadonlyUserPassword\": {\"description\": \"The user password for SNMPd with readonly rights running on all Overcloud nodes\", \"type\": \"string\", \"hidden\": true, \"default\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\"}, \"SnmpdBindHost\": {\"description\": \"An array of bind host addresses on which SNMP daemon will listen.\", \"type\": \"comma_delimited_list\", \"default\": [\"udp:161\", \"udp6:[::1]:161\"]}, \"SnmpdOptions\": {\"description\": \"A string containing the commandline options passed to snmpd\", \"type\": \"string\", \"default\": \"-LS0-5d\"}, \"SnmpdIpSubnet\": {\"default\": \"\", \"description\": \"IP address/subnet on the snmpd network. If empty (default), SnmpdNetwork will be taken.\", \"type\": \"string\"}}, \"conditions\": {\"snmpd_network_unset\": {\"equals\": [{\"get_param\": \"SnmpdIpSubnet\"}, \"\"]}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the SNMP services\", \"value\": {\"service_name\": \"snmp\", \"firewall_rules\": {\"if\": [\"snmpd_network_unset\", {\"map_merge\": {\"repeat\": {\"for_each\": {\"<%net_cidr%>\": {\"get_param\": [\"ServiceData\", \"net_cidr_map\", {\"get_param\": [\"ServiceNetMap\", \"SnmpdNetwork\"]}]}}, \"template\": {\"124 snmp <%net_cidr%>\": {\"dport\": 161, \"proto\": \"udp\", \"source\": \"<%net_cidr%>\"}}}}}, {\"124 snmp\": {\"dport\": 161, \"proto\": \"udp\", \"source\": {\"get_param\": \"SnmpdIpSubnet\"}}}]}, \"config_settings\": {\"tripleo::profile::base::snmp::snmpd_user\": {\"get_param\": \"SnmpdReadonlyUserName\"}, \"tripleo::profile::base::snmp::snmpd_password\": {\"get_param\": \"SnmpdReadonlyUserPassword\"}, \"snmp::agentaddress\": {\"get_param\": \"SnmpdBindHost\"}, \"snmp::snmpd_options\": {\"get_param\": \"SnmpdOptions\"}}, \"step_config\": \"include tripleo::profile::base::snmp\\n\", \"upgrade_tasks\": [{\"when\": \"step|int == 0\", \"block\": [{\"name\": \"Check if snmpd is enabled\", \"command\": \"systemctl is-enabled --quiet snmpd\", \"failed_when\": false, \"register\": \"snmpd_enabled_result\"}, {\"name\": \"Set fact snmpd_enabled\", \"set_fact\": {\"snmpd_enabled\": \"{{ snmpd_enabled_result.rc == 0 }}\"}}]}, {\"name\": \"Stop snmp service\", \"when\": [\"step|int == 1\", \"snmpd_enabled|bool\"], \"service\": \"name=snmpd state=stopped\"}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(239,'2026-06-10 07:47:42',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(240,'2026-06-10 07:47:42',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mysql client settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role for setting mysql client parameters\", \"value\": {\"service_name\": \"mysql_client\", \"config_settings\": {\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"tripleo::profile::base::database::mysql::client::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}}, \"step_config\": \"include tripleo::profile::base::database::mysql::client\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(241,'2026-06-10 07:47:42',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Containerized logrotate with crond for containerized service logs rotation\\n\", \"parameters\": {\"ContainerCrondImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\"}, \"ContainerCrondConfigImage\": {\"description\": \"The container image to use for the crond config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"LogrotateMaxsize\": {\"description\": \"Configures the maxsize param for containerized logrotate.\", \"type\": \"string\", \"default\": \"10M\"}, \"LogrotateRotationInterval\": {\"description\": \"Configures rotation interval for containerized logrotate.\", \"type\": \"string\", \"default\": \"daily\", \"constraints\": [{\"allowed_values\": [\"hourly\", \"daily\", \"weekly\", \"monthly\"]}]}, \"LogrotateRotate\": {\"description\": \"Configures the rotate param for containerized logrotate.\", \"type\": \"string\", \"default\": \"14\"}, \"LogrotatePurgeAfterDays\": {\"description\": \"Enforces life time (days) of rotated and compressed files.\", \"type\": \"string\", \"default\": \"14\"}, \"LogrotateDateExt\": {\"description\": \"Enable/disable dateext parameter.\", \"type\": \"boolean\", \"default\": false}, \"LogrotateDateFormat\": {\"description\": \"Configures dateformat strings for containerized logrotate. This is valid when LogrotateDateExt is true. The allowed specifiers are only %Y %m %d %H %M %S %V and %s.\", \"type\": \"string\", \"default\": \"-%Y%m%d\", \"constraints\": [{\"allowed_pattern\": \"-(%[YmdHMSVs])+$\"}]}, \"LogrotateDateYesterday\": {\"description\": \"Configures dateyesterday paramter for containerized logrotate. This is valid when LogrotateDateExt is true.\", \"type\": \"boolean\", \"default\": false}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerCrondImage\": \"ContainerCrondImage\", \"ContainerCrondConfigImage\": \"ContainerCrondConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerCrondImage\": {\"get_param\": \"ContainerCrondImage\"}, \"ContainerCrondConfigImage\": {\"get_param\": \"ContainerCrondConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the crond role.\", \"value\": {\"service_name\": \"logrotate_crond\", \"config_settings\": {\"map_merge\": [{\"tripleo::profile::base::logging::logrotate::maxsize\": {\"get_param\": \"LogrotateMaxsize\"}, \"tripleo::profile::base::logging::logrotate::rotation\": {\"get_param\": \"LogrotateRotationInterval\"}, \"tripleo::profile::base::logging::logrotate::rotate\": {\"get_param\": \"LogrotateRotate\"}, \"tripleo::profile::base::logging::logrotate::purge_after_days\": {\"get_param\": \"LogrotatePurgeAfterDays\"}, \"tripleo::profile::base::logging::logrotate::dateext\": {\"get_param\": \"LogrotateDateExt\"}}, {\"if\": [{\"get_param\": \"LogrotateDateExt\"}, {\"tripleo::profile::base::logging::logrotate::dateformat\": {\"get_param\": \"LogrotateDateFormat\"}, \"tripleo::profile::base::logging::logrotate::dateyesterday\": {\"get_param\": \"LogrotateDateYesterday\"}}]}]}, \"host_prep_tasks\": [{\"name\": \"allow logrotate to read inside containers\", \"seboolean\": {\"name\": \"logrotate_read_inside_containers\", \"persistent\": true, \"state\": true}, \"when\": [\"ansible_facts.selinux is defined\", \"ansible_facts.selinux.status == \\\"enabled\\\"\"]}], \"deploy_steps_tasks\": [{\"name\": \"configure tmpwatch on the host\", \"when\": \"step|int == 2\", \"block\": [{\"name\": \"Push script\", \"copy\": {\"dest\": \"/usr/local/sbin/containers-tmpwatch\", \"owner\": \"root\", \"group\": \"root\", \"mode\": 493, \"content\": \"#!/bin/sh\\ntmpwatch --nodirs \\\\\\n  -X \\\"/var/log/containers/*/*log\\\" \\\\\\n  -X \\\"/var/log/containers/*/*/*log\\\" \\\\\\n  -X \\\"/var/log/containers/*/*err\\\" \\\\\\n  {{ LogrotatePurgeAfterDays|int +1 }}d \\\\\\n  /var/log/containers/ 2>&1 | logger -t container-tmpwatch\\n\"}, \"vars\": {\"LogrotatePurgeAfterDays\": {\"get_param\": \"LogrotatePurgeAfterDays\"}}}, {\"name\": \"Insert cronjob in root crontab\", \"cron\": {\"name\": \"Remove old logs\", \"special_time\": \"daily\", \"user\": \"root\", \"job\": \"/usr/local/sbin/containers-tmpwatch\"}}]}], \"update_tasks\": [{\"name\": \"Ensure old cron.daily is absent\", \"when\": \"step|int == 1\", \"file\": {\"path\": \"/etc/cron.daily/containers-tmpwatch\", \"state\": \"absent\"}}], \"upgrade_tasks\": [{\"name\": \"Ensure old cron.daily is absent\", \"when\": \"step|int == 1\", \"file\": {\"path\": \"/etc/cron.daily/containers-tmpwatch\", \"state\": \"absent\"}}], \"puppet_config\": {\"config_volume\": \"crond\", \"step_config\": \"include tripleo::profile::base::logging::logrotate\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCrondConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/logrotate-crond.json\": {\"command\": \"/usr/sbin/crond -s -n\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]}}, \"docker_config\": {\"step_4\": {\"logrotate_crond\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCrondImage\"]}, \"net\": \"none\", \"pid\": \"host\", \"privileged\": true, \"user\": \"root\", \"restart\": \"always\", \"healthcheck\": {\"test\": \"/usr/share/openstack-tripleo-common/healthcheck/cron\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/logrotate-crond.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/crond:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers:/var/log/containers:z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop logrotate container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"logrotate_crond\"], \"tripleo_delegate_to\": \"{{ groups[\'logrotate_crond\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(242,'2026-06-10 07:47:43',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Swift Storage services.\\n\", \"parameters\": {\"ContainerSwiftProxyImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\"}, \"ContainerSwiftAccountImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\"}, \"ContainerSwiftContainerImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\"}, \"ContainerSwiftObjectImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\"}, \"ContainerSwiftConfigImage\": {\"description\": \"The container image to use for the swift config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"SwiftRawDisks\": {\"default\": {}, \"description\": \"A hash of additional raw devices to use as Swift backend (eg. {sdb: {}})\", \"type\": \"json\"}, \"SwiftReplicas\": {\"type\": \"number\", \"default\": 3, \"description\": \"How many replicas to use in the swift rings.\"}, \"SwiftUseLocalDir\": {\"default\": true, \"description\": \"Use a local directory for Swift storage services when building rings\", \"type\": \"boolean\"}, \"SwiftContainerSharderEnabled\": {\"description\": \"Set to True to enable Swift container sharder service\", \"default\": false, \"type\": \"boolean\"}, \"SwiftMountCheck\": {\"default\": false, \"description\": \"Value of mount_check in Swift account/container/object -server.conf\", \"type\": \"boolean\"}, \"SwiftUseNodeDataLookup\": {\"default\": false, \"description\": \"Use NodeDataLookup for disk devices in order to use persistent naming\", \"type\": \"boolean\"}, \"SwiftAccountWorkers\": {\"default\": 0, \"description\": \"Number of workers for Swift account service.\", \"type\": \"string\"}, \"SwiftContainerWorkers\": {\"default\": 0, \"description\": \"Number of workers for Swift account service.\", \"type\": \"string\"}, \"SwiftObjectWorkers\": {\"default\": 0, \"description\": \"Number of workers for Swift account service.\", \"type\": \"string\"}, \"DeployIdentifier\": {\"default\": 1781077560, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}, \"MemcachedTLS\": {\"default\": false, \"description\": \"Set to True to enable TLS on Memcached service. Because not all services support Memcached TLS, during the migration period, Memcached will listen on 2 ports - on the port set with MemcachedPort parameter (above) and on 11211, without TLS.\", \"type\": \"boolean\"}, \"ControllerEnableSwiftStorage\": {\"default\": true, \"description\": \"Whether to enable Swift Storage on the Controller\", \"type\": \"boolean\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"Do not use deprecated params, they will be removed.\", \"parameters\": [\"ControllerEnableSwiftStorage\"]}], \"conditions\": {\"single_replica_mode\": {\"equals\": [{\"get_param\": \"SwiftReplicas\"}, 1]}, \"swift_container_sharder_enabled\": {\"equals\": [{\"get_param\": \"SwiftContainerSharderEnabled\"}, true]}, \"swift_mount_check\": {\"or\": [{\"equals\": [{\"get_param\": \"SwiftMountCheck\"}, true]}, {\"not\": {\"equals\": [{\"get_param\": \"SwiftRawDisks\"}, {}]}}]}, \"account_workers_zero\": {\"equals\": [{\"get_param\": \"SwiftAccountWorkers\"}, \"0\"]}, \"container_workers_zero\": {\"equals\": [{\"get_param\": \"SwiftContainerWorkers\"}, \"0\"]}, \"object_workers_zero\": {\"equals\": [{\"get_param\": \"SwiftObjectWorkers\"}, \"0\"]}, \"use_node_data_lookup\": {\"equals\": [{\"get_param\": \"SwiftUseNodeDataLookup\"}, true]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"SwiftBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-base.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerSwiftProxyImage\": \"ContainerSwiftProxyImage\", \"ContainerSwiftAccountImage\": \"ContainerSwiftAccountImage\", \"ContainerSwiftContainerImage\": \"ContainerSwiftContainerImage\", \"ContainerSwiftObjectImage\": \"ContainerSwiftObjectImage\", \"ContainerSwiftConfigImage\": \"ContainerSwiftConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerSwiftProxyImage\": {\"get_param\": \"ContainerSwiftProxyImage\"}, \"ContainerSwiftAccountImage\": {\"get_param\": \"ContainerSwiftAccountImage\"}, \"ContainerSwiftContainerImage\": {\"get_param\": \"ContainerSwiftContainerImage\"}, \"ContainerSwiftObjectImage\": {\"get_param\": \"ContainerSwiftObjectImage\"}, \"ContainerSwiftConfigImage\": {\"get_param\": \"ContainerSwiftConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the swift storage services.\", \"value\": {\"service_name\": \"swift_storage\", \"firewall_rules\": {\"123 swift storage\": {\"dport\": [873, 6000, 6001, 6002]}}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"SwiftBase\", \"role_data\", \"config_settings\"]}, {\"swift::storage::all::mount_check\": false, \"tripleo::profile::base::swift::storage::use_local_dir\": {\"get_param\": \"SwiftUseLocalDir\"}, \"swift::storage::all::incoming_chmod\": \"Du=rwx,g=rx,o=rx,Fu=rw,g=r,o=r\", \"swift::storage::all::outgoing_chmod\": \"Du=rwx,g=rx,o=rx,Fu=rw,g=r,o=r\", \"swift::storage::all::account_port\": 6002, \"swift::storage::all::container_port\": 6001, \"swift::storage::all::object_port\": 6000, \"swift::storage::all::object_pipeline\": [\"healthcheck\", \"recon\", \"object-server\"], \"swift::storage::all::container_pipeline\": [\"healthcheck\", \"recon\", \"container-server\"], \"swift::storage::all::account_pipeline\": [\"healthcheck\", \"recon\", \"account-server\"]}, {\"if\": [\"use_node_data_lookup\", {}, {\"swift::storage::disks::args\": {\"get_param\": \"SwiftRawDisks\"}}]}, {\"swift::storage::all::storage_local_net_ip\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"SwiftStorageNetwork\"]}}}}, \"rsync::server::pid_file\": \"UNSET\", \"swift::objectexpirer::cache_tls_enabled\": {\"get_param\": \"MemcachedTLS\"}}, {\"if\": [\"account_workers_zero\", {}, {\"swift::storage::all::account_server_workers\": {\"get_param\": \"SwiftAccountWorkers\"}}]}, {\"if\": [\"container_workers_zero\", {}, {\"swift::storage::all::container_server_workers\": {\"get_param\": \"SwiftContainerWorkers\"}}]}, {\"if\": [\"object_workers_zero\", {}, {\"swift::storage::all::object_server_workers\": {\"get_param\": \"SwiftObjectWorkers\"}}]}]}, \"service_config_settings\": {}, \"puppet_config\": {\"config_volume\": \"swift\", \"puppet_tags\": \"swift_config,swift_container_config,swift_container_sync_realms_config,swift_account_config,swift_object_config,swift_object_expirer_config,rsync::server\", \"step_config\": {\"list_join\": [\"\\n\", [\"class xinetd() {}\", \"define xinetd::service($bind=\'\',$port=\'\',$server=\'\',$server_args=\'\') {}\", \"noop_resource(\'service\')\", \"include tripleo::profile::base::swift::storage\"]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerSwiftConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/swift_account_auditor.json\": {\"command\": \"/usr/bin/swift-account-auditor /etc/swift/account-server.conf\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]}, \"/var/lib/kolla/config_files/swift_account_reaper.json\": {\"command\": \"/usr/bin/swift-account-reaper /etc/swift/account-server.conf\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]}, \"/var/lib/kolla/config_files/swift_account_replicator.json\": {\"command\": \"/usr/bin/swift-account-replicator /etc/swift/account-server.conf\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]}, \"/var/lib/kolla/config_files/swift_account_server.json\": {\"command\": \"/usr/bin/swift-account-server /etc/swift/account-server.conf\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]}, \"/var/lib/kolla/config_files/swift_container_auditor.json\": {\"command\": \"/usr/bin/swift-container-auditor /etc/swift/container-server.conf\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]}, \"/var/lib/kolla/config_files/swift_container_replicator.json\": {\"command\": \"/usr/bin/swift-container-replicator /etc/swift/container-server.conf\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]}, \"/var/lib/kolla/config_files/swift_container_updater.json\": {\"command\": \"/usr/bin/swift-container-updater /etc/swift/container-server.conf\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]}, \"/var/lib/kolla/config_files/swift_container_server.json\": {\"command\": \"/usr/bin/swift-container-server /etc/swift/container-server.conf\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]}, \"/var/lib/kolla/config_files/swift_container_sharder.json\": {\"command\": \"/usr/bin/swift-container-sharder /etc/swift/container-server.conf\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]}, \"/var/lib/kolla/config_files/swift_object_auditor.json\": {\"command\": \"/usr/bin/swift-object-auditor /etc/swift/object-server.conf\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]}, \"/var/lib/kolla/config_files/swift_object_expirer.json\": {\"command\": \"/usr/bin/swift-object-expirer /etc/swift/object-expirer.conf\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]}, \"/var/lib/kolla/config_files/swift_object_replicator.json\": {\"command\": \"/usr/bin/swift-object-replicator /etc/swift/object-server.conf\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]}, \"/var/lib/kolla/config_files/swift_object_updater.json\": {\"command\": \"/usr/bin/swift-object-updater /etc/swift/object-server.conf\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]}, \"/var/lib/kolla/config_files/swift_object_server.json\": {\"command\": \"/usr/bin/swift-object-server /etc/swift/object-server.conf\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/cache/swift\", \"owner\": \"swift:swift\", \"recurse\": true}]}, \"/var/lib/kolla/config_files/swift_rsync.json\": {\"command\": \"/usr/bin/rsync --daemon --no-detach --config=/etc/rsyncd.conf\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]}}, \"docker_config\": {\"step_3\": {\"swift_setup_srv\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerSwiftAccountImage\"]}, \"net\": \"none\", \"user\": \"root\", \"command\": [\"find\", \"/srv/node\", \"-maxdepth\", \"1\", \"-type\", \"d\", \"-exec\", \"chown\", \"swift:\", \"{}\", \";\"], \"volumes\": [\"/srv/node:/srv/node:z\"], \"environment\": {\"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}}}}, \"step_4\": {\"map_merge\": [{\"if\": [\"single_replica_mode\", {}, {\"swift_account_auditor\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerSwiftAccountImage\"]}, \"net\": \"host\", \"user\": \"swift\", \"restart\": \"always\", \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/swift_account_auditor.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/swift:/var/lib/kolla/config_files/src:ro\", \"/srv/node:/srv/node\", \"/dev:/dev\", \"/var/cache/swift:/var/cache/swift:z\", \"/var/log/containers/swift:/var/log/swift:z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}, \"swift_account_replicator\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerSwiftAccountImage\"]}, \"net\": \"host\", \"user\": \"swift\", \"restart\": \"always\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/swift_account_replicator.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/swift:/var/lib/kolla/config_files/src:ro\", \"/srv/node:/srv/node\", \"/dev:/dev\", \"/var/cache/swift:/var/cache/swift\", \"/var/log/containers/swift:/var/log/swift:z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}, \"swift_container_auditor\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerSwiftContainerImage\"]}, \"net\": \"host\", \"user\": \"swift\", \"restart\": \"always\", \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/swift_container_auditor.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/swift:/var/lib/kolla/config_files/src:ro\", \"/srv/node:/srv/node\", \"/dev:/dev\", \"/var/cache/swift:/var/cache/swift\", \"/var/log/containers/swift:/var/log/swift:z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}, \"swift_container_replicator\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerSwiftContainerImage\"]}, \"net\": \"host\", \"user\": \"swift\", \"restart\": \"always\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/swift_container_replicator.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/swift:/var/lib/kolla/config_files/src:ro\", \"/srv/node:/srv/node\", \"/dev:/dev\", \"/var/cache/swift:/var/cache/swift\", \"/var/log/containers/swift:/var/log/swift:z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}, \"swift_object_auditor\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerSwiftObjectImage\"]}, \"net\": \"host\", \"user\": \"swift\", \"restart\": \"always\", \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/swift_object_auditor.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/swift:/var/lib/kolla/config_files/src:ro\", \"/srv/node:/srv/node\", \"/dev:/dev\", \"/var/cache/swift:/var/cache/swift\", \"/var/log/containers/swift:/var/log/swift:z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}, \"swift_object_replicator\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerSwiftObjectImage\"]}, \"net\": \"host\", \"user\": \"swift\", \"restart\": \"always\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/swift_object_replicator.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/swift:/var/lib/kolla/config_files/src:ro\", \"/srv/node:/srv/node\", \"/dev:/dev\", \"/var/cache/swift:/var/cache/swift\", \"/var/log/containers/swift:/var/log/swift:z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}, \"swift_rsync\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerSwiftObjectImage\"]}, \"net\": \"host\", \"user\": \"root\", \"restart\": \"always\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"privileged\": false, \"cap_add\": [\"NET_BIND_SERVICE\"], \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/swift_rsync.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/swift:/var/lib/kolla/config_files/src:ro\", \"/srv/node:/srv/node\", \"/dev:/dev\", \"/var/log/containers/swift:/var/log/swift:z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}]}, {\"swift_account_reaper\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerSwiftAccountImage\"]}, \"net\": \"host\", \"user\": \"swift\", \"restart\": \"always\", \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/swift_account_reaper.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/swift:/var/lib/kolla/config_files/src:ro\", \"/srv/node:/srv/node\", \"/dev:/dev\", \"/var/cache/swift:/var/cache/swift:z\", \"/var/log/containers/swift:/var/log/swift:z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}, \"swift_account_server\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerSwiftAccountImage\"]}, \"net\": \"host\", \"user\": \"swift\", \"restart\": \"always\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/swift_account_server.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/swift:/var/lib/kolla/config_files/src:ro\", \"/srv/node:/srv/node\", \"/dev:/dev\", \"/var/cache/swift:/var/cache/swift\", \"/var/log/containers/swift:/var/log/swift:z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}, \"swift_container_updater\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerSwiftContainerImage\"]}, \"net\": \"host\", \"user\": \"swift\", \"restart\": \"always\", \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/swift_container_updater.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/swift:/var/lib/kolla/config_files/src:ro\", \"/srv/node:/srv/node\", \"/dev:/dev\", \"/var/cache/swift:/var/cache/swift\", \"/var/log/containers/swift:/var/log/swift:z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}, \"swift_container_server\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerSwiftContainerImage\"]}, \"net\": \"host\", \"user\": \"swift\", \"restart\": \"always\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/swift_container_server.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/swift:/var/lib/kolla/config_files/src:ro\", \"/srv/node:/srv/node\", \"/dev:/dev\", \"/var/cache/swift:/var/cache/swift\", \"/var/log/containers/swift:/var/log/swift:z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}, \"swift_object_expirer\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerSwiftProxyImage\"]}, \"net\": \"host\", \"user\": \"swift\", \"restart\": \"always\", \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/swift_object_expirer.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/swift:/var/lib/kolla/config_files/src:ro\", \"/srv/node:/srv/node\", \"/dev:/dev\", \"/var/cache/swift:/var/cache/swift\", \"/var/log/containers/swift:/var/log/swift:z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}, \"swift_object_updater\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerSwiftObjectImage\"]}, \"net\": \"host\", \"user\": \"swift\", \"restart\": \"always\", \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/swift_object_updater.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/swift:/var/lib/kolla/config_files/src:ro\", \"/srv/node:/srv/node\", \"/dev:/dev\", \"/var/cache/swift:/var/cache/swift\", \"/var/log/containers/swift:/var/log/swift:z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}, \"swift_object_server\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerSwiftObjectImage\"]}, \"net\": \"host\", \"user\": \"swift\", \"restart\": \"always\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/swift_object_server.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/swift:/var/lib/kolla/config_files/src:ro\", \"/srv/node:/srv/node\", \"/dev:/dev\", \"/var/cache/swift:/var/cache/swift\", \"/var/log/containers/swift:/var/log/swift:z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}, {\"if\": [\"swift_container_sharder_enabled\", {\"swift_container_sharder\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerSwiftContainerImage\"]}, \"net\": \"host\", \"user\": \"swift\", \"restart\": \"always\", \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/swift_container_sharder.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/swift:/var/lib/kolla/config_files/src:ro\", \"/srv/node:/srv/node\", \"/dev:/dev\", \"/var/cache/swift:/var/cache/swift\", \"/var/log/containers/swift:/var/log/swift:z\"]]}}}, {}]}]}}, \"host_prep_tasks\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/srv/node\", \"setype\": \"container_file_t\"}, {\"path\": \"/var/cache/swift\", \"setype\": \"container_file_t\"}, {\"path\": \"/var/log/containers/swift\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}, {\"name\": \"Set swift_use_local_disks fact\", \"set_fact\": {\"swift_use_local_disks\": {\"get_param\": \"SwiftUseLocalDir\"}}}, {\"name\": \"Set use_node_data_lookup fact\", \"set_fact\": {\"use_node_data_lookup\": {\"get_param\": \"SwiftUseNodeDataLookup\"}}}, {\"name\": \"Create Swift d1 directory if needed\", \"file\": {\"path\": \"/srv/node/d1\", \"state\": \"directory\"}, \"when\": \"swift_use_local_disks\"}, {\"name\": \"Set fact for SwiftRawDisks\", \"set_fact\": {\"swift_raw_disks\": {\"get_param\": \"SwiftRawDisks\"}}, \"when\": \"not use_node_data_lookup|bool\"}, {\"name\": \"Get hiera swift::storage::disks::args\", \"shell\": \"hiera -c /etc/puppet/hiera.yaml swift::storage::disks::args | sed =e \'s/=>/:/g\'\", \"register\": \"hiera_output\", \"when\": \"use_node_data_lookup|bool\"}, {\"name\": \"Set fact for swift_raw_disks\", \"set_fact\": {\"swift_raw_disks\": \"{{ hiera_output.stdout | from_json }}\"}, \"when\": \"use_node_data_lookup|bool\"}, {\"name\": \"Format SwiftRawDisks\", \"community.general.filesystem\": {\"fstype\": \"xfs\", \"dev\": \"{{ swift_raw_disks[item][\'base_dir\']|default(\'/dev\') }}/{{ item }}\", \"opts\": \"-f -i size=1024\"}, \"with_items\": \"{{ swift_raw_disks }}\", \"when\": \"swift_raw_disks|length > 0\"}, {\"name\": \"Refresh facts if SwiftRawDisks is set to get uuids if newly created partitions\", \"setup\": {\"gather_subset\": [\"!all\", \"!min\", \"hardware\"], \"filter\": \"ansible_device_links\"}, \"when\": \"swift_raw_disks|length > 0\"}, {\"name\": \"Mount devices defined in SwiftRawDisks\", \"mount\": {\"name\": \"/srv/node/{{ item }}\", \"src\": \"{% if lsblk.results[\'uuids\'][item] is defined %}UUID={{ ansible_facts[\'device_links\'][\'uuids\'][item][0] }}{% else %}{{ swift_raw_disks[item][\'base_dir\']|default(\'/dev\') }}/{{ item }}{% endif %}\", \"fstype\": \"xfs\", \"opts\": \"noatime\", \"state\": \"mounted\"}, \"with_items\": \"{{ swift_raw_disks }}\", \"when\": \"swift_raw_disks|length > 0\"}], \"deploy_steps_tasks\": [{\"name\": \"Configure rsyslog for swift\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"Check if rsyslog exists\", \"shell\": \"systemctl is-active rsyslog\", \"register\": \"swift_rsyslog_config\"}, {\"name\": \"Forward logging to swift.log file\", \"copy\": {\"content\": \"# Fix for https://bugs.launchpad.net/tripleo/+bug/1776180\\nlocal2.*                 /var/log/containers/swift/swift.log\\n&                        stop\\n\", \"dest\": \"/etc/rsyslog.d/openstack-swift.conf\"}, \"register\": \"swift_logconfig\", \"when\": [\"swift_rsyslog_config is defined\", \"swift_rsyslog_config.rc == 0\"]}, {\"name\": \"Restart rsyslogd service after logging conf change\", \"service\": {\"name\": \"rsyslog\", \"state\": \"restarted\"}, \"when\": [\"swift_logconfig is defined\", \"swift_logconfig is changed\"]}]}, {\"name\": \"Run kolla_set_configs to copy ring files\", \"when\": \"step|int == 5\", \"shell\": \"{{ container_cli }} exec -u root {{ item }} /usr/local/bin/kolla_set_configs\", \"become\": true, \"register\": \"kolla_set_configs_result\", \"failed_when\": [\"kolla_set_configs_result.rc is defined\", \"kolla_set_configs_result.rc not in [0, 125]\"], \"with_items\": [\"swift_account_auditor\", \"swift_account_reaper\", \"swift_account_replicator\", \"swift_account_server\", \"swift_container_auditor\", \"swift_container_replicator\", \"swift_container_server\", \"swift_container_updater\", \"swift_object_auditor\", \"swift_object_expirer\", \"swift_object_replicator\", \"swift_object_server\", \"swift_object_updater\"]}], \"update_tasks\": [{\"name\": \"Check swift containers log folder/symlink exists\", \"stat\": {\"path\": \"/var/log/containers/swift\"}, \"register\": \"swift_log_link\"}, {\"name\": \"Delete if symlink\", \"file\": {\"path\": \"/var/log/containers/swift\", \"state\": \"absent\"}, \"when\": \"swift_log_link.stat.islnk is defined and swift_log_link.stat.islnk\"}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (243,'2026-06-10 07:47:43',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(244,'2026-06-10 07:47:43',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Swift Proxy service configured with Puppet\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"SwiftHashSuffix\": {\"description\": \"A random string to be used as a salt when hashing to determine mappings in the ring.\", \"hidden\": true, \"type\": \"string\", \"default\": \"sRK7MrWoYpaoPNYnblO2G8U5z\"}, \"SwiftHashPrefix\": {\"default\": \"\", \"description\": \"A random string to be used as an extra salt when hashing to determine mappings in the ring.\", \"hidden\": true, \"type\": \"string\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Swift common swift settings.\", \"value\": {\"service_name\": \"swift_base\", \"config_settings\": {\"swift::swift_hash_path_suffix\": {\"get_param\": \"SwiftHashSuffix\"}, \"swift::swift_hash_path_prefix\": {\"get_param\": \"SwiftHashPrefix\"}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(245,'2026-06-10 07:47:44',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(246,'2026-06-10 07:47:45',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(247,'2026-06-10 07:47:46',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Containerized rsyslogd service for purposes of centralized log collection of OpenStack services\' logs.\\n\", \"parameters\": {\"ContainerRsyslogImage\": {\"description\": \"The container image to use for container\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\"}, \"ContainerRsyslogConfigImage\": {\"description\": \"The container image to use for the rsyslog config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"RsyslogReopenOnTruncate\": {\"default\": true, \"description\": \"Rsyslog imfile reopenOnTruncate parameter\", \"type\": \"boolean\"}, \"RsyslogElasticsearchSetting\": {\"default\": {}, \"description\": \"Configuration for rsyslog-elasticsearch plugin\", \"type\": \"json\"}, \"RsyslogElasticsearchTlsCACert\": {\"default\": \"\", \"description\": \"Contains content of the CA cert for the CA that issued Elasticsearch server cert.\", \"type\": \"string\"}, \"RsyslogElasticsearchTlsClientCert\": {\"default\": \"\", \"description\": \"Contains content of the client cert for doing client cert auth against Elasticsearch.\", \"type\": \"string\"}, \"RsyslogElasticsearchTlsClientKey\": {\"default\": \"\", \"description\": \"Contains content of the private key corresponding to the cert RsyslogElasticsearchTlsClientCert.\", \"type\": \"string\"}, \"CloudName\": {\"default\": \"multicell.ooo.test\", \"description\": \"The DNS name of this cloud. E.g. ci-overcloud.tripleo.org\", \"type\": \"string\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"RsyslogAmqp1Setting\": {\"default\": {}, \"description\": \"Configuration for rsyslog-omamqp1 plugin\", \"type\": \"json\"}, \"RsyslogAmqp1Local\": {\"default\": true, \"description\": \"Set to false to disable prefilling host connection value to local QDR in RsyslogAmqp1Setting.\", \"type\": \"boolean\"}, \"MetricsQdrPort\": {\"default\": 5666, \"description\": \"Service name or port number on which the qdrouterd will accept connections.\", \"type\": \"number\"}, \"RsyslogMaxMessageSize\": {\"default\": \"32k\", \"description\": \"Maximum supported message size (both for sending and receiving) for rsyslogd.\", \"type\": \"string\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerRsyslogImage\": \"ContainerRsyslogImage\", \"ContainerRsyslogConfigImage\": \"ContainerRsyslogConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerRsyslogImage\": {\"get_param\": \"ContainerRsyslogImage\"}, \"ContainerRsyslogConfigImage\": {\"get_param\": \"ContainerRsyslogConfigImage\"}}}]}}}}, \"conditions\": {\"use_tls\": {\"not\": {\"and\": [{\"equals\": [{\"get_param\": \"RsyslogElasticsearchTlsCACert\"}, \"\"]}, {\"equals\": [{\"get_param\": \"RsyslogElasticsearchTlsClientCert\"}, \"\"]}, {\"equals\": [{\"get_param\": \"RsyslogElasticsearchTlsClientKey\"}, \"\"]}]}}, \"use_elasticsearch\": {\"not\": {\"equals\": [{\"get_param\": \"RsyslogElasticsearchSetting\"}, {}]}}, \"use_amqp1\": {\"not\": {\"equals\": [{\"get_param\": \"RsyslogAmqp1Setting\"}, {}]}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the rsyslog role.\", \"value\": {\"service_name\": \"rsyslog\", \"config_settings\": {\"map_merge\": [{\"rsyslog::server::global_config\": {\"WorkDirectory\": {\"type\": \"legacy\", \"target\": \"00_rsyslog.conf\", \"value\": \"/var/lib/rsyslog\"}, \"MaxMessageSize\": {\"type\": \"legacy\", \"target\": \"00_rsyslog.conf\", \"value\": {\"get_param\": \"RsyslogMaxMessageSize\"}}}, \"rsyslog::confdir\": \"/etc/rsyslog.d\", \"rsyslog::package_name\": \"rsyslog\", \"rsyslog::package_version\": \"installed\", \"rsyslog::manage_package\": true, \"rsyslog::manage_confdir\": true, \"rsyslog::purge_config_files\": true, \"rsyslog::override_default_config\": true, \"rsyslog::config_file\": \"/etc/rsyslog.conf\", \"rsyslog::manage_service\": true, \"rsyslog::service_name\": \"rsyslog\", \"rsyslog::service_status\": \"running\", \"rsyslog::service_enabled\": true, \"rsyslog::external_service\": false, \"rsyslog::use_upstream_repo\": false, \"rsyslog::feature_packages\": [\"rsyslog-elasticsearch\", \"rsyslog-mmnormalize\"], \"rsyslog::global_config_priority\": 10, \"rsyslog::module_load_priority\": 20, \"rsyslog::input_priority\": 30, \"rsyslog::main_queue_priority\": 40, \"rsyslog::parser_priority\": 45, \"rsyslog::template_priority\": 50, \"rsyslog::filter_priority\": 55, \"rsyslog::action_priority\": 60, \"rsyslog::ruleset_priority\": 65, \"rsyslog::lookup_table_priority\": 70, \"rsyslog::legacy_config_priority\": 80, \"rsyslog::custom_priority\": 90, \"rsyslog::target_file\": \"50_openstack_logs.conf\", \"rsyslog::server::modules\": {\"imfile\": {}, \"omelasticsearch\": {}, \"omamqp1\": {}}, \"rsyslog::server::templates\": {\"rsyslog-node-index\": {\"type\": \"list\", \"list_descriptions\": [{\"constant\": {\"value\": \"%{hiera(\'fqdn_canonical\')}-\"}}, {\"property\": {\"name\": \"timereported\", \"dateFormat\": \"year\"}}, {\"constant\": {\"value\": \".\"}}, {\"property\": {\"name\": \"timereported\", \"dateFormat\": \"month\"}}, {\"constant\": {\"value\": \".\"}}, {\"property\": {\"name\": \"timereported\", \"dateFormat\": \"day\"}}]}, \"rsyslog-record\": {\"type\": \"list\", \"options\": {\"jsonf\": \"on\"}, \"list_descriptions\": [{\"property\": {\"outname\": \"@timestamp\", \"name\": \"timereported\", \"dateFormat\": \"rfc3339\", \"format\": \"jsonf\"}}, {\"property\": {\"outname\": \"host\", \"name\": \"hostname\", \"format\": \"jsonf\"}}, {\"property\": {\"outname\": \"severity\", \"name\": \"syslogseverity\", \"format\": \"jsonf\"}}, {\"property\": {\"outname\": \"facility\", \"name\": \"syslogfacility-text\", \"format\": \"jsonf\"}}, {\"property\": {\"outname\": \"tag\", \"name\": \"syslogtag\", \"format\": \"jsonf\"}}, {\"property\": {\"outname\": \"source\", \"name\": \"app-name\", \"format\": \"jsonf\"}}, {\"property\": {\"outname\": \"message\", \"name\": \"msg\", \"format\": \"jsonf\"}}, {\"property\": {\"outname\": \"file\", \"name\": \"$!metadata!filename\", \"format\": \"jsonf\"}}, {\"constant\": {\"outname\": \"cloud\", \"value\": {\"get_param\": \"CloudName\"}, \"format\": \"jsonf\"}}, {\"constant\": {\"outname\": \"region\", \"value\": {\"get_param\": \"KeystoneRegion\"}, \"format\": \"jsonf\"}}]}}}, {\"if\": [\"use_elasticsearch\", {\"tripleo::profile::base::logging::rsyslog::elasticsearch\": {\"map_merge\": [{\"get_param\": \"RsyslogElasticsearchSetting\"}, {\"template\": \"rsyslog-record\", \"searchIndex\": \"rsyslog-node-index\", \"dynSearchIndex\": \"on\", \"errorfile\": \"/var/log/rsyslog/omelasticsearch.log\"}]}}, {}]}, {\"if\": [\"use_amqp1\", {\"tripleo::profile::base::logging::rsyslog::amqp1\": {\"map_merge\": [{\"get_param\": \"RsyslogAmqp1Setting\"}, {\"template\": \"rsyslog-record\"}, {\"if\": [{\"get_param\": \"RsyslogAmqp1Local\"}, {\"host\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}:$PORT\", \"params\": {\"$PORT\": {\"get_param\": \"MetricsQdrPort\"}, \"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", {\"str_replace\": {\"template\": \"ROLENAMEMetricsQdrNetwork\", \"params\": {\"ROLENAME\": {\"get_param\": \"RoleName\"}}}}]}}}}}]}]}}, {}]}, {\"if\": [{\"get_param\": \"RsyslogReopenOnTruncate\"}, {\"tripleo::profile::base::logging::rsyslog::reopen_on_truncate\": \"on\"}, {}]}, {\"if\": [\"use_tls\", {\"tripleo::profile::base::logging::rsyslog::elasticsearch_tls_ca_cert\": {\"get_param\": \"RsyslogElasticsearchTlsCACert\"}, \"tripleo::profile::base::logging::rsyslog::elasticsearch_tls_client_cert\": {\"get_param\": \"RsyslogElasticsearchTlsClientCert\"}, \"tripleo::profile::base::logging::rsyslog::elasticsearch_tls_client_key\": {\"get_param\": \"RsyslogElasticsearchTlsClientKey\"}}]}]}, \"puppet_config\": {\"config_volume\": \"rsyslog\", \"puppet_tags\": \"rsyslog::generate_concat,concat::fragment\", \"step_config\": \"include tripleo::profile::base::logging::rsyslog\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerRsyslogConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/rsyslog.json\": {\"command\": \"/usr/sbin/rsyslogd -n -iNONE\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/lib/rsyslog\", \"owner\": \"root:root\", \"recurse\": true}, {\"path\": \"/var/log/rsyslog\", \"owner\": \"root:root\", \"recurse\": true}]}}, \"docker_config\": {\"step_3\": {\"rsyslog\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerRsyslogImage\"]}, \"net\": \"host\", \"privileged\": true, \"user\": \"root\", \"restart\": \"always\", \"security_opt\": [\"label=disable\"], \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/rsyslog.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/rsyslog:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers:/var/log/containers:ro\", \"/var/log/containers/rsyslog:/var/log/rsyslog:rw,z\", \"/var/log:/var/log/host:ro\", \"/var/lib/rsyslog.container:/var/lib/rsyslog:rw,z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"host_prep_tasks\": [{\"name\": \"create persistent logs directory for rsyslog\", \"file\": {\"path\": \"/var/log/containers/rsyslog\", \"state\": \"directory\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}}, {\"name\": \"create persistent state directory for rsyslog\", \"file\": {\"path\": \"/var/lib/rsyslog.container\", \"state\": \"directory\", \"setype\": \"container_file_t\"}}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(248,'2026-06-10 07:47:46',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Pacemaker service configured with Puppet\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"MonitoringSubscriptionPacemaker\": {\"default\": \"overcloud-pacemaker\", \"type\": \"string\"}, \"CorosyncIPv6\": {\"default\": false, \"description\": \"Enable IPv6 in Corosync\", \"type\": \"boolean\"}, \"EnableFencing\": {\"default\": false, \"description\": \"Whether to enable fencing in Pacemaker or not.\", \"type\": \"boolean\"}, \"PacemakerTLSPriorities\": {\"type\": \"string\", \"description\": \"Pacemaker TLS Priorities\", \"default\": \"\"}, \"PacemakerRemoteAuthkey\": {\"type\": \"string\", \"description\": \"The authkey for the pacemaker remote service.\", \"hidden\": true, \"default\": \" \"}, \"PcsdPassword\": {\"type\": \"string\", \"description\": \"The password for the \'pcsd\' user for pacemaker.\", \"hidden\": true, \"default\": \"8doXbkNy1AZbY9c3\"}, \"CorosyncTokenTimeout\": {\"type\": \"number\", \"description\": \"Time in milliseconds until a token loss is declared after not receiving a token.\", \"default\": 10000}, \"CorosyncSettleTries\": {\"type\": \"number\", \"description\": \"Number of tries for cluster settling. This has the same default as the pacemaker puppet module. Override to a smaller value when in need to replace a controller node.\", \"default\": 360}, \"FencingConfig\": {\"default\": {}, \"description\": \"Pacemaker fencing configuration. The JSON should have\\nthe following structure:\\n  {\\n    \\\"devices\\\": [\\n      {\\n        \\\"agent\\\": \\\"AGENT_NAME\\\",\\n        \\\"host_mac\\\": \\\"HOST_MAC_ADDRESS\\\",\\n        \\\"params\\\": {\\\"PARAM_NAME\\\": \\\"PARAM_VALUE\\\"}\\n      }\\n    ]\\n  }\\nFor instance:\\n  {\\n    \\\"devices\\\": [\\n      {\\n        \\\"agent\\\": \\\"fence_xvm\\\",\\n        \\\"host_mac\\\": \\\"52:54:00:aa:bb:cc\\\",\\n        \\\"params\\\": {\\n          \\\"multicast_address\\\": \\\"225.0.0.12\\\",\\n          \\\"port\\\": \\\"baremetal_0\\\",\\n          \\\"manage_fw\\\": true,\\n          \\\"manage_key_file\\\": true,\\n          \\\"key_file\\\": \\\"/etc/fence_xvm.key\\\",\\n          \\\"key_file_password\\\": \\\"abcdef\\\"\\n        }\\n      }\\n    ]\\n  }\\n\", \"type\": \"json\"}, \"PacemakerLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"system.pacemaker\", \"file\": \"/var/log/host/pacemaker/pacemaker.log\", \"startmsg.regex\": \"^[a-zA-Z]{3} [0-9]{2} [:0-9]{8}\"}}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}, \"EnableInstanceHA\": {\"default\": false, \"description\": \"Whether to enable an Instance Ha configurarion or not. This setup requires the Compute role to have the PacemakerRemote service added to it.\", \"type\": \"boolean\"}, \"PacemakerBundleOperationTimeout\": {\"type\": \"string\", \"default\": \"\", \"description\": \"The timeout for start, monitor and stop operations run by the container resource agent, in seconds. When set to default \'\', the timeout comes from pacemaker\'s default operation timeouts (20s). When set to default and podman is used, force the timeout to 120s.\", \"constraints\": [{\"allowed_pattern\": \"([1-9][0-9]*s)?\"}]}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"The following parameters are deprecated and will be removed. They should not\\nbe relied on for new deployments. If you have concerns regarding deprecated\\nparameters, please contact the TripleO development team on IRC or the\\nOpenStack mailing list.\\n\", \"parameters\": [\"CorosyncIPv6\"]}], \"conditions\": {\"pcmk_tls_priorities_empty\": {\"equals\": [{\"get_param\": \"PacemakerTLSPriorities\"}, \"\"]}, \"pcmk_bundle_op_timeout_empty\": {\"equals\": [{\"get_param\": \"PacemakerBundleOperationTimeout\"}, \"\"]}, \"podman_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"podman\"]}, \"is_ipv6\": {\"equals\": [{\"get_param\": [\"ServiceData\", \"net_ip_version_map\", {\"get_param\": [\"ServiceNetMap\", \"PacemakerNetwork\"]}]}, 6]}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Pacemaker role.\", \"value\": {\"service_name\": \"pacemaker\", \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionPacemaker\"}, \"firewall_rules\": {\"130 pacemaker tcp\": {\"proto\": \"tcp\", \"dport\": [2224, 3121, 21064]}, \"131 pacemaker udp\": {\"proto\": \"udp\", \"dport\": 5405}}, \"config_settings\": {\"map_merge\": [{\"pacemaker::corosync::cluster_name\": \"tripleo_cluster\", \"pacemaker::corosync::manage_fw\": false, \"pacemaker::resource_defaults::defaults\": {\"resource-stickiness\": {\"value\": \"INFINITY\"}}, \"corosync_token_timeout\": {\"get_param\": \"CorosyncTokenTimeout\"}, \"pacemaker::corosync::settle_tries\": {\"get_param\": \"CorosyncSettleTries\"}, \"pacemaker::resource::bundle::deep_compare\": true, \"pacemaker::resource::ip::deep_compare\": true, \"pacemaker::resource::ocf::deep_compare\": true, \"corosync_ipv6\": {\"if\": [\"is_ipv6\", true, false]}, \"tripleo::fencing::config\": {\"get_param\": \"FencingConfig\"}, \"tripleo::fencing::deep_compare\": true, \"enable_fencing\": {\"get_param\": \"EnableFencing\"}, \"hacluster_pwd\": {\"get_param\": \"PcsdPassword\"}, \"tripleo::profile::base::pacemaker::remote_authkey\": {\"get_param\": \"PacemakerRemoteAuthkey\"}, \"tripleo::profile::base::pacemaker::pcsd_bind_addr\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PacemakerNetwork\"]}}}}}, {\"if\": [\"pcmk_tls_priorities_empty\", {}, {\"tripleo::pacemaker::tls_priorities\": {\"get_param\": \"PacemakerTLSPriorities\"}}]}, {\"if\": [{\"and\": [\"pcmk_bundle_op_timeout_empty\", {\"not\": \"podman_enabled\"}]}, {}, {\"tripleo::profile::base::pacemaker::resource_op_defaults\": {\"bundle\": {\"name\": \"timeout\", \"value\": {\"if\": [\"pcmk_bundle_op_timeout_empty\", \"120s\", {\"get_param\": \"PacemakerBundleOperationTimeout\"}]}}}}]}]}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_pacemaker\": [{\"get_param\": \"PacemakerLoggingSource\"}]}}, \"step_config\": \"include tripleo::profile::base::pacemaker\\n\", \"host_prep_tasks\": [{\"name\": \"Make sure python3-novaclient is installed when IHA is enabled\", \"package\": {\"name\": \"python3-novaclient\", \"state\": \"present\"}, \"when\": {\"get_param\": \"EnableInstanceHA\"}}, {\"name\": \"Remove existing entries from logind conf\", \"ansible.builtin.lineinfile\": {\"path\": \"/etc/systemd/logind.conf\", \"regexp\": \"^\\\\s*#?\\\\s*HandlePowerKey\\\\s*=.*\", \"state\": \"absent\"}}, {\"name\": \"Make sure systemd-logind ignores power off\", \"ansible.builtin.lineinfile\": {\"path\": \"/etc/systemd/logind.conf\", \"regexp\": \"^#?HandlePowerKey\", \"line\": \"HandlePowerKey=ignore\"}}, {\"name\": \"Restart systemd-logind\", \"ansible.builtin.service\": {\"name\": \"systemd-logind\", \"state\": \"restarted\"}}, {\"name\": \"Gather service_facts on pacemaker_bootstrap_node\", \"ansible.builtin.service_facts\": null, \"when\": [\"{{(pacemaker_short_bootstrap_node_name|lower == ansible_facts[\'hostname\']|lower)|bool}}\", {\"get_param\": \"EnableInstanceHA\"}]}, {\"name\": \"Check and eventually delete duplicate constraints (bootstrap node)\", \"become\": true, \"shell\": \"COUNT=$(cibadmin --query | xmllint --xpath \'//rsc_location[@rsc=\\\"stonith-fence_compute-fence-nova\\\"]/@id\' - |grep -oP \'(?<=[\\\"])[^\\\"]*\' -c)\\nif [[ $COUNT > 1 ]]; then\\n    echo \\\"Detected $COUNT duplicate constraints, deleting them\\\"\\n    # assemble string with current list of computes\\n    GOOD=$(echo location-stonith-fence_compute-fence-nova-$(hiera pacemaker_remote_short_node_names |grep -oP \'\\\".*?\\\"\' |tr -d \'\\\"\'|tr -d \'\\\\n\' )--10000)\\n    # delete old constraints\\n    for i in $(cibadmin --query | xmllint --xpath \'//rsc_location[@rsc=\\\"stonith-fence_compute-fence-nova\\\"]/@id\' - |grep -oP \'(?<=[\\\"])[^\\\"]*\' |grep -v $GOOD ); do pcs constraint delete $i ; done\\nelse\\n    echo \\\"No duplicate constraint found\\\"\\nfi\\n\", \"when\": [\"{{(pacemaker_short_bootstrap_node_name|lower == ansible_facts[\'hostname\']|lower)|bool}}\", {\"get_param\": \"EnableInstanceHA\"}, \"ansible_facts[\'services\'][\'pacemaker.service\'][\'state\'] == \'running\'\"]}], \"scale_tasks\": [{\"when\": [\"step|int == 1\", \"container_cli == \'podman\'\", \"\\\"pacemaker_remote\\\" in enabled_services|list\", \"inventory_hostname_short in compute_instanceha_short_node_names\"], \"tags\": \"down\", \"become\": true, \"block\": [{\"name\": \"Getting Nova compute hostname\", \"command\": \"crm_node -n\", \"register\": \"nova_compute_hostname\"}, {\"name\": \"Check if pacemaker_short_bootstrap_node_name is a defined variable\", \"when\": \"pacemaker_short_bootstrap_node_name is not defined\", \"fail\": {\"msg\": \"Cannot delegate pacemaker cleanup to the bootstrap node. Please delete the resources manually.\"}, \"ignore_errors\": true}, {\"name\": \"Clean up Pacemaker remote and STONITH resources for Compute node\", \"when\": [\"nova_compute_hostname.stdout in compute_instanceha_short_node_names\", \"pacemaker_short_bootstrap_node_name is defined\"], \"block\": [{\"name\": \"List STONITH resource for the Compute node\", \"command\": \"stonith_admin -l {{ nova_compute_hostname.stdout }}\", \"register\": \"stonith_service_results\", \"delegate_to\": \"{{ pacemaker_short_bootstrap_node_name }}\"}, {\"name\": \"Disable the STONITH resources for the Compute node\", \"command\": \"pcs stonith disable \\\"{{ item }}\\\"\", \"loop\": \"{{ stonith_service_results.stdout | regex_findall(\'^(stonith-fence(?!_compute-fence-nova).*)\', multiline=True)}}\", \"delegate_to\": \"{{ pacemaker_short_bootstrap_node_name }}\", \"register\": \"disable_output\", \"failed_when\": \"disable_output.rc != 0\", \"retries\": 3, \"delay\": 5, \"until\": \"disable_output.rc == 0\"}, {\"name\": \"Delete the STONITH resources for the Compute node\", \"command\": \"pcs stonith delete \\\"{{ item }}\\\"\", \"loop\": \"{{ stonith_service_results.stdout | regex_findall(\'^(stonith-fence(?!_compute-fence-nova).*)\', multiline=True)}}\", \"delegate_to\": \"{{ pacemaker_short_bootstrap_node_name }}\", \"register\": \"delete_output\", \"failed_when\": \"delete_output.rc != 0\", \"retries\": 3, \"delay\": 5, \"until\": \"delete_output.rc == 0\"}, {\"name\": \"Clear the stonith level hierarchy for the Compute node target\", \"command\": \"pcs stonith level clear target {{ nova_compute_hostname.stdout }}\", \"delegate_to\": \"{{ pacemaker_short_bootstrap_node_name }}\"}, {\"name\": \"Delete Compute node from cluster\", \"command\": \"pcs cluster node remove-remote {{ nova_compute_hostname.stdout }}\", \"delegate_to\": \"{{ pacemaker_short_bootstrap_node_name }}\"}, {\"name\": \"Remove compute node in pcmk_host_list parameter from stonith-fence_compute-fence-nova\", \"command\": \"crm_resource --set-parameter=pcmk_host_list -r stonith-fence_compute-fence-nova -v \\\"{{ pacemaker_remote_short_node_names | reject(\'search\', nova_compute_hostname.stdout) | join(\',\') }}\\\"\", \"delegate_to\": \"{{ pacemaker_short_bootstrap_node_name }}\"}]}]}], \"upgrade_tasks\": [{\"name\": \"Ensure redis is removed\", \"when\": [\"step|int == 5\", \"\\\"redis\\\" not in enabled_services|list\", \"{{ (pacemaker_short_bootstrap_node_name|lower == ansible_facts[\'hostname\']|lower)|bool}}\"], \"become\": true, \"shell\": \"if crm_resource -r redis-bundle -q &>/dev/null; then\\n   pcs resource delete redis-bundle || true\\n   pcs resource delete ip-$(hiera redis_vip) || true\\nfi\\n\"}, {\"name\": \"Clean up cluster node cache\", \"when\": [\"step|int == 5\", \"\\\"redis\\\" not in enabled_services|list\", \"{{ (pacemaker_short_bootstrap_node_name|lower == ansible_facts[\'hostname\']|lower)|bool}}\"], \"become\": true, \"shell\": \"pcs cluster node clear redis-bundle-0\\npcs cluster node clear redis-bundle-1\\npcs cluster node clear redis-bundle-2\\ncrm_attribute --name redis_REPL_INFO --delete\\n\"}, {\"name\": \"Clean up redis attribute\", \"when\": [\"step|int == 5\", \"\\\"redis\\\" not in enabled_services|list\", \"{{ (pacemaker_short_bootstrap_node_name|lower == ansible_facts[\'hostname\']|lower)|bool}}\"], \"become\": true, \"shell\": \"pcs node attribute \\\"{{ item }}\\\" redis-role= || true\\n\", \"loop\": \"{{ pacemaker_short_node_names }}\"}], \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_stop_services\", \"system_upgrade_transfer_data\"], \"block\": [{\"name\": \"Stop cluster\", \"become\": true, \"shell\": \"set -eu\\nFILE=/usr/sbin/pcs\\nif test -f \\\"$FILE\\\"; then\\n  /usr/sbin/pcs cluster stop --force\\nfi\\n\", \"delegate_to\": \"{{ item }}\", \"with_items\": \"{{ groups[\'pacemaker\'] | difference(groups[\'excluded_overcloud\']) }}\"}]}], \"update_tasks\": [{\"name\": \"Check pacemaker cluster running before the minor update\", \"when\": \"step|int == 0\", \"pacemaker_cluster\": \"state=online check_and_fail=true\", \"async\": 30, \"poll\": 4}, {\"name\": \"Acquire the cluster shutdown lock to stop pacemaker cluster\", \"when\": \"step|int == 1\", \"command\": \"systemd-cat -t ha-shutdown /var/lib/container-config-scripts/pacemaker_mutex_shutdown.sh --acquire\"}, {\"name\": \"Stop pacemaker cluster\", \"when\": \"step|int == 1\", \"pacemaker_cluster\": \"state=offline\"}, {\"name\": \"Start pacemaker cluster\", \"when\": \"step|int == 4\", \"pacemaker_cluster\": \"state=online\"}, {\"name\": \"Release the cluster shutdown lock\", \"when\": \"step|int == 4\", \"command\": \"systemd-cat -t ha-shutdown /var/lib/container-config-scripts/pacemaker_mutex_shutdown.sh --release\"}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(249,'2026-06-10 07:47:46',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Placement API service\\n\", \"parameters\": {\"ContainerPlacementImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\"}, \"ContainerPlacementConfigImage\": {\"description\": \"The container image to use for the placement config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"DeployIdentifier\": {\"default\": 1781077560, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"PlacementWorkers\": {\"default\": 1, \"description\": \"Number of workers for Placement services.\", \"type\": \"number\"}, \"PlacementPassword\": {\"description\": \"The password for the Placement service and db account\", \"type\": \"string\", \"hidden\": true, \"default\": \"LmdoVblRSfwmhsbe1og9276Oe\"}, \"PlacementAPIInterface\": {\"type\": \"string\", \"description\": \"Endpoint interface to be used for the placement API.\\n\", \"default\": \"internal\"}, \"EnforceSecureRbac\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Setting this option to True will configure each OpenStack service to enforce Secure RBAC by setting `[oslo_policy] enforce_new_defaults` and `[oslo_policy] enforce_scope` to True. This introduces a consistent set of RBAC personas across OpenStack services that include support for system and project scope, as well as keystone\'s default roles, admin, member, and reader. Do not enable this functionality until all services in your deployment actually support secure RBAC.\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"MonitoringSubscriptionPlacement\": {\"default\": \"overcloud-placement\", \"type\": \"string\"}, \"PlacementLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.placement\", \"file\": \"/var/log/containers/placement/placement.log\"}}, \"NovaPassword\": {\"description\": \"The password for the nova service and db account\", \"type\": \"string\", \"hidden\": true, \"default\": \"btE80AtSdL16lZ5QqRx6f9I9L\"}, \"Debug\": {\"type\": \"boolean\", \"default\": true, \"description\": \"Set to True to enable debugging on all services.\"}, \"MemcacheUseAdvancedPool\": {\"type\": \"boolean\", \"description\": \"Use the advanced (eventlet safe) memcached client pool.\\n\", \"default\": true}, \"PlacementDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Placement services.\", \"type\": \"boolean\"}, \"PlacementPolicies\": {\"description\": \"A hash of policies to configure for Placement API.\\ne.g. { nova-context_is_admin: { key: context_is_admin, value: \'role:admin\' } }\\n\", \"default\": {}, \"type\": \"json\"}}, \"conditions\": {\"placement_workers_zero\": {\"equals\": [{\"get_param\": \"PlacementWorkers\"}, 0]}, \"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"enable_sqlalchemy_collectd\": {\"equals\": [{\"get_param\": \"EnableSQLAlchemyCollectd\"}, true]}}, \"resources\": {\"ApacheServiceBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}, \"EnableInternalTLS\": {\"get_param\": \"EnableInternalTLS\"}}}, \"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MySQLClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\"}, \"PlacementLogging\": {\"type\": \"OS::TripleO::Services::Logging::PlacementApi\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerPlacementImage\": \"ContainerPlacementImage\", \"ContainerPlacementConfigImage\": \"ContainerPlacementConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerPlacementImage\": {\"get_param\": \"ContainerPlacementImage\"}, \"ContainerPlacementConfigImage\": {\"get_param\": \"ContainerPlacementConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Placement API role.\", \"value\": {\"service_name\": \"placement\", \"firewall_rules\": {\"138 placement\": {\"dport\": [8778]}}, \"firewall_frontend_rules\": {\"100 placement_haproxy_frontend\": {\"dport\": [8778]}}, \"firewall_ssl_frontend_rules\": {\"100 placement_haproxy_frontend_ssl\": {\"dport\": [13778]}}, \"keystone_resources\": {\"placement\": {\"endpoints\": {\"public\": {\"get_param\": [\"EndpointMap\", \"PlacementPublic\", \"uri\"]}, \"internal\": {\"get_param\": [\"EndpointMap\", \"PlacementInternal\", \"uri\"]}, \"admin\": {\"get_param\": [\"EndpointMap\", \"PlacementAdmin\", \"uri\"]}}, \"users\": {\"placement\": {\"password\": {\"get_param\": \"PlacementPassword\"}}}, \"region\": {\"get_param\": \"KeystoneRegion\"}, \"service\": \"placement\"}}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"PlacementLogging\", \"config_settings\"]}, {\"apache::default_vhost\": false}, {\"placement::keystone::authtoken::project_name\": \"service\", \"placement::keystone::authtoken::password\": {\"get_param\": \"PlacementPassword\"}, \"placement::keystone::authtoken::www_authenticate_uri\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"uri_no_suffix\"]}, \"placement::keystone::authtoken::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"placement::keystone::authtoken::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"placement::keystone::authtoken::interface\": \"internal\", \"placement::keystone::authtoken::memcache_use_advanced_pool\": {\"get_param\": \"MemcacheUseAdvancedPool\"}, \"placement::logging::debug\": {\"if\": [{\"get_param\": \"PlacementDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"placement::policy::enforce_new_defaults\": {\"get_param\": \"EnforceSecureRbac\"}, \"placement::policy::enforce_scope\": {\"get_param\": \"EnforceSecureRbac\"}, \"placement::policy::policies\": {\"get_param\": \"PlacementPolicies\"}, \"placement::wsgi::apache::api_port\": \"8778\", \"placement::wsgi::apache::ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"placement::wsgi::apache::bind_host\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}}}}, \"placement::wsgi::apache::servername\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}}}}, \"placement::db::database_connection\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"protocol\"]}, \"username\": \"placement\", \"password\": {\"get_param\": \"PlacementPassword\"}, \"host\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"host\"]}, \"path\": \"/placement\", \"query\": {\"if\": [\"enable_sqlalchemy_collectd\", {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\", \"plugin\": \"collectd\", \"collectd_program_name\": \"placement_api\", \"collectd_host\": \"localhost\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\"}]}}}}, {\"if\": [\"placement_workers_zero\", {}, {\"placement::wsgi::apache::workers\": {\"get_param\": \"PlacementWorkers\"}}]}]}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_placement\": [{\"get_param\": \"PlacementLoggingSource\"}]}, \"mysql\": {\"placement::db::mysql::password\": {\"get_param\": \"PlacementPassword\"}, \"placement::db::mysql::user\": \"placement\", \"placement::db::mysql::host\": \"%\", \"placement::db::mysql::dbname\": \"placement\"}}, \"puppet_config\": {\"config_volume\": \"placement\", \"puppet_tags\": \"placement_config\", \"step_config\": {\"list_join\": [\"\\n\", [{\"get_attr\": [\"MySQLClient\", \"role_data\", \"step_config\"]}, \"include tripleo::profile::base::placement::api\"]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerPlacementConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/placement_api.json\": {\"command\": \"/usr/sbin/httpd -DFOREGROUND\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.d\", \"dest\": \"/etc/httpd/conf.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.modules.d\", \"dest\": \"/etc/httpd/conf.modules.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/placement\", \"owner\": \"placement:placement\", \"recurse\": true}]}, \"/var/lib/kolla/config_files/placement_api_db_sync.json\": {\"command\": \"/usr/bin/bootstrap_host_exec placement su placement -s /bin/bash -c \'/usr/bin/placement-manage db sync\'\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.d\", \"dest\": \"/etc/httpd/conf.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.modules.d\", \"dest\": \"/etc/httpd/conf.modules.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/placement\", \"owner\": \"placement:placement\", \"recurse\": true}]}, \"/var/lib/kolla/config_files/placement_api_wait_for_service.json\": {\"command\": \"/usr/bin/bootstrap_host_exec placement su placement -s /bin/bash -c \'/container-config-scripts/pyshim.sh /container-config-scripts/placement_wait_for_service.py\'\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.d\", \"dest\": \"/etc/httpd/conf.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.modules.d\", \"dest\": \"/etc/httpd/conf.modules.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/placement\", \"owner\": \"placement:placement\", \"recurse\": true}]}}, \"container_config_scripts\": {\"map_merge\": [{\"get_attr\": [\"ContainersCommon\", \"container_config_scripts\"]}, {\"placement_wait_for_service.py\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/placement_wait_for_service.py\"}}}]}, \"docker_config\": {\"step_2\": {\"get_attr\": [\"PlacementLogging\", \"docker_config\", \"step_2\"]}, \"step_3\": {\"placement_api_db_sync\": {\"start_order\": 1, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerPlacementImage\"]}, \"cap_add\": [\"AUDIT_WRITE\"], \"net\": \"host\", \"detach\": false, \"user\": \"root\", \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"PlacementLogging\", \"volumes\"]}, [\"/var/lib/kolla/config_files/placement_api_db_sync.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/placement:/var/lib/kolla/config_files/src:ro\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\", \"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}}}}, \"step_4\": {\"placement_api\": {\"start_order\": 1, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerPlacementImage\"]}, \"net\": \"host\", \"user\": \"root\", \"restart\": \"always\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"PlacementLogging\", \"volumes\"]}, [\"/var/lib/kolla/config_files/placement_api.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/placement:/var/lib/kolla/config_files/src:ro\"], {\"if\": [\"internal_tls_enabled\", [\"/etc/pki/tls/certs/httpd:/etc/pki/tls/certs/httpd:ro\"], []]}, {\"if\": [\"internal_tls_enabled\", [\"/etc/pki/tls/private/httpd:/etc/pki/tls/private/httpd:ro\"], []]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}, \"placement_wait_for_service\": {\"start_order\": 2, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerPlacementImage\"]}, \"user\": \"root\", \"net\": \"host\", \"privileged\": false, \"detach\": false, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"PlacementLogging\", \"volumes\"]}, [\"/var/lib/kolla/config_files/placement_api_wait_for_service.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/placement:/var/lib/kolla/config_files/src:ro\", \"/var/lib/container-config-scripts:/container-config-scripts:z\"]]}, \"environment\": {\"__OS_DEBUG\": {\"yaql\": {\"expression\": \"str($.data.debug)\", \"data\": {\"debug\": {\"get_param\": \"Debug\"}}}}, \"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"host_prep_tasks\": {\"get_attr\": [\"PlacementLogging\", \"host_prep_tasks\"]}, \"deploy_steps_tasks\": {\"get_attr\": [\"ApacheServiceBase\", \"role_data\", \"deploy_steps_tasks\"]}, \"upgrade_tasks\": []}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(250,'2026-06-10 07:47:47',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(251,'2026-06-10 07:47:47',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mysql client settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role for setting mysql client parameters\", \"value\": {\"service_name\": \"mysql_client\", \"config_settings\": {\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"tripleo::profile::base::database::mysql::client::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}}, \"step_config\": \"include tripleo::profile::base::database::mysql::client\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(252,'2026-06-10 07:47:47',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Configures podman on the host\\n\", \"parameters\": {\"DockerInsecureRegistryAddress\": {\"description\": \"Optional. The IP Address and Port of an insecure docker namespace that will be configured in /etc/sysconfig/docker. The value can be multiple addresses separated by commas.\", \"type\": \"comma_delimited_list\", \"default\": []}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ContainerImageRegistryLogin\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Flag to enable container registry login actions during the deployment. Setting this to true will cause login calls to be performed during the deployment.\"}, \"ContainerImageRegistryCredentials\": {\"type\": \"json\", \"hidden\": true, \"default\": {}, \"description\": \"Mapping of image registry hosts to login credentials. Must be in the following example format\\n\\n  docker.io:\\n    username: pa55word\\n  \'192.0.2.1:8787\':\\n    registry_username: password\\n\"}, \"ContainerDefaultPidsLimit\": {\"type\": \"number\", \"default\": 4096, \"description\": \"Setting to configure the default pids_limit in /etc/container/container.conf. This is supported starting with podman 2.0.x\"}, \"ContainerDefaultEventsLogger\": {\"type\": \"string\", \"default\": \"journald\", \"description\": \"Setting to configure where podman logs its events. Uses journald by default as that will rotate data stored in tmpfs.\", \"constraints\": [{\"allowed_values\": [\"journald\", \"file\", \"none\"]}]}, \"SystemdDropInDependencies\": {\"default\": true, \"description\": \"tell the tripleo_container_manage to inject additional ordering dependencies for the systemd scopes associated to podman containers.\", \"type\": \"boolean\"}, \"deployment_source_hosts\": {\"default\": \"Undercloud\", \"type\": \"string\", \"description\": \"Host or hostgroup that runs the deployment\"}}, \"conditions\": {\"insecure_registry_is_empty\": {\"equals\": [{\"get_param\": \"DockerInsecureRegistryAddress\"}, []]}, \"systemd_drop_in_dependencies_enabled\": {\"get_param\": \"SystemdDropInDependencies\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the podman service\", \"value\": {\"service_name\": \"podman\", \"config_settings\": {}, \"step_config\": \"\", \"host_prep_tasks\": [{\"name\": \"Install and configure Podman\", \"block\": [{\"name\": \"Set login facts\", \"no_log\": true, \"set_fact\": {\"container_registry_insecure_registries\": {\"if\": [\"insecure_registry_is_empty\", [], {\"get_param\": \"DockerInsecureRegistryAddress\"}]}, \"container_registry_login\": {\"get_param\": \"ContainerImageRegistryLogin\"}, \"container_registry_logins\": {}, \"container_registry_logins_json\": {\"get_param\": \"ContainerImageRegistryCredentials\"}, \"container_default_pids_limit\": {\"get_param\": \"ContainerDefaultPidsLimit\"}, \"container_events_logger_mechanism\": {\"get_param\": \"ContainerDefaultEventsLogger\"}}}, {\"name\": \"Convert logins json to dict\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json | from_json }}\"}, \"when\": [\"container_registry_logins_json is string\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Set registry logins\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json }}\"}, \"when\": [\"container_registry_logins_json is mapping\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Run podman install\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_install.yml\"}, \"vars\": {\"tripleo_container_registry_insecure_registries\": \"{{ container_registry_insecure_registries }}\", \"tripleo_container_default_pids_limit\": \"{{ container_default_pids_limit }}\", \"tripleo_container_events_logger_mechanism\": \"{{ container_events_logger_mechanism }}\"}}, {\"name\": \"Run podman login\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_login.yml\"}, \"vars\": {\"tripleo_container_registry_logins\": \"{{ container_registry_logins }}\", \"tripleo_container_registry_login\": \"{{ container_registry_login | bool }}\"}}]}, {\"if\": [\"systemd_drop_in_dependencies_enabled\", [{\"name\": \"Configure tripleo_container_manage to generate systemd drop-in dependencies\", \"copy\": {\"dest\": \"/etc/sysconfig/podman_drop_in\", \"content\": \"This file makes tripleo_container_manage generate additional systemd\\ndependencies for containers that have special\\nstart/stop ordering constraints. It ensures that\\nthose constraints are enforced on reboot/shutdown.\\n\"}}], [{\"name\": \"Configure tripleo_container_manage to not generate drop-in dependencies\", \"file\": {\"path\": \"/etc/sysconfig/podman_drop_in\", \"state\": \"absent\"}}]]}], \"deploy_steps_tasks\": [{\"when\": [\"(step|int) == 1\"], \"block\": [{\"name\": \"Pre-fetch all the containers\", \"become\": true, \"containers.podman.podman_image\": {\"name\": \"{{ prefetch_image }}\", \"validate_certs\": false, \"force\": true}, \"register\": \"result\", \"until\": \"result is succeeded\", \"retries\": 5, \"delay\": 5, \"loop_control\": {\"loop_var\": \"prefetch_image\"}, \"loop\": \"{{ lookup(\'template\', tripleo_role_name + \'/docker_config.yaml\', errors=\'ignore\') | default(\'{}\', True) | from_yaml | recursive_get_key_from_dict(key=\'image\') | unique }}\"}]}], \"service_config_settings\": {}, \"workaround_upgrade_tasks\": [{\"name\": \"Configure Podman registry\", \"when\": [\"step|int == 0\"], \"tags\": [\"setup_packages\"], \"block\": [{\"name\": \"Make sure the Undercloud hostname is included in /etc/hosts\", \"when\": [\"undercloud_hosts_entries is defined\"], \"lineinfile\": {\"dest\": \"/etc/hosts\", \"line\": \"{{ undercloud_hosts_entries | join(\'\') }}\", \"state\": \"present\"}}]}, {\"name\": \"Run podman install\", \"tags\": [\"system_upgrade\", \"system_upgrade_run\", \"setup_packages\"], \"when\": [\"step|int == 0\"], \"block\": [{\"name\": \"Set login facts\", \"no_log\": true, \"set_fact\": {\"container_registry_insecure_registries\": {\"if\": [\"insecure_registry_is_empty\", [], {\"get_param\": \"DockerInsecureRegistryAddress\"}]}, \"container_registry_login\": {\"get_param\": \"ContainerImageRegistryLogin\"}, \"container_registry_logins\": {}, \"container_registry_logins_json\": {\"get_param\": \"ContainerImageRegistryCredentials\"}, \"container_default_pids_limit\": {\"get_param\": \"ContainerDefaultPidsLimit\"}, \"container_events_logger_mechanism\": {\"get_param\": \"ContainerDefaultEventsLogger\"}}}, {\"name\": \"Convert logins json to dict\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json | from_json }}\"}, \"when\": [\"container_registry_logins_json is string\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Set registry logins\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json }}\"}, \"when\": [\"container_registry_logins_json is mapping\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Run podman install\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_install.yml\"}, \"vars\": {\"tripleo_container_registry_insecure_registries\": \"{{ container_registry_insecure_registries }}\", \"tripleo_container_default_pids_limit\": \"{{ container_default_pids_limit }}\", \"tripleo_container_events_logger_mechanism\": \"{{ container_events_logger_mechanism }}\"}}, {\"name\": \"Run podman login\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_login.yml\"}, \"vars\": {\"tripleo_container_registry_logins\": \"{{ container_registry_logins }}\", \"tripleo_container_registry_login\": \"{{ container_registry_login | bool }}\"}}]}, {\"name\": \"Comment infra_image in container.conf\", \"lineinfile\": {\"dest\": \"/usr/share/containers/containers.conf\", \"regexp\": \"(?i)^(infra_image.*)\", \"line\": \"#\\\\1\", \"backrefs\": true, \"state\": \"present\"}, \"tags\": [\"setup_packages\"], \"when\": [\"step|int == 0\"]}], \"upgrade_tasks\": [{\"name\": \"Configure Podman registry\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"Make sure the Undercloud hostname is included in /etc/hosts\", \"when\": [\"undercloud_hosts_entries is defined\"], \"lineinfile\": {\"dest\": \"/etc/hosts\", \"line\": \"{{ undercloud_hosts_entries | join(\'\') }}\", \"state\": \"present\"}}]}, {\"name\": \"Run podman install\", \"tags\": [\"system_upgrade\", \"system_upgrade_run\"], \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"Set login facts\", \"no_log\": true, \"set_fact\": {\"container_registry_insecure_registries\": {\"if\": [\"insecure_registry_is_empty\", [], {\"get_param\": \"DockerInsecureRegistryAddress\"}]}, \"container_registry_login\": {\"get_param\": \"ContainerImageRegistryLogin\"}, \"container_registry_logins\": {}, \"container_registry_logins_json\": {\"get_param\": \"ContainerImageRegistryCredentials\"}, \"container_default_pids_limit\": {\"get_param\": \"ContainerDefaultPidsLimit\"}, \"container_events_logger_mechanism\": {\"get_param\": \"ContainerDefaultEventsLogger\"}}}, {\"name\": \"Convert logins json to dict\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json | from_json }}\"}, \"when\": [\"container_registry_logins_json is string\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Set registry logins\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json }}\"}, \"when\": [\"container_registry_logins_json is mapping\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Run podman install\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_install.yml\"}, \"vars\": {\"tripleo_container_registry_insecure_registries\": \"{{ container_registry_insecure_registries }}\", \"tripleo_container_default_pids_limit\": \"{{ container_default_pids_limit }}\", \"tripleo_container_events_logger_mechanism\": \"{{ container_events_logger_mechanism }}\"}}, {\"name\": \"Run podman login\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_login.yml\"}, \"vars\": {\"tripleo_container_registry_logins\": \"{{ container_registry_logins }}\", \"tripleo_container_registry_login\": \"{{ container_registry_login | bool }}\"}}]}], \"update_tasks\": [{\"name\": \"Force pre-fetch of container images\", \"when\": [\"(step|int) == 5\"], \"block\": [{\"name\": \"Pre-fetch all the containers\", \"become\": true, \"containers.podman.podman_image\": {\"name\": \"{{ prefetch_image }}\", \"validate_certs\": false, \"force\": true}, \"register\": \"result\", \"until\": \"result is succeeded\", \"retries\": 5, \"delay\": 5, \"loop_control\": {\"loop_var\": \"prefetch_image\"}, \"loop\": \"{{ lookup(\'template\', tripleo_role_name + \'/docker_config.yaml\', errors=\'ignore\') | default(\'{}\', True) | from_yaml | recursive_get_key_from_dict(key=\'image\') | unique }}\"}]}], \"post_upgrade_tasks\": [{\"name\": \"Purge Podman\", \"when\": [\"(step | int) == 3\", \"container_cli == \'podman\'\", \"deployment_source_hosts not in group_names\"], \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_purge.yml\"}, \"vars\": {\"deployment_source_hosts\": {\"get_param\": \"deployment_source_hosts\"}}}], \"post_update_tasks\": [{\"name\": \"Purge Podman\", \"when\": [\"(step | int) == 3\", \"container_cli == \'podman\'\", \"deployment_source_hosts not in group_names\"], \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_purge.yml\"}, \"vars\": {\"deployment_source_hosts\": {\"get_param\": \"deployment_source_hosts\"}}}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (253,'2026-06-10 07:47:48',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"TripleO Package installation settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnablePackageInstall\": {\"default\": true, \"description\": \"Set to true to enable package installation at deploy time\", \"type\": \"boolean\"}, \"UpgradeLeappEnabled\": {\"description\": \"Use Leapp for operating system upgrade\", \"type\": \"boolean\", \"default\": false}, \"UpgradeLeappDebug\": {\"description\": \"Print debugging output when running Leapp\", \"type\": \"boolean\", \"default\": false}, \"UpgradeLeappDevelSkip\": {\"description\": \"Skip Leapp checks by setting env variables when running Leapp in\\ndevelopment/testing. For example, LEAPP_DEVEL_SKIP_RHSM=1.\\n\", \"type\": \"string\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"UpgradeLeappCommandOptions\": {\"description\": \"In case or using UpgradeLeappDevelSkip with LEAPP_NO_RHSM=1 user\\ncan specify --enablerepo <repo1> --enablerepo <repo2> options for\\nleapp to use these repositories for the upgrade process.\\n\", \"type\": \"string\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"UpgradeLeappRebootTimeout\": {\"description\": \"Timeout (seconds) for the OS upgrade phase via Leapp\", \"type\": \"number\", \"default\": 3600}, \"UpgradeLeappPostRebootDelay\": {\"description\": \"Maximum (seconds) to wait for machine to reboot and respond to a test\\ncommand.\\n\", \"type\": \"number\", \"default\": 120}, \"UpgradeLeappToRemove\": {\"default\": [], \"description\": \"List of packages to remove during Leapp upgrade.\", \"type\": \"comma_delimited_list\", \"tags\": [\"role_specific\"]}, \"UpgradeLeappToInstall\": {\"default\": [], \"description\": \"List of packages to install after Leapp upgrade.\", \"type\": \"comma_delimited_list\", \"tags\": [\"role_specific\"]}, \"LeappUnloadKernelDrivers\": {\"type\": \"comma_delimited_list\", \"default\": [], \"description\": \"List of modules to unload from the system due to being incompatible\\nwith the next RHEL version. If not being unloaded Leapp will\\ninhibit the upgrade.\\n\"}, \"LeappActorsToRemove\": {\"type\": \"comma_delimited_list\", \"default\": [], \"description\": \"List of actors to remove from the leapp process to prevent them\\nfrom inhibiting the upgrade.\\n\"}, \"LeappRepoInitCommand\": {\"type\": \"string\", \"description\": \"Command or script snippet to run on all overcloud nodes to\\ninitialize the Leapp process. E.g. a repository switch.\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"LeappInitCommand\": {\"type\": \"string\", \"description\": \"Command or script snippet to run on all overcloud nodes to\\napply any necessary workarounds to get Leapp working.\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"NICsPrefixesToUdev\": {\"default\": [], \"description\": \"List of NIC prefixes to hardcode into udev in order to prevent\\nrenaming.\\n\", \"type\": \"comma_delimited_list\", \"tags\": [\"role_specific\"]}, \"LeappPreRebootCommand\": {\"type\": \"string\", \"description\": \"Command or script snippet to run on all overcloud nodes to\\napply any necessary workarounds before rebooting into Leapp.\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"LeappPostRebootCommand\": {\"type\": \"string\", \"description\": \"Command or script snippet to run on all overcloud nodes to\\napply any necessary workarounds after rebooting from Leapp.\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"UpgradeInitCommand\": {\"type\": \"string\", \"description\": \"Command or script snippet to run on all overcloud nodes to\\ninitialize the upgrade process. E.g. a repository switch.\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"UpgradeInitCommonCommand\": {\"type\": \"string\", \"description\": \"Common commands required by the upgrades process. This should not\\nnormally be modified by the operator and is set and unset in the\\nmajor-upgrade-composable-steps.yaml and major-upgrade-converge.yaml\\nenvironment files.\\n\", \"default\": \"\"}, \"SkipPackageUpdate\": {\"default\": false, \"description\": \"Set to true to skip the update all packages\", \"type\": \"boolean\"}, \"SkipRhelEnforcement\": {\"default\": false, \"description\": \"Whether to avoid or not RHEL/OSP policies enforcement on Red Hat. Mainly for CI purpose.  It shouldn\'t matter on other distributions where it\'s disabled in the role. Set to true to skip the enforcement.\", \"type\": \"boolean\"}, \"DnfStreams\": {\"default\": [], \"description\": \"List of streams to be configured before updating packages. Each list element contains a dictionary with the following values defined module[mandatory], stream[mandatory], distribution_version[mandatory] and profile[optional]. If the profile is not specified \'common\' will be used instead.\", \"type\": \"json\", \"tags\": [\"role_specific\"]}, \"BaseTripleoPackages\": {\"default\": [], \"description\": \"List of packages to install.\", \"type\": \"comma_delimited_list\", \"tags\": [\"role_specific\"]}, \"ContainerImageRegistryLogin\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Flag to enable container registry login actions during the deployment. Setting this to true will cause login calls to be performed during the deployment.\"}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"dnf_module_list\": \"DnfStreams\", \"upgrade_leapp_devel_skip\": \"UpgradeLeappDevelSkip\", \"upgrade_leapp_command_options\": \"UpgradeLeappCommandOptions\", \"upgrade_leapp_to_remove\": \"UpgradeLeappToRemove\", \"upgrade_leapp_to_install\": \"UpgradeLeappToInstall\", \"leapp_repo_init_command\": \"LeappRepoInitCommand\", \"leapp_init_command\": \"LeappInitCommand\", \"nics_prefixes_to_keep\": \"NICsPrefixesToUdev\", \"upgrade_leapp_modules_to_unload\": \"LeappUnloadKernelDrivers\", \"upgrade_leapp_actors_to_remove\": \"LeappActorsToRemove\", \"upgrade_init_command\": \"UpgradeInitCommand\", \"base_tripleo_packages\": \"BaseTripleoPackages\", \"leapp_pre_reboot_command\": \"LeappPreRebootCommand\", \"leapp_post_reboot_command\": \"LeappPostRebootCommand\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"DnfStreams\": {\"get_param\": \"DnfStreams\"}, \"UpgradeLeappDevelSkip\": {\"get_param\": \"UpgradeLeappDevelSkip\"}, \"UpgradeLeappCommandOptions\": {\"get_param\": \"UpgradeLeappCommandOptions\"}, \"UpgradeLeappToRemove\": {\"get_param\": \"UpgradeLeappToRemove\"}, \"UpgradeLeappToInstall\": {\"get_param\": \"UpgradeLeappToInstall\"}, \"LeappUnloadKernelDrivers\": {\"get_param\": \"LeappUnloadKernelDrivers\"}, \"LeappPreRebootCommand\": {\"get_param\": \"LeappPreRebootCommand\"}, \"LeappPostRebootCommand\": {\"get_param\": \"LeappPostRebootCommand\"}, \"LeappActorsToRemove\": {\"get_param\": \"LeappActorsToRemove\"}, \"UpgradeInitCommand\": {\"get_param\": \"UpgradeInitCommand\"}, \"LeappRepoInitCommand\": {\"get_param\": \"LeappRepoInitCommand\"}, \"LeappInitCommand\": {\"get_param\": \"LeappInitCommand\"}, \"NICsPrefixesToUdev\": {\"get_param\": \"NICsPrefixesToUdev\"}, \"BaseTripleoPackages\": {\"get_param\": \"BaseTripleoPackages\"}}}]}}}, \"Podman\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}}, \"conditions\": {\"podman_requires_login\": {\"equals\": [{\"get_param\": \"ContainerImageRegistryLogin\"}, true]}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the TripleO package settings\", \"value\": {\"service_name\": \"tripleo_packages\", \"config_settings\": {\"tripleo::packages::enable_install\": {\"get_param\": \"EnablePackageInstall\"}}, \"step_config\": \"include ::tripleo::packages\\n\", \"upgrade_tasks\": {\"list_concat\": [[{\"name\": \"Gather missing facts\", \"setup\": {\"gather_subset\": [\"!all\", \"!min\", \"distribution\"]}, \"tags\": [\"always\"]}, {\"name\": \"Set leapp facts\", \"set_fact\": {\"upgrade_leapp_enabled\": \"{{ _upgradeLeappEnabled | bool and\\n   ansible_facts[\'distribution\'] == \'RedHat\' and\\n   ansible_facts[\'distribution_major_version\'] is version(\'8\', \'==\') }}\", \"upgrade_leapp_debug\": {\"get_param\": \"UpgradeLeappDebug\"}, \"upgrade_leapp_devel_skip\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"upgrade_leapp_devel_skip\"]}, \"upgrade_leapp_command_options\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"upgrade_leapp_command_options\"]}, \"upgrade_leapp_reboot_timeout\": {\"get_param\": \"UpgradeLeappRebootTimeout\"}, \"upgrade_leapp_post_reboot_delay\": {\"get_param\": \"UpgradeLeappPostRebootDelay\"}}, \"vars\": {\"_upgradeLeappEnabled\": {\"get_param\": \"UpgradeLeappEnabled\"}}, \"tags\": [\"always\"]}, {\"name\": \"system_upgrade_prepare step 3\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_prepare\"], \"when\": [\"step|int == 3\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Run LeappRepoInitCommand\", \"shell\": {\"list_join\": [\"\", [\"#!/bin/bash\\n\\n\", {\"get_attr\": [\"RoleParametersValue\", \"value\", \"leapp_repo_init_command\"]}]]}}, {\"name\": \"Remove firewalld bindings\", \"package\": {\"name\": \"python3-firewall\", \"state\": \"absent\"}}, {\"name\": \"install leapp\", \"package\": {\"name\": \"leapp-repository-openstack\", \"state\": \"latest\"}}, {\"name\": \"Run LeappInitCommand\", \"shell\": {\"list_join\": [\"\", [\"#!/bin/bash\\n\\n\", {\"get_attr\": [\"RoleParametersValue\", \"value\", \"leapp_init_command\"]}]]}}, {\"name\": \"Remove vdo\", \"package\": {\"name\": \"vdo\", \"state\": \"absent\"}}, {\"name\": \"add packages into Leapp\'s to_remove file\", \"vars\": {\"pkg_to_remove\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"upgrade_leapp_to_remove\"]}}, \"lineinfile\": {\"path\": \"/etc/leapp/transaction/to_remove\", \"line\": \"{{ item }}\"}, \"loop\": \"{{ pkg_to_remove }}\"}, {\"name\": \"add packages into Leapp\'s to_install file\", \"vars\": {\"pkg_to_install\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"upgrade_leapp_to_install\"]}}, \"lineinfile\": {\"path\": \"/etc/leapp/transaction/to_install\", \"line\": \"{{ item }}\"}, \"loop\": \"{{ pkg_to_install }}\"}, {\"name\": \"check sshd_config file\", \"stat\": {\"path\": \"/etc/ssh/sshd_config\"}, \"register\": \"sshd_config_result\"}, {\"name\": \"add PermitRootLogin option for leapp\", \"lineinfile\": {\"path\": \"/etc/ssh/sshd_config\", \"regexp\": \"^(# *)?PermitRootLogin\", \"line\": \"PermitRootLogin without-password\"}}, {\"name\": \"Remove paunch-services\", \"package\": {\"name\": \"paunch-services\", \"state\": \"absent\"}}, {\"name\": \"tripleo_container_manage reconfiguration\", \"import_role\": {\"name\": \"tripleo_container_manage\", \"tasks_from\": \"shutdown.yml\"}}]}, {\"name\": \"system_upgrade_prepare step 4\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_prepare\"], \"when\": [\"step|int == 4\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Delete the kernel modules in Leapp database (device_driver_deprecation_data.json)\", \"vars\": {\"modules_to_unload\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"upgrade_leapp_modules_to_unload\"]}}, \"shell\": \"set -o pipefail && jq \'. | del(.data[] | select(.driver_name == \\\"{{ item }}\\\"))\' /etc/leapp/files/device_driver_deprecation_data.json > /etc/leapp/files/device_driver_deprecation_data.json_modified && mv /etc/leapp/files/device_driver_deprecation_data.json_modified /etc/leapp/files/device_driver_deprecation_data.json\\n\", \"loop\": \"{{ modules_to_unload }}\"}, {\"name\": \"Remove leapp actors to prevent them inhibiting the upgrade\", \"vars\": {\"actors_to_remove\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"upgrade_leapp_actors_to_remove\"]}}, \"command\": {\"cmd\": \"find /usr/share/leapp-repository/repositories/ -name {{ item }} -type d -print -exec rm -rf \\\"{}\\\" +\"}, \"loop\": \"{{ actors_to_remove }}\"}, {\"name\": \"set leapp required answers\", \"shell\": \"leapp answer --add --section check_vdo.confirm=True\\n\"}, {\"name\": \"Replace EFI grub.cfg with redirect to /boot/grub2/grub.cfg\", \"import_role\": {\"name\": \"tripleo_kernel\", \"tasks_from\": \"efigrub.yml\"}}, {\"name\": \"Keep nics with prefix in NICsPrefixesToUdev from renaming\", \"vars\": {\"nics_prefixes_to_keep\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nics_prefixes_to_keep\"]}}, \"shell\": \"ip -j link show | \\\\ jq -r --arg prefix \\\"{{ item }}\\\" \'.[] |\\n  select((.ifname | startswith($prefix)) and\\n  (.ifname | test(\\\"^.*v[0-9]*$\\\") | not) and\\n  (.ifname | test(\\\"^.*_[0-9]*$\\\") | not) and\\n  (.ifname | test(\\\"^.*\\\\\\\\..*$\\\") | not)) |\\n  if .permaddr? then .address=.permaddr else . end |\\n  \\\"SUBSYSTEM==\\\\\\\"net\\\\\\\",ACTION==\\\\\\\"add\\\\\\\",DRIVERS==\\\\\\\"?*\\\\\\\",\\\" + \\\"NAME=\\\\\\\"\\\" + .ifname +\\\"\\\\\\\" ,ATTR{address}==\\\\\\\"\\\" + .address + \\\"\\\\\\\"\\\"\' >> /etc/udev/rules.d/70-rhosp-persistent-net.rules\\n\", \"loop\": \"{{ nics_prefixes_to_keep|list }}\"}, {\"name\": \"run leapp upgrade (download packages)\", \"shell\": \"{% if upgrade_leapp_devel_skip|default(false) %}{{ upgrade_leapp_devel_skip }}{% endif %} leapp upgrade {% if upgrade_leapp_debug|default(true) %}--debug{% endif %} {% if upgrade_leapp_command_options|default(false) %}{{ upgrade_leapp_command_options }}{% endif %}\\n\", \"when\": \"upgrade_leapp_enabled\"}]}, {\"name\": \"system_upgrade_run step 4\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_reboot\"], \"when\": [\"step|int == 4\", \"upgrade_leapp_enabled\", \"\'Undercloud\' not in group_names\"], \"block\": [{\"name\": \"Run LeappPreRebootCommand\", \"shell\": {\"list_join\": [\"\", [\"#!/bin/bash\\n\\n\", {\"get_attr\": [\"RoleParametersValue\", \"value\", \"leapp_pre_reboot_command\"]}]]}}, {\"name\": \"Check that nova_libvirt is running\", \"shell\": \"podman ps --filter name=^nova_virtlogd$ --format \\\"{% raw %}{{ .Image }}{% endraw %}\\\"\\n\", \"register\": \"is_virtlogd_image_running\"}, {\"name\": \"Remove systemd files to disable them\", \"file\": {\"path\": \"/etc/systemd/system/{{ item }}\", \"state\": \"absent\"}, \"with_items\": [\"tripleo_nova_libvirt.service\", \"tripleo_nova_virtlogd_wrapper.service\", \"tripleo_nova_libvirt.target\"], \"when\": \"is_virtlogd_image_running.stdout != \'\'\"}, {\"name\": \"reboot to perform the upgrade\", \"reboot\": {\"reboot_timeout\": \"{{upgrade_leapp_reboot_timeout}}\", \"test_command\": \"source /etc/os-release; [ \\\"${VERSION_ID%.*}\\\" -ge \\\"8\\\" ] && systemctl is-system-running | grep -qE \\\"running|degraded\\\" || exit 1\", \"post_reboot_delay\": \"{{ upgrade_leapp_post_reboot_delay }}\"}}, {\"name\": \"Set selinux back to enforcing after leapp reboot\", \"selinux\": {\"policy\": \"targeted\", \"state\": \"enforcing\"}}, {\"name\": \"Run LeappPostRebootCommand\", \"shell\": {\"list_join\": [\"\", [\"#!/bin/bash\\n\\n\", {\"get_attr\": [\"RoleParametersValue\", \"value\", \"leapp_post_reboot_command\"]}]]}}]}, {\"name\": \"Host packages setup step0\", \"tags\": \"setup_packages\", \"when\": \"step|int == 0\", \"block\": [{\"name\": \"Package and repo update tasks\", \"block\": [{\"name\": \"Run UpgradeInitCommand\", \"shell\": {\"list_join\": [\"\", [\"#!/bin/bash\\n\\n\", \"if [[ -f /etc/resolv.conf.save ]] ; then rm /etc/resolv.conf.save; fi\\n\\n\", {\"get_attr\": [\"RoleParametersValue\", \"value\", \"upgrade_init_command\"]}]]}}, {\"name\": \"Run UpgradeInitCommonCommand\", \"shell\": {\"list_join\": [\"\", [\"#!/bin/bash\\n\\n\", {\"get_param\": \"UpgradeInitCommonCommand\"}]]}}, {\"name\": \"Ensure DNF modules have the right stream\", \"vars\": {\"dnf_module_list\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"dnf_module_list\"]}}, \"dnf\": {\"name\": \"@{{ item.module }}:{{ item.stream }}/{{ item.profile|default(\'common\') }}\", \"state\": \"present\"}, \"loop\": \"{{ dnf_module_list|list }}\", \"when\": [\"dnf_module_list|length > 0\", \"item.distribution_version is defined\", \"ansible_facts[\'distribution_major_version\'] is version(item.distribution_version, \'==\')\"]}, {\"name\": \"Ensure TripleO prerequisite packages are installed\", \"package\": {\"name\": [\"jq\", \"lvm2\", \"openstack-selinux\", \"os-net-config\", \"puppet-tripleo\", \"python3-heat-agent*\", \"rsync\"], \"state\": \"present\"}, \"when\": \"ansible_facts[\'distribution_major_version\'] is version(\'8\', \'==\')\"}, {\"name\": \"Ensure TripleO prerequisite packages are installed and use role based heat variable to provide specific list of packages\", \"vars\": {\"base_tripleo_packages\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"base_tripleo_packages\"]}}, \"package\": {\"name\": \"{{ base_tripleo_packages }}\", \"state\": \"present\"}, \"when\": [\"ansible_facts[\'distribution_major_version\'] is version(\'8\', \'==\')\", \"base_tripleo_packages|length > 0\"]}, {\"name\": \"WA for 2240185 - If the image is schema 1 and lacks signatures than add empty signatures\", \"shell\": \"for manifest_file in `find /var/lib/containers/storage/overlay-images/ -name \'manifest\'`\\ndo\\n    cat <<< $( jq  \'if .schemaVersion == 1 then if has(\\\"signatures\\\") then . else .signatures=[] end else . end\' $manifest_file ) > $manifest_file\\ndone\\n\", \"when\": \"ansible_facts[\'distribution_major_version\'] is version(\'8\', \'==\')\"}]}, {\"name\": \"check if libvirt is installed\", \"command\": \"/usr/bin/rpm -q libvirt-daemon\", \"failed_when\": false, \"register\": \"libvirt_installed\", \"check_mode\": false}, {\"name\": \"make sure libvirt services are disabled and masked\", \"service\": {\"name\": \"{{ item }}\", \"state\": \"stopped\", \"enabled\": false, \"masked\": true, \"daemon_reload\": true}, \"loop\": [\"libvirtd.service\", \"virtlogd.socket\"], \"when\": [\"libvirt_installed.rc == 0\"]}]}, {\"name\": \"Host packages setup step2\", \"tags\": \"setup_packages\", \"when\": \"step|int == 2\", \"block\": [{\"name\": \"Special treatment for OpenvSwitch\", \"tripleo_ovs_upgrade\": null, \"register\": \"ovs_upgrade\"}, {\"name\": \"Always ensure the openvswitch service is enabled and running after upgrades\", \"service\": {\"name\": \"openvswitch\", \"enabled\": true, \"state\": \"started\"}, \"when\": [\"ovs_upgrade.changed|bool\"]}]}, {\"name\": \"Host packages setup step3\", \"tags\": \"setup_packages\", \"when\": \"step|int == 3\", \"block\": [{\"name\": \"Check for os-net-config upgrade\", \"shell\": \"yum check-upgrade | awk \'/os-net-config/{print}\'\", \"register\": \"os_net_config_need_upgrade\"}, {\"name\": \"Check that os-net-config has legacy configuration\", \"stat\": {\"path\": \"/etc/os-net-config/config.json\", \"get_attributes\": false, \"get_checksum\": false, \"get_mime\": false}, \"register\": \"stat_config_json\"}, {\"name\": \"Check that os-net-config has new configuration\", \"stat\": {\"path\": \"/etc/os-net-config/config.yaml\", \"get_attributes\": false, \"get_checksum\": false, \"get_mime\": false}, \"register\": \"stat_config_yaml\"}, {\"name\": \"Slurp the os-net-config config.json\", \"slurp\": {\"src\": \"/etc/os-net-config/config.json\"}, \"register\": \"os_config_json\", \"when\": [\"stat_config_json.stat.exists\", \"not stat_config_yaml.stat.exists\"]}, {\"name\": \"Write updated /etc/os-net-config/config.yaml\", \"copy\": {\"content\": \"{{ os_config_json.content | b64decode | from_json | to_yaml }}\", \"dest\": \"/etc/os-net-config/config.yaml\"}, \"when\": [\"stat_config_json.stat.exists\", \"not stat_config_yaml.stat.exists\"]}, {\"name\": \"Remove legacy os-net-config configuration\", \"command\": \"mv /etc/os-net-config/config.json /etc/os-net-config/deprecated_config.json\", \"when\": [\"stat_config_json.stat.exists\"]}, {\"block\": [{\"name\": \"Upgrade os-net-config\", \"package\": \"name=os-net-config state=latest\"}, {\"name\": \"take new os-net-config parameters into account now\", \"command\": \"os-net-config --no-activate -c /etc/os-net-config/config.yaml -v --detailed-exit-codes\", \"register\": \"os_net_config_upgrade\", \"failed_when\": \"os_net_config_upgrade.rc not in [0,2]\", \"changed_when\": \"os_net_config_upgrade.rc == 2\"}], \"when\": [\"os_net_config_need_upgrade.stdout\", \"stat_config_yaml.stat.exists or stat_config_json.stat.exists\"]}, {\"name\": \"Update all packages\", \"when\": [\"not skip_package_update|bool\"], \"yum\": {\"name\": \"*\", \"state\": \"latest\", \"exclude\": \"ansible-core\"}, \"vars\": {\"skip_package_update\": {\"get_param\": \"SkipPackageUpdate\"}}}, {\"name\": \"Check whether openvswitch exits\", \"command\": \"systemctl status openvswitch.service\", \"register\": \"ovs_service\", \"ignore_errors\": true}, {\"name\": \"Always ensure the openvswitch service is enabled and running after upgrades rhbz#2329821\", \"service\": {\"name\": \"openvswitch\", \"enabled\": true, \"state\": \"started\"}, \"when\": [\"ovs_service.stderr != \\\"Unit openvswitch.service could not be found.\\\"\"]}]}], {\"if\": [\"podman_requires_login\", {\"get_attr\": [\"Podman\", \"role_data\", \"workaround_upgrade_tasks\"]}, []]}]}, \"external_upgrade_tasks\": [{\"name\": \"Clean up upgrade artifacts\", \"when\": \"step|int == 1\", \"tags\": [\"never\", \"system_upgrade_cleanup\"], \"block\": [{\"name\": \"cleanup tripleo_persist\", \"include_role\": {\"name\": \"tripleo_persist\", \"tasks_from\": \"cleanup.yml\"}}]}], \"update_tasks\": [{\"name\": \"Enforce RHOSP rules regarding subscription.\", \"include_role\": {\"name\": \"tripleo_redhat_enforce\"}, \"vars\": {\"skip_rhel_enforcement\": {\"get_param\": \"SkipRhelEnforcement\"}}, \"when\": [\"step|int == 0\", \"ansible_facts[\'distribution\'] == \'RedHat\'\", \"not (skip_rhel_enforcement | bool)\"]}, {\"name\": \"Ensure DNF modules have the right stream enabled\", \"vars\": {\"dnf_module_list\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"dnf_module_list\"]}}, \"tripleo_dnf_stream\": {\"name\": \"{{ item.module }}:{{ item.stream }}\", \"state\": \"enabled\"}, \"loop\": \"{{ dnf_module_list|list }}\", \"when\": [\"step|int == 0\", \"dnf_module_list|length > 0\", \"item.distribution_version is defined\", \"ansible_facts[\'distribution_major_version\'] is version(item.distribution_version, \'==\')\"]}, {\"name\": \"Check for existing yum.pid\", \"stat\": \"path=/run/yum.pid\", \"register\": \"yum_pid_file\", \"when\": \"step|int == 0 or step|int == 3\"}, {\"name\": \"Exit if existing yum process\", \"fail\": \"msg=\\\"ERROR existing yum.pid detected - can\'t continue! Please ensure there is no other package update process for the duration of the minor update worfklow. Exiting.\\\"\", \"when\": \"(step|int == 0 or step|int == 3) and yum_pid_file.stat.exists\"}, {\"name\": \"Special treatment for OpenvSwitch\", \"tripleo_ovs_upgrade\": null, \"when\": [\"step|int == 2\"], \"register\": \"ovs_upgrade\"}, {\"name\": \"Always ensure the openvswitch service is enabled and running after upgrades\", \"service\": {\"name\": \"openvswitch\", \"enabled\": true, \"state\": \"started\"}, \"when\": [\"step|int == 2\", \"ovs_upgrade.changed|bool\"]}, {\"name\": \"Update packages and EFI grub.cfg\", \"when\": [\"step|int == 3\", \"not skip_package_update|bool\"], \"block\": [{\"name\": \"Update all packages\", \"yum\": {\"name\": \"*\", \"state\": \"latest\", \"exclude\": \"ansible-core\"}}, {\"name\": \"Replace EFI grub.cfg with redirect to /boot/grub2/grub.cfg\", \"import_role\": {\"name\": \"tripleo_kernel\", \"tasks_from\": \"efigrub.yml\"}}], \"vars\": {\"skip_package_update\": {\"get_param\": \"SkipPackageUpdate\"}}}, {\"name\": \"Ensure openvswitch is running after update\", \"when\": \"step|int == 3\", \"service\": {\"name\": \"openvswitch\", \"enabled\": true, \"state\": \"started\"}, \"ignore_errors\": true}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(254,'2026-06-10 07:47:48',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Apache service configured with Puppet. Note this is typically included automatically via other services which run via Apache.\\n\", \"parameters\": {\"ApacheMaxRequestWorkers\": {\"default\": 100, \"description\": \"Maximum number of simultaneously processed requests.\", \"type\": \"number\"}, \"ApacheServerLimit\": {\"default\": 100, \"description\": \"Maximum number of Apache processes.\", \"type\": \"number\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"ApacheCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}, \"ApacheTimeout\": {\"type\": \"number\", \"default\": 90, \"description\": \"The timeout in seconds for Apache, which defines duration Apache waits for I/O operations\"}}, \"conditions\": {\"key_size_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"ApacheCertificateKeySize\"}, \"\"]}}}, \"resources\": {\"ApacheNetworks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"Controller\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"CellController\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"CellControllerCompute\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"Compute\": [\"ctlplane\", \"storage\", \"internal_api\"], \"BlockStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"ObjectStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"CephStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\"], \"Networker\": [\"ctlplane\", \"internal_api\"]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Apache role.\", \"value\": {\"service_name\": \"apache\", \"config_settings\": {\"map_merge\": [{\"apache::ip\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ApacheNetwork\"]}}}}, \"apache::default_vhost\": false, \"apache::trace_enable\": \"Off\", \"apache::server_signature\": \"Off\", \"apache::server_tokens\": \"Prod\", \"apache::timeout\": {\"get_param\": \"ApacheTimeout\"}, \"apache::default_mods\": false, \"apache::mod::prefork::maxrequestworkers\": {\"get_param\": \"ApacheMaxRequestWorkers\"}, \"apache::mod::prefork::serverlimit\": {\"get_param\": \"ApacheServerLimit\"}, \"apache::mod::remoteip::proxy_ips\": {\"get_param\": [\"ServiceData\", \"net_cidr_map\", {\"get_param\": [\"ServiceNetMap\", \"ApacheNetwork\"]}]}, \"apache::mod::alias::icons_options\": \"None\"}, {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"apache::mod::ssl::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}, \"apache::mod::ssl::ssl_protocol\": [\"all\", \"-SSLv2\", \"-SSLv3\", \"-TLSv1\"], \"apache_certificates_specs\": {\"map_merge\": {\"repeat\": {\"template\": {\"httpd-NETWORK\": {\"service_certificate\": \"/etc/pki/tls/certs/httpd/httpd-NETWORK.crt\", \"service_key\": \"/etc/pki/tls/private/httpd/httpd-NETWORK.key\"}}, \"for_each\": {\"NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}}}]}]}, \"metadata_settings\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"repeat\": {\"template\": [{\"service\": \"HTTP\", \"network\": \"$NETWORK\", \"type\": \"node\"}], \"for_each\": {\"$NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}]}, \"upgrade_tasks\": [], \"deploy_steps_tasks\": [{\"name\": \"Certificate generation\", \"when\": [\"step|int == 1\", \"enable_internal_tls\"], \"block\": [{\"name\": \"Create dirs for certificates and keys\", \"file\": {\"path\": \"{{ item }}\", \"state\": \"directory\", \"serole\": \"object_r\", \"setype\": \"cert_t\", \"seuser\": \"system_u\"}, \"with_items\": [\"/etc/pki/tls/certs/httpd\", \"/etc/pki/tls/private/httpd\"]}, {\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": {\"repeat\": {\"template\": {\"name\": \"httpd-NETWORK\", \"dns\": \"{{ fqdn_NETWORK }}\", \"principal\": \"HTTP/{{ fqdn_NETWORK }}@{{ idm_realm }}\", \"run_after\": \"cp /etc/pki/tls/certs/httpd-NETWORK.crt /etc/pki/tls/certs/httpd/httpd-NETWORK.crt\\ncp /etc/pki/tls/private/httpd-NETWORK.key /etc/pki/tls/private/httpd/httpd-NETWORK.key\\npkill -USR1 httpd\\n\", \"key_size\": {\"if\": [\"key_size_override_set\", {\"get_param\": \"ApacheCertificateKeySize\"}, {\"get_param\": \"CertificateKeySize\"}]}, \"ca\": \"ipa\"}, \"for_each\": {\"NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"EnableInternalTLS\": false}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(255,'2026-06-10 07:47:48',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Swift Ringbuilder\\n\", \"parameters\": {\"ContainerSwiftConfigImage\": {\"description\": \"The container image to use for the swift config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"SwiftMinPartHours\": {\"type\": \"number\", \"default\": 1, \"description\": \"The minimum time (in hours) before a partition in a ring can be moved following a rebalance.\"}, \"SwiftPartPower\": {\"default\": 10, \"description\": \"Partition Power to use when building Swift rings\", \"type\": \"number\"}, \"SwiftRingBuild\": {\"default\": true, \"description\": \"Whether to manage Swift rings or not\", \"type\": \"boolean\"}, \"SwiftReplicas\": {\"type\": \"number\", \"default\": 3, \"description\": \"How many replicas to use in the swift rings.\"}, \"SwiftRawDisks\": {\"default\": {}, \"description\": \"A hash of additional raw devices to use as Swift backend (eg. {sdb: {}})\", \"type\": \"json\"}, \"SwiftUseLocalDir\": {\"default\": true, \"description\": \"Use a local directory for Swift storage services when building rings\", \"type\": \"boolean\"}, \"SwiftUseNodeDataLookup\": {\"default\": false, \"description\": \"Use NodeDataLookup for disk devices in order to use persistent naming\", \"type\": \"boolean\"}, \"SwiftRingGetTempurl\": {\"default\": \"\", \"description\": \"A temporary Swift URL to download rings from.\", \"type\": \"string\"}, \"SwiftRingPutTempurl\": {\"default\": \"\", \"description\": \"A temporary Swift URL to upload rings to.\", \"type\": \"string\"}, \"DeployIdentifier\": {\"default\": 1781077560, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}}, \"conditions\": {\"swift_use_local_dir\": {\"and\": [{\"equals\": [{\"get_param\": \"SwiftUseLocalDir\"}, true]}, {\"equals\": [{\"get_param\": \"SwiftRawDisks\"}, {}]}]}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerSwiftConfigImage\": \"ContainerSwiftConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerSwiftConfigImage\": {\"get_param\": \"ContainerSwiftConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for Swift Ringbuilder configuration in containers.\", \"value\": {\"service_name\": \"swift_ringbuilder\", \"config_settings\": {\"map_merge\": [{\"tripleo::profile::base::swift::ringbuilder::skip_consistency_check\": true, \"tripleo::profile::base::swift::ringbuilder::swift_ring_get_tempurl\": {\"get_param\": \"SwiftRingGetTempurl\"}, \"tripleo::profile::base::swift::ringbuilder::swift_ring_put_tempurl\": {\"get_param\": \"SwiftRingPutTempurl\"}, \"tripleo::profile::base::swift::ringbuilder::build_ring\": {\"get_param\": \"SwiftRingBuild\"}, \"tripleo::profile::base::swift::ringbuilder::replicas\": {\"get_param\": \"SwiftReplicas\"}, \"tripleo::profile::base::swift::ringbuilder::part_power\": {\"get_param\": \"SwiftPartPower\"}, \"tripleo::profile::base::swift::ringbuilder::min_part_hours\": {\"get_param\": \"SwiftMinPartHours\"}, \"tripleo::profile::base::swift::ringbuilder::raw_disk_prefix\": \"r1z1-\"}, {\"if\": [{\"get_param\": \"SwiftUseNodeDataLookup\"}, {}, {\"tripleo::profile::base::swift::ringbuilder::raw_disks\": {\"list_concat\": [{\"if\": [\"swift_use_local_dir\", [\":%PORT%/d1\"]]}, {\"repeat\": {\"template\": \":%PORT%/DEVICE\", \"for_each\": {\"DEVICE\": {\"get_param\": \"SwiftRawDisks\"}}}}]}}]}]}, \"service_config_settings\": {}, \"puppet_config\": {\"config_volume\": \"swift_ringbuilder\", \"puppet_tags\": \"swift_config,exec,fetch_swift_ring_tarball,extract_swift_ring_tarball,ring_object_device,swift::ringbuilder::create,tripleo::profile::base::swift::add_devices,swift::ringbuilder::rebalance,create_swift_ring_tarball,upload_swift_ring_tarball\", \"step_config\": \"include tripleo::profile::base::swift::ringbuilder\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerSwiftConfigImage\"]}}, \"kolla_config\": {}, \"docker_config\": {\"step_3\": {\"swift_copy_rings\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerSwiftConfigImage\"]}, \"net\": \"none\", \"user\": \"root\", \"detach\": false, \"command\": [\"/bin/bash\", \"-c\", \"cp -v -dR --preserve -t /etc/swift /swift_ringbuilder/etc/swift/*.gz /swift_ringbuilder/etc/swift/*.builder /swift_ringbuilder/etc/swift/backups\"], \"volumes\": [\"/var/lib/config-data/puppet-generated/swift/etc/swift:/etc/swift:rw,z\", \"/var/lib/config-data/puppet-generated/swift_ringbuilder:/swift_ringbuilder:ro\"], \"environment\": {\"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(256,'2026-06-10 07:47:49',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Configure sshd_config\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"BannerText\": {\"default\": \"\", \"description\": \"Configures Banner text in sshd_config\", \"type\": \"string\"}, \"MessageOfTheDay\": {\"default\": \"\", \"description\": \"Configures /etc/motd text\", \"type\": \"string\"}, \"SshServerOptions\": {\"default\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"description\": \"Mapping of sshd_config values\", \"type\": \"json\"}, \"PasswordAuthentication\": {\"default\": \"no\", \"description\": \"Whether or not disable password authentication\", \"type\": \"string\"}, \"SshFirewallAllowAll\": {\"default\": true, \"description\": \"Set this to true to open up ssh access from all sources.\", \"type\": \"boolean\"}, \"SshServerOptionsOverrides\": {\"default\": {}, \"description\": \"Mapping of sshd_config values to override definitions in SshServerOptions\", \"type\": \"json\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"The following parameters are deprecated and will be removed. They should not\\nbe relied on for new deployments. If you have concerns regarding deprecated\\nparameters, please contact the TripleO development team on IRC or the\\nOpenStack mailing list.\\n\", \"parameters\": [\"SshServerOptionsOverrides\"]}], \"conditions\": {\"ssh_firewall_allow_all\": {\"equals\": [{\"get_param\": \"SshFirewallAllowAll\"}, true]}, \"ssh_banner_text_set\": {\"not\": {\"equals\": [{\"get_param\": \"BannerText\"}, \"\"]}}, \"ssh_motd_text_set\": {\"not\": {\"equals\": [{\"get_param\": \"MessageOfTheDay\"}, \"\"]}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the ssh\", \"value\": {\"service_name\": \"sshd\", \"firewall_rules\": {\"003 accept ssh from all\": {\"proto\": \"tcp\", \"dport\": 22, \"extras\": {\"ensure\": {\"if\": [\"ssh_firewall_allow_all\", \"present\", \"absent\"]}}}}, \"host_prep_tasks\": [{\"include_role\": {\"name\": \"tripleo_sshd\"}, \"vars\": {\"tripleo_sshd_server_options\": {\"map_merge\": [{\"get_param\": \"SshServerOptions\"}, {\"get_param\": \"SshServerOptionsOverrides\"}]}, \"tripleo_sshd_password_authentication\": {\"get_param\": \"PasswordAuthentication\"}, \"tripleo_sshd_banner_enabled\": {\"if\": [\"ssh_banner_text_set\", true, false]}, \"tripleo_sshd_banner_text\": {\"get_param\": \"BannerText\"}, \"tripleo_sshd_motd_enabled\": {\"if\": [\"ssh_motd_text_set\", true, false]}, \"tripleo_sshd_message_of_the_day\": {\"get_param\": \"MessageOfTheDay\"}}}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(257,'2026-06-10 07:47:49',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Configures podman on the host\\n\", \"parameters\": {\"DockerInsecureRegistryAddress\": {\"description\": \"Optional. The IP Address and Port of an insecure docker namespace that will be configured in /etc/sysconfig/docker. The value can be multiple addresses separated by commas.\", \"type\": \"comma_delimited_list\", \"default\": []}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ContainerImageRegistryLogin\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Flag to enable container registry login actions during the deployment. Setting this to true will cause login calls to be performed during the deployment.\"}, \"ContainerImageRegistryCredentials\": {\"type\": \"json\", \"hidden\": true, \"default\": {}, \"description\": \"Mapping of image registry hosts to login credentials. Must be in the following example format\\n\\n  docker.io:\\n    username: pa55word\\n  \'192.0.2.1:8787\':\\n    registry_username: password\\n\"}, \"ContainerDefaultPidsLimit\": {\"type\": \"number\", \"default\": 4096, \"description\": \"Setting to configure the default pids_limit in /etc/container/container.conf. This is supported starting with podman 2.0.x\"}, \"ContainerDefaultEventsLogger\": {\"type\": \"string\", \"default\": \"journald\", \"description\": \"Setting to configure where podman logs its events. Uses journald by default as that will rotate data stored in tmpfs.\", \"constraints\": [{\"allowed_values\": [\"journald\", \"file\", \"none\"]}]}, \"SystemdDropInDependencies\": {\"default\": true, \"description\": \"tell the tripleo_container_manage to inject additional ordering dependencies for the systemd scopes associated to podman containers.\", \"type\": \"boolean\"}, \"deployment_source_hosts\": {\"default\": \"Undercloud\", \"type\": \"string\", \"description\": \"Host or hostgroup that runs the deployment\"}}, \"conditions\": {\"insecure_registry_is_empty\": {\"equals\": [{\"get_param\": \"DockerInsecureRegistryAddress\"}, []]}, \"systemd_drop_in_dependencies_enabled\": {\"get_param\": \"SystemdDropInDependencies\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the podman service\", \"value\": {\"service_name\": \"podman\", \"config_settings\": {}, \"step_config\": \"\", \"host_prep_tasks\": [{\"name\": \"Install and configure Podman\", \"block\": [{\"name\": \"Set login facts\", \"no_log\": true, \"set_fact\": {\"container_registry_insecure_registries\": {\"if\": [\"insecure_registry_is_empty\", [], {\"get_param\": \"DockerInsecureRegistryAddress\"}]}, \"container_registry_login\": {\"get_param\": \"ContainerImageRegistryLogin\"}, \"container_registry_logins\": {}, \"container_registry_logins_json\": {\"get_param\": \"ContainerImageRegistryCredentials\"}, \"container_default_pids_limit\": {\"get_param\": \"ContainerDefaultPidsLimit\"}, \"container_events_logger_mechanism\": {\"get_param\": \"ContainerDefaultEventsLogger\"}}}, {\"name\": \"Convert logins json to dict\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json | from_json }}\"}, \"when\": [\"container_registry_logins_json is string\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Set registry logins\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json }}\"}, \"when\": [\"container_registry_logins_json is mapping\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Run podman install\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_install.yml\"}, \"vars\": {\"tripleo_container_registry_insecure_registries\": \"{{ container_registry_insecure_registries }}\", \"tripleo_container_default_pids_limit\": \"{{ container_default_pids_limit }}\", \"tripleo_container_events_logger_mechanism\": \"{{ container_events_logger_mechanism }}\"}}, {\"name\": \"Run podman login\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_login.yml\"}, \"vars\": {\"tripleo_container_registry_logins\": \"{{ container_registry_logins }}\", \"tripleo_container_registry_login\": \"{{ container_registry_login | bool }}\"}}]}, {\"if\": [\"systemd_drop_in_dependencies_enabled\", [{\"name\": \"Configure tripleo_container_manage to generate systemd drop-in dependencies\", \"copy\": {\"dest\": \"/etc/sysconfig/podman_drop_in\", \"content\": \"This file makes tripleo_container_manage generate additional systemd\\ndependencies for containers that have special\\nstart/stop ordering constraints. It ensures that\\nthose constraints are enforced on reboot/shutdown.\\n\"}}], [{\"name\": \"Configure tripleo_container_manage to not generate drop-in dependencies\", \"file\": {\"path\": \"/etc/sysconfig/podman_drop_in\", \"state\": \"absent\"}}]]}], \"deploy_steps_tasks\": [{\"when\": [\"(step|int) == 1\"], \"block\": [{\"name\": \"Pre-fetch all the containers\", \"become\": true, \"containers.podman.podman_image\": {\"name\": \"{{ prefetch_image }}\", \"validate_certs\": false, \"force\": true}, \"register\": \"result\", \"until\": \"result is succeeded\", \"retries\": 5, \"delay\": 5, \"loop_control\": {\"loop_var\": \"prefetch_image\"}, \"loop\": \"{{ lookup(\'template\', tripleo_role_name + \'/docker_config.yaml\', errors=\'ignore\') | default(\'{}\', True) | from_yaml | recursive_get_key_from_dict(key=\'image\') | unique }}\"}]}], \"service_config_settings\": {}, \"workaround_upgrade_tasks\": [{\"name\": \"Configure Podman registry\", \"when\": [\"step|int == 0\"], \"tags\": [\"setup_packages\"], \"block\": [{\"name\": \"Make sure the Undercloud hostname is included in /etc/hosts\", \"when\": [\"undercloud_hosts_entries is defined\"], \"lineinfile\": {\"dest\": \"/etc/hosts\", \"line\": \"{{ undercloud_hosts_entries | join(\'\') }}\", \"state\": \"present\"}}]}, {\"name\": \"Run podman install\", \"tags\": [\"system_upgrade\", \"system_upgrade_run\", \"setup_packages\"], \"when\": [\"step|int == 0\"], \"block\": [{\"name\": \"Set login facts\", \"no_log\": true, \"set_fact\": {\"container_registry_insecure_registries\": {\"if\": [\"insecure_registry_is_empty\", [], {\"get_param\": \"DockerInsecureRegistryAddress\"}]}, \"container_registry_login\": {\"get_param\": \"ContainerImageRegistryLogin\"}, \"container_registry_logins\": {}, \"container_registry_logins_json\": {\"get_param\": \"ContainerImageRegistryCredentials\"}, \"container_default_pids_limit\": {\"get_param\": \"ContainerDefaultPidsLimit\"}, \"container_events_logger_mechanism\": {\"get_param\": \"ContainerDefaultEventsLogger\"}}}, {\"name\": \"Convert logins json to dict\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json | from_json }}\"}, \"when\": [\"container_registry_logins_json is string\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Set registry logins\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json }}\"}, \"when\": [\"container_registry_logins_json is mapping\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Run podman install\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_install.yml\"}, \"vars\": {\"tripleo_container_registry_insecure_registries\": \"{{ container_registry_insecure_registries }}\", \"tripleo_container_default_pids_limit\": \"{{ container_default_pids_limit }}\", \"tripleo_container_events_logger_mechanism\": \"{{ container_events_logger_mechanism }}\"}}, {\"name\": \"Run podman login\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_login.yml\"}, \"vars\": {\"tripleo_container_registry_logins\": \"{{ container_registry_logins }}\", \"tripleo_container_registry_login\": \"{{ container_registry_login | bool }}\"}}]}, {\"name\": \"Comment infra_image in container.conf\", \"lineinfile\": {\"dest\": \"/usr/share/containers/containers.conf\", \"regexp\": \"(?i)^(infra_image.*)\", \"line\": \"#\\\\1\", \"backrefs\": true, \"state\": \"present\"}, \"tags\": [\"setup_packages\"], \"when\": [\"step|int == 0\"]}], \"upgrade_tasks\": [{\"name\": \"Configure Podman registry\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"Make sure the Undercloud hostname is included in /etc/hosts\", \"when\": [\"undercloud_hosts_entries is defined\"], \"lineinfile\": {\"dest\": \"/etc/hosts\", \"line\": \"{{ undercloud_hosts_entries | join(\'\') }}\", \"state\": \"present\"}}]}, {\"name\": \"Run podman install\", \"tags\": [\"system_upgrade\", \"system_upgrade_run\"], \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"Set login facts\", \"no_log\": true, \"set_fact\": {\"container_registry_insecure_registries\": {\"if\": [\"insecure_registry_is_empty\", [], {\"get_param\": \"DockerInsecureRegistryAddress\"}]}, \"container_registry_login\": {\"get_param\": \"ContainerImageRegistryLogin\"}, \"container_registry_logins\": {}, \"container_registry_logins_json\": {\"get_param\": \"ContainerImageRegistryCredentials\"}, \"container_default_pids_limit\": {\"get_param\": \"ContainerDefaultPidsLimit\"}, \"container_events_logger_mechanism\": {\"get_param\": \"ContainerDefaultEventsLogger\"}}}, {\"name\": \"Convert logins json to dict\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json | from_json }}\"}, \"when\": [\"container_registry_logins_json is string\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Set registry logins\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json }}\"}, \"when\": [\"container_registry_logins_json is mapping\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Run podman install\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_install.yml\"}, \"vars\": {\"tripleo_container_registry_insecure_registries\": \"{{ container_registry_insecure_registries }}\", \"tripleo_container_default_pids_limit\": \"{{ container_default_pids_limit }}\", \"tripleo_container_events_logger_mechanism\": \"{{ container_events_logger_mechanism }}\"}}, {\"name\": \"Run podman login\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_login.yml\"}, \"vars\": {\"tripleo_container_registry_logins\": \"{{ container_registry_logins }}\", \"tripleo_container_registry_login\": \"{{ container_registry_login | bool }}\"}}]}], \"update_tasks\": [{\"name\": \"Force pre-fetch of container images\", \"when\": [\"(step|int) == 5\"], \"block\": [{\"name\": \"Pre-fetch all the containers\", \"become\": true, \"containers.podman.podman_image\": {\"name\": \"{{ prefetch_image }}\", \"validate_certs\": false, \"force\": true}, \"register\": \"result\", \"until\": \"result is succeeded\", \"retries\": 5, \"delay\": 5, \"loop_control\": {\"loop_var\": \"prefetch_image\"}, \"loop\": \"{{ lookup(\'template\', tripleo_role_name + \'/docker_config.yaml\', errors=\'ignore\') | default(\'{}\', True) | from_yaml | recursive_get_key_from_dict(key=\'image\') | unique }}\"}]}], \"post_upgrade_tasks\": [{\"name\": \"Purge Podman\", \"when\": [\"(step | int) == 3\", \"container_cli == \'podman\'\", \"deployment_source_hosts not in group_names\"], \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_purge.yml\"}, \"vars\": {\"deployment_source_hosts\": {\"get_param\": \"deployment_source_hosts\"}}}], \"post_update_tasks\": [{\"name\": \"Purge Podman\", \"when\": [\"(step | int) == 3\", \"container_cli == \'podman\'\", \"deployment_source_hosts not in group_names\"], \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_purge.yml\"}, \"vars\": {\"deployment_source_hosts\": {\"get_param\": \"deployment_source_hosts\"}}}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(258,'2026-06-10 07:47:49',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Template for placement\'s logging to files\\n\", \"parameters\": {\"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ContainerPlacementImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\"}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerPlacementImage\": \"ContainerPlacementImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerPlacementImage\": {\"get_param\": \"ContainerPlacementImage\"}}}]}}}}, \"outputs\": {\"config_settings\": {\"description\": \"Extra hieradata needed to log to files in the host.\", \"value\": null}, \"volumes\": {\"description\": \"The volumes needed to log to files in the host.\", \"value\": [\"/var/log/containers/placement:/var/log/placement:z\", \"/var/log/containers/httpd/placement:/var/log/httpd:z\"]}, \"docker_config\": {\"description\": \"Extra containers needed for logging to files in the host.\", \"value\": {\"step_2\": {\"placement_init_log\": {\"start_order\": 1, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerPlacementImage\"]}, \"net\": \"none\", \"user\": \"root\", \"command\": [\"/bin/bash\", \"-c\", \"chown -R placement:placement /var/log/placement\"], \"volumes\": [\"/var/log/containers/placement:/var/log/placement:z\", \"/var/log/containers/httpd/placement:/var/log/httpd:z\"]}}}}, \"host_prep_tasks\": {\"description\": \"Extra ansible tasks needed for logging to files in the host.\", \"value\": [{\"name\": \"create persistent logs directory\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/placement\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/log/containers/httpd/placement\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}]}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(259,'2026-06-10 07:47:50',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"TripleO Firewall settings\\n\", \"parameters\": {\"Debug\": {\"type\": \"boolean\", \"default\": true, \"description\": \"Set to True to enable debugging on all services.\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ExtraFirewallRules\": {\"default\": {}, \"description\": \"Mapping of firewall rules.\", \"type\": \"json\", \"tags\": [\"role_specific\"]}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"extra_firewall_rules\": \"ExtraFirewallRules\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ExtraFirewallRules\": {\"get_param\": \"ExtraFirewallRules\"}}}]}}}}, \"conditions\": {\"no_ctlplane\": {\"equals\": [{\"get_params\": [\"ServiceData\", \"net_cidr_map\", \"ctlplane\"]}, null]}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the TripleO firewall settings\", \"value\": {\"service_name\": \"tripleo_firewall\", \"config_settings\": {\"tripleo::firewall::manage_firewall\": false, \"tripleo::firewall::purge_firewall_rules\": false}, \"ansible_group_vars\": {\"tripleo_nftables_debug\": {\"get_param\": \"Debug\"}}, \"firewall_rules\": {\"map_merge\": [{\"map_merge\": {\"repeat\": {\"for_each\": {\"<%net_cidr%>\": {\"get_param\": [\"ServiceData\", \"net_cidr_map\", \"ctlplane\"]}}, \"template\": {\"003 accept ssh from ctlplane subnet <%net_cidr%>\": {\"source\": \"<%net_cidr%>\", \"proto\": \"tcp\", \"dport\": 22}}}}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"extra_firewall_rules\"]}]}, \"host_prep_tasks\": [{\"if\": [\"no_ctlplane\", {\"name\": \"Failure - ctlplane subnet is unset\", \"fail\": {\"msg\": \"No CIDRs found in the ctlplane network tags.\\nPlease refer to the documentation in order to\\nset the correct network tags in DeployedServerPortMap.\\n\"}}, {\"name\": \"Notice - ctlplane subnet is set\", \"debug\": {\"msg\": \"CIDRs found in the ctlplane network tags.\\n\"}}]}], \"host_firewall_tasks\": [{\"name\": \"Run firewall role\", \"include_role\": {\"name\": \"tripleo_firewall\"}}], \"update_tasks\": [{\"name\": \"Cleanup tripleo-iptables services\", \"when\": [\"(step | int) == 1\"], \"block\": [{\"name\": \"Disable tripleo-iptables.service\", \"systemd\": {\"name\": \"tripleo-iptables.service\", \"state\": \"stopped\", \"enabled\": false}, \"register\": \"systemd_tripleo_iptables\", \"failed_when\": false}, {\"name\": \"Cleanup tripleo-iptables.services\", \"file\": {\"path\": \"/etc/systemd/system/tripleo-iptables.service\", \"state\": \"absent\"}}, {\"name\": \"Disable tripleo-ip6tables.service\", \"systemd\": {\"name\": \"tripleo-ip6tables.service\", \"state\": \"stopped\", \"enabled\": false}, \"register\": \"systemd_tripleo_ip6tables\", \"failed_when\": false}, {\"name\": \"Cleanup tripleo-ip6tables.services\", \"file\": {\"path\": \"/etc/systemd/system/tripleo-ip6tables.service\", \"state\": \"absent\"}}, {\"name\": \"Reload systemd\", \"systemd\": {\"daemon_reload\": true}, \"when\": [\"(systemd_tripleo_iptables is changed or systemd_tripleo_ip6tables is changed)\"]}]}], \"upgrade_tasks\": [{\"name\": \"Cleanup tripleo-iptables services\", \"when\": [\"(step | int) == 1\"], \"block\": [{\"name\": \"Disable tripleo-iptables.service\", \"systemd\": {\"name\": \"tripleo-iptables.service\", \"state\": \"stopped\", \"enabled\": false}, \"register\": \"systemd_tripleo_iptables\", \"failed_when\": false}, {\"name\": \"Cleanup tripleo-iptables.services\", \"file\": {\"path\": \"/etc/systemd/system/tripleo-iptables.service\", \"state\": \"absent\"}}, {\"name\": \"Disable tripleo-ip6tables.service\", \"systemd\": {\"name\": \"tripleo-ip6tables.service\", \"state\": \"stopped\", \"enabled\": false}, \"register\": \"systemd_tripleo_ip6tables\", \"failed_when\": false}, {\"name\": \"Cleanup tripleo-ip6tables.services\", \"file\": {\"path\": \"/etc/systemd/system/tripleo-ip6tables.service\", \"state\": \"absent\"}}, {\"name\": \"Reload systemd\", \"systemd\": {\"daemon_reload\": true}, \"when\": [\"(systemd_tripleo_iptables is changed or systemd_tripleo_ip6tables is changed)\"]}]}, {\"when\": [\"(step | int) == 3\"], \"block\": [{\"name\": \"blank ipv6 rule before activating ipv6 firewall.\", \"shell\": \"cat /etc/sysconfig/ip6tables > /etc/sysconfig/ip6tables.n-o-upgrade; cat</dev/null>/etc/sysconfig/ip6tables\", \"args\": {\"creates\": \"/etc/sysconfig/ip6tables.n-o-upgrade\"}}, {\"name\": \"cleanup unmanaged rules pushed by iptables-services\", \"shell\": \"iptables -C INPUT -m state --state RELATED,ESTABLISHED -j ACCEPT &>/dev/null && \\\\\\n  iptables -D INPUT -m state --state RELATED,ESTABLISHED -j ACCEPT\\niptables -C INPUT -p icmp -j ACCEPT &>/dev/null && \\\\\\n  iptables -D INPUT -p icmp -j ACCEPT\\niptables -C INPUT -i lo -j ACCEPT &>/dev/null && \\\\\\n  iptables -D INPUT -i lo -j ACCEPT\\niptables -C INPUT -p tcp -m state --state NEW -m tcp --dport 22 -j ACCEPT &>/dev/null && \\\\\\n  iptables -D INPUT -p tcp -m state --state NEW -m tcp --dport 22 -j ACCEPT\\niptables -C INPUT -j REJECT --reject-with icmp-host-prohibited &>/dev/null && \\\\\\n  iptables -D INPUT -j REJECT --reject-with icmp-host-prohibited\\niptables -C FORWARD -j REJECT --reject-with icmp-host-prohibited &>/dev/null && \\\\\\n  iptables -D FORWARD -j REJECT --reject-with icmp-host-prohibited\\n\\nsed -i \'/^-A INPUT -m state --state RELATED,ESTABLISHED -j ACCEPT$/d\' /etc/sysconfig/iptables\\nsed -i \'/^-A INPUT -p icmp -j ACCEPT$/d\' /etc/sysconfig/iptables\\nsed -i \'/^-A INPUT -i lo -j ACCEPT$/d\' /etc/sysconfig/iptables\\nsed -i \'/^-A INPUT -p tcp -m state --state NEW -m tcp --dport 22 -j ACCEPT$/d\' /etc/sysconfig/iptables\\nsed -i \'/^-A INPUT -j REJECT --reject-with icmp-host-prohibited$/d\' /etc/sysconfig/iptables\\nsed -i \'/^-A FORWARD -j REJECT --reject-with icmp-host-prohibited$/d\' /etc/sysconfig/iptables\\n\\nip6tables -C INPUT -m state --state RELATED,ESTABLISHED -j ACCEPT &>/dev/null && \\\\\\n  ip6tables -D INPUT -m state --state RELATED,ESTABLISHED -j ACCEPT\\nip6tables -C INPUT -p ipv6-icmp -j ACCEPT &>/dev/null && \\\\\\n  ip6tables -D INPUT -p ipv6-icmp -j ACCEPT\\nip6tables -C INPUT -i lo -j ACCEPT &>/dev/null && \\\\\\n  ip6tables -D INPUT -i lo -j ACCEPT\\nip6tables -C INPUT -p tcp -m state --state NEW -m tcp --dport 22 -j ACCEPT &>/dev/null && \\\\\\n  ip6tables -D INPUT -p tcp -m state --state NEW -m tcp --dport 22 -j ACCEPT\\nip6tables -C INPUT -d fe80::/64 -p udp -m udp --dport 546 -m state --state NEW -j ACCEPT &>/dev/null && \\\\\\n  ip6tables -D INPUT -d fe80::/64 -p udp -m udp --dport 546 -m state --state NEW -j ACCEPT\\nip6tables -C INPUT -j REJECT --reject-with icmp6-adm-prohibited &>/dev/null && \\\\\\n  ip6tables -D INPUT -j REJECT --reject-with icmp6-adm-prohibited\\nip6tables -C FORWARD -j REJECT --reject-with icmp6-adm-prohibited &>/dev/null && \\\\\\n  ip6tables -D FORWARD -j REJECT --reject-with icmp6-adm-prohibited\\n\\nsed -i \'/^-A INPUT -m state --state RELATED,ESTABLISHED -j ACCEPT$/d\' /etc/sysconfig/ip6tables\\nsed -i \'/^-A INPUT -p ipv6-icmp -j ACCEPT$/d\' /etc/sysconfig/ip6tables\\nsed -i \'/^-A INPUT -i lo -j ACCEPT$/d\' /etc/sysconfig/ip6tables\\nsed -i \'/^-A INPUT -p tcp -m state --state NEW -m tcp --dport 22 -j ACCEPT$/d\' /etc/sysconfig/ip6tables\\nsed -i \'/^-A INPUT -d fe80::\\\\/64 -p udp -m udp --dport 546 -m state --state NEW -j ACCEPT$/d\' /etc/sysconfig/ip6tables\\nsed -i \'/^-A INPUT -j REJECT --reject-with icmp6-adm-prohibited$/d\' /etc/sysconfig/ip6tables\\nsed -i \'/^-A FORWARD -j REJECT --reject-with icmp6-adm-prohibited$/d\' /etc/sysconfig/ip6tables\"}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(260,'2026-06-10 07:47:50',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Chrony time service deployment using ansible, this YAML file creates the interface between the HOT template and the ansible role that actually installs and configure chronyd.\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"NtpServer\": {\"default\": \"pool.ntp.org\", \"description\": \"NTP servers list. Defaulted to a set of pool.ntp.org servers in order to have a sane default for Pacemaker deployments when not configuring this parameter by default.\", \"type\": \"comma_delimited_list\"}, \"NtpPool\": {\"default\": [], \"description\": \"NTP pool list.  Defaults to [], so only NtpServer is used by default.\", \"type\": \"comma_delimited_list\"}, \"ChronyGlobalServerOptions\": {\"default\": \"\", \"description\": \"Default server options for the configured NTP servers in chrony.conf. If this is specified, NtpIburstEnable, MaxPoll, and MinPoll are ignored.\", \"type\": \"string\"}, \"ChronyGlobalPoolOptions\": {\"default\": \"\", \"description\": \"Default pool options for the configured NTP pools in chrony.conf. If this is specified, NtpIburstEnable, MaxPoll, and MinPoll are ignored.\", \"type\": \"string\"}, \"NtpIburstEnable\": {\"default\": true, \"description\": \"Specifies whether to enable the iburst option for every NTP peer. If iburst is enabled, when the ntp server is unreachable ntp will send a burst of eight packages instead of one. This is designed to speed up the initial syncrhonization.\", \"type\": \"boolean\"}, \"MaxPoll\": {\"description\": \"Specify maximum poll interval of upstream servers for NTP messages, in seconds to the power of two. The maximum poll interval defaults to 10 (1,024 s). Allowed values are 4 to 17.\", \"type\": \"number\", \"default\": 10, \"constraints\": [{\"range\": {\"min\": 4, \"max\": 17}}]}, \"MinPoll\": {\"description\": \"Specify minimum poll interval of upstream servers for NTP messages, in seconds to the power of two. The minimum poll interval defaults to 6 (64 s). Allowed values are 4 to 17.\", \"type\": \"number\", \"default\": 6, \"constraints\": [{\"range\": {\"min\": 4, \"max\": 17}}]}, \"EnablePackageInstall\": {\"default\": true, \"description\": \"Set to true to enable package installation at deploy time\", \"type\": \"boolean\"}, \"ChronyAclRules\": {\"default\": [\"deny all\"], \"description\": \"Access Control List of NTP clients.  By default no clients are permitted.\", \"type\": \"comma_delimited_list\"}}, \"conditions\": {\"chrony_global_server_settings_is_empty\": {\"equals\": [{\"get_param\": \"ChronyGlobalServerOptions\"}, \"\"]}, \"chrony_global_pool_settings_is_empty\": {\"equals\": [{\"get_param\": \"ChronyGlobalPoolOptions\"}, \"\"]}, \"ntp_iburst\": {\"equals\": [{\"get_param\": \"NtpIburstEnable\"}, true]}}, \"outputs\": {\"role_data\": {\"description\": \"Role chrony using composable timesync services.\", \"value\": {\"service_name\": \"chrony\", \"firewall_rules\": {\"105 ntp\": {\"dport\": 123, \"proto\": \"udp\"}}, \"host_prep_tasks\": [{\"name\": \"Check for NTP service\", \"shell\": \"systemctl is-active ntpd.service || systemctl is-enabled ntpd.service\", \"failed_when\": false, \"become\": true, \"register\": \"ntp_service_check\"}, {\"name\": \"Disable NTP before configuring Chrony\", \"service\": {\"name\": \"ntpd\", \"state\": \"stopped\", \"enabled\": false}, \"when\": [\"ntp_service_check.rc is defined\", \"ntp_service_check.rc == 0\"]}, {\"name\": \"Install, Configure and Run Chrony\", \"include_role\": {\"name\": \"chrony\"}}, {\"name\": \"Force NTP sync\", \"command\": \"chronyc makestep\"}, {\"name\": \"Ensure system is NTP time synced\", \"command\": \"chronyc waitsync 30\"}], \"ansible_group_vars\": {\"chrony_role_action\": \"all\", \"chrony_ntp_servers\": {\"get_param\": \"NtpServer\"}, \"chrony_ntp_pools\": {\"get_param\": \"NtpPool\"}, \"chrony_global_server_settings\": {\"if\": [\"chrony_global_server_settings_is_empty\", {\"str_replace\": {\"template\": \"IBURST minpoll MINPOLL maxpoll MAXPOLL\", \"params\": {\"IBURST\": {\"if\": [\"ntp_iburst\", \"iburst\", \"\"]}, \"MINPOLL\": {\"get_param\": \"MinPoll\"}, \"MAXPOLL\": {\"get_param\": \"MaxPoll\"}}}}, {\"get_param\": \"ChronyGlobalServerOptions\"}]}, \"chrony_global_pool_settings\": {\"if\": [\"chrony_global_pool_settings_is_empty\", {\"str_replace\": {\"template\": \"IBURST minpoll MINPOLL maxpoll MAXPOLL\", \"params\": {\"IBURST\": {\"if\": [\"ntp_iburst\", \"iburst\", \"\"]}, \"MINPOLL\": {\"get_param\": \"MinPoll\"}, \"MAXPOLL\": {\"get_param\": \"MaxPoll\"}}}}, {\"get_param\": \"ChronyGlobalPoolOptions\"}]}, \"chrony_manage_package\": {\"get_param\": \"EnablePackageInstall\"}, \"chrony_acl_rules\": {\"get_param\": \"ChronyAclRules\"}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(261,'2026-06-10 07:47:50',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (262,'2026-06-10 07:47:52',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Configure tuned\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"TunedCustomProfile\": {\"default\": \"\", \"description\": \"The definition of a new tuned profile in INI format which will be named after the TunedProfileName and applied to the host. E.g. if TunedProfileName is \'my_profile\', it creates the file \'/etc/tuned/my_profile/tuned.conf\' on host whose content is the value of TunedCustomProfile, e.g. \\\"[main]\\\\n include=throughput-performance\\\\n[sysctl]\\\\nvm.dirty_ratio=10\\\"\", \"type\": \"string\", \"tags\": [\"role_specific\"]}, \"TunedProfileName\": {\"default\": \"throughput-performance\", \"description\": \"Tuned Profile to apply to the host\", \"type\": \"string\", \"tags\": [\"role_specific\"]}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"tuned_profile\": \"TunedProfileName\", \"tuned_custom_profile\": \"TunedCustomProfile\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"TunedProfileName\": {\"get_param\": \"TunedProfileName\"}, \"TunedCustomProfile\": {\"get_param\": \"TunedCustomProfile\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for tuned\", \"value\": {\"service_name\": \"tuned\", \"host_prep_tasks\": [{\"include_role\": {\"name\": \"tuned\"}}], \"ansible_group_vars\": {\"tuned_profile\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"tuned_profile\"]}, \"tuned_custom_profile\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"tuned_custom_profile\"]}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(263,'2026-06-10 07:47:53',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Redis services\\n\", \"parameters\": {\"ContainerRedisImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\"}, \"ContainerRedisConfigImage\": {\"description\": \"The container image to use for the redis config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\"}, \"ClusterCommonTag\": {\"default\": false, \"description\": \"When set to false, a pacemaker service is configured to use a floating tag for its container image name, e.g. \'REGISTRY/NAMESPACE/IMAGENAME:pcmklatest\'. When set to true, the service uses a floating prefix as well, e.g. \'cluster.common.tag/IMAGENAME:pcmklatest\'.\", \"type\": \"boolean\"}, \"ClusterFullTag\": {\"default\": true, \"description\": \"When set to true, the pacemaker service uses a fully constant tag for its container image name, e.g. \'cluster.common.tag/SERVICENAME:pcmklatest\'.\", \"type\": \"boolean\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ConfigDebug\": {\"default\": false, \"description\": \"Whether to run config management (e.g. Puppet) in debug mode.\", \"type\": \"boolean\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"RedisIPv6\": {\"default\": false, \"description\": \"Enable IPv6 in Redis\", \"type\": \"boolean\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}, \"DeployIdentifier\": {\"default\": 1781077560, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"The following parameters are deprecated and will be removed. They should not\\nbe relied on for new deployments. If you have concerns regarding deprecated\\nparameters, please contact the TripleO development team on IRC or the\\nOpenStack mailing list.\\n\", \"parameters\": [\"RedisIPv6\"]}], \"conditions\": {\"is_ipv6\": {\"equals\": [{\"get_param\": [\"ServiceData\", \"net_ip_version_map\", {\"get_param\": [\"ServiceNetMap\", \"RedisNetwork\"]}]}, 6]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml\"}, \"RedisBase\": {\"type\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-container-puppet.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerRedisImage\": \"ContainerRedisImage\", \"ContainerRedisConfigImage\": \"ContainerRedisConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerRedisImage\": {\"get_param\": \"ContainerRedisImage\"}, \"ContainerRedisConfigImage\": {\"get_param\": \"ContainerRedisConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Redis API role.\", \"value\": {\"service_name\": \"redis\", \"firewall_rules\": {\"108 redis-bundle\": {\"dport\": [3124, 6379, 26379]}}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"RedisBase\", \"role_data\", \"config_settings\"]}, {\"redis::service_manage\": false, \"redis::notify_service\": false, \"redis::managed_by_cluster_manager\": true, \"tripleo::profile::pacemaker::database::redis_bundle::redis_docker_image\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/redis:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerRedisImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerRedisImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"tripleo::profile::pacemaker::database::redis_bundle::control_port\": 3124, \"tripleo::profile::pacemaker::database::redis_bundle::container_backend\": {\"get_param\": \"ContainerCli\"}, \"tripleo::profile::pacemaker::database::redis_bundle::force_ocf\": true, \"tripleo::stunnel::manage_service\": false, \"tripleo::stunnel::foreground\": \"yes\", \"tripleo::profile::pacemaker::database::redis_bundle::tls_proxy_bind_ip\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"RedisNetwork\"]}}}}, \"tripleo::profile::pacemaker::database::redis_bundle::tls_proxy_fqdn\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"RedisNetwork\"]}}}}, \"tripleo::profile::pacemaker::database::redis_bundle::tls_proxy_port\": 6379, \"tripleo::profile::pacemaker::database::redis::tls_proxy_bind_ip\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"RedisNetwork\"]}}}}, \"tripleo::profile::pacemaker::database::redis::tls_proxy_fqdn\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"RedisNetwork\"]}}}}, \"tripleo::profile::pacemaker::database::redis::tls_proxy_port\": 6379}, {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"redis::extra_config_file\": \"/etc/redis-tls.conf\", \"tripleo::profile::pacemaker::database::redis_bundle::extra_config_file\": \"/etc/redis-tls.conf\", \"tripleo::profile::pacemaker::database::redis_bundle::tls_tunnel_base_port\": 6660, \"tripleo::profile::pacemaker::database::redis_bundle::tls_tunnel_local_name\": {\"if\": [\"is_ipv6\", \"::1\", \"127.0.0.1\"]}}]}]}, \"service_config_settings\": {\"get_attr\": [\"RedisBase\", \"role_data\", \"service_config_settings\"]}, \"puppet_config\": {\"config_volume\": \"redis\", \"puppet_tags\": \"exec\", \"step_config\": \"Exec <| title == \'systemd-reload-redis\' |> { unless => \'true\' }\\ninclude tripleo::profile::pacemaker::database::redis_bundle\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerRedisConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/redis.json\": {\"command\": \"/usr/sbin/pacemaker_remoted\", \"config_files\": [{\"dest\": \"/etc/libqb/force-filesystem-sockets\", \"source\": \"/dev/null\", \"owner\": \"root\", \"perm\": \"0644\"}, {\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true, \"optional\": true}], \"permissions\": [{\"path\": \"/run/redis\", \"owner\": \"redis:redis\", \"recurse\": true}, {\"path\": \"/var/lib/redis\", \"owner\": \"redis:redis\", \"recurse\": true}, {\"path\": \"/var/log/redis\", \"owner\": \"redis:redis\", \"recurse\": true}]}, \"/var/lib/kolla/config_files/redis_tls_proxy.json\": {\"command\": {\"str_replace\": {\"template\": \"bash -c $* -- eval /wait-port-and-run.sh $(hiera fqdn_$NETWORK) 6379 stunnel /etc/stunnel/stunnel.conf\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"RedisNetwork\"]}}}}, \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"optional\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/etc/pki/tls/certs/redis.crt\", \"owner\": \"root:root\", \"perm\": \"0600\", \"optional\": true}, {\"path\": \"/etc/pki/tls/private/redis.key\", \"owner\": \"root:root\", \"perm\": \"0600\", \"optional\": true}]}}, \"container_config_scripts\": {\"get_attr\": [\"ContainersCommon\", \"container_config_scripts\"]}, \"docker_config\": {\"step_1\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"redis_tls_proxy\": {\"start_order\": 0, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerRedisImage\"]}, \"net\": \"host\", \"user\": \"root\", \"restart\": \"always\", \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/redis_tls_proxy.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/redis:/var/lib/kolla/config_files/src:ro\", \"/etc/pki/tls/certs/redis.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/redis.crt:ro\", \"/etc/pki/tls/private/redis.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/redis.key:ro\", \"/var/lib/container-config-scripts/wait-port-and-run.sh:/wait-port-and-run.sh:ro\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}]}}, \"metadata_settings\": {\"get_attr\": [\"RedisBase\", \"role_data\", \"metadata_settings\"]}, \"external_deploy_tasks\": {\"get_attr\": [\"RedisBase\", \"role_data\", \"external_deploy_tasks\"]}, \"host_prep_tasks\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/lib/redis\", \"setype\": \"container_file_t\"}, {\"path\": \"/var/log/containers/redis\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/run/redis\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure /run/redis is present upon reboot\", \"copy\": {\"dest\": \"/etc/tmpfiles.d/run-redis.conf\", \"content\": \"d /run/redis 0755 root root - -\\n\"}}], \"deploy_steps_tasks\": {\"list_concat\": [{\"get_attr\": [\"RedisBase\", \"role_data\", \"deploy_steps_tasks\"]}, [{\"name\": \"Redis tag container image for pacemaker\", \"when\": \"step|int == 1\", \"import_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerRedisImage\"]}, \"container_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/redis:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerRedisImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerRedisImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}}}, {\"name\": \"Redis HA Wrappers Step\", \"when\": \"step|int == 2\", \"block\": [{\"name\": \"Redis puppet bundle\", \"import_role\": {\"name\": \"tripleo_ha_wrapper\"}, \"vars\": {\"tripleo_ha_wrapper_service_name\": \"redis\", \"tripleo_ha_wrapper_resource_name\": \"redis\", \"tripleo_ha_wrapper_bundle_name\": \"redis-bundle\", \"tripleo_ha_wrapper_resource_state\": \"Slave Master\", \"tripleo_ha_wrapper_puppet_config_volume\": \"redis\", \"tripleo_ha_wrapper_puppet_execute\": \"include ::tripleo::profile::base::pacemaker; include ::tripleo::profile::pacemaker::database::redis_bundle\", \"tripleo_ha_wrapper_puppet_tags\": \"pacemaker::resource::bundle,pacemaker::property,pacemaker::resource::ocf,pacemaker::constraint::order,pacemaker::constraint::colocation\", \"tripleo_ha_wrapper_puppet_debug\": {\"get_param\": \"ConfigDebug\"}, \"tripleo_ha_wrapper_config_suffix\": \".previous_run\"}}]}]]}, \"external_update_tasks\": {\"list_concat\": [{\"get_attr\": [\"RedisBase\", \"role_data\", \"external_update_tasks\"]}, [{\"when\": \"step|int == 1\", \"tags\": \"ha_image_update\", \"block\": [{\"block\": [{\"name\": \"Get redis image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_redis_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'redis-bundle\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container redis image\", \"set_fact\": {\"redis_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerRedisImage\"]}, \"redis_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/redis:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerRedisImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerRedisImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"pcmk_redis_image\": \"{{xmllint_pcmk_redis_image.stdout}}\"}}], \"delegate_to\": \"{{ (groups[\\\"redis\\\"] | difference(groups[\\\"excluded_overcloud\\\"]))[0] }}\"}, {\"name\": \"redis temporary pacemaker container tag in case of image switch\", \"become\": true, \"import_role\": {\"name\": \"tripleo_ha_image_update\"}, \"vars\": {\"tripleo_ha_image_update_node_names\": \"{{ groups[\\\"redis\\\"] | difference(groups[\\\"excluded_overcloud\\\"]) }}\", \"tripleo_ha_image_update_bundle\": \"redis-bundle\", \"tripleo_ha_image_update_new_image\": \"{{redis_image_latest}}\", \"tripleo_ha_image_update_old_image\": \"{{pcmk_redis_image}}\"}, \"when\": [\"(pcmk_redis_image != \\\"\\\")\", \"(pcmk_redis_image != redis_image_latest)\"]}]}]]}, \"update_tasks\": [{\"block\": [{\"name\": \"Get redis image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_redis_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'redis-bundle\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container redis image\", \"set_fact\": {\"redis_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerRedisImage\"]}, \"redis_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/redis:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerRedisImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerRedisImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"pcmk_redis_image\": \"{{xmllint_pcmk_redis_image.stdout}}\"}}], \"when\": \"(step|int == 0 or step|int == 2)\"}, {\"name\": \"Check for update of redis container image name\", \"when\": \"step|int == 0\", \"assert\": {\"that\": \"pcmk_redis_image == redis_image_latest\", \"fail_msg\": \"redis image change detected, run overcloud external-update --tags ha_image_update first\"}}, {\"name\": \"redis_pacemaker_puppet_tmpfile_cleanup\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"Clean old tmpfile configuration\", \"file\": {\"path\": \"/etc/tmpfiles.d/var-run-redis.conf\", \"state\": \"absent\"}}]}, {\"name\": \"Tear-down non-HA redis container\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"Remove non-HA redis container\", \"include_role\": {\"name\": \"tripleo_container_rm\"}, \"vars\": {\"tripleo_container_cli\": \"{{ container_cli }}\", \"tripleo_containers_to_rm\": [\"redis\"]}}]}, {\"name\": \"Redis fetch and retag container image for pacemaker\", \"when\": \"step|int == 2\", \"block\": [{\"name\": \"Retag pcmklatest to latest redis image\", \"include_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{redis_image}}\", \"container_image_latest\": \"{{redis_image_latest}}\"}}]}], \"post_update_tasks\": [{\"name\": \"Redis bundle post update\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"Redis puppet bundle\", \"import_role\": {\"name\": \"tripleo_ha_wrapper\"}, \"vars\": {\"tripleo_ha_wrapper_service_name\": \"redis\", \"tripleo_ha_wrapper_resource_name\": \"redis\", \"tripleo_ha_wrapper_bundle_name\": \"redis-bundle\", \"tripleo_ha_wrapper_resource_state\": \"Slave Master\", \"tripleo_ha_wrapper_puppet_config_volume\": \"redis\", \"tripleo_ha_wrapper_puppet_execute\": \"include ::tripleo::profile::base::pacemaker; include ::tripleo::profile::pacemaker::database::redis_bundle\", \"tripleo_ha_wrapper_puppet_tags\": \"pacemaker::resource::bundle,pacemaker::property,pacemaker::resource::ocf,pacemaker::constraint::order,pacemaker::constraint::colocation\", \"tripleo_ha_wrapper_puppet_debug\": {\"get_param\": \"ConfigDebug\"}, \"tripleo_ha_wrapper_config_suffix\": \".previous_run\"}}], \"vars\": {\"tripleo_ha_wrapper_minor_update\": true}}], \"upgrade_tasks\": [{\"name\": \"redis_pacemaker_puppet_tmpfile_cleanup\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"Clean old tmpfile configuration\", \"file\": {\"path\": \"/etc/tmpfiles.d/var-run-redis.conf\", \"state\": \"absent\"}}]}, {\"name\": \"Tear-down non-HA redis container\", \"when\": [\"step|int == 0\"], \"block\": [{\"name\": \"Remove non-HA redis container\", \"include_role\": {\"name\": \"tripleo_container_rm\"}, \"vars\": {\"tripleo_container_cli\": \"{{ container_cli }}\", \"tripleo_containers_to_rm\": [\"redis\"]}}]}, {\"name\": \"Prepare switch of redis image name\", \"when\": [\"step|int == 0\"], \"block\": [{\"name\": \"Get redis image id currently used by pacemaker\", \"shell\": \"pcs resource config redis-bundle | grep -Eo \'image=[^ ]+\' | awk -F= \'{print $2;}\'\", \"register\": \"redis_image_current_res\", \"failed_when\": false}, {\"name\": \"Image facts for redis\", \"set_fact\": {\"redis_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/redis:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerRedisImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerRedisImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"redis_image_current\": \"{{redis_image_current_res.stdout}}\"}}, {\"name\": \"Temporarily tag the current redis image id with the upgraded image name\", \"import_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{redis_image_current}}\", \"container_image_latest\": \"{{redis_image_latest}}\", \"pull_image\": false}, \"when\": [\"redis_image_current != \'\'\", \"redis_image_current != redis_image_latest\"]}, {\"name\": \"Create redis retag statefile\", \"file\": {\"path\": \"/var/lib/tripleo/redis_needs_retag\", \"state\": \"touch\"}, \"when\": [\"redis_image_current != \'\'\", \"redis_image_current != redis_image_latest\"]}]}, {\"name\": \"Update redis-bundle pcs resource bundle for new container image\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"Set upgrade redis facts\", \"set_fact\": {\"is_redis_bootstrap_node\": \"{{redis_short_bootstrap_node_name|lower == ansible_facts[\'hostname\']|lower}}\"}}, {\"name\": \"Check for redis retag statefile\", \"stat\": {\"path\": \"/var/lib/tripleo/redis_needs_retag\"}, \"register\": \"redis_retag_state_file\"}]}, {\"name\": \"Update redis-bundle pcs resource bundle for new container image\", \"when\": [\"step|int == 1\", \"is_redis_bootstrap_node|bool\", \"redis_retag_state_file.stat.exists|bool\"], \"block\": [{\"name\": \"Disable the redis cluster resource before container upgrade\", \"pacemaker_resource\": {\"resource\": \"redis-bundle\", \"state\": \"disable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}, {\"name\": \"Move redis logging to /var/log/containers\", \"block\": [{\"name\": \"Check redis logging configuration in pacemaker\", \"command\": \"cibadmin --query --xpath \\\"//storage-mapping[@id=\'redis-log\' and @source-dir=\'/var/log/containers/redis\']\\\"\", \"failed_when\": false, \"register\": \"redis_logs_moved\"}, {\"name\": \"Change redis logging configuration in pacemaker\", \"when\": \"redis_logs_moved.rc == 6\", \"block\": [{\"name\": \"Remove old bind mount for logging in the redis bundle\", \"command\": \"pcs resource bundle update redis-bundle storage-map remove redis-log\"}, {\"name\": \"Add a bind mount for logging in the redis bundle\", \"command\": \"pcs resource bundle update redis-bundle storage-map add id=redis-log source-dir=/var/log/containers/redis target-dir=/var/log/redis options=rw\"}]}]}, {\"name\": \"Update the redis bundle to use the new container image name\", \"command\": \"pcs resource bundle update redis-bundle container image={{redis_image_latest}}\"}, {\"name\": \"Enable the redis cluster resource\", \"pacemaker_resource\": {\"resource\": \"redis-bundle\", \"state\": \"enable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}]}, {\"name\": \"Check for redis retag statefile\", \"when\": [\"step|int == 3\"], \"stat\": {\"path\": \"/var/lib/tripleo/redis_needs_retag\"}, \"register\": \"redis_retag_state_file\"}, {\"name\": \"Retag redis-bundle container image\", \"when\": [\"step|int == 3\", \"redis_retag_state_file.stat.exists|bool\"], \"block\": [{\"name\": \"Disable the redis cluster resource before container upgrade\", \"pacemaker_resource\": {\"resource\": \"redis-bundle\", \"state\": \"disable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}, {\"name\": \"Retag the pacemaker image if containerized\", \"block\": [{\"block\": [{\"name\": \"Get redis image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_redis_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'redis-bundle\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container redis image\", \"set_fact\": {\"redis_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerRedisImage\"]}, \"redis_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/redis:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerRedisImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerRedisImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"pcmk_redis_image\": \"{{xmllint_pcmk_redis_image.stdout}}\"}}]}, {\"block\": [{\"name\": \"Retag pcmklatest to latest redis image\", \"include_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{redis_image}}\", \"container_image_latest\": \"{{redis_image_latest}}\"}}]}]}, {\"name\": \"Enable the redis-bundle cluster resource\", \"pacemaker_resource\": {\"resource\": \"redis-bundle\", \"state\": \"enable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}, {\"name\": \"Remove redis retag statefile\", \"file\": {\"path\": \"/var/lib/tripleo/redis_needs_retag\", \"state\": \"absent\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(264,'2026-06-10 07:47:53',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(265,'2026-06-10 07:47:54',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Redis services\\n\", \"parameters\": {\"ContainerRedisImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\"}, \"ContainerRedisConfigImage\": {\"description\": \"The container image to use for the redis config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"RedisCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}}, \"conditions\": {\"key_size_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"RedisCertificateKeySize\"}, \"\"]}}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml\"}, \"RedisBase\": {\"type\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-base-puppet.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerRedisImage\": \"ContainerRedisImage\", \"ContainerRedisConfigImage\": \"ContainerRedisConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerRedisImage\": {\"get_param\": \"ContainerRedisImage\"}, \"ContainerRedisConfigImage\": {\"get_param\": \"ContainerRedisConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Redis API role.\", \"value\": {\"service_name\": \"redis\", \"firewall_rules\": {\"108 redis\": {\"dport\": [6379, 26379]}}, \"firewall_frontend_rules\": {\"100 redis_haproxy_frontend\": {\"dport\": [6379, 26379]}}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"RedisBase\", \"role_data\", \"config_settings\"]}, {\"redis::daemonize\": false, \"tripleo::stunnel::manage_service\": false, \"tripleo::stunnel::foreground\": \"yes\"}, {\"tripleo::profile::base::database::redis::tls_proxy_bind_ip\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"RedisNetwork\"]}}}}, \"tripleo::profile::base::database::redis::tls_proxy_fqdn\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"RedisNetwork\"]}}}}, \"tripleo::profile::base::database::redis::tls_proxy_port\": 6379}, {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"tripleo::redis::service_certificate\": \"/etc/pki/tls/certs/redis.crt\", \"redis_certificate_specs\": {\"service_certificate\": \"/etc/pki/tls/certs/redis.crt\", \"service_key\": \"/etc/pki/tls/private/redis.key\"}}]}]}, \"service_config_settings\": {\"get_attr\": [\"RedisBase\", \"role_data\", \"service_config_settings\"]}, \"puppet_config\": {\"config_volume\": \"redis\", \"puppet_tags\": \"exec\", \"step_config\": {\"list_join\": [\"\\n\", [\"Exec <| title == \'systemd-reload-redis\' |> { unless => \'true\' }\", \"include tripleo::profile::base::database::redis\", {\"get_attr\": [\"RedisBase\", \"role_data\", \"step_config\"]}]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerRedisConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/redis.json\": {\"command\": \"/usr/bin/redis-server /etc/redis.conf\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/run/redis\", \"owner\": \"redis:redis\", \"recurse\": true}]}, \"/var/lib/kolla/config_files/redis_tls_proxy.json\": {\"command\": \"stunnel /etc/stunnel/stunnel.conf\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]}}, \"docker_config\": {\"step_1\": {\"map_merge\": [{\"redis_init_logs\": {\"start_order\": 0, \"detach\": false, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerRedisImage\"]}, \"net\": \"none\", \"privileged\": false, \"user\": \"root\", \"volumes\": [\"/var/log/containers/redis:/var/log/redis:z\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R redis:redis /var/log/redis\"]}}, {\"redis\": {\"start_order\": 1, \"stop_grace_period\": 60, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerRedisImage\"]}, \"net\": \"host\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": [\"/var/lib/kolla/config_files/redis.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/redis:/var/lib/kolla/config_files/src:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/var/log/containers/redis:/var/log/redis:z\", \"/run/redis:/run/redis:z\"], \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}, {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"redis_tls_proxy\": {\"start_order\": 2, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerRedisImage\"]}, \"net\": \"host\", \"user\": \"root\", \"restart\": \"always\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/redis_tls_proxy.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/redis:/var/lib/kolla/config_files/src:ro\", \"/etc/pki/tls/certs/redis.crt:/etc/pki/tls/certs/redis.crt:ro\", \"/etc/pki/tls/private/redis.key:/etc/pki/tls/private/redis.key:ro\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}]}]}}, \"metadata_settings\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [{\"service\": \"redis\", \"network\": {\"get_param\": [\"ServiceNetMap\", \"RedisNetwork\"]}, \"type\": \"vip\"}, {\"service\": \"redis\", \"network\": {\"get_param\": [\"ServiceNetMap\", \"RedisNetwork\"]}, \"type\": \"node\"}]]}, \"deploy_steps_tasks\": [{\"name\": \"Certificate generation\", \"when\": [\"step|int == 1\", \"enable_internal_tls\"], \"block\": [{\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": [{\"name\": \"redis\", \"dns\": [{\"str_replace\": {\"template\": \"{{fqdn_$NETWORK}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"RedisNetwork\"]}}}}, {\"str_replace\": {\"template\": \"{{cloud_names.cloud_name_NETWORK}}\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"RedisNetwork\"]}}}}], \"principal\": {\"str_replace\": {\"template\": \"redis/{{fqdn_$NETWORK}}@{{idm_realm}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"RedisNetwork\"]}}}}, \"run_after\": \"container_name=$({{container_cli}} ps --format=\\\\{\\\\{.Names\\\\}\\\\} | grep redis_tls_proxy)\\nservice_crt=\\\"/etc/pki/tls/certs/redis.crt\\\"\\nservice_key=\\\"/etc/pki/tls/private/redis.key\\\"\\n# Copy the new cert from the mount-point to the real path\\n{{container_cli}} exec \\\"$container_name\\\" cp \\\"/var/lib/kolla/config_files/src-tls$service_crt\\\" \\\"$service_crt\\\"\\n# Copy the new cert from the mount-point to the real path\\n{{container_cli}} exec \\\"$container_name\\\" cp \\\"/var/lib/kolla/config_files/src-tls$service_key\\\" \\\"$service_key\\\"\\n# Set appropriate permissions\\n{{container_cli}} exec \\\"$container_name\\\" chown memcached:memcached \\\"$service_crt\\\"\\n{{container_cli}} exec \\\"$container_name\\\" chown memcached:memcached \\\"$service_key\\\"\\n# Trigger a reload for stunnel to read the new certificate\\n{{container_cli}} exec pkill -o -HUP stunnel\\n\", \"key_size\": {\"if\": [\"key_size_override_set\", {\"get_param\": \"RedisCertificateKeySize\"}, {\"get_param\": \"CertificateKeySize\"}]}, \"ca\": \"ipa\"}]}}]}], \"external_deploy_tasks\": {\"get_attr\": [\"RedisBase\", \"role_data\", \"external_deploy_tasks\"]}, \"host_prep_tasks\": [{\"name\": \"create fcontext entry for redis data\", \"community.general.sefcontext\": {\"target\": \"/var/run/redis(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/redis\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/run/redis\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure /run/redis is present upon reboot\", \"copy\": {\"dest\": \"/etc/tmpfiles.d/run-redis.conf\", \"content\": \"d /run/redis 0755 root root - -\\n\"}}], \"update_tasks\": [{\"name\": \"redis_container_puppet_redis_pkg_clean\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"Ensure redis is uninstalled on container host\", \"package\": {\"name\": \"redis\", \"state\": \"absent\"}}]}, {\"name\": \"redis_container_puppet_tmpfile_cleanup\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"remove old tmpfiles.d config\", \"file\": {\"path\": \"/etc/tmpfiles.d/var-run-redis.conf\", \"state\": \"absent\"}}]}], \"external_update_tasks\": {\"get_attr\": [\"RedisBase\", \"role_data\", \"external_update_tasks\"]}, \"upgrade_tasks\": [{\"name\": \"redis_container_puppet_redis_pkg_clean\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"Ensure redis is uninstalled on container host\", \"package\": {\"name\": \"redis\", \"state\": \"absent\"}}]}, {\"name\": \"redis_container_puppet_tmpfile_cleanup\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"remove old tmpfiles.d config\", \"file\": {\"path\": \"/etc/tmpfiles.d/var-run-redis.conf\", \"state\": \"absent\"}}]}], \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop redis container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": {\"with_items\": {\"list_concat\": [[\"redis\"], [{\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [\"redis_tls_proxy\"]]}]]}}, \"tripleo_delegate_to\": \"{{ groups[\'redis\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(266,'2026-06-10 07:47:54',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(267,'2026-06-10 07:47:55',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Redis service configured with Puppet\\n\", \"parameters\": {\"RootStackName\": {\"description\": \"The name of the stack/plan.\", \"type\": \"string\", \"default\": \"overcloud\"}, \"RedisPassword\": {\"description\": \"The password for the redis service account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"PeixZYMWlure0PQXGfRipmgn4\"}, \"RedisFDLimit\": {\"description\": \"Configure Redis FD limit\", \"type\": \"number\", \"default\": 10240}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"RedisIPv6\": {\"default\": false, \"description\": \"Enable IPv6 in Redis\", \"type\": \"boolean\"}, \"RedisVirtualFixedIPs\": {\"default\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"description\": \"Control the IP allocation for the virtual IP used by Redis. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"type\": \"json\"}, \"ServiceVips\": {\"default\": {}, \"type\": \"json\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"The following parameters are deprecated and will be removed. They should not\\nbe relied on for new deployments. If you have concerns regarding deprecated\\nparameters, please contact the TripleO development team on IRC or the\\nOpenStack mailing list.\\n\", \"parameters\": [\"RedisIPv6\"]}], \"conditions\": {\"is_ipv6\": {\"equals\": [{\"get_param\": [\"ServiceData\", \"net_ip_version_map\", {\"get_param\": [\"ServiceNetMap\", \"RedisNetwork\"]}]}, 6]}, \"redis_virtual_fixed_ip_set\": {\"not\": {\"equals\": [{\"get_param\": \"RedisVirtualFixedIPs\"}, []]}}, \"redis_service_vip_set\": {\"not\": {\"equals\": [{\"get_param\": [\"ServiceVips\", \"redis\"]}, \"\"]}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the redis role.\", \"value\": {\"service_name\": \"redis_base\", \"config_settings\": {\"redis::requirepass\": {\"get_param\": \"RedisPassword\"}, \"redis::masterauth\": {\"get_param\": \"RedisPassword\"}, \"redis::sentinel_auth_pass\": {\"get_param\": \"RedisPassword\"}, \"redis_ipv6\": {\"if\": [\"is_ipv6\", true, false]}, \"redis::bind\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"if\": [\"is_ipv6\", \"::1\", \"127.0.0.1\"]}, {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"RedisNetwork\"]}}}}]}, \"redis::port\": 6379, \"redis::sentinel::master_name\": \"%{hiera(\'redis_short_bootstrap_node_name\')}\", \"redis::sentinel::redis_host\": \"%{hiera(\'redis_bootstrap_node_ip\')}\", \"redis::sentinel::notification_script\": \"/usr/local/bin/redis-notifications.sh\", \"redis::sentinel::sentinel_bind\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"if\": [\"is_ipv6\", \"::1\", \"127.0.0.1\"]}, {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"RedisNetwork\"]}}}}]}, \"redis::ulimit\": {\"get_param\": \"RedisFDLimit\"}}, \"external_deploy_tasks\": [{\"when\": [\"step|int == 0\"], \"name\": \"redis_external_deploy_init\", \"block\": [{\"name\": \"create redis virtual ip\", \"tripleo_service_vip\": {\"playbook_dir\": \"{{ playbook_dir }}\", \"stack_name\": {\"get_param\": \"RootStackName\"}, \"service_name\": \"redis\", \"network\": {\"get_param\": [\"ServiceNetMap\", \"RedisNetwork\"]}, \"fixed_ips\": {\"if\": [\"redis_virtual_fixed_ip_set\", {\"get_param\": \"RedisVirtualFixedIPs\"}, {\"if\": [\"redis_service_vip_set\", [{\"ip_address\": {\"get_param\": [\"ServiceVips\", \"redis\"]}}], [{\"subnet\": {\"get_param\": [\"ServiceData\", \"vip_subnet_map\", \"redis\"]}}]]}]}}}]}], \"external_update_tasks\": [{\"when\": [\"step|int == 0\"], \"name\": \"redis_external_update_init\", \"block\": [{\"name\": \"create redis virtual ip\", \"tripleo_service_vip\": {\"playbook_dir\": \"{{ playbook_dir }}\", \"stack_name\": {\"get_param\": \"RootStackName\"}, \"service_name\": \"redis\", \"network\": {\"get_param\": [\"ServiceNetMap\", \"RedisNetwork\"]}, \"fixed_ips\": {\"if\": [\"redis_virtual_fixed_ip_set\", {\"get_param\": \"RedisVirtualFixedIPs\"}, {\"if\": [\"redis_service_vip_set\", [{\"ip_address\": {\"get_param\": [\"ServiceVips\", \"redis\"]}}], [{\"subnet\": {\"get_param\": [\"ServiceData\", \"vip_subnet_map\", \"redis\"]}}]]}]}}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(268,'2026-06-10 07:47:58',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized swift proxy service\\n\", \"parameters\": {\"ContainerSwiftProxyImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\"}, \"ContainerSwiftConfigImage\": {\"description\": \"The container image to use for the swift config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"SwiftEncryptionEnabled\": {\"description\": \"Set to True to enable data-at-rest encryption in Swift\", \"default\": false, \"type\": \"boolean\"}, \"DeployIdentifier\": {\"default\": 1781077560, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}, \"SwiftPassword\": {\"description\": \"The password for the swift service account\", \"type\": \"string\", \"hidden\": true, \"default\": \"NvUMzL93JbdNrISGkFwzL6Qcw\"}, \"SwiftProxyNodeTimeout\": {\"default\": 60, \"description\": \"Timeout for requests going from swift-proxy to swift a/c/o services.\", \"type\": \"number\"}, \"SwiftProxyRecoverableNodeTimeout\": {\"default\": 30, \"description\": \"Timeout for GET/HEAD requests going from swift-proxy to swift a/c/o services.\", \"type\": \"number\"}, \"SwiftWorkers\": {\"default\": 1, \"description\": \"Number of workers for Swift service.\", \"type\": \"string\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"MonitoringSubscriptionSwiftProxy\": {\"default\": \"overcloud-swift-proxy\", \"type\": \"string\"}, \"SwiftCeilometerPipelineEnabled\": {\"description\": \"Set to False to disable the swift proxy ceilometer pipeline.\", \"default\": false, \"type\": \"boolean\"}, \"SwiftCeilometerIgnoreProjects\": {\"default\": [\"service\"], \"description\": \"Comma-seperated list of project names to ignore.\", \"type\": \"comma_delimited_list\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"MemcachedTLS\": {\"default\": false, \"description\": \"Set to True to enable TLS on Memcached service. Because not all services support Memcached TLS, during the migration period, Memcached will listen on 2 ports - on the port set with MemcachedPort parameter (above) and on 11211, without TLS.\", \"type\": \"boolean\"}, \"SwiftCorsAllowedOrigin\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Indicate whether this resource may be shared with the domain received in the request \\\"origin\\\" header.\"}, \"EnforceSecureRbac\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Setting this option to True will configure each OpenStack service to enforce Secure RBAC by setting `[oslo_policy] enforce_new_defaults` and `[oslo_policy] enforce_scope` to True. This introduces a consistent set of RBAC personas across OpenStack services that include support for system and project scope, as well as keystone\'s default roles, admin, member, and reader. Do not enable this functionality until all services in your deployment actually support secure RBAC.\"}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"swift_encryption_enabled\": {\"equals\": [{\"get_param\": \"SwiftEncryptionEnabled\"}, true]}, \"ceilometer_pipeline_enabled\": {\"equals\": [{\"get_param\": \"SwiftCeilometerPipelineEnabled\"}, true]}, \"use_tls_proxy\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"cors_allowed_origin_unset\": {\"equals\": [{\"get_param\": \"SwiftCorsAllowedOrigin\"}, \"\"]}, \"swift_workers_zero\": {\"equals\": [{\"get_param\": \"SwiftWorkers\"}, \"0\"]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"SwiftBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-base.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"TLSProxyBase\": {\"type\": \"OS::TripleO::Services::TLSProxyBase\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}, \"EnableInternalTLS\": {\"get_param\": \"EnableInternalTLS\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerSwiftProxyImage\": \"ContainerSwiftProxyImage\", \"ContainerSwiftConfigImage\": \"ContainerSwiftConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerSwiftProxyImage\": {\"get_param\": \"ContainerSwiftProxyImage\"}, \"ContainerSwiftConfigImage\": {\"get_param\": \"ContainerSwiftConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the swift proxy.\", \"value\": {\"service_name\": \"swift_proxy\", \"firewall_rules\": {\"122 swift proxy\": {\"dport\": [8080]}}, \"firewall_frontend_rules\": {\"100 swift_proxy_server_haproxy_frontend\": {\"dport\": [8080]}}, \"firewall_ssl_frontend_rules\": {\"100 swift_proxy_server_haproxy_frontend_ssl\": {\"dport\": [13808]}}, \"keystone_resources\": {\"swift\": {\"endpoints\": {\"public\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"uri\"]}, \"internal\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"uri\"]}, \"admin\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"uri\"]}}, \"users\": {\"swift\": {\"password\": {\"get_param\": \"SwiftPassword\"}}}, \"region\": {\"get_param\": \"KeystoneRegion\"}, \"service\": \"object-store\", \"roles\": [\"swiftoperator\", \"ResellerAdmin\"]}}, \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionSwiftProxy\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"SwiftBase\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"TLSProxyBase\", \"role_data\", \"config_settings\"]}, {\"if\": [\"cors_allowed_origin_unset\", {}, {\"swift::proxy::cors_allow_origin\": {\"get_param\": \"SwiftCorsAllowedOrigin\"}}]}, {\"swift::proxy::authtoken::www_authenticate_uri\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"uri_no_suffix\"]}, \"swift::proxy::authtoken::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"swift::proxy::authtoken::password\": {\"get_param\": \"SwiftPassword\"}, \"swift::proxy::authtoken::project_name\": \"service\", \"swift::proxy::authtoken::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"swift::proxy::authtoken::interface\": \"internal\", \"swift::proxy::s3token::auth_uri\": {\"get_param\": [\"EndpointMap\", \"KeystoneV3Internal\", \"uri\"]}, \"swift::proxy::node_timeout\": {\"get_param\": \"SwiftProxyNodeTimeout\"}, \"swift::proxy::recoverable_node_timeout\": {\"get_param\": \"SwiftProxyRecoverableNodeTimeout\"}}, {\"if\": [\"swift_workers_zero\", {}, {\"swift::proxy::workers\": {\"get_param\": \"SwiftWorkers\"}}]}, {\"if\": [\"ceilometer_pipeline_enabled\", {\"swift::proxy::ceilometer::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"swift::proxy::ceilometer::password\": {\"get_param\": \"SwiftPassword\"}, \"swift::proxy::ceilometer::project_name\": \"service\", \"swift::proxy::ceilometer::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"swift::proxy::ceilometer::ignore_projects\": {\"get_param\": \"SwiftCeilometerIgnoreProjects\"}, \"swift::proxy::ceilometer::nonblocking_notify\": true, \"swift::proxy::ceilometer::rabbit_heartbeat_in_pthread\": false}, {}]}, {\"swift::proxy::staticweb::url_base\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"uri_no_suffix\"]}, \"tripleo::profile::base::swift::proxy::ceilometer_enabled\": {\"get_param\": \"SwiftCeilometerPipelineEnabled\"}, \"swift::proxy::keystone::operator_roles\": [\"admin\", \"swiftoperator\", \"ResellerAdmin\"], \"swift::proxy::versioned_writes::allow_versioned_writes\": true}, {\"if\": [{\"get_param\": \"EnforceSecureRbac\"}, {\"swift::proxy::keystone::project_reader_roles\": [\"SwiftProjectReader\"]}, {\"swift::proxy::keystone::system_reader_roles\": [\"SwiftSystemReader\"]}]}, {\"if\": [\"swift_encryption_enabled\", {\"swift::keymaster::key_id\": \"test_id\", \"swift::keymaster::username\": \"swift\", \"swift::keymaster::password\": {\"get_param\": \"SwiftPassword\"}, \"swift::keymaster::project_name\": \"service\", \"swift::keymaster::project_domain_id\": \"default\", \"swift::keymaster::user_domain_id\": \"default\", \"swift::keymaster::auth_endpoint\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri\"]}}, {}]}, {\"swift::proxy::pipeline\": {\"list_concat\": [[\"catch_errors\", \"gatekeeper\", \"healthcheck\", \"proxy-logging\", \"cache\", \"listing_formats\", \"ratelimit\", \"bulk\", \"tempurl\", \"formpost\", \"authtoken\", \"s3api\", \"s3token\", \"keystone\", \"staticweb\", \"copy\", \"container_quotas\", \"account_quotas\", \"slo\", \"dlo\", \"versioned_writes\"], {\"if\": [\"ceilometer_pipeline_enabled\", [\"ceilometer\"], []]}, {\"if\": [\"swift_encryption_enabled\", [\"kms_keymaster\", \"encryption\"], []]}, [\"proxy-logging\", \"proxy-server\"]]}, \"swift::proxy::account_autocreate\": true, \"tripleo::profile::base::swift::proxy::tls_proxy_bind_ip\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}}}}, \"tripleo::profile::base::swift::proxy::tls_proxy_fqdn\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}}}}, \"tripleo::profile::base::swift::proxy::tls_proxy_port\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"port\"]}, \"swift::proxy::port\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"port\"]}, \"swift::proxy::proxy_local_net_ip\": {\"if\": [\"use_tls_proxy\", \"%{hiera(\'localhost_address\')}\", {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}}}}]}, \"swift::proxy::cache::tls_enabled\": {\"get_param\": \"MemcachedTLS\"}}]}, \"puppet_config\": {\"config_volume\": \"swift\", \"puppet_tags\": \"swift_config,swift_proxy_config,swift_keymaster_config\", \"step_config\": \"include tripleo::profile::base::swift::proxy\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerSwiftConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/swift_proxy.json\": {\"command\": \"/usr/bin/swift-proxy-server /etc/swift/proxy-server.conf\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]}, \"/var/lib/kolla/config_files/swift_proxy_tls_proxy.json\": {\"command\": \"/usr/sbin/httpd -DFOREGROUND\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.d\", \"dest\": \"/etc/httpd/conf.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.modules.d\", \"dest\": \"/etc/httpd/conf.modules.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]}}, \"container_config_scripts\": {\"create_swift_secret.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nexport OS_PROJECT_DOMAIN_ID=$(crudini --get /etc/swift/keymaster.conf kms_keymaster project_domain_id)\\nexport OS_USER_DOMAIN_ID=$(crudini --get /etc/swift/keymaster.conf kms_keymaster user_domain_id)\\nexport OS_PROJECT_NAME=$(crudini --get /etc/swift/keymaster.conf kms_keymaster project_name)\\nexport OS_USERNAME=$(crudini --get /etc/swift/keymaster.conf kms_keymaster username)\\nexport OS_PASSWORD=$(crudini --get /etc/swift/keymaster.conf kms_keymaster password)\\nexport OS_AUTH_URL=$(crudini --get /etc/swift/keymaster.conf kms_keymaster auth_endpoint)\\nexport OS_AUTH_TYPE=password\\nexport OS_IDENTITY_API_VERSION=3\\n\\necho \\\"Check if secret already exists\\\"\\nsecret_href=$(openstack secret list --name swift_root_secret_uuid)\\nrc=$?\\nif [[ $rc != 0 ]]; then\\n  echo \\\"Failed to check secrets, check if Barbican in enabled and responding properly\\\"\\n  exit $rc;\\nfi\\nif [ -z \\\"$secret_href\\\" ]; then\\n  echo \\\"Create new secret\\\"\\n  order_href=$(openstack secret order create --name swift_root_secret_uuid --payload-content-type=\\\"application/octet-stream\\\" --algorithm aes --bit-length 256 --mode ctr key -f value -c \\\"Order href\\\")\\nfi\\n\"}, \"set_swift_keymaster_key_id.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nexport OS_PROJECT_DOMAIN_ID=$(crudini --get /etc/swift/keymaster.conf kms_keymaster project_domain_id)\\nexport OS_USER_DOMAIN_ID=$(crudini --get /etc/swift/keymaster.conf kms_keymaster user_domain_id)\\nexport OS_PROJECT_NAME=$(crudini --get /etc/swift/keymaster.conf kms_keymaster project_name)\\nexport OS_USERNAME=$(crudini --get /etc/swift/keymaster.conf kms_keymaster username)\\nexport OS_PASSWORD=$(crudini --get /etc/swift/keymaster.conf kms_keymaster password)\\nexport OS_AUTH_URL=$(crudini --get /etc/swift/keymaster.conf kms_keymaster auth_endpoint)\\nexport OS_AUTH_TYPE=password\\nexport OS_IDENTITY_API_VERSION=3\\necho \\\"retrieve key_id\\\"\\nloop_wait=2\\nfor i in {0..5}; do\\n  #TODO update uuid from mistral here too\\n  secret_href=$(openstack secret list --name swift_root_secret_uuid)\\n  if [ \\\"$secret_href\\\" ]; then\\n    echo \\\"set key_id in keymaster.conf\\\"\\n    secret_href=$(openstack secret list --name swift_root_secret_uuid -f value -c \\\"Secret href\\\")\\n    crudini --set /etc/swift/keymaster.conf kms_keymaster key_id ${secret_href##*/}\\n    exit 0\\n  else\\n    echo \\\"no key, wait for $loop_wait and check again\\\"\\n    sleep $loop_wait\\n    ((loop_wait++))\\n  fi\\ndone\\necho \\\"Failed to set secret in keymaster.conf, check if Barbican is enabled and responding properly\\\"\\nexit 1\\n\"}}, \"docker_config\": {\"step_4\": {\"map_merge\": [{\"if\": [\"swift_encryption_enabled\", {\"create_swift_secret\": {\"start_order\": 0, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerSwiftProxyImage\"]}, \"net\": \"host\", \"detach\": false, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/swift/etc/swift:/etc/swift:ro\", \"/var/lib/container-config-scripts/create_swift_secret.sh:/create_swift_secret.sh:ro\"]]}, \"user\": \"root\", \"command\": \"/usr/bin/bootstrap_host_exec swift_proxy /create_swift_secret.sh\"}}, {}]}, {\"if\": [\"swift_encryption_enabled\", {\"set_swift_secret\": {\"start_order\": 1, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerSwiftProxyImage\"]}, \"net\": \"host\", \"detach\": false, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/swift/etc/swift:/etc/swift:rw,z\", \"/var/lib/container-config-scripts/set_swift_keymaster_key_id.sh:/set_swift_keymaster_key_id.sh:ro\"]]}, \"user\": \"root\", \"command\": \"/set_swift_keymaster_key_id.sh\", \"environment\": {\"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}}}}, {}]}, {\"swift_proxy\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerSwiftProxyImage\"]}, \"start_order\": 2, \"net\": \"host\", \"user\": \"swift\", \"restart\": \"always\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/swift_proxy.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/swift:/var/lib/kolla/config_files/src:ro\", \"/srv/node:/srv/node\", \"/dev:/dev\", \"/var/log/containers/swift:/var/log/swift:z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}, {\"if\": [\"internal_tls_enabled\", {\"swift_proxy_tls_proxy\": {\"start_order\": 3, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerSwiftProxyImage\"]}, \"net\": \"host\", \"user\": \"root\", \"restart\": \"always\", \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/swift_proxy_tls_proxy.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/swift:/var/lib/kolla/config_files/src:ro\", \"/etc/pki/tls/certs/httpd:/etc/pki/tls/certs/httpd:ro\", \"/etc/pki/tls/private/httpd:/etc/pki/tls/private/httpd:ro\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}, {}]}]}}, \"host_prep_tasks\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/srv/node\", \"setype\": \"container_file_t\"}, {\"path\": \"/var/log/swift\", \"setype\": \"container_file_t\"}, {\"path\": \"/var/log/containers/swift\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}], \"deploy_steps_tasks\": [{\"name\": \"Configure rsyslog for swift\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"Check if rsyslog exists\", \"shell\": \"systemctl is-active rsyslog\", \"register\": \"swift_rsyslog_config\"}, {\"name\": \"Forward logging to swift.log file\", \"copy\": {\"content\": \"# Fix for https://bugs.launchpad.net/tripleo/+bug/1776180\\nlocal2.*                 /var/log/containers/swift/swift.log\\n&                        stop\\n\", \"dest\": \"/etc/rsyslog.d/openstack-swift.conf\"}, \"register\": \"swift_logconfig\", \"when\": [\"swift_rsyslog_config is defined\", \"swift_rsyslog_config.rc == 0\"]}, {\"name\": \"Restart rsyslogd service after logging conf change\", \"service\": {\"name\": \"rsyslog\", \"state\": \"restarted\"}, \"when\": [\"swift_logconfig is defined\", \"swift_logconfig is changed\"]}]}, {\"name\": \"Run kolla_set_configs to copy ring files\", \"when\": \"step|int == 5\", \"shell\": \"{{ container_cli }} exec -u root {{ item }} /usr/local/bin/kolla_set_configs \", \"become\": true, \"register\": \"kolla_set_configs_result\", \"failed_when\": [\"kolla_set_configs_result.rc is defined\", \"kolla_set_configs_result.rc not in [0, 125]\"], \"with_items\": [\"swift_proxy\"]}], \"update_tasks\": [{\"name\": \"Check swift containers log folder/symlink exists\", \"stat\": {\"path\": \"/var/log/containers/swift\"}, \"register\": \"swift_log_link\"}, {\"name\": \"Delete if symlink\", \"file\": {\"path\": \"/var/log/containers/swift\", \"state\": \"absent\"}, \"when\": \"swift_log_link.stat.islnk is defined and swift_log_link.stat.islnk\"}], \"metadata_settings\": {\"get_attr\": [\"TLSProxyBase\", \"role_data\", \"metadata_settings\"]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(269,'2026-06-10 07:48:00',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Swift Proxy service configured with Puppet\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"SwiftHashSuffix\": {\"description\": \"A random string to be used as a salt when hashing to determine mappings in the ring.\", \"hidden\": true, \"type\": \"string\", \"default\": \"sRK7MrWoYpaoPNYnblO2G8U5z\"}, \"SwiftHashPrefix\": {\"default\": \"\", \"description\": \"A random string to be used as an extra salt when hashing to determine mappings in the ring.\", \"hidden\": true, \"type\": \"string\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Swift common swift settings.\", \"value\": {\"service_name\": \"swift_base\", \"config_settings\": {\"swift::swift_hash_path_suffix\": {\"get_param\": \"SwiftHashSuffix\"}, \"swift::swift_hash_path_prefix\": {\"get_param\": \"SwiftHashPrefix\"}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(270,'2026-06-10 07:48:02',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (271,'2026-06-10 07:48:04',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Composable Timezone service\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"TimeZone\": {\"default\": \"UTC\", \"description\": \"The timezone to be set on the overcloud.\", \"type\": \"string\"}}, \"outputs\": {\"role_data\": {\"description\": \"Timezone role using composable services.\", \"value\": {\"service_name\": \"timezone\", \"host_prep_tasks\": [{\"name\": \"Run timezone role\", \"include_role\": {\"name\": \"tripleo_timezone\"}, \"vars\": {\"tripleo_timezone\": {\"get_param\": \"TimeZone\"}}}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.90\", \"ctlplane_subnet\": \"192.168.122.90/24\", \"ctlplane_uri\": \"192.168.122.90\", \"storage\": \"172.18.0.140\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.140\", \"storage_mgmt\": \"172.20.0.150\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.150\", \"internal_api\": \"172.17.0.130\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.130\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.80\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.80\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(273,'2026-06-10 07:48:17',NULL,'{\"heat_template_version\": \"2015-04-30\", \"resources\": {\"0\": {\"type\": \"OS::TripleO::Controller\", \"properties\": {\"CloudDomain\": \"ooo.test\", \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"Hostname\": \"overcloud-controller-0\", \"NodeIndex\": \"0\", \"ControllerSchedulerHints\": {}, \"ServiceNames\": [\"keystone_admin_api\", \"keystone_public_api\", \"boot_params_service\", \"ca_certs\", \"ceilometer_agent_central\", \"ceilometer_agent_notification\", \"cinder_api\", \"cinder_backup\", \"cinder_scheduler\", \"cinder_volume\", \"clustercheck\", \"collectd\", \"container_image_prepare\", \"glance_api\", \"glance_api_internal\", \"haproxy\", \"heat_api\", \"heat_api_cloudwatch_disabled\", \"heat_api_cfn\", \"heat_engine\", \"horizon\", \"iscsid\", \"kernel\", \"keystone\", \"manila_api\", \"manila_backend_cephfs\", \"manila_scheduler\", \"manila_share\", \"memcached\", \"metrics_qdr\", \"mysql\", \"mysql_client\", \"neutron_api\", \"neutron_plugin_ml2_ovn\", \"nova_api\", \"nova_conductor\", \"nova_metadata\", \"nova_scheduler\", \"nova_vnc_proxy\", \"logrotate_crond\", \"ovn_dbs\", \"ovn_controller\", \"pacemaker\", \"placement\", \"oslo_messaging_rpc\", \"oslo_messaging_notify\", \"podman\", \"redis\", \"rsyslog\", \"snmp\", \"sshd\", \"swift_proxy\", \"swift_ringbuilder\", \"swift_storage\", \"chrony\", \"timezone\", \"tripleo_firewall\", \"tripleo_packages\", \"tuned\"], \"OVNBridgeMappings\": [\"datacentre:br-ex\"], \"DeploymentServerBlacklistDict\": {}, \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"UserData\": \"cecc8089-a249-459b-97e9-0c0c4a245f42\"}}}, \"outputs\": {\"internal_api_ip_address\": {\"value\": [{\"get_attr\": [\"0\", \"internal_api_ip_address\"]}]}, \"hostname\": {\"value\": [{\"get_attr\": [\"0\", \"hostname\"]}]}, \"ansible_host_vars_map\": {\"value\": [{\"get_attr\": [\"0\", \"ansible_host_vars_map\"]}]}, \"hosts_entry\": {\"value\": [{\"get_attr\": [\"0\", \"hosts_entry\"]}]}, \"hostname_map\": {\"value\": [{\"get_attr\": [\"0\", \"hostname_map\"]}]}, \"tenant_ip_address\": {\"value\": [{\"get_attr\": [\"0\", \"tenant_ip_address\"]}]}, \"storage_ip_address\": {\"value\": [{\"get_attr\": [\"0\", \"storage_ip_address\"]}]}, \"blacklist_ip_address\": {\"value\": [{\"get_attr\": [\"0\", \"blacklist_ip_address\"]}]}, \"storage_mgmt_ip_address\": {\"value\": [{\"get_attr\": [\"0\", \"storage_mgmt_ip_address\"]}]}, \"attributes, nova_server_resource\": {\"value\": {\"0\": {\"get_attr\": [\"0\", \"nova_server_resource\"]}}}, \"blacklist_hostname\": {\"value\": [{\"get_attr\": [\"0\", \"blacklist_hostname\"]}]}, \"ip_address\": {\"value\": [{\"get_attr\": [\"0\", \"ip_address\"]}]}, \"nova_server_resource\": {\"value\": [{\"get_attr\": [\"0\", \"nova_server_resource\"]}]}, \"refs_map\": {\"value\": {\"0\": {\"get_resource\": \"0\"}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(274,'2026-06-10 07:48:17',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Controller node configured by Puppet\", \"parameters\": {\"OvercloudControlFlavor\": {\"description\": \"DEPRECATED Use OvercloudControllerFlavor instead.\", \"default\": \"baremetal\", \"type\": \"string\"}, \"OvercloudControllerFlavor\": {\"description\": \"Flavor for the Controller node.\", \"default\": \"baremetal\", \"type\": \"string\"}, \"controllerImage\": {\"type\": \"string\", \"default\": \"overcloud-full\", \"description\": \"DEPRECATED Use ControllerImage instead\"}, \"ControllerImage\": {\"type\": \"string\", \"default\": \"overcloud-full\", \"description\": \"The disk image file to use for the role.\"}, \"ImageUpdatePolicy\": {\"default\": \"REBUILD_PRESERVE_EPHEMERAL\", \"description\": \"What policy to use when reconstructing instances. REBUILD for rebuilds, REBUILD_PRESERVE_EPHEMERAL to preserve /mnt.\", \"type\": \"string\"}, \"KeyName\": {\"description\": \"Name of an existing Nova key pair to enable SSH access to the instances\", \"type\": \"string\", \"default\": \"default\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"UpdateIdentifier\": {\"default\": \"\", \"type\": \"string\", \"description\": \"Setting to a previously unused value during stack-update will trigger package update on all nodes\\n\"}, \"Hostname\": {\"type\": \"string\", \"default\": \"\"}, \"HostnameMap\": {\"type\": \"json\", \"default\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"description\": \"Optional mapping to override hostnames\"}, \"ControllerIPs\": {\"default\": {}, \"type\": \"json\"}, \"SoftwareConfigTransport\": {\"default\": \"POLL_SERVER_HEAT\", \"description\": \"How the server should receive the metadata required for software configuration.\\n\", \"type\": \"string\", \"constraints\": [{\"allowed_values\": [\"POLL_SERVER_CFN\", \"POLL_SERVER_HEAT\", \"POLL_TEMP_URL\", \"ZAQAR_MESSAGE\"]}]}, \"CloudDomain\": {\"default\": \"ooo.test\", \"type\": \"string\", \"description\": \"The DNS domain used for the hosts. This must match the overcloud_domain_name configured on the undercloud.\\n\"}, \"ControllerServerMetadata\": {\"default\": {}, \"description\": \"Extra properties or metadata passed to Nova for the created nodes in the overcloud. It\'s accessible via the Nova metadata API. This option is role-specific and is merged with the values given to the ServerMetadata parameter.\\n\", \"type\": \"json\"}, \"ServerMetadata\": {\"default\": {}, \"description\": \"Extra properties or metadata passed to Nova for the created nodes in the overcloud. It\'s accessible via the Nova metadata API. This applies to all roles and is merged with a role-specific metadata parameter.\\n\", \"type\": \"json\"}, \"ControllerSchedulerHints\": {\"type\": \"json\", \"description\": \"Optional scheduler hints to pass to nova\", \"default\": {}}, \"NodeIndex\": {\"type\": \"number\", \"default\": 0}, \"ServiceNames\": {\"type\": \"comma_delimited_list\", \"default\": []}, \"MonitoringSubscriptions\": {\"type\": \"comma_delimited_list\", \"default\": []}, \"ServiceMetadataSettings\": {\"type\": \"json\", \"default\": {}}, \"OVNBridgeMappings\": {\"type\": \"comma_delimited_list\", \"default\": []}, \"ConfigCommand\": {\"type\": \"string\", \"description\": \"Command which will be run whenever configuration data changes\", \"default\": \"os-refresh-config --timeout 14400\"}, \"ConfigCollectSplay\": {\"type\": \"number\", \"default\": 30, \"description\": \"Maximum amount of time to possibly to delay configuration collection\\npolling. Defaults to 30 seconds. Set to 0 to disable it which will cause\\nthe configuration collection to occur as soon as the collection process\\nstarts.  This setting is used to prevent the configuration collection\\nprocesses from polling all at the exact same time.\\n\"}, \"UpgradeInitCommand\": {\"type\": \"string\", \"description\": \"Command or script snippet to run on all overcloud nodes to\\ninitialize the upgrade process. E.g. a repository switch.\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"UpgradeInitCommonCommand\": {\"type\": \"string\", \"description\": \"Common commands required by the upgrades process. This should not\\nnormally be modified by the operator and is set and unset in the\\nmajor-upgrade-composable-steps.yaml and major-upgrade-converge.yaml\\nenvironment files.\\n\", \"default\": \"\"}, \"DeploymentServerBlacklistDict\": {\"default\": {}, \"type\": \"json\", \"description\": \"Map of server hostnames to blacklist from any triggered deployments. If the value is 1, the server will be blacklisted. This parameter is generated from the parent template.\\n\"}, \"RoleParameters\": {\"type\": \"json\", \"description\": \"Parameters specific to the role\", \"default\": {}}, \"ControllerControlPlaneSubnet\": {\"default\": \"ctlplane-subnet\", \"description\": \"Name of the subnet on ctlplane network for this role.\\n\", \"type\": \"string\"}, \"ControlPlaneSubnetCidr\": {\"default\": \"\", \"description\": \"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\n\", \"type\": \"string\"}, \"ServerDeletionPolicy\": {\"description\": \"Whether to retain or delete servers on deletion of the stack\", \"type\": \"string\", \"default\": \"delete\", \"constraints\": [{\"allowed_values\": [\"delete\", \"retain\"]}]}, \"UserData\": {\"type\": \"string\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"Do not use deprecated params, they will be removed.\", \"parameters\": [\"OvercloudControlFlavor\", \"controllerImage\"]}], \"conditions\": {\"server_blacklisted\": {\"or\": [{\"equals\": [{\"get_param\": [\"DeploymentServerBlacklistDict\", {\"get_param\": \"Hostname\"}]}, 1]}, {\"equals\": [{\"get_param\": [\"DeploymentServerBlacklistDict\", {\"get_param\": [\"HostnameMap\", {\"get_param\": \"Hostname\"}]}]}, 1]}]}, \"server_not_blacklisted\": {\"and\": [{\"not\": {\"equals\": [{\"get_param\": [\"DeploymentServerBlacklistDict\", {\"get_param\": \"Hostname\"}]}, 1]}}, {\"not\": {\"equals\": [{\"get_param\": [\"DeploymentServerBlacklistDict\", {\"get_param\": [\"HostnameMap\", {\"get_param\": \"Hostname\"}]}]}, 1]}}]}, \"deprecated_param_image_set\": {\"not\": {\"equals\": [{\"get_param\": \"controllerImage\"}, \"overcloud-full\"]}}, \"deprecated_param_flavor_set\": {\"not\": {\"equals\": [{\"get_param\": \"OvercloudControlFlavor\"}, \"baremetal\"]}}, \"ctlplane_fixed_ip_set\": {\"or\": [{\"not\": {\"equals\": [{\"get_param\": [\"ControllerIPs\", \"ctlplane\", {\"get_param\": \"NodeIndex\"}]}, \"\"]}}, false]}, \"Controller_Storage_fixed_ip_set\": {\"not\": {\"equals\": [{\"get_param\": [\"ControllerIPs\", \"storage\", {\"get_param\": \"NodeIndex\"}]}, \"\"]}}, \"Controller_StorageMgmt_fixed_ip_set\": {\"not\": {\"equals\": [{\"get_param\": [\"ControllerIPs\", \"storage_mgmt\", {\"get_param\": \"NodeIndex\"}]}, \"\"]}}, \"Controller_InternalApi_fixed_ip_set\": {\"not\": {\"equals\": [{\"get_param\": [\"ControllerIPs\", \"internal_api\", {\"get_param\": \"NodeIndex\"}]}, \"\"]}}, \"Controller_Tenant_fixed_ip_set\": {\"not\": {\"equals\": [{\"get_param\": [\"ControllerIPs\", \"tenant\", {\"get_param\": \"NodeIndex\"}]}, \"\"]}}}, \"resources\": {\"Controller\": {\"type\": \"OS::TripleO::ControllerServer\", \"deletion_policy\": {\"get_param\": \"ServerDeletionPolicy\"}, \"properties\": {\"image\": {\"if\": [\"deprecated_param_image_set\", {\"get_param\": \"controllerImage\"}, {\"get_param\": \"ControllerImage\"}]}, \"image_update_policy\": {\"get_param\": \"ImageUpdatePolicy\"}, \"flavor\": {\"if\": [\"deprecated_param_flavor_set\", {\"get_param\": \"OvercloudControlFlavor\"}, {\"get_param\": \"OvercloudControllerFlavor\"}]}, \"key_name\": {\"get_param\": \"KeyName\"}, \"networks\": [{\"if\": [\"ctlplane_fixed_ip_set\", {\"network\": \"ctlplane\", \"subnet\": {\"get_param\": \"ControllerControlPlaneSubnet\"}, \"fixed_ip\": {\"yaql\": {\"expression\": \"$.data.where(not isEmpty($)).first()\", \"data\": [{\"get_param\": [\"ControllerIPs\", \"ctlplane\", {\"get_param\": \"NodeIndex\"}]}]}}}, {\"network\": \"ctlplane\", \"subnet\": {\"get_param\": \"ControllerControlPlaneSubnet\"}}]}], \"user_data_format\": \"SOFTWARE_CONFIG\", \"user_data\": {\"get_param\": \"UserData\"}, \"name\": {\"yaql\": {\"expression\": \"$.data.hostname_map.get($.data.hostname, $.data.hostname).toLower()\", \"data\": {\"hostname\": {\"get_param\": \"Hostname\"}, \"hostname_map\": {\"get_param\": \"HostnameMap\"}}}}, \"software_config_transport\": {\"get_param\": \"SoftwareConfigTransport\"}, \"metadata\": {\"map_merge\": [{\"get_param\": \"ServerMetadata\"}, {\"get_param\": \"ControllerServerMetadata\"}, {\"get_param\": \"ServiceMetadataSettings\"}]}, \"scheduler_hints\": {\"get_param\": \"ControllerSchedulerHints\"}}}, \"StoragePort\": {\"type\": \"OS::TripleO::Controller::Ports::StoragePort\", \"properties\": {\"PortName\": {\"list_join\": [\"_\", [{\"get_attr\": [\"Controller\", \"name\"]}, \"Storage\"]]}, \"DnsName\": {\"get_attr\": [\"Controller\", \"name\"]}, \"ControlPlaneIP\": {\"get_attr\": [\"Controller\", \"networks\", \"ctlplane\", 0]}, \"FixedIPs\": {\"if\": [\"Controller_Storage_fixed_ip_set\", [{\"ip_address\": {\"get_param\": [\"ControllerIPs\", \"storage\", {\"get_param\": \"NodeIndex\"}]}}], [{\"subnet\": \"storage_subnet\"}]]}, \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Controller\", \"addresses\", \"ctlplane\", 0, \"subnets\", 0, \"cidr\"]}, -1]}, \"IPPool\": {\"map_merge\": [{\"get_param\": \"ControllerIPs\"}]}, \"NodeIndex\": {\"get_param\": \"NodeIndex\"}, \"Role\": \"Controller\"}}, \"StorageMgmtPort\": {\"type\": \"OS::TripleO::Controller::Ports::StorageMgmtPort\", \"properties\": {\"PortName\": {\"list_join\": [\"_\", [{\"get_attr\": [\"Controller\", \"name\"]}, \"StorageMgmt\"]]}, \"DnsName\": {\"get_attr\": [\"Controller\", \"name\"]}, \"ControlPlaneIP\": {\"get_attr\": [\"Controller\", \"networks\", \"ctlplane\", 0]}, \"FixedIPs\": {\"if\": [\"Controller_StorageMgmt_fixed_ip_set\", [{\"ip_address\": {\"get_param\": [\"ControllerIPs\", \"storage_mgmt\", {\"get_param\": \"NodeIndex\"}]}}], [{\"subnet\": \"storage_mgmt_subnet\"}]]}, \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Controller\", \"addresses\", \"ctlplane\", 0, \"subnets\", 0, \"cidr\"]}, -1]}, \"IPPool\": {\"map_merge\": [{\"get_param\": \"ControllerIPs\"}]}, \"NodeIndex\": {\"get_param\": \"NodeIndex\"}, \"Role\": \"Controller\"}}, \"InternalApiPort\": {\"type\": \"OS::TripleO::Controller::Ports::InternalApiPort\", \"properties\": {\"PortName\": {\"list_join\": [\"_\", [{\"get_attr\": [\"Controller\", \"name\"]}, \"InternalApi\"]]}, \"DnsName\": {\"get_attr\": [\"Controller\", \"name\"]}, \"ControlPlaneIP\": {\"get_attr\": [\"Controller\", \"networks\", \"ctlplane\", 0]}, \"FixedIPs\": {\"if\": [\"Controller_InternalApi_fixed_ip_set\", [{\"ip_address\": {\"get_param\": [\"ControllerIPs\", \"internal_api\", {\"get_param\": \"NodeIndex\"}]}}], [{\"subnet\": \"internal_api_subnet\"}]]}, \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Controller\", \"addresses\", \"ctlplane\", 0, \"subnets\", 0, \"cidr\"]}, -1]}, \"IPPool\": {\"map_merge\": [{\"get_param\": \"ControllerIPs\"}]}, \"NodeIndex\": {\"get_param\": \"NodeIndex\"}, \"Role\": \"Controller\"}}, \"TenantPort\": {\"type\": \"OS::TripleO::Controller::Ports::TenantPort\", \"properties\": {\"PortName\": {\"list_join\": [\"_\", [{\"get_attr\": [\"Controller\", \"name\"]}, \"Tenant\"]]}, \"DnsName\": {\"get_attr\": [\"Controller\", \"name\"]}, \"ControlPlaneIP\": {\"get_attr\": [\"Controller\", \"networks\", \"ctlplane\", 0]}, \"FixedIPs\": {\"if\": [\"Controller_Tenant_fixed_ip_set\", [{\"ip_address\": {\"get_param\": [\"ControllerIPs\", \"tenant\", {\"get_param\": \"NodeIndex\"}]}}], [{\"subnet\": \"tenant_subnet\"}]]}, \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Controller\", \"addresses\", \"ctlplane\", 0, \"subnets\", 0, \"cidr\"]}, -1]}, \"IPPool\": {\"map_merge\": [{\"get_param\": \"ControllerIPs\"}]}, \"NodeIndex\": {\"get_param\": \"NodeIndex\"}, \"Role\": \"Controller\"}}, \"NetIpMap\": {\"type\": \"OS::TripleO::Network::Ports::NetIpMap\", \"properties\": {\"ControlPlaneIp\": {\"get_attr\": [\"Controller\", \"networks\", \"ctlplane\", 0]}, \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Controller\", \"addresses\", \"ctlplane\", 0, \"subnets\", 0, \"cidr\"]}, -1]}, \"StorageIp\": {\"get_attr\": [\"StoragePort\", \"ip_address\"]}, \"StorageIpSubnet\": {\"get_attr\": [\"StoragePort\", \"ip_subnet\"]}, \"StorageIpUri\": {\"get_attr\": [\"StoragePort\", \"ip_address_uri\"]}, \"StorageMgmtIp\": {\"get_attr\": [\"StorageMgmtPort\", \"ip_address\"]}, \"StorageMgmtIpSubnet\": {\"get_attr\": [\"StorageMgmtPort\", \"ip_subnet\"]}, \"StorageMgmtIpUri\": {\"get_attr\": [\"StorageMgmtPort\", \"ip_address_uri\"]}, \"InternalApiIp\": {\"get_attr\": [\"InternalApiPort\", \"ip_address\"]}, \"InternalApiIpSubnet\": {\"get_attr\": [\"InternalApiPort\", \"ip_subnet\"]}, \"InternalApiIpUri\": {\"get_attr\": [\"InternalApiPort\", \"ip_address_uri\"]}, \"TenantIp\": {\"get_attr\": [\"TenantPort\", \"ip_address\"]}, \"TenantIpSubnet\": {\"get_attr\": [\"TenantPort\", \"ip_subnet\"]}, \"TenantIpUri\": {\"get_attr\": [\"TenantPort\", \"ip_address_uri\"]}}}, \"NetHostMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"storage\": {\"fqdn\": {\"list_join\": [\".\", [{\"get_attr\": [\"Controller\", \"name\"]}, \"storage\", {\"get_param\": \"CloudDomain\"}]]}, \"short\": {\"list_join\": [\".\", [{\"get_attr\": [\"Controller\", \"name\"]}, \"storage\"]]}}, \"storage_mgmt\": {\"fqdn\": {\"list_join\": [\".\", [{\"get_attr\": [\"Controller\", \"name\"]}, \"storagemgmt\", {\"get_param\": \"CloudDomain\"}]]}, \"short\": {\"list_join\": [\".\", [{\"get_attr\": [\"Controller\", \"name\"]}, \"storagemgmt\"]]}}, \"internal_api\": {\"fqdn\": {\"list_join\": [\".\", [{\"get_attr\": [\"Controller\", \"name\"]}, \"internalapi\", {\"get_param\": \"CloudDomain\"}]]}, \"short\": {\"list_join\": [\".\", [{\"get_attr\": [\"Controller\", \"name\"]}, \"internalapi\"]]}}, \"tenant\": {\"fqdn\": {\"list_join\": [\".\", [{\"get_attr\": [\"Controller\", \"name\"]}, \"tenant\", {\"get_param\": \"CloudDomain\"}]]}, \"short\": {\"list_join\": [\".\", [{\"get_attr\": [\"Controller\", \"name\"]}, \"tenant\"]]}}, \"ctlplane\": {\"fqdn\": {\"list_join\": [\".\", [{\"get_attr\": [\"Controller\", \"name\"]}, \"ctlplane\", {\"get_param\": \"CloudDomain\"}]]}, \"short\": {\"list_join\": [\".\", [{\"get_attr\": [\"Controller\", \"name\"]}, \"ctlplane\"]]}}, \"canonical\": {\"fqdn\": {\"list_join\": [\".\", [{\"get_attr\": [\"Controller\", \"name\"]}, {\"get_param\": \"CloudDomain\"}]]}, \"short\": [{\"get_attr\": [\"Controller\", \"name\"]}]}}}}, \"PreNetworkConfig\": {\"type\": \"OS::TripleO::Controller::PreNetworkConfig\", \"condition\": \"server_not_blacklisted\", \"properties\": {\"server\": {\"get_resource\": \"Controller\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}, \"ServiceNames\": {\"get_param\": \"ServiceNames\"}, \"deployment_actions\": {\"get_attr\": [\"DeploymentActions\", \"value\"]}}}, \"NodeTLSCAData\": {\"type\": \"OS::TripleO::NodeTLSCAData\", \"properties\": {\"server\": {\"get_resource\": \"Controller\"}}}, \"ControllerExtraConfigPre\": {\"type\": \"OS::TripleO::ControllerExtraConfigPre\", \"condition\": \"server_not_blacklisted\", \"properties\": {\"server\": {\"get_resource\": \"Controller\"}}}, \"NodeExtraConfig\": {\"depends_on\": [\"ControllerExtraConfigPre\", \"NodeTLSCAData\"], \"type\": \"OS::TripleO::NodeExtraConfig\", \"condition\": \"server_not_blacklisted\", \"properties\": {\"server\": {\"get_resource\": \"Controller\"}}}, \"DeploymentActions\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"if\": [\"server_not_blacklisted\", [\"CREATE\", \"UPDATE\"], []]}}}, \"ControllerAnsibleHostVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"fqdn_storage\": {\"get_attr\": [\"NetHostMap\", \"value\", \"storage\", \"fqdn\"]}, \"fqdn_storage_mgmt\": {\"get_attr\": [\"NetHostMap\", \"value\", \"storage_mgmt\", \"fqdn\"]}, \"fqdn_internal_api\": {\"get_attr\": [\"NetHostMap\", \"value\", \"internal_api\", \"fqdn\"]}, \"fqdn_tenant\": {\"get_attr\": [\"NetHostMap\", \"value\", \"tenant\", \"fqdn\"]}, \"fqdn_ctlplane\": {\"get_attr\": [\"NetHostMap\", \"value\", \"ctlplane\", \"fqdn\"]}, \"fqdn_canonical\": {\"get_attr\": [\"NetHostMap\", \"value\", \"canonical\", \"fqdn\"]}, \"hostname_resolve_network\": {\"get_param\": [\"ServiceNetMap\", \"ControllerHostnameResolveNetwork\"]}}}}}, \"outputs\": {\"ansible_host_vars_map\": {\"description\": \"Map of Ansible variables specific per host.\\nThis map is used to construct the AnsibleHostVarsMap output for the\\nansible vars per host in config-download.\\n\", \"value\": {\"map_replace\": [{\"host\": {\"get_attr\": [\"ControllerAnsibleHostVars\", \"value\"]}}, {\"keys\": {\"host\": {\"get_attr\": [\"Controller\", \"name\"]}}}]}}, \"ip_address\": {\"description\": \"IP address of the server in the ctlplane network\", \"value\": {\"get_attr\": [\"Controller\", \"networks\", \"ctlplane\", 0]}}, \"blacklist_ip_address\": {\"description\": \"IP address of the server if the server is blacklisted, otherwise this output will be an empty string\", \"value\": {\"if\": [\"server_blacklisted\", {\"get_attr\": [\"Controller\", \"networks\", \"ctlplane\", 0]}, \"\"]}}, \"blacklist_hostname\": {\"description\": \"Hostname of the server if the server is blacklisted, otherwise this output will be an empty string\", \"value\": {\"if\": [\"server_blacklisted\", {\"get_attr\": [\"Controller\", \"name\"]}, \"\"]}}, \"hostname\": {\"description\": \"Hostname of the server\", \"value\": {\"get_attr\": [\"Controller\", \"name\"]}}, \"hostname_map\": {\"description\": \"Mapping of network names to hostnames\", \"value\": {\"storage\": {\"get_attr\": [\"NetHostMap\", \"value\", \"storage\", \"fqdn\"]}, \"storage_mgmt\": {\"get_attr\": [\"NetHostMap\", \"value\", \"storage_mgmt\", \"fqdn\"]}, \"internal_api\": {\"get_attr\": [\"NetHostMap\", \"value\", \"internal_api\", \"fqdn\"]}, \"tenant\": {\"get_attr\": [\"NetHostMap\", \"value\", \"tenant\", \"fqdn\"]}, \"ctlplane\": {\"get_attr\": [\"NetHostMap\", \"value\", \"ctlplane\", \"fqdn\"]}, \"canonical\": {\"get_attr\": [\"NetHostMap\", \"value\", \"canonical\", \"fqdn\"]}}}, \"hosts_entry\": {\"value\": [{\"str_replace\": {\"template\": \"PRIMARYIP PRIMARYHOST.DOMAIN PRIMARYHOST\", \"params\": {\"PRIMARYIP\": {\"get_attr\": [\"NetIpMap\", \"net_ip_map\", {\"get_param\": [\"ServiceNetMap\", \"ControllerHostnameResolveNetwork\"]}]}, \"DOMAIN\": {\"get_param\": \"CloudDomain\"}, \"PRIMARYHOST\": {\"get_attr\": [\"Controller\", \"name\"]}}}}, {\"str_replace\": {\"template\": \"StorageIP StorageHOST.DOMAIN StorageHOST\", \"params\": {\"DOMAIN\": {\"get_param\": \"CloudDomain\"}, \"StorageIP\": {\"get_attr\": [\"StoragePort\", \"ip_address\"]}, \"StorageHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"storage\", \"short\"]}, \"StorageMgmtIP\": {\"get_attr\": [\"StorageMgmtPort\", \"ip_address\"]}, \"StorageMgmtHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"storage_mgmt\", \"short\"]}, \"InternalApiIP\": {\"get_attr\": [\"InternalApiPort\", \"ip_address\"]}, \"InternalApiHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"internal_api\", \"short\"]}, \"TenantIP\": {\"get_attr\": [\"TenantPort\", \"ip_address\"]}, \"TenantHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"tenant\", \"short\"]}}}}, {\"str_replace\": {\"template\": \"StorageMgmtIP StorageMgmtHOST.DOMAIN StorageMgmtHOST\", \"params\": {\"DOMAIN\": {\"get_param\": \"CloudDomain\"}, \"StorageIP\": {\"get_attr\": [\"StoragePort\", \"ip_address\"]}, \"StorageHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"storage\", \"short\"]}, \"StorageMgmtIP\": {\"get_attr\": [\"StorageMgmtPort\", \"ip_address\"]}, \"StorageMgmtHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"storage_mgmt\", \"short\"]}, \"InternalApiIP\": {\"get_attr\": [\"InternalApiPort\", \"ip_address\"]}, \"InternalApiHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"internal_api\", \"short\"]}, \"TenantIP\": {\"get_attr\": [\"TenantPort\", \"ip_address\"]}, \"TenantHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"tenant\", \"short\"]}}}}, {\"str_replace\": {\"template\": \"InternalApiIP InternalApiHOST.DOMAIN InternalApiHOST\", \"params\": {\"DOMAIN\": {\"get_param\": \"CloudDomain\"}, \"StorageIP\": {\"get_attr\": [\"StoragePort\", \"ip_address\"]}, \"StorageHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"storage\", \"short\"]}, \"StorageMgmtIP\": {\"get_attr\": [\"StorageMgmtPort\", \"ip_address\"]}, \"StorageMgmtHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"storage_mgmt\", \"short\"]}, \"InternalApiIP\": {\"get_attr\": [\"InternalApiPort\", \"ip_address\"]}, \"InternalApiHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"internal_api\", \"short\"]}, \"TenantIP\": {\"get_attr\": [\"TenantPort\", \"ip_address\"]}, \"TenantHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"tenant\", \"short\"]}}}}, {\"str_replace\": {\"template\": \"TenantIP TenantHOST.DOMAIN TenantHOST\", \"params\": {\"DOMAIN\": {\"get_param\": \"CloudDomain\"}, \"StorageIP\": {\"get_attr\": [\"StoragePort\", \"ip_address\"]}, \"StorageHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"storage\", \"short\"]}, \"StorageMgmtIP\": {\"get_attr\": [\"StorageMgmtPort\", \"ip_address\"]}, \"StorageMgmtHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"storage_mgmt\", \"short\"]}, \"InternalApiIP\": {\"get_attr\": [\"InternalApiPort\", \"ip_address\"]}, \"InternalApiHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"internal_api\", \"short\"]}, \"TenantIP\": {\"get_attr\": [\"TenantPort\", \"ip_address\"]}, \"TenantHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"tenant\", \"short\"]}}}}, {\"str_replace\": {\"template\": \"CTLPLANEIP CTLPLANEHOST.DOMAIN CTLPLANEHOST\", \"params\": {\"DOMAIN\": {\"get_param\": \"CloudDomain\"}, \"CTLPLANEIP\": {\"get_attr\": [\"Controller\", \"networks\", \"ctlplane\", 0]}, \"CTLPLANEHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"ctlplane\", \"short\"]}}}}]}, \"nova_server_resource\": {\"description\": \"Heat resource handle for Controller server\", \"value\": {\"get_resource\": \"Controller\"}, \"condition\": \"server_not_blacklisted\"}, \"deployed_server_port_map\": {\"description\": \"Map of Heat created hostname of the server to ip address. This is the\\nhostname before it has been mapped with the HostnameMap parameter, and\\nthe IP address from the ctlplane network. This map can be used to construct\\nthe DeployedServerPortMap parameter when using split-stack.\\n\", \"value\": {\"map_replace\": [{\"hostname\": {\"fixed_ips\": [{\"ip_address\": {\"get_attr\": [\"Controller\", \"networks\", \"ctlplane\", 0]}}], \"subnets\": [{\"cidr\": {\"get_attr\": [\"Controller\", \"addresses\", \"ctlplane\", 0, \"subnets\", 0, \"cidr\"]}}]}}, {\"keys\": {\"hostname\": {\"list_join\": [\"-\", [{\"get_param\": \"Hostname\"}, \"ctlplane\"]]}}}]}}, \"storage_ip_address\": {\"description\": \"IP address of the server in the Storage network\", \"value\": {\"get_attr\": [\"StoragePort\", \"ip_address\"]}}, \"storage_mgmt_ip_address\": {\"description\": \"IP address of the server in the StorageMgmt network\", \"value\": {\"get_attr\": [\"StorageMgmtPort\", \"ip_address\"]}}, \"internal_api_ip_address\": {\"description\": \"IP address of the server in the InternalApi network\", \"value\": {\"get_attr\": [\"InternalApiPort\", \"ip_address\"]}}, \"tenant_ip_address\": {\"description\": \"IP address of the server in the Tenant network\", \"value\": {\"get_attr\": [\"TenantPort\", \"ip_address\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}}, \"Hostname\": \"overcloud-controller-0\", \"CloudDomain\": \"ooo.test\", \"ControllerSchedulerHints\": {}, \"NodeIndex\": 0, \"ServiceNames\": \"keystone_admin_api,keystone_public_api,boot_params_service,ca_certs,ceilometer_agent_central,ceilometer_agent_notification,cinder_api,cinder_backup,cinder_scheduler,cinder_volume,clustercheck,collectd,container_image_prepare,glance_api,glance_api_internal,haproxy,heat_api,heat_api_cloudwatch_disabled,heat_api_cfn,heat_engine,horizon,iscsid,kernel,keystone,manila_api,manila_backend_cephfs,manila_scheduler,manila_share,memcached,metrics_qdr,mysql,mysql_client,neutron_api,neutron_plugin_ml2_ovn,nova_api,nova_conductor,nova_metadata,nova_scheduler,nova_vnc_proxy,logrotate_crond,ovn_dbs,ovn_controller,pacemaker,placement,oslo_messaging_rpc,oslo_messaging_notify,podman,redis,rsyslog,snmp,sshd,swift_proxy,swift_ringbuilder,swift_storage,chrony,timezone,tripleo_firewall,tripleo_packages,tuned\", \"OVNBridgeMappings\": \"datacentre:br-ex\", \"DeploymentServerBlacklistDict\": {}, \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"UserData\": \"cecc8089-a249-459b-97e9-0c0c4a245f42\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(275,'2026-06-10 07:48:18',NULL,'{\"heat_template_version\": \"wallaby\", \"parameters\": {\"RootStackName\": {\"description\": \"The name of the stack/plan.\", \"type\": \"string\", \"default\": \"overcloud\"}, \"image\": {\"type\": \"string\", \"default\": \"unused\"}, \"flavor\": {\"type\": \"string\", \"default\": \"unused\"}, \"key_name\": {\"type\": \"string\", \"default\": \"unused\", \"description\": \"Name of keypair to assign to servers\"}, \"security_groups\": {\"type\": \"json\", \"default\": []}, \"user_data_format\": {\"type\": \"string\"}, \"user_data\": {\"type\": \"string\", \"default\": \"\"}, \"name\": {\"type\": \"string\", \"default\": \"deployed-server\"}, \"image_update_policy\": {\"type\": \"string\", \"default\": \"\"}, \"networks\": {\"type\": \"comma_delimited_list\", \"default\": \"\"}, \"metadata\": {\"type\": \"json\", \"default\": {}}, \"software_config_transport\": {\"default\": \"POLL_SERVER_CFN\", \"type\": \"string\"}, \"scheduler_hints\": {\"type\": \"json\", \"description\": \"Optional scheduler hints to pass to nova\", \"default\": {}}, \"UpgradeInitCommand\": {\"type\": \"string\", \"description\": \"Command or script snippet to run on all overcloud nodes to\\ninitialize the upgrade process. E.g. a repository switch.\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"UpgradeInitCommonCommand\": {\"type\": \"string\", \"description\": \"Common commands required by the upgrades process. This should not\\nnormally be modified by the operator and is set and unset in the\\nmajor-upgrade-composable-steps.yaml and major-upgrade-converge.yaml\\nenvironment files.\\n\", \"default\": \"\"}, \"ControlPlaneSubnet\": {\"default\": \"ctlplane-subnet\", \"description\": \"The name of the undercloud Neutron control plane subnet\", \"type\": \"string\"}}, \"resources\": {\"deployed-server\": {\"type\": \"OS::Heat::DeployedServer\", \"properties\": {\"name\": {\"get_param\": \"name\"}, \"software_config_transport\": {\"get_param\": \"software_config_transport\"}}}, \"ControlPlanePort\": {\"type\": \"OS::TripleO::DeployedServer::ControlPlanePort\", \"properties\": {\"network\": \"ctlplane\", \"fixed_ips\": [{\"subnet\": {\"get_param\": \"ControlPlaneSubnet\"}}], \"name\": {\"list_join\": [\"-\", [{\"get_param\": \"name\"}, \"ctlplane\"]]}, \"replacement_policy\": \"AUTO\", \"tags\": [{\"str_replace\": {\"template\": \"tripleo_stack_name=$STACK_NAME\", \"params\": {\"$STACK_NAME\": {\"get_param\": \"RootStackName\"}}}}]}}}, \"outputs\": {\"OS::stack_id\": {\"value\": {\"get_resource\": \"deployed-server\"}}, \"networks\": {\"value\": {\"ctlplane\": [{\"get_attr\": [\"ControlPlanePort\", \"fixed_ips\", 0, \"ip_address\"]}]}}, \"addresses\": {\"value\": {\"ctlplane\": [{\"subnets\": {\"get_attr\": [\"ControlPlanePort\", \"subnets\"]}}]}}, \"name\": {\"value\": {\"get_param\": \"name\"}}, \"os_collect_config\": {\"value\": {\"get_attr\": [\"deployed-server\", \"os_collect_config\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"image\": \"overcloud-full\", \"flavor\": \"baremetal\", \"key_name\": \"default\", \"user_data_format\": \"SOFTWARE_CONFIG\", \"user_data\": \"cecc8089-a249-459b-97e9-0c0c4a245f42\", \"name\": \"np0000069435\", \"image_update_policy\": \"REBUILD_PRESERVE_EPHEMERAL\", \"networks\": \".member.0.network=ctlplane,.member.0.subnet=ctlplane-subnet\", \"metadata\": {}, \"software_config_transport\": \"POLL_SERVER_HEAT\", \"scheduler_hints\": {}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(276,'2026-06-10 07:48:19',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \" A fake OS::Neutron::Port stack which outputs fixed_ips and subnets based on the input from the DeployedServerPortMap (set via parameter_defaults). This lookup requires the use of port naming conventions. In order for this to work with deployed-server the keys should be <hostname>-<network>. Example: parameter_defaults: DeployedServerPortMap: gatsby-ctlplane: fixed_ips: - ip_address: 127.0.0.1 subnets: - cidr: 127.0.0.0/24 network: tags: - 127.0.0.0/24\", \"parameters\": {\"name\": {\"default\": \"\", \"type\": \"string\"}, \"dns_name\": {\"default\": \"\", \"type\": \"string\"}, \"network\": {\"default\": \"\", \"type\": \"string\"}, \"fixed_ips\": {\"default\": \"\", \"type\": \"comma_delimited_list\"}, \"replacement_policy\": {\"default\": \"\", \"type\": \"string\"}, \"tags\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"DeployedServerPortMap\": {\"default\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"type\": \"json\"}, \"IsVirtualIP\": {\"default\": false, \"type\": \"boolean\"}, \"Role\": {\"description\": \"The TripleO Role Name\\n\", \"type\": \"string\", \"default\": \"\"}}, \"outputs\": {\"fixed_ips\": {\"value\": {\"get_param\": [\"DeployedServerPortMap\", {\"get_param\": \"name\"}, \"fixed_ips\"]}}, \"subnets\": {\"value\": {\"get_param\": [\"DeployedServerPortMap\", {\"get_param\": \"name\"}, \"subnets\"]}}, \"network\": {\"value\": {\"get_param\": [\"DeployedServerPortMap\", {\"get_param\": \"name\"}, \"network\"]}}, \"name\": {\"value\": {\"get_param\": \"name\"}}, \"status\": {\"value\": \"DOWN\"}, \"allowed_address_pairs\": {\"value\": {}}, \"device_id\": {\"value\": \"\"}, \"device_owner\": {\"value\": {\"get_param\": \"network\"}}, \"dns_assignment\": {\"value\": \"\"}, \"port_security_enabled\": {\"value\": false}, \"admin_state_up\": {\"value\": false}, \"security_groups\": {\"value\": {}}, \"network_id\": {\"value\": \"\"}, \"tenant_id\": {\"value\": \"\"}, \"qos_policy_id\": {\"value\": \"\"}, \"mac_address\": {\"value\": \"\"}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"name\": \"np0000069435-ctlplane\", \"network\": \"ctlplane\", \"fixed_ips\": \".member.0.subnet=ctlplane-subnet\", \"replacement_policy\": \"AUTO\", \"tags\": \"tripleo_stack_name=overcloud\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(277,'2026-06-10 07:48:21',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Noop Extra Pre-Deployment Config\", \"parameters\": {\"server\": {\"type\": \"string\"}}, \"outputs\": {\"deploy_stdout\": {\"value\": \"None\"}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"server\": \"26edea7b-926e-460d-a71f-3aaa56a1af9e\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(278,'2026-06-10 07:48:21',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Deployed port on the StorageMgmt network.\\n\", \"parameters\": {\"StackName\": {\"description\": \"Name of the overcloud heat stack\", \"default\": \"overcloud\", \"type\": \"string\"}, \"PortName\": {\"description\": \"Name of the port\", \"default\": \"\", \"type\": \"string\"}, \"DnsName\": {\"description\": \"DNS name of the port\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneIP\": {\"description\": \"IP address on the control plane\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneSubnetCidr\": {\"default\": \"\", \"description\": \"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\n\", \"type\": \"string\"}, \"ControlPlaneNetwork\": {\"description\": \"The name of the undercloud Neutron control plane\", \"default\": \"ctlplane\", \"type\": \"string\"}, \"ControlPlaneSubnet\": {\"description\": \"The name of the undercloud Neutron control plane subnet\", \"default\": \"ctlplane-subnet\", \"type\": \"string\"}, \"FixedIPs\": {\"description\": \"Control the IP allocation for the VIP port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"default\": [], \"type\": \"json\"}, \"IPPool\": {\"default\": {}, \"type\": \"json\"}, \"NodeIndex\": {\"default\": 0, \"type\": \"number\"}, \"NodePortMap\": {\"description\": \"A map of deployed port data\\n\", \"default\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"type\": \"json\"}, \"IsVirtualIP\": {\"type\": \"boolean\", \"default\": false}, \"DefaultRoute\": {\"description\": \"Whether this interface is used for the default route\\n\", \"type\": \"boolean\", \"default\": false}, \"Role\": {\"description\": \"The TripleO Role Name\\n\", \"type\": \"string\", \"default\": \"\"}}, \"resources\": {\"StorageMgmtDeployedPort\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"ip_address\": {\"get_param\": [\"NodePortMap\", {\"get_param\": \"DnsName\"}, \"storage_mgmt\", \"ip_address\"]}, \"ip_address_uri\": {\"get_param\": [\"NodePortMap\", {\"get_param\": \"DnsName\"}, \"storage_mgmt\", \"ip_address_uri\"]}, \"ip_subnet\": {\"get_param\": [\"NodePortMap\", {\"get_param\": \"DnsName\"}, \"storage_mgmt\", \"ip_subnet\"]}}}}}, \"outputs\": {\"ip_address\": {\"description\": \"StorageMgmt network IP\", \"value\": {\"get_attr\": [\"StorageMgmtDeployedPort\", \"value\", \"ip_address\"]}}, \"ip_address_uri\": {\"description\": \"StorageMgmt network IP (with brackets for IPv6 URLs)\", \"value\": {\"get_attr\": [\"StorageMgmtDeployedPort\", \"value\", \"ip_address_uri\"]}}, \"ip_subnet\": {\"description\": \"IP/Subnet CIDR for the StorageMgmt network IP\", \"value\": {\"get_attr\": [\"StorageMgmtDeployedPort\", \"value\", \"ip_subnet\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"PortName\": \"np0000069435_StorageMgmt\", \"DnsName\": \"np0000069435\", \"ControlPlaneIP\": \"192.168.122.103\", \"ControlPlaneSubnetCidr\": \"24\", \"FixedIPs\": \"[{\\\"subnet\\\": \\\"storage_mgmt_subnet\\\"}]\", \"IPPool\": {}, \"NodeIndex\": 0, \"Role\": \"Controller\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"SshFirewallAllowAll\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 1, \"CellControllerCount\": 0, \"CellControllerComputeCount\": 0, \"ComputeCount\": 0, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-1-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069435-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.90\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.80\", \"ip_address_uri\": \"172.21.0.80\", \"ip_subnet\": \"172.21.0.80/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.130\", \"ip_address_uri\": \"172.17.0.130\", \"ip_subnet\": \"172.17.0.130/24\"}, \"storage\": {\"ip_address\": \"172.18.0.140\", \"ip_address_uri\": \"172.18.0.140\", \"ip_subnet\": \"172.18.0.140/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.150\", \"ip_address_uri\": \"172.20.0.150\", \"ip_subnet\": \"172.20.0.150/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"5Inbz01FTud8Rr1i1p3QQo8TS\", \"AdminToken\": \"IYV82nvaxlUUniqVsGTpKZ1V1\", \"CeilometerMeteringSecret\": \"Uq3xYnJdfo8dxBrwtREQJqzyB\", \"CeilometerPassword\": \"PsskYBX4IGkIc7Q8EVuiLBAmk\", \"CephClientKey\": \"AQA4FilqAAAAABAAsg0Y1FFmGUmksjSk5AUDkg==\", \"CephClusterFSID\": \"88ea1c0b-450b-4072-ab68-7beb4fb9aeeb\", \"CinderPassword\": \"gtBv0TkCYxjriNwpG4AlCd1ll\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781077560, \"GlancePassword\": \"gQtNQwRGQ6FDne8ZIbYV3p0sE\", \"HAProxyStatsPassword\": \"NnI7BOXcaQyDYYo4IRQT8ddyk\", \"HeatAuthEncryptionKey\": \"5x7389lMfjKOt4P1fHWhRNlE4F0gcohm\", \"HeatPassword\": \"bFBTZhN5CyNCch5KSkr70C02s\", \"HeatStackDomainAdminPassword\": \"UVdJtbPbJkihrvjY5nov69TzB\", \"HorizonSecret\": \"qFqrstvXVq\", \"KeystoneCredential0\": \"g7-icMoc9OSFKH61drQBTPZe1bkovDr73Li93NpJv9s=\", \"KeystoneCredential1\": \"68mB-_BgIkoOqojpGxIMRMA8OszCv16ZF4vm6K6Geos=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"VwvJ4-fu5aHVR_0mc8tNbJWYLxzdii1KGm4Ng-Yvyu4=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"tIqWclejCs7x4CmmDnideBfxTMktSwGhrCasg9wH1UY=\"}}, \"LibvirtTLSPassword\": \"hVIRSk7OKsg2myMO4JakznLRf\", \"ManilaPassword\": \"KqSyIJe4bogoBLLwnLhZJDRFk\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAw4jmMuwm2Thf66ScUVxFAa1tXLutiTP6J3yTCNHKFiae5UcX\\njIHEs9IS0Tyk6xPGy1kXvek2cU8ZmSZ253obJqDJUtP7PPGWBiAG5/U47J22XbAL\\nAX5f4qckSWwO1Fkxqz+BTmdiyrBOtM8P5uIqRMJ8uCRgK/5xDqwS4gAPPh98kwze\\nd1VglZALCEkO8BWg1b897FfNH06uJsaDKXhk5UJWUPYoa8Jl/feslXUi9qUPDq5R\\n3FScvIr2CcmjNzBWHoTZGxCzlqlDfkmz7+w+Rw/+2poi+QtWDPGRxNmrLrg6DKQA\\nnIJnrkvWlBvH9mP00oLm4naVf0zYJk/6tE0flwIDAQABAoIBAEvDEnaum4rU1g2m\\ntU6s8qvot5QTv/SGaCm+kfX721Jj2nM57Xzqlv2ZquLZnYjcG82Ukqdp4kda/68g\\ngTfFTxnTeM4YBqOhc6Ch7isYD9tWbF+2oz0L6zkVy/CK5uAOQzl4HLD1TAj+8TAL\\nfrzV6szDkrGCnqTNLJ8juxlILp/Bw1KTfqFqgpzrFJFfmoR1KliJGLeoBlA2UJjR\\nfxvyum0/I/JRHD/bHGU3rEBN+NdBE33WrIYDFYHthh6QRb5fuVHXvY1fJgId++jd\\nH/iYXWIw41GdifXfXLNvg74/lt9KVoHnD2yHs2nwmXAU3eaXc4XoCOsZ3mhmb/HG\\n3TfSSrECgYEA9XBmBlQQCikAwCLgpTQ52ELeiyVDMZlZTqqBAqttzMu1QryLqTXB\\n0qOVFNF3jMq+e92LiNspr4yQIWW5Z/4zRkpIzQXQLk4/pcuPWFxs+YL/qa25tp2c\\nIKMlhmSSh+Kvwx+hS6s9X5IXekEtxUYcfac517chAtzyhNPTZxtJxikCgYEAy/LJ\\nWesGTsH+Xac7wMRXHNkhoYAb9Q4K5iICviqmEUo9NXBfvosbVuk6vvZ3a5hO3u9s\\nQXEJQlNiwrHkLAiIMzB1rePn8MocgyUczi+JFpZAKhTxzt6fOJx0WoS1ihRM4TkR\\n5XgMWAetrYYR+LF0hMaI/327j/hPNlDGUqpy778CgYAduXQRtiKPKHIX0uGEAHQ0\\n9bw/+85MdnbzaQDg0uQkVlNodq8vWfxUR01pzQh+e5tgIu+gLnK4+PwHn2s55fZN\\nv/dbJSYWRZG9wY5ltCPaf/v4j7qbHDFpXnjP8uQwIssIhY8iO+Xd6jJ/st8ZMimH\\nKjZ+IoaT8zBH1+OVbB+eKQKBgGOJNY3l72kmsq8gfEAjUuSocApzDLH3zYftl2sa\\nQ3xywBbBpmjHWWt8Xohun2/qoKubLDlwInW1XqDo0xROgbKB9x0L+toAuhOjXECg\\n4IYehGhFWpJ9AjZN3VeEJ1mheLf+82YLxfJ8pN3obgLzEIvwnVIcGhs0s+wtVe1o\\ndLnfAoGAW9oOsLF1voA4gPxJum74JUd8nmqG+Coi69lIoIUNy57hK2R6TH2CBa98\\nbbzSgdxJSQb9RJ2sBSiVQRODGfRONyv/Hh0UGow9lBOReG2EQh+0aDbROKrKlnW0\\nW1P7GpmQYldo9GgFpX9BUv6SMo9u+disUWRjGZHmr2Yb1ffVEEQ=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDDiOYy7CbZOF/rpJxRXEUBrW1cu62JM/onfJMI0coWJp7lRxeMgcSz0hLRPKTrE8bLWRe96TZxTxmZJnbnehsmoMlS0/s88ZYGIAbn9TjsnbZdsAsBfl/ipyRJbA7UWTGrP4FOZ2LKsE60zw/m4ipEwny4JGAr/nEOrBLiAA8+H3yTDN53VWCVkAsISQ7wFaDVvz3sV80fTq4mxoMpeGTlQlZQ9ihrwmX996yVdSL2pQ8OrlHcVJy8ivYJyaM3MFYehNkbELOWqUN+SbPv7D5HD/7amiL5C1YM8ZHE2asuuDoMpACcgmeuS9aUG8f2Y/TSgubidpV/TNgmT/q0TR+X Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"hepAGELIsa9DMKgtpIM5NwEsU\", \"MysqlMariabackupPassword\": \"8I5mvt66ebeLQhZAOpOekHv6P\", \"MysqlRootPassword\": \"wDcXw6Z0DC\", \"NeutronMetadataProxySharedSecret\": \"ZsuO7PdDpr6or9fZj2NjaPori\", \"NeutronPassword\": \"CSHADbT1sOG9bZ2OXsQ00qoOC\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"btE80AtSdL16lZ5QqRx6f9I9L\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"8doXbkNy1AZbY9c3\", \"PlacementPassword\": \"LmdoVblRSfwmhsbe1og9276Oe\", \"RabbitCookie\": \"mSuIvlFkPdOYUvFgLZx2\", \"RabbitPassword\": \"YBsJWf2H0b7bOztSoZY2lUw6b\", \"RedisPassword\": \"PeixZYMWlure0PQXGfRipmgn4\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"nn2j7FFx97Fxmpoub5H3UFEYy\", \"SnmpdReadonlyUserPassword\": \"BNDw4uH9EsZTE8AtCcYXd4Fj\", \"SwiftHashSuffix\": \"sRK7MrWoYpaoPNYnblO2G8U5z\", \"SwiftPassword\": \"NvUMzL93JbdNrISGkFwzL6Qcw\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(279,'2026-06-10 07:48:21',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Deployed port on the Tenant network.\\n\", \"parameters\": {\"StackName\": {\"description\": \"Name of the overcloud heat stack\", \"default\": \"overcloud\", \"type\": \"string\"}, \"PortName\": {\"description\": \"Name of the port\", \"default\": \"\", \"type\": \"string\"}, \"DnsName\": {\"description\": \"DNS name of the port\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneIP\": {\"description\": \"IP address on the control plane\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneSubnetCidr\": {\"default\": \"\", \"description\": \"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\n\", \"type\": \"string\"}, \"ControlPlaneNetwork\": {\"description\": \"The name of the undercloud Neutron control plane\", \"default\": \"ctlplane\", \"type\": \"string\"}, \"ControlPlaneSubnet\": {\"description\": \"The name of the undercloud Neutron control plane subnet\", \"default\": \"ctlplane-subnet\", \"type\": \"string\"}, \"FixedIPs\": {\"description\": \"Control the IP allocation for the VIP port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"default\": [], \"type\": \"json\"}, \"IPPool\": {\"default\": {}, \"type\": \"json\"}, \"NodeIndex\": {\"default\": 0, \"type\": \"number\"}, \"NodePortMap\": {\"description\": \"A map of deployed port data\\n\", \"default\": {\"compute-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-1\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069435\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"type\": \"json\"}, \"IsVirtualIP\": {\"type\": \"boolean\", \"default\": false}, \"DefaultRoute\": {\"description\": \"Whether this interface is used for the default route\\n\", \"type\": \"boolean\", \"default\": false}, \"Role\": {\"description\": \"The TripleO Role Name\\n\", \"type\": \"string\", \"default\": \"\"}}, \"resources\": {\"TenantDeployedPort\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"ip_address\": {\"get_param\": [\"NodePortMap\", {\"get_param\": \"DnsName\"}, \"tenant\", \"ip_address\"]}, \"ip_address_uri\": {\"get_param\": [\"NodePortMap\", {\"get_param\": \"DnsName\"}, \"tenant\", \"ip_address_uri\"]}, \"ip_subnet\": {\"get_param\": [\"NodePortMap\", {\"get_param\": \"DnsName\"}, \"tenant\", \"ip_subnet\"]}}}}}, \"outputs\": {\"ip_address\": {\"description\": \"Tenant network IP\", \"value\": {\"get_attr\": [\"TenantDeployedPort\", \"value\", \"ip_address\"]}}, \"ip_address_uri\": {\"description\": \"Tenant network IP (with brackets for IPv6 URLs)\", \"value\": {\"get_attr\": [\"TenantDeployedPort\", \"value\", \"ip_address_uri\"]}}, \"ip_subnet\": {\"description\": \"IP/Subnet CIDR for the Tenant network IP\", \"value\": {\"get_attr\": [\"TenantDeployedPort\", \"value\", \"ip_subnet\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"PortName\": \"np0000069435_Tenant\", \"DnsName\": \"np0000069435\", \"ControlPlaneIP\": \"192.168.122.103\", \"ControlPlaneSubnetCidr\": \"24\", \"FixedIPs\": \"[{\\\"subnet\\\": \\\"tenant_subnet\\\"}]\", \"IPPool\": {}, \"NodeIndex\": 0, \"Role\": \"Controller\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069435\", \"cell1-controller-0\": \"np0000069436\", \"cell1-compute-0\": \"np0000069437\", \"cell2-controller-compute-0\": \"np0000069438\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheu